(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5333,        165]*)
(*NotebookOutlinePosition[      6713,        208]*)
(*  CellTagsIndexPosition[      6669,        204]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\

Statement of Originality 

\
\>", "Text",
  FontSize->24],

Cell["\<\
As the results from this PhD thesis were not yet published and some \
of the essential ideas on which it is based are due to my supervisor, Prof. \
Bruno Buchberger, who did not publish them either, I will make here a \
statement on which contributions belong to whom.\
\>", "Text"],

Cell["\<\
My supervisor reserves the right to publish, notably, the following \
ideas in future papers: \
\>", "Text"],

Cell["\<\
the decomposition of predicate logic proving into an iteration of \
\"proving\", \"simplifying\", and \"solving\" phases,\
\>", "BItem1"],

Cell["\<\
the reduction of elementary analysis proving to solving formulae \
over the reals and using real number constraint solvers as, for example, \
Collins' algorithm,\
\>", "BItem1"],

Cell["\<\
the generalization of rewriting to implications and formulae \
involving quantifiers and the technique of \"semantical rewriting\",\
\>", \
"BItem1"],

Cell["\<\
the use of Skolem functions at certain phases of natural deduction,\
\
\>", "BItem1"],

Cell["\<\
the idea of setting up a \"natural deduction\" solve calculus in \
parallel to a \"natural deduction\" prove calculus,\
\>", "BItem1"],

Cell["\<\
the set\[Dash]up of induction provers for equalities in various \
domains,\
\>", "BItem1"],

Cell["the induction principle for \"sequence variables\".", "BItem1"],

Cell["\<\
Some of these ideas are contained in unpublished Mathematica \
notebooks in which he sketched experimental implementations of them. This is \
the case for the induction provers for equalities, induction principle for \
sequence variables, the decomposition of predicate logic in iterations of \
\"proving\" and \"simplifying\" phases.  \
\>", "Text"],

Cell["\<\
The main original contribution of this thesis is formalizing, \
combining and implementing in a coherent way all these ideas within the \
Theorema system. This work implied a systematic study of the feasibility of \
the above ideas in case studies of realistic size taken from various areas of \
mathematics which led to extensions and/or modifications of the initial \
ideas. Summarizing, original contributions of this thesis are:\
\>", "Text"],

Cell["\<\
the invention and justification of the natural deduction solving \
rules and of the inference rules for handling case distinction, \
\>", \
"BItem1"],

Cell["\<\
a further extension of rewriting by considering several equivalent \
forms of the implications and using AC rewriting with respect to \[And] and \
\[Or].\
\>", "BItem1"],

Cell["\<\
the exact concept of semantical rewriting, invention of the \
semantical match measure,\
\>", "BItem1"],

Cell["\<\
the identification of the subset of natural deduction rules to be \
used in prove phases,\
\>", "BItem1"],

Cell["\<\
finding out the correct way of using the Collins' algorithm \
implementation in Mathematica which is restricted to quantifier\[Dash]free \
formulae and accepts no assumptions,\
\>", "BItem1"],

Cell["\<\
finding good heuristics for combining the inference rules in \
various provers, like a modified version of the \
\"prove\[Dash]simplify\[Dash]solve\" iteration or induction provers for \
general formulae (not only equalities), \
\>", "BItem1"],

Cell["the compression of proof objects to certain detail levels,", "BItem1"],

Cell["the implementation of all the above mentioned ideas.", "BItem1"],

Cell["\<\
In the course of the implementation, a great number of technical \
difficulties, both on the logical and the software\[Dash]technological level, \
had to be overcome. \
\>", "Text"]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{764, 640},
WindowMargins->{{Automatic, 1}, {6, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageHeaderLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{99, 99}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->False,
"FacingPages"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "dvasaru", \
"work", "MmaThesis", "together"}, "Orig.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
Magnification->1,
StyleDefinitions -> "ThesisStyle.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 68, 6, 134, "Text"],
Cell[1788, 57, 292, 5, 50, "Text"],
Cell[2083, 64, 118, 3, 32, "Text"],
Cell[2204, 69, 147, 3, 22, "BItem1"],
Cell[2354, 74, 187, 4, 40, "BItem1"],
Cell[2544, 80, 159, 4, 22, "BItem1"],
Cell[2706, 86, 95, 3, 22, "BItem1"],
Cell[2804, 91, 144, 3, 22, "BItem1"],
Cell[2951, 96, 100, 3, 22, "BItem1"],
Cell[3054, 101, 69, 0, 22, "BItem1"],
Cell[3126, 103, 360, 6, 68, "Text"],
Cell[3489, 111, 456, 7, 86, "Text"],
Cell[3948, 120, 159, 4, 22, "BItem1"],
Cell[4110, 126, 179, 4, 29, "BItem1"],
Cell[4292, 132, 113, 3, 29, "BItem1"],
Cell[4408, 137, 115, 3, 29, "BItem1"],
Cell[4526, 142, 201, 4, 42, "BItem1"],
Cell[4730, 148, 253, 5, 42, "BItem1"],
Cell[4986, 155, 76, 0, 16, "BItem1"],
Cell[5065, 157, 70, 0, 16, "BItem1"],
Cell[5138, 159, 191, 4, 37, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

