(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1052169,      33158]*)
(*NotebookOutlinePosition[   1130596,      35416]*)
(*  CellTagsIndexPosition[   1117566,      35014]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1.  Introduction", "Chapter",
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["1. 1.  Goal", "Section",
  CellTags->"c:2"],

Cell["\<\
The goal of the Theorema project is to provide computer\[Dash]assisted \
support, in the frame of one uniform logic and one coherent software system, \
to the entire mathematical exploration cycle:\
\>", "Text"],

Cell["introducing new notions by definitions or axioms,", "BItem1"],

Cell["\<\
conjecturing, proving and disproving facts about the new notions with respect \
to the knowledge bases (consisting of definitions, axioms, lemmata, theorems, \
temporary assumptions),\
\>", "BItem1"],

Cell["extracting algorithms from theorems,", "BItem1"],

Cell["computing and solving by using the algorithms,", "BItem1"],

Cell["\<\
writing books, lecture notes with interactive mathematical \
text,\
\>", "BItem1"],

Cell["teaching.", "BItem1"],

Cell[TextData[{
  "To fulfill these requirements one has to com",
  "bine the power of the computer algebra systems widely used in the mathe",
  "matical community with the power of theorem proving systems. B. \
Buchberger, the founder of the Theorema system, already expressed the need \
for such an integration in the editorial of the Journal for Symbolic \
Computation (",
  ButtonBox["[16]",
    ButtonData:>"Buchb:85c",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1985, Editorial"],
  "). This view was later reformulated in ",
  ButtonBox["[17] ",
    ButtonData:>"Buchb:96b",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1996, Mathematical Software Systems: The Future \
(German)"],
  "and ",
  ButtonBox["[21]",
    ButtonData:>"Buchb:97a",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1997, Mathematica: A System for Doing Mathematics by \
Computer?"],
  ". Finally, a clear formulation of the specific goals and methods to be \
used for a system which assists in \"proving, solving and computing\" \
together with the chosen approach of starting from an existing computer \
algebra system was given in ",
  ButtonBox["[18]",
    ButtonData:>"Buchb:96c",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1996, Proving, Solving, Computing"],
  ", ",
  ButtonBox["[20]",
    ButtonData:>"Buchb:96e",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1996, Using Mathematica for Doing Simple Mathematical \
Proofs"],
  "."
}], "Text"],

Cell[TextData[{
  "Theorema is programmed in Mathematica (",
  ButtonBox["[97]",
    ButtonData:>"Wolfram:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->"S. Wolfram, 1996, The Mathematica Book"],
  "). The reason for choosing Mathematica as the system on top of which the \
Theorema system is built is two\[Dash]fold: Mathematica has an advanced user \
interface and, also, Mathematica as a programming language fits nicely to the \
principle of having a programming language inside logic (see ",
  ButtonBox["[19]",
    ButtonData:>"Buchb:96d",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1996, Mathematica as a Rewrite Language"],
  ")."
}], "Text"],

Cell["\<\
There are other projects that have similar goals as the Theorema \
project. The distinctive features of  Theorema, as compared to the other \
projects, are:\
\>", "Text"],

Cell[TextData[{
  "We emphasize the importance of \"theory exploration\" versus \"theorem \
proving\": Our intent is to help the user developing and proving coherent \
portions of mathematical text (\"theories\") and not only isolated \"theorems\
\". (For a detailed description see ",
  ButtonBox["[26]",
    ButtonData:>"Buchb_expl:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1999, Theory Exploration versus Theorem Proving"],
  "). Hence, our approach in proving, for example, a limit theorem is  to \
assume that all the knowledge about the \"lower level\" notions like +,*, ... \
that go into the definition of the notion \"limit\", is already available ."
}], "BItem1"],

Cell["\<\
We emphasize automated proof generation over automated proof checking or user\
\[Dash]driven step\[Dash]wise proof development.\
\>", "BItem1"],

Cell["\<\
We emphasize the importance of supporting the generation of  \
\"routine\" parts of  proofs by general but, maybe, not so powerful automated \
provers and to combine this with the automated decision about the truth of \
statements by using strong, but special, algebraic techniques.\
\>", "BItem1"],

Cell["\<\
We emphasize the importance of generating, for the routine proofs, human \
readable representation of proofs in \"natural\[Dash]style\". As a \
consequence, we do not strive for the minimality of the set of inference \
rules rather for having inference rules which would create human\[Dash]like \
proofs.\
\>", "BItem1"],

Cell["\<\
We integrate into one coherent system the three main activities of \
mathematical exploration: proving, solving and computing. \
\>", "BItem1"],

Cell["\<\
We start from a computer algebra system and, hence, already have all the \
computational  power of up\[Dash]to\[Dash]date math software systems \
accessible in our system. \
\>", "BItem1"],

Cell["\<\
We do not attempt to have one general proving method for all of \
mathematics but, rather, view Theorema as one uniform platform from which \
many different, general and special, proving, solving, and simplifying \
methods can be called.\
\>", "BItem1"],

Cell["\<\
The purpose of this thesis was to design and implement within the \
Theorema system special and general purpose provers that can automatically \
generate proofs for particular classes of problems. The most important such \
class of problems is represented by the rewrite\[Dash]type properties of \
notions involving alternating quantifiers. Such notions arise, for example, \
in mathematical analysis: limit, continuity, differentiability, etc. Rewrite\
\[Dash]properties of these notions are: \"limit of sum is sum of limits\", \
\"the product of continuous functions is continuous\", \"limit of quotient is \
quotient of limits\", etc. The motivation for choosing this particular class \
of problems was the interest of the author in mathematical analysis and also \
the difficulty of automatically generating this type of proofs (see also \
Section 1.2.4). Other class of problems we had in mind involved definitions \
by cases, or general formulae over natural numbers or tuples.\
\>", "Text"],

Cell["The thesis is structured as follows:", "Text"],

Cell["\<\
For the rest of this section we give an overview of the \
state\[Dash]of\[Dash]the\[Dash]art. We will mainly focus on systems related \
to Theorema and, in particular, to our work. At the end, a summary of the \
achievements is given.\
\>", "BItem1"],

Cell["\<\
In Section 2, the language, notation and terminology used in the \
thesis is given together with an informal description on how proofs are \
generated in Theorema. This will help to understand the implementation part \
of the next sections.\
\>", "BItem1"],

Cell["\<\
In Section 3, we introduce the general rewriting technique: a \
generalization of rewriting to implications and formulae involving \
quantifiers and to \"semantic rewriting\".\
\>", "BItem1"],

Cell["\<\
In Section 4, we introduce solving in natural deduction \
style.\
\>", "BItem1"],

Cell["\<\
In Section 5, we introduce the inference rules for handling \
definitions by cases.\
\>", "BItem1"],

Cell["\<\
In Section 6, the inductive inference rules we use for natural \
numbers and sequences are described.\
\>", "BItem1"],

Cell["\<\
In Section 7, the mechanism for choosing the desired level of \
detail in a proof is described.\
\>", "BItem1"],

Cell["\<\
In Section 8, various provers which we designed and implemented are \
 described and examples of proofs generated automatically by them are \
included. (Among them there are the Prove\[Dash]Solve\[Dash]Compute type of \
provers.) These provers are based on the inference rules described in the \
previous chapters. \
\>", "BItem1"],

Cell["\<\
An example of theory exploration in mathematical analysis is given \
in the Appendix.\
\>", "BItem1"],

Cell["\<\
Apart from this section and the next one on preliminaries, the \
content of the other sections will describe work done by the author of this \
thesis. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. 2.  State\[Dash]of\[Dash]the\[Dash]art", "Section",
  CellTags->"c:3"],

Cell[TextData[{
  "The importance of integrating computer algebra systems with theorem \
proving systems was expressed long time ago in the editorial of the Journal \
of Symbolic Computation, see ",
  ButtonBox["[16]",
    ButtonData:>"Buchb:85c",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1985, Editorial"],
  ". The main objective of this journal was (and still is) to bring together \
the two communities. This integration, however, started to be a hot research \
topic only in the last years. In earlier times, the two communities worked \
separately. This work, which involved both academic and industrial groups, \
resulted in powerful but separated systems."
}], "Text"],

Cell[CellGroupData[{

Cell["1. 2. 1.  Computer Algebra Systems", "Subsection",
  CellTags->"c:4"],

Cell["These systems can be classified in two categories:", "Text"],

Cell["\<\
General\[Dash]purpose: They try to provide algorithms for a large \
spectrum of mathematical areas. Examples of such systems are: AXIOM, \
Mathematica, Maple, REDUCE.\
\>", "BItem1"],

Cell["\<\
Special\[Dash]purpose: They provide algorithms only for a specific \
area of mathematics. Examples of such systems are: Cayley (Algebra and Number \
Theory), Cocoa (Computations in Commutative Algebra using Groebner Bases), \
GAP (Groups and Discrete Structures), Magma (Group Theory), Macaulay \
(Algebraic Geometry and Commutative Algebra using Groebner Bases).\
\>", \
"BItem1"],

Cell["\<\
Computer algebra systems have, usually, numerical and graphical \
facilities integrated to them, and impressing graphical user interfaces. \
Their use is not limited to the community but it is also widespread among \
nonexperts, students and scientists from various fields. These systems are \
fast and powerful but they have the disadvantage that they might return \
incorrect answers. (Some algorithms might not have been implemented for all \
possible cases). \
\>", "Text"],

Cell[TextData[{
  "For an overview on the existing computer algebra systems see ",
  ButtonBox["[42]",
    ButtonData:>"Davenport_all:88",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "J. H. Davenport, Y. Siret and E. Tournier, 1988, Computer Algebra: \
Systems and Algorithms  ..."],
  ", ",
  ButtonBox["[96]",
    ButtonData:>"Winkler:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "F. Winkler, 1996, Polynomial Algorithms in Computer Algebra"],
  ", ",
  ButtonBox["[32]",
    ButtonData:>"CA",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      ", 1993, Computeralgebra in Deutschland: Bestandsaufnahme, M\
\[ODoubleDot]glichkeiten, Perspektiven"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. 2. 2.  Theorem Proving Systems", "Subsection",
  CellTags->"c:5"],

Cell[TextData[{
  "An up\[Dash]to\[Dash]date and comprehensive description of the \
achievements in the field of automatic deduction, existing systems together \
with some main directions for future research is given by Donald Loveland in \
",
  ButtonBox["[66]",
    ButtonData:>"Loveland:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "D. W. Loveland, 1997, Automatic Deduction. Some Achievements and \
Future Directions"],
  ". One of these future directions is, in fact, the integration of theorem \
proving systems with computer algebra systems. Another  recent survey on \
automatic deduction covering all the different types of proof methods and \
their applications is given in ",
  ButtonBox["[30]",
    ButtonData:>"Bundy_AD:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->"A. Bundy, 1999, A Survey of Automatic Deduction"],
  ". Here we will only briefly present the different types of theorem \
provers. We are mainly interested in the automated theorem provers as this is \
the topic of this thesis."
}], "Text"],

Cell["Theorem proving systems fall into one of the categories: ", "Text"],

Cell["\<\
general\[Dash]purpose theorem provers,\
\>", "BItem1"],

Cell["\<\
special\[Dash]purpose theorem provers,\
\>", "BItem1"],

Cell["\<\
special \"black\[Dash]box\" decision algorithms.\
\>", "BItem1"],

Cell[TextData[{
  "Most of general theorem provers are provers for first\[Dash]order logic  \
based on the resolution method developed by Robinson (",
  ButtonBox["[83]",
    ButtonData:>"Robinson:65",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "J. A. Robinson, 1965, A Machine-oriented Logic based on the Resolution \
Principle"],
  "). Some of the most famous resolution provers are: Otter (",
  ButtonBox["[70]",
    ButtonData:>"McCune_Wos:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. McCune and L. Wos, 1997, Otter: The CADE-13 Competition \
incarnations"],
  "), Spass (",
  ButtonBox["[95]",
    ButtonData:>"Spass",
    ButtonStyle->"Hyperlink",
    ButtonNote->"C. Weidenbach, 1993, SPASS: Version 0.49"],
  "), Setheo (",
  ButtonBox["[74]",
    ButtonData:>"Setheo",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. Moser, O. Ibens, R. Letz, J. Steinbach, C. Goller, J. Schumann, and \
K. Mayr, 1997, SETH ..."],
  "). Comparisons between these provers are done using the TPTP set of \
problems (",
  ButtonBox["[90]",
    ButtonData:>"TPTP",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Suttner, G. Sutcliffe and T. Yemenis, 1994, The TPTP Problem \
Library"],
  "). Other used deduction mechanisms, apart resolution, are sequence \
calculus, natural deduction, semantic tableaux. There exists also provers for \
higher\[Dash]order logic, like: TPS (",
  ButtonBox["[1]",
    ButtonData:>"TPS",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. B. Andrews, M. Bishop, S. Issar, D. Nesmith, F. Pfenning and H. Xi, \
1996, TPS: A Theore ..."],
  "), HOL (",
  ButtonBox["[49]",
    ButtonData:>"Gordon:93",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. J. C. Gordon and T. F. Melham, 1993, Introduction to HOL: A Theorem \
Proving Environment ..."],
  "), PVS (",
  ButtonBox["[76]",
    ButtonData:>"PVS:92",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "S. Owre, J. M. Rushby and N. Shankar, 1992, PVS: An Integrated \
Approach to Specification a ..."],
  "), provers based on constructive logic, like: Nuprl (see ",
  ButtonBox["[39]",
    ButtonData:>"Constable:86",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "R. L. Constable, et al., 1986, Implementing Mathematics with the Nuprl \
Proof Development S ..."],
  "), Coq (",
  ButtonBox["[57]",
    ButtonData:>"Huet_all:94",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. Huet and G. Kahn and C. Paulin-Mohring, 1994, The Coq Proof \
Assistant. A Tutorial. Vers ..."],
  "), or generic provers where the logic can be given as an argument: \
Isabelle (see ",
  ButtonBox["[78]",
    ButtonData:>"paulson_90isabelle",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "L. C. Paulson, 1990, Isabelle: The next 700 theorem provers"],
  "). "
}], "Text"],

Cell[TextData[{
  "Special purpose theorem provers produce proofs in specific areas of \
mathematics or they work in a restricted logic. Example of induction provers \
are: the Boyer\[Dash]Moore prover NQTHM (",
  ButtonBox["[13]",
    ButtonData:>"Boyer_Moore:79",
    ButtonStyle->"Hyperlink",
    ButtonNote->"R. S. Boyer and J. S. Moore, 1979, A Computational Logic"],
  "), its successor ACL2 (",
  ButtonBox["[63]",
    ButtonData:>"ACL2-manual",
    ButtonStyle->"Hyperlink",
    ButtonNote->"M. Kaufmann and J. Moore, , The ACL2 User's Manual"],
  ") and the proof planner Oyster\[Dash]Clam (",
  ButtonBox["[29]",
    ButtonData:>"Bundy:90",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Bundy, F. van Harmelen, C. Horn and A. Smaill, 1990, The \
Oyster-Clam system"],
  "). An example of prover for set\[Dash]theory is given in ",
  ButtonBox["[87]",
    ButtonData:>"Suppes:81",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Suppes and J. Sheehan, 1981, CAI Course in Axiomatic Set Theory"],
  ". Several special\[Dash]purpose provers for general topology, calculus, \
were developed by Bledsoe and his students. Provers for equational theories \
also fall in this category. An example of equational prover is EQP (",
  ButtonBox["[68]",
    ButtonData:>"EQP",
    ButtonStyle->"Hyperlink",
    ButtonNote->"W. McCune, , EQP Web Page"],
  "), a prover which solved Robbins algebra open problem, see ",
  ButtonBox["[69]",
    ButtonData:>"McCune_Robbins",
    ButtonStyle->"Hyperlink",
    ButtonNote->"W. McCune, 1997, Solution of the Robbins Problem"],
  ". "
}], "Text"],

Cell[TextData[{
  "The black\[Dash]box, decision algorithms reduce the validity of a certain \
class of formulae to algebraic problems. For example, there exists decision \
algorithms for propositional logic (",
  ButtonBox["[14]",
    ButtonData:>"OBDD",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "R. E. Bryant, 1992, Symbolic Boolean Manipulation with Ordered \
Binary-Decision Diagrams"],
  "), Presburger arithmetic (",
  ButtonBox["[40]",
    ButtonData:>"Cooper",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "D. C. Cooper, 1972, Theorem Proving in Arithmetic without \
Multiplication"],
  ") and Euclidian geometry (",
  ButtonBox["[35]",
    ButtonData:>"Chou:88",
    ButtonStyle->"Hyperlink",
    ButtonNote->"S-C. Chou, 1988, Mechanical Geometric Theorem Proving"],
  ", ",
  ButtonBox["[98]",
    ButtonData:>"Wu:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "WenTsun Wu, 1997, The Char-Set Method and its Applications to \
Automated Reasoning"],
  "). Such black\[Dash]box provers are not based on inference rules. For an \
overview, see ",
  ButtonBox["[25]",
    ButtonData:>"Buchb_Coll_Kutz:88",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and G. E. Collins and B. Kutzler, 1988, Algebraic \
Methods in Computational G ..."],
  "."
}], "Text"],

Cell[TextData[{
  "The emphasis in automated deduction was initially on fully automated \
theorem provers. Examples of automated provers are: resolution provers, TPS, \
Oyster-Clam (",
  ButtonBox["[29]",
    ButtonData:>"Bundy:90",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Bundy, F. van Harmelen, C. Horn and A. Smaill, 1990, The \
Oyster-Clam system"],
  "). However, as such systems can fail in proving non\[Dash]trivial \
theorems, interactivity was introduced as a possible alternative in which the \
user and the system cooperate in proving difficult theorems. The level of \
interactivity can vary. One can have systems that do only proof checking: \
Mizar (",
  ButtonBox["[84]",
    ButtonData:>"Rudnicki:92",
    ButtonStyle->"Hyperlink",
    ButtonNote->"P. Rudnicki, 1992, An Overview of the MIZAR Project"],
  "); systems that help in the step by step construction of a proof: ETPS \
(the interactive version of TPS), Nuprl (see ",
  ButtonBox["[39]",
    ButtonData:>"Constable:86",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "R. L. Constable, et al., 1986, Implementing Mathematics with the Nuprl \
Proof Development S ..."],
  "), Coq (",
  ButtonBox["[57]",
    ButtonData:>"Huet_all:94",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. Huet and G. Kahn and C. Paulin-Mohring, 1994, The Coq Proof \
Assistant. A Tutorial. Vers ..."],
  "); systems which give the possibility to apply more inference steps in one \
stroke by tactics or other methods: Isabelle, HOL, IMPS (",
  ButtonBox["[45]",
    ButtonData:>"Farmer_al:93",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. D. Farmer, J. D. Guttman and F. J. Thayer, 1993, IMPS: An \
Interactive Mathematical Proo ..."],
  "), Larch Prover (",
  ButtonBox["[47]",
    ButtonData:>"Garland_Guttag:91",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "S. Garland and J. V. Guttag, 1991, A Guide to LP, the Larch Prover"],
  "); systems which only ask the user to interact in difficult parts of the \
proofs or systems that allow the user to set some parameters which influence \
the proof search. Our work is in the direction of automated theorem proving. \
We provide though the last type of interaction described previously."
}], "Text"],

Cell[TextData[{
  "As opposed to the computer algebra systems, theorem proving systems are \
trustworthy but they do not have a wide\[Dash]spread use outside the \
community. Two of the reasons that limit their use by the nonspecialists are: \
the need of understanding, sometimes, the inner works of the system (mainly \
for interactive systems) and the user interface. The language used for input \
and output is, usually, not very similar to the formalism used by a user. An \
exception is the Mizar system which is meant for writing and checking formal \
mathematics (",
  ButtonBox["[94]",
    ButtonData:>"Trybulec_Blair:85",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Trybulec and H. Blair, 1985, Computer Aided Reasoning with Mizar"],
  ", ",
  ButtonBox["[84]",
    ButtonData:>"Rudnicki:92",
    ButtonStyle->"Hyperlink",
    ButtonNote->"P. Rudnicki, 1992, An Overview of the MIZAR Project"],
  "). Another lack of the theorem proving systems is that proofs are not \
given in a human understandable form, especially the ones produced by \
resolution provers. A series of workshops on the topic of proof \
transformation and presentation, started in 1997 at Dagstuhl (",
  ButtonBox["[80]",
    ButtonData:>"Dagstuhl:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "PTP-97, 1997, First International Workshop on Proof Transformation and \
Presentation, Schlo ..."],
  "), shows that efforts in translating proofs to natural language are now \
pursued. Coq, for example, provides facilities for pretty\[Dash]printing \
proofs in nested natural language text (ASCII). The user can specify the \
desired language: English or French, and the deepness of nesting. Another \
nice feature of Coq is the possibility of declaring implicit proof steps, \
contractible proof steps and transparent definitions which result in \
different proof presentations. A subproject of the Omega system (",
  ButtonBox["[7]",
    ButtonData:>"Benzmueller_al:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Benzm\[UDoubleDot]ller, L. Cheikhrouhou, D. Fehrer, A. Fiedler, X. \
Huang, M. Kerber, M. Kohlhase, K ..."],
  ") is working on proof verbalization, see ",
  ButtonBox["[56]",
    ButtonData:>"Huang:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "X. Huang, 1996, Translating Machine-Generated Resolution Proofs into \
ND-Proofs at the Asse ..."],
  ", ",
  ButtonBox["[71]",
    ButtonData:>"Melis_Leron:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "E. Melis and U. Leron, 1999, A Proof Presentation Suitable for \
Teaching Proofs"],
  ". Another system in which effort was put in the generation of \
human\[Dash]readable proofs is IPR (",
  ButtonBox["[85]",
    ButtonData:>"Shults_thesis",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. P. Shults, 1997, Discoveries and Experiments in the Automation of \
Mathematical Reasonin ..."],
  "). The ILF system (",
  ButtonBox["[41]",
    ButtonData:>"ILF",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. I. Dahn, J. Gehne, Th. Honigmann and A. Wolf, 1997, Integration of \
Automated and Intera ..."],
  "), a shell for combining provers, provides facilities for generating Latex \
manuscripts that display theories and proofs with ordinary mathematical \
notation. Compared to all these systems, due also to the use of the \
Mathematica front\[Dash]end as graphical user interface, the input/output and \
natural language presentation of the proofs in Theorema are much more near to \
the formalism that scientists in general and mathematicians in particular \
use."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. 2. 3.  Integrating the Two Worlds", "Subsection",
  CellTags->"c:6"],

Cell[TextData[{
  "There exists a number of systems which are now conducting experiments on \
integrating computer algebra systems and theorem proving systems. Theorema is \
member of a consortium, CALCULEMUS (see ",
  ButtonBox["[59]",
    ButtonData:>"Calculemus",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "IRST and Univ. Edinburgh and Univ. Karlsruhe and Univ. Nijmegen and \
Univ. Roma 3 and Univ. ..."],
  "), whose groups share the view that this integration is very important for \
the development of computer\[Dash]supported mathematics. In fact, in our \
opinion, this is the only way for providing support in the three main \
activities of a mathematician, namely: proving, solving and computing. A \
project related to CALCULEMUS is QED (",
  ButtonBox["[81]",
    ButtonData:>"QED",
    ButtonStyle->"Hyperlink",
    ButtonNote->"QED Group, 1994, The QED Manifesto"],
  "), whose aim is to build a computer system that effectively represents all \
important mathematical knowledge and techniques."
}], "Text"],

Cell["\<\
Bringing together the two worlds for building a more powerful \
system can be done in one of the following ways:\
\>", "Text"],

Cell["\<\
Enhancing an existing theorem proving system by computing \
capabilities. The majority of experiments in integrating computer algebra \
with theorem proving are follow this approach. Some representative systems of \
this type are: Coq, CLAM, HOL, Isabelle, NQTHM, Nuprl, Omega. \
\>", "BItem1",\

  CellDingbat->"1."],

Cell["\<\
Enhancing an existing computer algebra system by proving \
capabilities. Fewer systems of this type exist: Analytica, Redlog, \
Theorema.\
\>", "BItem1",
  CellDingbat->"2."],

Cell[TextData[{
  "Establishing software links between existing computer algebra and theorem \
proving systems. This approach aims to provide a uniform framework in which \
computer algebra systems and theorem proving systems can be connected \
together in a plug\[Dash]and\[Dash]play manner. Such experiments are reported \
in ",
  ButtonBox["[55]",
    ButtonData:>"Homann_Calmet:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "K. Homman and J. Calmet, 1996, Structures for Symbolic Mathematical \
Reasoning and Computat ..."],
  ", ",
  ButtonBox["[33]",
    ButtonData:>"openmath:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "O. Caprotti and A. M. Cohen, 1999, Integrating Computational and \
Deduction Systems Using O ..."],
  ", ",
  ButtonBox["[8]",
    ButtonData:>"AISC98*94",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P.G. Bertoli and J. Calmet and F. Giunchiglia and K. Homann, 1998, \
Specification and Integ ..."],
  " and ",
  ButtonBox["[75]",
    ButtonData:>"OMD132a",
    ButtonStyle->"Hyperlink",
    ButtonNote->"The OpenMath Consortium, 1999, The OpenMath Standard"],
  "."
}], "BItem1",
  CellDingbat->"3."],

Cell["\<\
We will now give some details on the systems investigating these \
various approaches.\
\>", "Text"],

Cell[TextData[{
  "The Coq proof assistant (",
  ButtonBox["[57]",
    ButtonData:>"Huet_all:94",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. Huet and G. Kahn and C. Paulin-Mohring, 1994, The Coq Proof \
Assistant. A Tutorial. Vers ..."],
  "), based on the Calculus of Inductive Constructions, incorporates a solver \
for Presburger arithmetic. Coq can be used as a proof checker, as an \
interactive theorem prover or can be used to extract certified programs from \
constructive proofs. Recently, a certified version of Buchberger's algorithm \
(",
  ButtonBox["[15]",
    ButtonData:>"Buchb:70",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1970, An Algorithmical Criterion for the Solvability of \
Algebraic Systems o ..."],
  ") was obtained with the help of Coq, see ",
  ButtonBox["[92]",
    ButtonData:>"Thery",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "L. Th\[EAcute]ry, 1998, A Certified Version of Buchberger's \
Algorithm"],
  ". This implied also implementing all the necessary mathematical theory \
within the system.  "
}], "Text"],

Cell[TextData[{
  "HOL, see ",
  ButtonBox["[49]",
    ButtonData:>"Gordon:93",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. J. C. Gordon and T. F. Melham, 1993, Introduction to HOL: A Theorem \
Proving Environment ..."],
  ", is an interactive prover for higher order logic based on tactics.  The \
HOL prover was extended by Harrison in ",
  ButtonBox["[50]",
    ButtonData:>"Harrison-thesis",
    ButtonStyle->"Hyperlink",
    ButtonNote->"J. Harrison, 1998, Theorem Proving with the Real Numbers"],
  " such that it can reason over real numbers. This extension involved the \
implementation of several mathematical algorithms and of a quantifier \
elimination decision procedure for the first\[Dash]order theory of reals into \
HOL. Another extension of HOL with computer algebra possibilities, this time \
by using the Maple system (",
  ButtonBox["[34]",
    ButtonData:>"maple",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B.W. Char and K.O. Geddes and G.H. Gonnet and B.L. Leong and M.B. \
Monagan and S.M. Watt, 1 ..."],
  ") in a master\[Dash]slave manner, was described in ",
  ButtonBox["[51]",
    ButtonData:>"hol-cas1",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "J. Harrison and L. Th\[EGrave]ry, 1993, Extending the HOL Theorem \
Prover with a Computer Algebra S ..."],
  "."
}], "Text"],

Cell[TextData[{
  "Two provers for quantifier\[Dash]free logic, the Boyer\[Dash]Moore \
automatic induction prover Nqthm (",
  ButtonBox["[12]",
    ButtonData:>"Boyer:88a",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "R. S. Boyer and J. S. Moore, 1988, A Computational Logic HandBook"],
  ") and its successor ACL2 (",
  ButtonBox["[62]",
    ButtonData:>"ACL2:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. Kaufmann and J. Moore, 1997, An Industrial Strength Theorem Prover \
for a Logic Based on ..."],
  ", ",
  ButtonBox["[63]",
    ButtonData:>"ACL2-manual",
    ButtonStyle->"Hyperlink",
    ButtonNote->"M. Kaufmann and J. Moore, , The ACL2 User's Manual"],
  "), incorporate elementary arithmetic. They are mainly used in computer \
aided verification. An extension of the ACL2 system such that it can reason \
about reals is described in ",
  ButtonBox["[46]",
    ButtonData:>"Gamboa",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Ruben Gamboa, 1999, Mechanically Verifying Real-Valued Algorithms in \
ACL2"],
  ". The extension was done using non\[Dash]standard analysis. "
}], "Text"],

Cell[TextData[{
  "The interactive proof system Nuprl (see ",
  ButtonBox["[39]",
    ButtonData:>"Constable:86",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "R. L. Constable, et al., 1986, Implementing Mathematics with the Nuprl \
Proof Development S ..."],
  "), based on intuitionistic type theory, is a system for implementing \
mathematics. The goal of the system is to help a working mathematician in all \
the phases of his work: analyzing and understanding a problem, searching for \
possible solutions, checking solutions, writing notes. The system provides \
support for interactive development of proofs. An interesting experiment \
carried out in Nuprl was the implementation of the necessary mathematics for \
formalizing the Groebner Bases theory (",
  ButtonBox["[15]",
    ButtonData:>"Buchb:70",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1970, An Algorithmical Criterion for the Solvability of \
Algebraic Systems o ..."],
  ") within the system, see ",
  ButtonBox["[60]",
    ButtonData:>"Jackson:95",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. B. Jackson, 1995, Enhancing the Nuprl Proof Development System and \
Applying it to Compu ..."],
  ". "
}], "Text"],

Cell[TextData[{
  "The Oyster-Clam automatic induction prover (",
  ButtonBox["[29]",
    ButtonData:>"Bundy:90",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Bundy, F. van Harmelen, C. Horn and A. Smaill, 1990, The \
Oyster-Clam system"],
  ") is the first system which implemented the notion of proof\[Dash]plans. \
For guiding inductive proofs they use the rippling heuristics (",
  ButtonBox["[31]",
    ButtonData:>"Rippling",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Bundy and A. Stevens and F. van Harmelen and A. Ireland and A. D. \
Smaill, 1993, Ripplin ..."],
  ") and failure analysis (",
  ButtonBox["[58]",
    ButtonData:>"Ireland_Bundy:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Ireland and A. Bundy, 1996, Productive Use of Failure in Inductive \
Proof"],
  "). A recent higher\[Dash]order version of Oyster\[Dash]Clam is \
\[Lambda]Clam (",
  ButtonBox["[82]",
    ButtonData:>"lambdaClam:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "J. D. C. Richardson and A. Smaill and I. M. Green, 1998, System \
Description: Proof Plannin ..."],
  "). Experiments on the integration of decision procedures into the proof\
\[Dash]planning framework are described in ",
  ButtonBox["[61]",
    ButtonData:>"Janicic:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Janicic and A. Bundy and I. Green, 1999, A Framework for the \
Flexible Integration of a  ..."],
  "."
}], "Text"],

Cell[TextData[{
  "The main objective of the Omega system (",
  ButtonBox["[7]",
    ButtonData:>"Benzmueller_al:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Benzm\[UDoubleDot]ller, L. Cheikhrouhou, D. Fehrer, A. Fiedler, X. \
Huang, M. Kerber, M. Kohlhase, K ..."],
  ") is to become a mathematical proof assistant. Omega combines as deduction \
components proof planning, analogy\[Dash]based reasoning and resolution for \
higher\[Dash]order logic and provides a framework for calling external \
provers. Recent work reported also on the integration of a computer algebra \
system within Omega see ",
  ButtonBox["[64]",
    ButtonData:>"KeKoSo96b",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. Kerber and M. Kohlhase and V. Sorge, 1996, Integrating Computer \
Algebra with Proof Plan ..."],
  ", ",
  ButtonBox["[65]",
    ButtonData:>"KeKoSo98",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. Kerber and M. Kohlhase and V. Sorge, 1998, Integrating Computer \
Algebra Into Proof Plan ..."],
  ".  Another part of the system deals with proof transformation in natural \
language by using NLG techniques. "
}], "Text"],

Cell[TextData[{
  "A very interesting work in the area of special provers intended for \
teaching was done by the group headed by P. Suppes. They made extensive use \
of computer programs in teaching mathematics. Reports on the use of an \
interactive theorem prover for teaching axiomatic set\[Dash]theory are given \
in ",
  ButtonBox["[88]",
    ButtonData:>"Suppes:84",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Suppes and J. McDonald, 1984, Student Use of an Interactive Theorem \
Prover"],
  "and ",
  ButtonBox["[87]",
    ButtonData:>"Suppes:81",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Suppes and J. Sheehan, 1981, CAI Course in Axiomatic Set Theory"],
  ". Later on, they combined this interactive resolution prover for \
set\[Dash]theory with the computer algebra system REDUCE (",
  ButtonBox["[52]",
    ButtonData:>"Reduce",
    ButtonStyle->"Hyperlink",
    ButtonNote->"A. C. Hearn, 1995, REDUCE. User's Manual Verison 3.6"],
  ") for obtaining an interactive prover for elementary calculus, see  ",
  ButtonBox["[89]",
    ButtonData:>"Suppes_Ta:89",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Suppes and S. Takahashi, 1989, An Interactive Calculus \
Theorem-prover for Continuity Pr ..."],
  ". "
}], "Text"],

Cell[TextData[{
  "The Analytica prover (",
  ButtonBox["[36]",
    ButtonData:>"Clarke_Zhao:93",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "E. M. Clarke and X. Zhao, 1993, Analytica - A theorem prover for \
Mathematica"],
  "), developed at CMU, is built on top of Mathematica (",
  ButtonBox["[97]",
    ButtonData:>"Wolfram:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->"S. Wolfram, 1996, The Mathematica Book"],
  "). It can prove non\[Dash]trivial theorems in elementary mathematical \
analysis by making use of Mathematica's built\[Dash]in algorithms. However, a \
closer look to it shows that the most important rewrite properties related to \
calculus are given as known (hence, a human first proved it) and they are \
then used as rewrite rules for proving the more complicated theorems. \
Recently, Analytica produced fully automatically a proof of the correctness \
of a division circuit that implements the floating\[Dash]point IEEE standard. \
"
}], "Text"],

Cell[TextData[{
  "The Redlog system (",
  ButtonBox["[43]",
    ButtonData:>"RedLog:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Dolzmann and Th. Sturm, 1997, Redlog: Computer Algebra Meets \
Computer Logic"],
  ") adds proving capabilities to the REDUCE (",
  ButtonBox["[52]",
    ButtonData:>"Reduce",
    ButtonStyle->"Hyperlink",
    ButtonNote->"A. C. Hearn, 1995, REDUCE. User's Manual Verison 3.6"],
  ") computer algebra system. They implement symbolic algorithms on first\
\[Dash]order formulas with respect to temporarily fixed first\[Dash]order \
languages and theories like: computing various normal forms, quantifier \
elimination, formula simplification. One can choose to work in the theory of \
ordered fields or algebraically closed fields or discrete\[Dash]value fields. \
Compared to Theorema, the Redlog system has a narrower purpose. Note that in \
Mathematica (and hence in Theorema) are already available experimental \
functions for quantifier elimination. "
}], "Text"],

Cell[TextData[{
  "Extensive experiments were carried out at the University of Karlsruhe on \
linking computer algebra systems with theorem provers. A comprehensive \
description of the different possibilities of connections is given in ",
  ButtonBox["[55]",
    ButtonData:>"Homann_Calmet:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "K. Homman and J. Calmet, 1996, Structures for Symbolic Mathematical \
Reasoning and Computat ..."],
  ", ",
  ButtonBox["[54]",
    ButtonData:>"Homann:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "K. Homann, 1996, Symbolisches Loesen mathematischer Probleme durch \
Kooperation algorithMis ..."],
  ". Links between the generic theorem prover Isabelle (see ",
  ButtonBox["[78]",
    ButtonData:>"paulson_90isabelle",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "L. C. Paulson, 1990, Isabelle: The next 700 theorem provers"],
  ", ",
  ButtonBox["[79]",
    ButtonData:>"Paulson:96a",
    ButtonStyle->"Hyperlink",
    ButtonNote->"L. C. Paulson, 1996, Introduction to Isabelle"],
  ") and the computer algebra systems Maple (",
  ButtonBox["[34]",
    ButtonData:>"maple",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B.W. Char and K.O. Geddes and G.H. Gonnet and B.L. Leong and M.B. \
Monagan and S.M. Watt, 1 ..."],
  ") and Sumit are described in ",
  ButtonBox["[3]",
    ButtonData:>"BallarinEtAl1995",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Ballarin and K. Homann and J. Calmet, 1995, Theorems and \
Algorithms: An Interface betwe ..."],
  " and ",
  ButtonBox["[4]",
    ButtonData:>"BallarinPaulson1998",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Ballarin and L.C. Paulson, 1998, Reasoning about Coding Theory: The \
Benefits we get fro ..."],
  ", respectively. Another framework for connecting systems in a \
plug\[Dash]and\[Dash]play manner is the OpenMath project (",
  ButtonBox["[75]",
    ButtonData:>"OMD132a",
    ButtonStyle->"Hyperlink",
    ButtonNote->"The OpenMath Consortium, 1999, The OpenMath Standard"],
  "). Although was initially developed for connecting computer algebra \
systems, recent experiments on connecting also theorem provers were done, see \
",
  ButtonBox["[33]",
    ButtonData:>"openmath:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "O. Caprotti and A. M. Cohen, 1999, Integrating Computational and \
Deduction Systems Using O ..."],
  ". Similarly, coming from the opposite side, the OMRS project (see ",
  ButtonBox["[48]",
    ButtonData:>"omrs",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "F. Giunchiglia and P. Pecchiari and C. Talcott, 1994, Reasoning \
Theories: Towards an Archi ..."],
  ", ",
  ButtonBox["[2]",
    ButtonData:>"omrs:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Armando and A. Coglio and F. Giunchiglia, 1999, The Control \
Component of Open Mechanize ..."],
  ") was initially developed as a framework for combining theorem provers and \
now it experiments with combining also computer algebra systems, see ",
  ButtonBox["[8]",
    ButtonData:>"AISC98*94",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P.G. Bertoli and J. Calmet and F. Giunchiglia and K. Homann, 1998, \
Specification and Integ ..."],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. 2. 4.  Related Work", "Subsection",
  CellTags->{"sec:relw", "c:7"}],

Cell[TextData[{
  "While automatic deduction was successful in discrete mathematics, algebra \
or geometry, very little achievements were obtained in mathematical analysis. \
Certain theorems, like the intermediate value theorem, can be proved by some \
theorem provers. However, the basic properties of notions involving \
alternating quantifiers like limit and continuity cannot be proved or stay at \
the limit of what current automatic theorem provers can do. \
Rewrite\[Dash]properties are an example of such properties. The proofs of \
properties, not necessarily of rewrite type, involving alternating \
quantifiers in elementary analysis are also called in the literature \"\
\[Epsilon]-\[Delta] proofs\". In 1990, Bledsoe (",
  ButtonBox["[9]",
    ButtonData:>"Bledsoe:90",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. W. Bledsoe, 1990, Challenge Problems in Elementary Analysis"],
  ") proposed as challenge problem in elementary analysis the proof that the \
\"sum of continuous functions is continuous\", which he referred to as LIM+. \
He gave several versions of this problem which are now formalized in the TPTP \
library (",
  ButtonBox["[90]",
    ButtonData:>"TPTP",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "C. Suttner, G. Sutcliffe and T. Yemenis, 1994, The TPTP Problem \
Library"],
  "). LIM+ is still a challenge problem today, while other \
rewrite\[Dash]properties involving product or quotient are, with some \
exceptions, beyond of what current provers and proof\[Dash]planners can do. \
The main part of this thesis is devoted to the automated generation of \
\[Epsilon]\[Dash]\[Delta] proofs. A survey of related work follows."
}], "Text"],

Cell[TextData[{
  "We could not find in any of the reports on TPTP results  (both at the TPTP \
site as at the various automated provers sites) a resolution prover which \
succeeded to prove automatically LIM+. Only in ",
  ButtonBox["[71]",
    ButtonData:>"Melis_Leron:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "E. Melis and U. Leron, 1999, A Proof Presentation Suitable for \
Teaching Proofs"],
  ", an OTTER proof of this problem was shown. We have no other knowledge of \
resolution provers which automatically proved this type of properties. "
}], "Text"],

Cell[TextData[{
  "The early attempts in bringing computing power to theorem provers date on \
the early 70's when Bledsoe and his students were interested to do proofs in \
elementary mathematical analysis and set\[Dash]theory. In ",
  ButtonBox["[10]",
    ButtonData:>"Bledsoe_Boyer_Henneman:72",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. W. Bledsoe, R. S. Boyer and W. T. Henneman, 1972, Computer Proofs \
of Limit Theorems"],
  " they presented a special purpose prover, IMPLY, that can prove several \
rewrite properties of limit with no extra knowledge (the special knowledge on \
real numbers is included implicitly in the special prover). They used a \
routine for solving linear inequalities and introduced a special heuristic, \
called \"limit heuristic\", for reducing an inequality goal. Another prover \
for theorems in general topology is described in ",
  ButtonBox["[11]",
    ButtonData:>"Bledsoe_Bruell:74",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W.W. Bledsoe and P. Bruell, 1974, A Man-Machine Theorem-Proving \
System"],
  ". Both provers used natural deduction as the inference mechanism. During \
the years, this group has built a series of other provers combining \
resolution and special methods developed by them for reasoning in quantifier\
\[Dash]free Presburger arithmetic (e.g. Sup\[Dash]Inf and variable \
elimination methods). The STR+VE prover for inequalities (",
  ButtonBox["[53]",
    ButtonData:>"Hines",
    ButtonStyle->"Hyperlink",
    ButtonNote->"L. Hines, 1994, STR+VE and Integers"],
  ") proved the LIM+ and its variants. "
}], "Text"],

Cell[TextData[{
  "The heuristics and ideas behind Bledsoe's IMPLY prover were reconstructed \
and extended in the general purpose proof\[Dash]planning framework of the \
Omega system by Melis (",
  ButtonBox["[72]",
    ButtonData:>"melis-limit:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->"E. Melis, 1998, The Limit Domain"],
  "). They succeeded in automatically planning the proofs of properties from \
the so\[Dash]called Limit domain, which includes the rewrite\[Dash]properties \
we refer to, except the ones related to quotient. For these proofs, no \
knowledge was needed to be given, inequalities were handled by appropriate \
methods."
}], "Text"],

Cell[TextData[{
  "In ",
  ButtonBox["[73]",
    ButtonData:>"Melis_rep",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "E. Melis, 1997, Progress in Proof Planning: Planning Limit Theorems \
Automatically"],
  " was mentioned that the proof\[Dash]planner Oyster\[Dash]Clam succeeded to \
prove LIM+ property by using colored rippling (",
  ButtonBox["[91]",
    ButtonData:>"ColorRippl",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Y. Tetsuya, A. Bundy, I. Green, T. Walsh and D. Basin, 1994, Coloured \
Rippling: An Extensi ..."],
  "). It used explicitly four properties on real numbers like triangle \
inequality and three tautologies of predicate logic. We do not know if it \
succeeded to proof\[Dash]plan properties involving product."
}], "Text"],

Cell[TextData[{
  "Beeson's prover Weierstrass, connected to the Mathpert (",
  ButtonBox["[5]",
    ButtonData:>"Beeson:89",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "J. M. Beeson, 1989, Logic and Computation in Mathpert: An Expert \
System for Learning Mathe ..."],
  ") mathematical assistant for teaching algebra, calculus and geometry to \
college students, can automatically produce \[Epsilon]-\[Delta] proofs \
proving, for example, that certain elementary functions, like sine, square \
root, polynomials are continuous, or uniform continuous (",
  ButtonBox["[6]",
    ButtonData:>"Beeson:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "M. Beeson, 1998, Automatic Generation of Epsilon-Delta Proofs of \
Continuity"],
  "). It is not clear whether Weierstrass can prove LIM+. No explicit \
knowledge has to be given for these proofs as Weierstrass, like Omega and \
Bledsoe's prover, has built\[Dash]in rules for proving inequalities. The \
Mathpert system is mainly used for finding bounds on terms.  Proofs related \
to limit, continuity  of polynomials can be done also in the Omega system but \
not for other elementary functions as the constraint solver they use is a \
polynomial one. "
}], "Text"],

Cell["\<\
The Analytica system was used for doing non\[Dash]trivial proofs in \
mathematical analysis. However, the rewrite\[Dash]properties we are \
interested in are already given there as knowledge which is then used for \
rewriting. Hence, no attempt for proving them is made.\
\>", "Text"],

Cell[TextData[{
  "Interactive provers which succeeded in proving the type of properties we \
are interested are: HOL (as reported in the thesis of Harrison ",
  ButtonBox["[50]",
    ButtonData:>"Harrison-thesis",
    ButtonStyle->"Hyperlink",
    ButtonNote->"J. Harrison, 1998, Theorem Proving with the Real Numbers"],
  "), the interactive prover of Suppes and Takahashi (",
  ButtonBox["[89]",
    ButtonData:>"Suppes_Ta:89",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Suppes and S. Takahashi, 1989, An Interactive Calculus \
Theorem-prover for Continuity Pr ..."],
  "). Formalization of portions of mathematical analysis were also done in \
the proof checker Mizar and the interactive systems PVS (for details, see ",
  ButtonBox["[44]",
    ButtonData:>"Dutertre:96",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Dutertre, 1996, Elements of Mathematical Analysis in PVS"],
  ") and IMPS. In the last two systems the rewrite\[Dash]properties are given \
as knowledge. Proving them might be possible within the system, however not \
automatically."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. 3.  Achievements", "Section",
  CellTags->"c:8"],

Cell["\<\
This thesis contributes one step further towards the integration \
into one system of the three main activities mathematical exploration: \
proving, solving and computing. The main class of provers we designed and \
implemented are integrating these three activities. These provers are \
(particularly, but not only) suited for proving rewrite\[Dash]type properties \
of notions involving alternating quantifiers. Using them we succeeded to \
automatically prove the LIM+ challenge problem together with other similar \
problems which are beyond the capabilities of most of the current automatic \
theorem provers. \
\>", "Text"],

Cell[TextData[{
  "The provers we constructed within Theorema are general\[Dash]purpose. They \
are predicate provers for higher\[Dash]order logic and are based on natural \
deduction. By connecting our provers to a special algebraic solver for real \
numbers: Collins' cad\[Dash]method (",
  ButtonBox["[37]",
    ButtonData:>"Collins:75",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. E. Collins, 1975, Quantifier Elimination for Real Closed Fields by \
Cylindrical Algebrai ..."],
  "), we can automatically generate proofs for rewrite\[Dash]properties of \
limit, convergency of sequences or limit, continuity, uniform continuity, \
differentiability of functions which involve sums, differences, products, \
function composition. We also can prove certain properties of these notions \
which are not of rewrite type like: a function continuous at a point \
(different from a root) maintains the same sign in the neighborhood of the \
point. We cannot, yet, prove rewrite\[Dash]properties involving quotients. \
Our current approach is not general enough for this. We do not know of any \
prover which succeeded in proving quotient related rewrite\[Dash]properties. \
Comments on the IMPLY prover, say that if a different heuristic and extra \
axioms are added (IMPLY uses no explicit axioms) then probably the automatic \
proof would succeed. This might also be our case. "
}], "Text"],

Cell["\<\
We do not have any built\[Dash]in treatment of inequalities like \
the other systems have. This implies that we will need some extra knowledge \
on real numbers involving absolute value and the order relation. In the \
\[Epsilon]-\[Delta] proofs of rewrite\[Dash]properties we generate, the \
important part is providing one suitable lemma for each function or predicate \
on real numbers occurring in the definition of the notion, usually three: \
absolute value function, \"<\" and \">\". (In proofs related to sequences of \
real numbers we only need two lemmas.) These lemmas are assumed to have been \
proved when the theory of real numbers with absolute value, <, > was \
completely explored. Hence, we are somewhere in between (but more near to the \
first approach) no need for explicit knowledge (like Omega, IMPLY, \
Weierstrass) and need for lots of properties of real functions and predicates \
(Oyster-Clam). \
\>", "Text"],

Cell["\<\
Our provers can also automatically produce the type of proofs \
Weierstrass does for polynomial functions, provided we give suitable lemmas \
for the absolute value function. Proving continuity of sine or square root \
functions can be done, if also some suitable property between the variation \
of arguments and of the function is given. Probably, with this extra \
knowledge also in the Omega system it will be possible to obtain this type of \
proofs.\
\>", "Text"],

Cell["\<\
Summarizing, the advantages and differences of our approach of \
automatically proving rewrite\[Dash]properties of notions like limit, \
continuity, differentiability are:\
\>", "Text"],

Cell["\<\
We use higher\[Dash]order logic which makes proofs nearer to the \
formalism a mathematician use. The other provers are first\[Dash]order \
ones.\
\>", "BItem1"],

Cell["\<\
Our provers are general\[Dash]purpose provers which are coupled \
with a special solver for real numbers in order to prove \
rewrite\[Dash]properties in elementary mathematical analysis.  \
\>", "BItem1"],

Cell["\<\
By changing the special solver, we can use the same provers for \
proving rewrite\[Dash]properties of notions involving alternating quantifiers \
in other fields, not only in real mathematical analysis. \
\>", "BItem1"],

Cell["\<\
We can present the solutions to the solving problems which occur in \
\[Epsilon]\[Dash]\[Delta] proofs in different ways: the most general solution \
or example solutions. The other systems only can give a particular subset of \
the solutions, due to the heuristic they use.\
\>", "BItem1"],

Cell["\<\
Compared to the proof\[Dash]planning approach of Melis, where a \
different proof\[Dash]plan for each rewrite\[Dash]property has to be \
generated, we have the advantage that with one and the same prover we can \
prove several such rewrite\[Dash]properties. \
\>", "BItem1"],

Cell["\<\
The input/ouptut and the proof we generate in natural language are \
much more similar to the style humans use than in the other systems.\
\>", \
"BItem1"],

Cell["\<\
As a by\[Dash]product of our work, we designed and implemented few \
other provers in Theorema which are suited for particular classes of \
problems. For example, the predecessor of the provers we described above, is \
particularly suited for generating fast and human\[Dash]like proofs of \
problems involving implications and equivalences. We give in the thesis some \
examples where it performs better than the state\[Dash]of\[Dash]the\[Dash]art \
resolution prover Otter. We also designed and implemented several extensions \
of this prover. One of them is an inductive prover for proving general \
formulae over natural numbers. Another one is a prover for predicate logic \
handling case distinction constructs. By extending this last prover, we \
obtained an inductive prover for tuples. The tuple induction prover succeeded \
in proving automatically the correctness of merge. It cannot prove the \
correctness of the merge\[Dash]sort algorithm as it needs a different type of \
induction (namely, course of value induction). Other inductive provers for \
equalities over natural numbers and tuples were implemented.\
\>", "Text"],

Cell["\<\
The described provers are based, apart from natural deduction \
inference rules, on a general rewriting technique, natural deduction solving \
rules, inference rules for case distinction, and inductive inference rules. \
The general rewriting we introduce is an extension of rewriting by equalities \
to rewriting by equalities, equivalences and implications whose right-hand \
side can also contain quantifiers. We also introduce \"semantic rewriting\" \
in addition to purely syntactic rewriting. The natural deduction solving \
rules we give are new and they describe our way of treating solving. In other \
systems, metavariables or logical variables are used and inference rules for \
dealing with them are introduced.\
\>", "Text"],

Cell["\<\
In conclusion, our work succeeded in producing prototype provers \
that integrate aspects from several fields like theorem proving, rewriting, \
constraint solving. There is still place for improvement in all of these \
directions. Investigation on these and related questions is under way in the \
frame of the Theorema project.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.  Preliminaries", "Chapter",
  CellTags->{"sec:prel", "c:9"}],

Cell[CellGroupData[{

Cell["2. 1.  Language", "Section",
  CellTags->"c:10"],

Cell[TextData[{
  "The Theorema expression language is a version of higher\[Dash]order \
equational predicate logic. Let us denote this language with ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_Th\)]],
  ". The syntax of the language is very similar to the one mathematicians \
use, with the following differences:"
}], "Text"],

Cell[TextData[{
  "As in Mathematica, function and predicate applications are denoted by [ ], \
e.g. ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  " means \"",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " applied to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "\". "
}], "BItem1"],

Cell["\<\
The bound variables are written under the quantifiers and we have \
two lines for providing information on them. The first one specifies the \
range of the bound variables and the second specifies a condition on the \
bound variables. For example, in the formulae\
\>", "BItem1"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[ForAll] \+\(x \[Element] A\)\)\+\(c[x]\)p[
                x]\), \(\(\ \)\(and\)\(\ \)\), \(\(\[Exists] \+\(x \[Element] \
A\)\)\+\(c[x]\)p[x]\)}
          }], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] A\)]],
  " is the range information (\"",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " ranges over ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  "\") and ",
  Cell[BoxData[
      \(TraditionalForm\`c[x]\)]],
  " is a condition. These formulae are equivalent to"
}], "ContinueBItem1"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\[ForAll] \+\(x \[Element] A\)c[x] \[Implies] p[x]\), 
            "and", \(\[Exists] \+\(x \[Element] A\)\((c[x] \[And] 
                  p[x])\), \ \(\(respectively\)\(.\)\)\)}
          }], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "Another difference is that in addition to the ordinary variables, \
\"sequence variables\" are allowed in Theorema. They are denoted by \
overbarred symbols like ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  ". More details on sequence variables are given in Section 6.2. Unless we \
specify that we use sequence variables, in the following by variables we will \
refer the ordinary variables."
}], "Text"],

Cell[TextData[{
  "For more details on the Theorema language, see ",
  ButtonBox["[28]",
    ButtonData:>"Buchb_WW:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and W. Windsteiger, 1998, The \.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\.01\
\.01\.01\.01\.01\.01Theorema Language: Implementing Object- and M ..."],
  ", ",
  ButtonBox["[23]",
    ButtonData:>"Buchb_al:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and T. Jebelean and F. Kriftner and M. Marin and E. \
Tomuta and D. Vasaru, 19 ..."],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. 2.  Notation", "Section",
  CellTags->"c:11"],

Cell[TextData[{
  "Throughout the thesis we also make use of some of the terminology and \
notation from ",
  ButtonBox["[67]",
    ButtonData:>"Manna_Waldinger:85",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Z. Manna and R. Waldinger, 1985, The Logical Basis for Computer \
Programming"],
  ". Here is a summary of our notational conventions:"
}], "Text"],

Cell["We use lower case identifiers for functions and predicates.", "BItem1"],

Cell[TextData[{
  "In the following, ",
  Cell[BoxData[
      \(TraditionalForm\`m, n\)]],
  " denote natural numbers."
}], "BItem1"],

Cell["\<\
The variables occurring in the range of a quantifier are considered \
to be distinct.\
\>", "BItem1"],

Cell[TextData[{
  "Rewrite rules are denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`l \[Rule] r\)]],
  "."
}], "BItem1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[ScriptCapitalF]\ \[Sigma]\)\)\)]],
  " denotes the formula (term) obtained by applying the substitution \[Sigma] \
to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  "."
}], "BItem1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF][\[ScriptCapitalS] \[LeftArrow] \
\[ScriptCapitalT]]\)]],
  " denotes the formula obtained by replacing all occurrences of the \
subformula (subterm) ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  ". Note that, if ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is a variable and \[Sigma] is the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`{x \[Rule] a}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF][x \[LeftArrow] a]\)]],
  " denotes the same formula as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\ \[Sigma]\)]],
  ". "
}], "BItem1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[LeftAngleBracket]\
\[ScriptCapitalS] \[LeftArrow] \[ScriptCapitalT]\[RightAngleBracket]\)]],
  " denotes a formula obtained by replacing zero, one or more occurrences of \
formula \[ScriptCapitalS] in \[ScriptCapitalF] by \[ScriptCapitalT]."
}], "BItem1"],

Cell[TextData[{
  "We make use of the usual concepts of closed (ground) formulae, free and ",
  "bound",
  " variables. We also need the notions of ",
  "positive",
  " and ",
  "negative",
  " occurrences of a subformula in a formula (",
  "polarity of a subformula",
  "). Intuitively, an occurrence of a subformula is positive if there are an \
even number of negations applied to it within the formula. For example, the \
occurrence of ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`A \[Implies] B\)]],
  " is negative while the occurrence of ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is positive. We denote a positive occurrence of a subformula \
\[ScriptCapitalS] by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalS]\^+\)\)]],
  ". Replacing positive occurrences of a formula is denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[LeftAngleBracket]\(\
\[ScriptCapitalS]\^+\) \[LeftArrow] \
\[ScriptCapitalT]\[RightAngleBracket]\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. 3.  Terminology", "Section",
  CellTags->{"sec:term", "c:12"}],

Cell["\<\
A \"proof situation\" is a pair \
(\[ScriptCapitalG],\[ScriptCapitalK]) where \[ScriptCapitalG] is the formula \
to be proved (\"goal\") and \[ScriptCapitalK] is the list of formulae to be \
assumed (\"knowledge base\"). The formulae in the knowledge base are called \
\"assumptions\". All formulae which are either goals or assumptions in the \
knowledge base are considered to be closed formulae.\
\>", "Text"],

Cell["\<\
An inference rule acts on a proof situation and transforms it into \
\"simpler\" proof situations. When applying an inference rule to a proof \
situation, we have to specify: \
\>", "Text"],

Cell["\<\
Does the inference rule apply to the goal or to one of the \
assumptions?\
\>", "BItem1"],

Cell["\<\
What is the structure of the formula chosen (goal or assumption)?\
\
\>", "BItem1"],

Cell["\<\
How do the newly generated proof\[Dash]situations relate to the \
given one? There are two possibilities:\
\>", "BItem1"],

Cell["\<\
AND\[Dash]situation: If all newly generated proof situations are \
proved then also the given proof situation is proved.\
\>", "BItem2"],

Cell["\<\
OR\[Dash]situation: If any of the newly generated proof situations \
is proved, then also the given proof situation is proved. \
\>", "BItem2"],

Cell["\<\
A \"prover\" is a fixed combination of inference rules, suitable \
for a particular class of proof situations. By \"fixed\" we mean that the \
inference rules are fixed and also the order in which they are applied. \
\
\>", "Text"],

Cell["\<\
The proof of a proof situation is searched by successively applying \
a prover to it and to the intermediate newly generated proof situations. This \
process stops either when proving a proof situation was reduced to proving \
trivial proof situations (\"proof succeeded\") or when none of the inference \
rules can be applied to the intermediate proof situations (\"proof failed\"). \
A proof situation is trivial when, for example, the goal is contained in the \
knowledge base. The trace of the inference rules applied and the intermediate \
proof situations generated during this search is stored in Theorema in a tree \
data structure called \"proof object\". Proof objects are the internal \
representation of proofs. They are not intended to be read by humans. \
However, they contain all the information needed for generating a natural \
language representation of the proof. When OR\[Dash]situations occur in a \
proof, the corresponding proof object can contain intermediate proof \
situations which were not yet explored (\"pending\") or branches which \
represent failed attempts. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. 4.  Theorema Proving Sessions", "Section",
  CellTags->{"sec:Tps", "c:13"}],

Cell["\<\
A user of the Theorema system will start a Theorema proving \
session. Such a session, see example in Figure 2.1, consists of cycles of the \
following steps: \
\>", "Text"],

Cell["The user enters formulae into the system.", "BItem1"],

Cell["\<\
The user asks the system to use these formulae via the command \
Prove, by specifying which formula is the goal, which formulae are the \
assumptions (possibly none) and what prover should be applied to this proof \
situation.\
\>", "BItem1"],

Cell["\<\
The Theorema system returns either the formal proof of the proof \
situation or a proof attempt in a Mathematica notebook. The proof is given in \
natural language representation. For unsuccessful proof attempts, all \
inference steps are presented in natural language and also some information \
on the failure cause is given. \
\>", "BItem1"],

Cell[TextData[{
  StyleBox["Entering Formulae:",
    FontWeight->"Bold"],
  " Formulae are input in the Theorema system as Theorema formal text. The \
Theorema formal text language gives the possibility to attach auxiliary text \
to the formulae, for example, labels or keywords like definitions, axioms, \
theorems. The use of the formal text makes easier the combination and \
manipulation of large portions of mathematical text and also the hierarchical \
building\[Dash]up of knowledge bases from individual assumptions. Such an \
example of grouping into one knowledge base definitions and lemmas can be \
seen in Figure 2.1. For more details on formal text, see ",
  ButtonBox["[24]",
    ButtonData:>"Buchb_all:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, C. Dupre, T. Jebelean, F. Kriftner, K. Nakagawa, D. \
Vasaru, W. Windsteiger. ..."],
  ". "
}], "Paragraph"],

Cell[TextData[{
  StyleBox["The Prove Command.",
    FontWeight->"Bold"],
  " This function takes one argument representing the goal of the \
proof\[Dash]situation to be proved and it has several options among which: \
\"using\[Rule]\", \"by\[Rule]\" (note that all these options have default \
values). The option \"using\[Rule]\" specifies the knowledge base of the \
proof situation. The option \"by\[Rule]\" specifies which prover should be \
applied to the proof situation. In the example from Figure 2.1, the goal is \
the proposition \"limit of sum\" and the knowledge base consists of two \
definitions and two lemmas. "
}], "Paragraph"],

Cell[TextData[{
  StyleBox["Proof Generation.",
    FontWeight->"Bold"],
  " This process is done in two steps:"
}], "Paragraph"],

Cell["\<\
Search: A proof object is generated. (This is done dynamically: as \
the proof search proceeds, the proof object is updated.)\
\>", "BItem1"],

Cell["\<\
Show: By postprocessing the proof object generated in the search \
step, a proof in natural language is displayed.\
\>", "BItem1"],

Cell["\<\
The return value of a Prove call is the proof object of the \
automatically generated proof and, as a side effect, the natural language \
representation of the proof is displayed. Depending on the value of the \
option \"in\[Dash]notebook\[Rule]\" of the Prove call, displaying will be \
done in a new notebook (default), or in the notebook where the call to Prove \
was made (value \"Current\") or not at all (value \"None\"). In the last case \
(no display), the user can use the function Show for viewing the proof object \
in natural language representation at a later time. The user has also the \
possibility to specify the desired level of detail in the proof presentation \
via the option \"presentation\[Rule]\" (option both for Prove as for Show \
functions). In the example from Figure 2.1, the user specified that the proof \
should be given in the current notebook and that he is only interested to \
know the result of the proof. More details on the option \
\"presentation\[Rule]\" and the effects it has on the proof presentation are \
given in Section 7.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Definition",
            FontWeight->"Bold"], "[", 
          RowBox[{"\"\<limit\>\"", ",", GridBox[{
                {\(\[ForAll] \+\(f, a\)limit[f, 
                        a]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\
\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\[Exists] \+N\(\(\[ForAll] \+n\)\+\(n \
\[GreaterEqual] N\)\[LeftBracketingBar]f[n] - 
                                  a\[RightBracketingBar] < \
\[Epsilon]\)\)\)\), "\"\<l\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Definition",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<sum of sequences\>\"", ",", \(any[f, g, x]\), ",", GridBox[{
                {\(\((f + g)\)[x] = f[x] + g[x]\), "\"\<f+g\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Lemma",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<distance of sum\>\"", 
            ",", \(any[x, y, z, t, \[Delta], \[Epsilon]]\), ",", GridBox[{
                {\(\((\[LeftBracketingBar]\((x + z)\) - \((y + 
                                t)\)\[RightBracketingBar] < \((\[Delta] + \
\[Epsilon])\))\)\[DoubleLongLeftArrow]\((\[LeftBracketingBar]x - 
                              y\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]z - t\[RightBracketingBar] < \[Epsilon])\)\), 
                  "\"\<dist+\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Lemma",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<max greater\>\"", ",", \(any[m, M1, M2]\), ",", GridBox[{
                {\(\((m \[GreaterEqual] M1 \[And] 
                        m \[GreaterEqual] M2)\) \[DoubleLeftArrow] 
                    m \[GreaterEqual] max[M1, M2]\), 
                  "\"\<\[GreaterEqual]max\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<limit of sum\>\"", ",", \(any[f, a, g, b]\), ",", GridBox[{
                {\(\((limit[f, a] \[And] 
                        limit[g, b])\)\[DoubleLongRightArrow]
                                        limit[f + g, a + b]\), "\"\<l2+\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox["KnowledgeBase",
          FontWeight->"Bold"], "[", 
        RowBox[{"\"\<limit of sum\>\"", ",", GridBox[{
              {
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<limit\>\"", "]"}]},
              {
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<sum of sequences\>\"", 
                  "]"}]},
              {
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<distance of sum\>\"", 
                  "]"}]},
              {
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<max greater\>\"", "]"}]}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}], "\n", 
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<limit of sum\>\"", "]"}], ",", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["KnowledgeBase",
              FontWeight->"Bold"], "[", "\"\<limit of sum\>\"", "]"}]}], ",", 
        "\[IndentingNewLine]", \(by \[Rule] PCS\), ",", 
        " ", \(presentation \[Rule] 0\), ",", 
        " ", \(in\[Dash]notebook \[Rule] "\<Current\>"\)}], "]"}]}], "Input"],

Cell["The proof succeeded.", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["Figure 2.1 Example of Theorema Proving Session.", "Figure",
  CellTags->"fig:Tmasession"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. 5.  Theorema Provers as Seen by the User", "Section",
  CellTags->{"sec:up", "c:14"}],

Cell["\<\
A user of Theorema gets the provers as black\[Dash]boxes. He has to \
specify, via the command Prove, the proof situation to which a prover should \
be applied and the system will generate the proof. \
\>", "Text"],

Cell["\<\
Some of the provers we provide have options which enable the user \
to change certain parameters determining the way the inference rules are \
applied. For example, the user can specify that some inference rules should \
only be applied to the goal and not to the knowledge base or that \
back\[Dash]chaining on implications should not be used as inference rule or \
that a certain term ordering should be used instead of another in rewriting \
by equalities. These options are collected under an option of the Prove \
command: \"ProverOptions\[Rule]\". It should be clear that by modifying these \
options in a Prove call, also the prover applied will change. For example, in \
the call\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<limit of sum\>\"", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{
            StyleBox["KnowledgeBase",
              FontWeight->"Bold"], "[", "\"\<limit of sum\>\"", "]"}]}], ",", 
        "\[IndentingNewLine]", \(by \[Rule] PCS\), 
        ",", \(ProverOptions -> {GRWTarget -> {"\<goal\>", "\<kb\>"}}\)}], 
      "]"}]], "Input"],

Cell["\<\
a different prover will be called than in Figure 2.1. This prover \
will first attempt to rewrite the goal and only afterwards the knowledge base \
while the prover applied in the first call will first rewrite the knowledge \
base and only afterwards the goal (the default options). \
\>", "Text"],

Cell["\<\
Summarizing, a prover with options represents a family of provers, \
as, for example, PCS. The individual members of  such a family of provers are \
specified by fixing the value of the option \"by\[Rule]\" and varying the \
value for the option \"ProverOptions\[Rule]\". In our example, if we fix the \
value of the option \"by\[Rule]\" to \"by\[Rule]PCS\", to each possible value \
of \"ProverOptions\[Rule]\" will correspond a different prover from the \
family of provers PCS.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. 6.  Theorema Provers as Seen by the Prover Programmer", "Section",
  CellTags->{"sec:pp", "c:15"}],

Cell["\<\
Currently, only the Theorema developers are prover programmers but, \
in a forthcoming version of the system, also the user will have the \
possibility to program his own provers. A prover programmer must be able \
to:\
\>", "Text"],

Cell["\<\
implement new inference rules and specify what the natural language \
explanation of these rules should be, \
\>", "BItem1"],

Cell["\<\
use the existing inference rules as black\[Dash]boxes and\
\>", \
"BItem1"],

Cell["combine these inference rules in a variety of ways.", "BItem1"],

Cell["\<\
For this purpose, internally, the inference rules are grouped \
together depending on:\
\>", "Text"],

Cell["\<\
the type of inference rule, for example: natural deduction, \
rewriting, induction, or on\
\>", "BItem1"],

Cell["\<\
the structure of formulae to which they can be applied: definitions \
by cases, formulae involving sets or functors.\
\>", "BItem1"],

Cell[TextData[{
  "Note that each such group of inference rules, if the inference rules are \
given in a fixed order, is a prover in the sense of Section 2.3. These \
provers can be combined in order to obtain the provers provided to the user. \
It can happen that one prover contains just one inference rule, for example, \
the induction inference rule for natural numbers. Some of these provers can \
complete on their own the proofs for certain classes of proof situations, for \
example, the prover containing the natural deduction inference rules. Some \
provers have to be combined with others in order to finalize a proof, for \
example, the prover handling definitions by cases. The current mechanism used \
in Theorema for combining provers, hence, the one we also used for our work, \
was described in ",
  ButtonBox["[93]",
    ButtonData:>"Tomuta:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "E. Tomuta, 1998, An Architecture for Combining Provers and its \
Applications in the Theorem ..."],
  ". While it brought an improvement in the way provers could be programmed \
in Theorema, with the time, the mechanism proved not to be flexible enough \
for the purpose of the project. In the forthcoming version of the system it \
is suppose to change drastically."
}], "Text"],

Cell["\<\
It can well happen that in certain proofs it is necessary to apply \
to the proof situations inference rules of solving type -  for example, rules \
acting on existential goals - or of computing type - for example rules \
rewriting the goal or the assumptions. Groups of such inference rules are \
called solvers and computers (simplifiers), respectively.\
\>", "Text"],

Cell["\<\
A prover, solver, or computer (simplifier) that combines inference \
rules of the same type in a fixed order is implemented as a Mathematica \
function having one or more definitions of the form:\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          StyleBox[\(Name[Input] /; Preconditions\),
            "MR"], 
          StyleBox[")",
            "MR"]}], 
        StyleBox[":=",
          "MR"], 
        StyleBox["Output",
          "MR"]}], TextForm]], "NumberedEquation",
  CellTags->"eq:bp-def"],

Cell["where", "Text"],

Cell[TextData[{
  StyleBox["Name:", "MR"],
  " is the name of the prover / solver / computer."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Input:", "MR"],
  " is a schema of proof situations."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Preconditions:", "MR"],
  " is a set of conditions that a proof situation must fulfill in order for \
the respective prover (solver, computer) to be applicable."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Output:", "MR"],
  " can be either"
}], "BItem1"],

Cell["True, if the given proof situation is trivial, or", "BItem2"],

Cell["\<\
an AND\[Dash] or an OR\[Dash]situation containing simpler proof \
situations derived from the given one, or\
\>", "BItem2"],

Cell["\<\
Null, if the prover was unable to transform the proof situation \
into simpler ones.\
\>", "BItem2"],

Cell["\<\
Usually, one inference rule corresponds to one Mathematica \
definition of type (2.1). In this case, the order of the inference rules in \
the prover will be given by the order in which Mathematica stores the \
corresponding definitions. If the Mathematica function allows options which \
change the way the inference rules are applied then, as explained in the \
previous section, we have a family of provers / solvers / computers \
(simplifiers).\
\>", "Text"],

Cell[TextData[{
  StyleBox["Natural Language Explanation.",
    FontWeight->"Bold"],
  " For each implemented inference rule, the prover / solver / computer \
programmer gives a skeleton with the text that should appear as explanation \
in natural language. This skeleton has some empty parts where the actual \
labels, formulae, from the proof should be filled in and is implemented as a \
collection of Mathematica text cells. The skeleton will vary with the natural \
language used (English, Japanese, German, etc.). At the current moment we \
only have available the skeletons for English language and we are \
experimenting with a Japanese version. A postprocessor is recursively \
visiting all the nodes of the proof object, fills in the skeletons with the \
actual data and inserts them at appropriate places into the notebook \
containing the natural language representation of the proof. In generating \
the notebook with the natural language representation, extensive use of the \
cell nesting possibilities in Mathematica is made."
}], "Paragraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.  General Rewriting", "Chapter",
  CellTags->{"sec:grw", "c:16"}],

Cell["\<\
Rewriting of terms with respect to equalities between terms is a \
very well-known concept. In this thesis, we will generalize this concept to \
rewriting with respect to equalities, equivalences and implications whose \
right\[Dash]hand sides are arbitrary terms (and formulae), i.e. expressions \
that may also contain quantifiers. We call the equalities, equivalences and \
implications \"rewrite\[Dash]formulae\", while other types of formulae are \
called \"non\[Dash]rewrite\[Dash]formulae\". Note that, while rewriting \
formulae using equalities and equivalences produces equivalent formulae, \
rewriting by implications will \"expand the knowledge\" and \"reduce the goal\
\". A further generalization to rewriting which we make is \"semantic \
rewriting\".\
\>", "Text"],

Cell["\<\
The chapter is structured as follows: We first give a description \
by means of examples of the general rewriting, then we present the inference \
rules used for general rewriting, then we explain how semantic rewriting is \
applied and, finally, we describe the implementation.\
\>", "Text"],

Cell[CellGroupData[{

Cell["3. 1.  Main Idea", "Section",
  CellTags->{"sec:rw-idea", "c:17"}],

Cell["\<\
The syntax of the rewrite\[Dash]formulae we consider is\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\[ScriptCapitalA]\  \
\[RightArrowLeftArrow] \ \[ScriptCapitalB]\)},
          {\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\)\+\[ScriptCapitalA] \
\[ScriptCapitalB]\)}
          }], TraditionalForm]], "NumberedEquation"],

Cell["where", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[RightArrowLeftArrow]\)\(\(\[Element]\)\({\(=\)\
\(\(,\)\(\(:=\)\(\(,\)\(\(\[DoubleLeftRightArrow]\)\(\(,\)\(\(:\)\(\
\[DoubleLeftRightArrow]\)\)\(,\)\(\(\[Implies]\)\(\(,\)\(\[DoubleLeftArrow]\)\
\)\)\)\)\)\)\)}\)\)\)\)]],
  ","
}], "BItem1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  " are terms if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[RightArrowLeftArrow]\)\(\(\[Element]\)\({\(=\)\
\(\(,\)\(:=\)\)}\)\)\)\)]],
  " and formulae otherwise,"
}], "BItem1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  " contain no other free variables than ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  "(as we treat only closed formulae)."
}], "BItem1"],

Cell["\<\
Each rewrite\[Dash]formula from the knowledge base of a proof \
situation is transformed into one or more rewrite rules (if possible). Some \
of the rules are used for reducing the goal and some for expanding the \
knowledge. A summary is given in Figure 3.1.\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(Formula\)\(\ \)\), \(Rule\ for\ reducing\ the\ goal\), \(Rule\ \
for\ expanding\ the\ knowledge\)},
          {\(\(\[ScriptCapitalA] := \[ScriptCapitalB]\)\n\(\[ScriptCapitalA] \
= \[ScriptCapitalB]\)\n\(\[ScriptCapitalA] \[DoubleLeftRightArrow] \
\[ScriptCapitalB]\)\n\(\[ScriptCapitalA] : \(\(\[DoubleLeftRightArrow]\)\(\
\[ScriptCapitalB]\)\)\)\), \(\[ScriptCapitalA] \[Rule] \[ScriptCapitalB]\), \
\(\[ScriptCapitalA] \[Rule] \[ScriptCapitalB]\)},
          {\(\(\[ScriptCapitalA] \[Implies] \[ScriptCapitalB]\)\n\(\
\[ScriptCapitalB] \[DoubleLeftArrow] \[ScriptCapitalA]\)\), \(\
\[ScriptCapitalB] \[Rule] \[ScriptCapitalA]\), \(\[ScriptCapitalA] \[Rule] \
\[ScriptCapitalB]\)}
          }], TraditionalForm]], "3ColumnTable"],

Cell["\<\
Figure 3.1 Rewrite\[Dash]formulae and the Corresponding Rewrite\
\[Dash]rules. \
\>", "Figure",
  CellTags->"fig:rules"],

Cell["\<\
For handling the rewrite rules we are using Mathematica. Namely, we \
transform the knowledge in Mathematica rewrite rules and apply them in a \
controlled way using the Mathematica built-in rewriting capabilities. \
\>", \
"Text"],

Cell["\<\
Note that we only construct the rewrite rules if the right-hand \
side of the rewrite rule contains no other free variables than the \
left\[Dash]hand side. For example, the assumption\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x, y\)\((b[x] \[Implies] 
          a[x, y])\)\)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are predicates will only generate the Mathematica rewrite rule ",
  StyleBox[Cell[BoxData[
      \(a[x_, y_] \[Rule] b[x]\)], "MR"], "MR"],
  " which can be applied to the goal and no rule applicable to the knowledge. \
Actually, the formula above is equivalent to:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+x\((b[
            x] \[Implies] \[ForAll] \+y a[x, y])\)\)], "DisplayFormula"],

Cell[TextData[{
  "and one could generate the Mathematica rule  ",
  StyleBox[Cell[BoxData[
      \(b[x_] \[Rule] \[ForAll] \+y a[x, y]\)], "MR"], "MR"],
  " to be applied on the knowledge."
}], "Text"],

Cell[TextData[{
  StyleBox["Example (Rewriting by Equivalence). ",
    FontWeight->"Bold"],
  " Let us consider given the definition of point-continuity of a function:"
}], "Example"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(f, x\)continuous[f, 
          x] \[DoubleLeftRightArrow] \(\(\[ForAll] \+\[Epsilon]\)\+\(\
\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\
\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - 
                    f[x]\[RightBracketingBar] < \(\(\[Epsilon]\)\(.\)\)\)\)\)\
\)], "DisplayFormula"],

Cell["This will be translated in a  Mathematica rewrite rule", "Text"],

Cell[BoxData[
    StyleBox[\(continuous[f_, 
          x_] \[Rule] \(\[ForAll] \+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\(\
\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\)\+\(\
\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - f[x]\[RightBracketingBar] < \[Epsilon]\)\)\),
      "MR"]], "DisplayFormula",
  SingleLetterItalics->False],

Cell["\<\
which will be used for rewriting equivalently both assumptions and \
goals. For example, proving the ground goal\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`continuous[f\_0 + g\_0, a\_0]\)], "DisplayFormula"],

Cell["will be simplified to proving", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ForAll] \+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\(\
\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\)\+\(\
\[LeftBracketingBar]y - a\_0\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]\((f\_0 + g\_0)\)[y] - \((f\_0 + g\_0)\)[
                  a\_0]\[RightBracketingBar] < \(\(\[Epsilon]\)\(.\)\(\ \ \
\)\)\)\)\)], "DisplayFormula"],

Cell["Similarly, a ground assumption of the form ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`continuous[g\_0, a\_0]\)], "DisplayFormula"],

Cell["will be simplified to:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ForAll] \+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\(\
\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\)\+\(\
\[LeftBracketingBar]y - a\_0\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]g\_0[y] - 
                g\_0[a\_0]\[RightBracketingBar] < \[Epsilon] . \ \ \ \ \
\[EmptySquare]\)\)\)], "DisplayFormula"],

Cell[TextData[{
  StyleBox["Example (Rewriting by Implications). ",
    FontWeight->"Bold"],
  " Let us consider the following property of the absolute value:"
}], "Example"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x, y, z\)\(\((\[LeftBracketingBar]x - 
                  y\[RightBracketingBar] < z \[Implies] 
            x > y - z)\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
This property will be translated in two Mathematica rewrite rules, \
one to be applied on the knowledge:\
\>", "Text"],

Cell[BoxData[
    StyleBox[\(\[LeftBracketingBar]x_ - y_\[RightBracketingBar] < z_ \[Rule] 
        x > y - z\),
      "MR"]], "DisplayFormula",
  CellFrameLabels->{{None, "(A)"}, {None, None}},
  SingleLetterItalics->False],

Cell["and one to be applied on the goals:", "Text"],

Cell[BoxData[
    \(x_ > 
        y_ - z_ \[Rule] \[LeftBracketingBar]x - 
            y\[RightBracketingBar] < \(\(z\)\(.\)\)\)], "DisplayFormula",
  CellFrameLabels->{{None, "(G)"}, {None, None}},
  SingleLetterItalics->False],

Cell["Hence, from a ground assumption of the form", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[LeftBracketingBar]f\_0[a\_0] - 
          f\_0[b\_0]\[RightBracketingBar] < \[Epsilon]\_0\)], "DisplayFormula"],

Cell["one can deduce by (A)", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{Cell[TextData[{
          Cell[BoxData[
              FormBox[
                RowBox[{
                  FormBox[\(f\_0\),
                    "TraditionalForm"], "[", \(a\_0\), "]"}], 
                TraditionalForm]]],
          " > ",
          Cell[BoxData[
              FormBox[
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox[\(f\_0\),
                        "TraditionalForm"], "[", \(b\_0\), "]"}],
                    "TraditionalForm"], "-", \(\[Epsilon]\_0\)}], 
                TraditionalForm]]]
        }]], "."}], TraditionalForm]], "DisplayFormula"],

Cell["\<\
(Note that we will not replace the initial assumption by the \
simplified one but keep both of them in the knowledge base.) \
\>", "Text"],

Cell["Similarly, if the ground goal to be proved is ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(f\_0[a\_0]\  > \ 
      b\_0 - c\_0\)\(,\)\)\)], "DisplayFormula"],

Cell[" by rule (G) it follows that is sufficient to prove", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[LeftBracketingBar]f\_0[a\_0] - 
          b\_0\[RightBracketingBar] < \(\(c\_0\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
If we apply such a rule, we do not keep the old goal anymore and go \
on with the new one. \[EmptySquare]\
\>", "Text"],

Cell["\<\
General rewriting does not always help. It can generate infinite \
expansion of the knowledge and it can reduce the goal to unprovable goals. \
However, in many proof situations encountered in typical textbooks, the \
application of general rewriting yields \"natural\" proofs with little \
search. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 2.  Inference Rules", "Section",
  CellTags->"c:18"],

Cell["Note that the following formulae are equivalent:", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\[ScriptCapitalA]\  \
\[Implies] \[ScriptCapitalB]\)\(,\)\(\ \ \)\)},
          {\(\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\)\+\[ScriptCapitalA] \
\[ScriptCapitalB]\)\(,\)\)},
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\[ScriptCapitalB] \
\[DoubleLeftArrow] \(\(\[ScriptCapitalA]\)\(.\)\)\)}
          }], TraditionalForm]], "DisplayFormula"],

Cell["\<\
For this reason, from now on we will only consider the formulae of \
the first type.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["3.1",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Rewriting by Equivalences/Equalities). ",
    FontWeight->"Bold"],
  " Suppose we have a formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " and we know:"
}], "InferenceRule",
  CellTags->"r:rw-eq"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\
\[ScriptCapitalA]\  \[RightArrowLeftArrow] \[ScriptCapitalB]\)], \
"DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[RightArrowLeftArrow]\)\(\(\[Element]\)\({\(=\)\
\(\(,\)\(\(:=\)\(\(,\)\(\(\[DoubleLeftRightArrow]\)\(\(,\)\(\(:\)\(\
\[DoubleLeftRightArrow]\)\)\)\)\)\)\)}\)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  " contains no other free variables than the ones of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  " (possibly less). If ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " contains a subformula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\)]],
  " which is an instance of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  " (\[ScriptCapitalS] is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\ \[Sigma]\)]],
  " for some substitution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  "), then ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[DoubleLeftRightArrow] \
\[ScriptCapitalF][\[ScriptCapitalS] \[LeftArrow] \[ScriptCapitalB]\ \[Sigma]]\
\)]],
  ".  Furthermore, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\^\[FivePointedStar]\)]],
  " is the normal form of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " with respect  to the application of the rewrite rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] \[Rule] \[ScriptCapitalB]\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[DoubleLeftRightArrow] \
\[ScriptCapitalF]\^\[FivePointedStar]\)]],
  "."
}], "Text"],

Cell["\<\
The correctness of the rule follows from the instantiation rule for \
the universally quantified formulae and the replacement properties of \
equalities and equivalences in terms and formulae.  \[EmptySquare]\
\>", \
"ProofBegin"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["3.2",
    FontWeight->"Bold"],
  " ",
  StyleBox["(General Rewriting by Implications). ",
    FontWeight->"Bold"],
  " Suppose we have in the knowledge base the closed formula:"
}], "InferenceRule",
  CellTags->"r:rw-impl"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\
\[ScriptCapitalA]\  \[Implies] \(\(\[ScriptCapitalB]\)\(.\)\)\)], \
"DisplayFormula"],

Cell["\<\
For a closed formula \[ScriptCapitalF],  the following hold: \
\>", \
"Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " contains a positive occurrence ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalS]\^+\)\)]],
  "of an instance of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\ \[Sigma]\)]],
  " for some substitution \[Sigma], ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  " contains no other free variables than the ones of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  " (possibly less) then ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[Implies] \[ScriptCapitalF] \
\[LeftAngleBracket]\(\[ScriptCapitalS]\^+\) \[LeftArrow] \[ScriptCapitalB]\ \
\[Sigma]\[RightAngleBracket]\)]],
  "."
}], "BItem1",
  CellDingbat->"1."],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  " contains a positive occurrence ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalT]\^+\)\)]],
  "of an instance of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  ", i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\ \[Sigma]\)]],
  "  for some substitution \[Sigma], ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  " contains no other free variables than the ones of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  " (possibly less) then ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF] \[DoubleLeftArrow] \
\[ScriptCapitalF] \[LeftAngleBracket]\(\[ScriptCapitalT]\^+\) \[LeftArrow] \
\[ScriptCapitalA]\ \[Sigma]\[RightAngleBracket]\)]],
  "."
}], "BItem1",
  CellDingbat->"2."],

Cell[TextData[{
  "The correctness of the rule follows from the universal instantiation \
deduction rule and the positive polarity proposition (see ",
  ButtonBox["[67]",
    ButtonData:>"Manna_Waldinger:85",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Z. Manna and R. Waldinger, 1985, The Logical Basis for Computer \
Programming"],
  "). "
}], "ProofBegin"],

Cell["\<\
Note that syntactic rewriting can be applied also for formulae \
where sequence variables occur.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 3.  Semantic Rewriting", "Section",
  CellTags->{"sec:sem-match", "c:19"}],

Cell["\<\
For rewriting the goal we use also, apart from the pure syntactic \
rewriting, the stronger notion of \"semantic rewriting\". By semantic \
rewriting we do not intend the so\[Dash]called E-rewriting (rewriting modulo \
an equational theory). We will illustrate our concept of semantic rewriting \
in the following example. Suppose we have the ground goal \[ScriptCapitalG]\
\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[LeftBracketingBar]a - b\[RightBracketingBar] < 
      c\)\(,\)\)\)], "DisplayFormula"],

Cell["and we know that \[ScriptCapitalA] holds:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x, y, z, t\)\[LeftBracketingBar]x - 
              y\[RightBracketingBar] < 
          z + \ t\  \[DoubleLeftArrow] \(\((\[LeftBracketingBar]x\
\[RightBracketingBar] < z \[And] \[LeftBracketingBar]y\[RightBracketingBar] < 
                t)\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
We would like to reduce the goal \[ScriptCapitalG] using the \
knowledge \[ScriptCapitalA] which is of rewrite type. The corresponding \
Mathematica goal rewrite rule generated from \[ScriptCapitalA] is\
\>", "Text"],

Cell[BoxData[
    RowBox[{" ", 
      StyleBox[
        RowBox[{Cell[BoxData[
              \(\[LeftBracketingBar]x_ - y_\[RightBracketingBar] < 
                  z_ + t_ \[Rule] \[LeftBracketingBar]x\[RightBracketingBar] \
< z \[And] \[LeftBracketingBar]y\[RightBracketingBar] < t\)], "MR"], "."}],
        "MR"]}]], "DisplayFormula",
  SingleLetterItalics->False],

Cell[TextData[{
  "This rule will not be applicable on the goal as syntactic rewriting does \
not work (there is no substitution for the variables ",
  Cell[BoxData[
      \(TraditionalForm\`x, \ y, \ z, \ t\)]],
  " that unifies ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x\  - \ 
            y\[RightBracketingBar]\  < \ z\  + \ t\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]a\  - \ 
            b\[RightBracketingBar]\  < \ c\)]],
  "). However, we observe that \[ScriptCapitalG] is implied by (in other \
words, can be reduced to)"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Exists] \+\(z, t\)\)\+\(z + t = c\)\(\((\
\[LeftBracketingBar]a\[RightBracketingBar] < 
              z \[And] \[LeftBracketingBar]b\[RightBracketingBar] < 
              t)\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "Note that, in general, the following formula holds (for formulae \
\[ScriptCapitalA], \[ScriptCapitalB] whose only free variables are among ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  "and closed formulae \[ScriptCapitalG]):"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\((\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\
\[ScriptCapitalA] \[Implies] \[ScriptCapitalB])\))\) \[Implies] \(\((\((\(\
\[Exists] \+\(x\_1, \[Ellipsis], x\_n\)\)\+\(\[ScriptCapitalB] \
\[DoubleLeftRightArrow] \[ScriptCapitalG]\)\[ScriptCapitalA])\) \[Implies] \
\[ScriptCapitalG])\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
Of course, this does not always rewrite the goal \[ScriptCapitalG] \
to something \"simpler\". For our purposes, we will therefore restrict the \
application of semantic rewriting to cases when the rule for rewriting has as \
left-hand side a positive or negative literal (e.g., in the previous formula \
\[ScriptCapitalB] is a literal). The inference rule we use for applying \
semantic rewriting to a positive literal in the goal is:\
\>", "Text"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["3.3",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Semantic Rewriting).",
    FontWeight->"Bold"],
  "  Suppose we have in the knowledge base one of the closed formulae:"
}], "InferenceRule"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\_1, \[Ellipsis], x\_m\)\((\
\[ScriptCapitalA] \[Implies] 
            p[\[ScriptCapitalS]\_1, \[Ellipsis], \
\[ScriptCapitalS]\_n])\)\ \ \ or\ \ \ \ \(\[ForAll] \+\(x\_1, \[Ellipsis], \
x\_m\)p[\[ScriptCapitalS]\_1, \[Ellipsis], \[ScriptCapitalS]\_n] \
\[DoubleLeftRightArrow] \[ScriptCapitalA]\), 
    respectively, \)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "  is a predicate and the ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\_i\ \((i = 1, \[Ellipsis], 
          n)\)\)]],
  " are terms and we have to prove a closed formula \[ScriptCapitalF] \
containing a positive occurrence of ",
  Cell[BoxData[
      \(TraditionalForm\`p[\[ScriptCapitalT]\_1, \[Ellipsis], \
\[ScriptCapitalT]\_n]\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_i\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((i = 1, \[Ellipsis], n)\)\)]],
  " are terms. In order to prove \[ScriptCapitalF] it is sufficient to prove \
"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[ScriptCapitalF]", "[", 
          RowBox[{
            SuperscriptBox[
              
              FormBox[\(p[\[ScriptCapitalT]\_1, \[Ellipsis], \
\[ScriptCapitalT]\_n]\),
                "TraditionalForm"], "+"], "\[LeftArrow]", 
            RowBox[{"(", 
              
              FormBox[\(\(\[Exists] \+\(x\_1, \[Ellipsis], x\_m\)\)\+\(\((\
\[ScriptCapitalT]\_1 = \[ScriptCapitalS]\_1)\) \[And] \[Ellipsis] \[And] \((\
\[ScriptCapitalT]\_n = \[ScriptCapitalS]\_n)\)\)\[ScriptCapitalA]\),
                "TraditionalForm"], ")"}]}], "]"}], "."}], 
      TraditionalForm]], "DisplayFormula"],

Cell["\<\
The correctness of the rule follows from Rule 3.2 or Rule 3.1, \
respectively, and the replacement properties of equalities. \
\>", \
"ProofBegin"],

Cell[TextData[{
  StyleBox["Remark.", "IT"],
  " A similar rule is applied for negative literals."
}], "Remark"],

Cell["\<\
We only apply semantic matching when the formulae involved contain \
no sequence variables. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 4.  Implementation", "Section",
  CellTags->{"sec:rw-impl", "c:20"}],

Cell[TextData[{
  "The computer (simplifier) combining the above inference rules is \
implemented as the Mathematica function: ",
  StyleBox["GRS", "SR"],
  " (",
  StyleBox["G",
    FontWeight->"Bold"],
  "eneral ",
  StyleBox["R",
    FontWeight->"Bold"],
  "ewriting ",
  StyleBox["S",
    FontWeight->"Bold"],
  "implifier). As specified in Section 2.6, the function is given by one \
definition of the form:"
}], "Text"],

Cell[BoxData[
    \(\(\(\((GRS[Input] /; Precondition)\) := 
      Output\)\(,\)\)\)], "DisplayFormula"],

Cell["where", "Text"],

Cell[TextData[{
  StyleBox["Input:", "MR"],
  " is a proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG], \[ScriptCapitalK])\)\)]],
  "."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Precondition:", "MR"],
  " is a condition which checks if ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\)]],
  " has a rewrite part and either the goal ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  " is a candidate for rewriting or ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\)]],
  " contains an assumption which is a candidate for rewriting."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Output:", "MR"],
  " is one of the following:"
}], "BItem1"],

Cell[TextData[{
  "An ",
  StyleBox["AND\[Dash]", "SR"],
  "situation containing either the proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG]', \[ScriptCapitalK])\)\)]],
  " if the goal ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  " was rewritten to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]'\)]],
  " either syntactically or semantically using ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG], \[ScriptCapitalK] \[Union] \
\[ScriptCapitalA])\)\)]],
  " where \[ScriptCapitalA] was obtained by syntactic general rewriting of a \
formula in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\)]],
  "."
}], "BItem2"],

Cell[TextData[{
  StyleBox["Null,", "SR"],
  " if the general rewriting failed."
}], "BItem2"],

Cell[TextData[{
  "The ",
  StyleBox["GRS", "SR"],
  " simplifier is an example of family of simplifiers, see Section 2.6. Via \
the options it provides, the user can change the way rewriting is applied."
}], "Text"],

Cell[TextData[{
  StyleBox["Remark (Natural Language Explanation).", "IT"],
  " We provided skeletons with the text to be used when explaining a general \
rewriting step (see last section with the examples)."
}], "Remark"],

Cell[TextData[{
  "Note that the simplifier does not produce trivially true \
proof\[Dash]situations, hence in order to complete a proof one has to use it \
in connection with other provers which can reduce proof situations to \
trivially true ones, e.g. ",
  StyleBox["PND ", "SR"],
  "(the prover combining natural deduction rules). For the rest of the \
section we will clarify what formulae are candidates for rewriting, when and \
what rules are generated, how are they applied and what kind of bookkeeping \
we do."
}], "Paragraph"],

Cell[CellGroupData[{

Cell["3. 4. 1.  Deciding what Formulae are Rewriting Candidates", "Subsection",
  CellTags->{"sec:rw-cand", "c:21"}],

Cell["\<\
One can start by taking as rewriting candidates only literal \
formulae. We thought that we could apply natural deduction rules until the \
formulae will become literals, and then apply rewriting. However, many of the \
proofs that involve goals with alternating quantifiers, e.g. limit and \
continuity proofs become feasible only if one applies rewriting also to \
subformulae of the goal. Hence, we implemented general rewriting for\
\>", \
"Text"],

Cell["positive or negative literals,", "BItem1",
  CellDingbat->"1."],

Cell["conjunctive/disjunctive forms,", "BItem1",
  CellDingbat->"2."],

Cell["\<\
existential goals and universal assumptions whose \"innermost \
subformula\" is of type 1 or 2.\
\>", "BItem1",
  CellDingbat->"3."],

Cell["\<\
Here, the innermost subformula of a formula, roughly, is the one \
obtained by stripping off the quantifiers together with their range \
specification and conditions. For example, the innermost subformula of\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[ForAll] \+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\
\[Exists] \+N\(\(\[ForAll] \+n\)\+\(n \[GreaterEqual] \
N\)\[LeftBracketingBar]f[n] - 
                a\[RightBracketingBar] < \[Epsilon]\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "is ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]f[n]\  - 
            a\[RightBracketingBar]\  < \ \[Epsilon]\)]],
  ". This notion is defined recursively and it has the property that the \
subformula it returns has a positive polarity in the formula. "
}], "Text"],

Cell["\<\
The default behavior of the simplifier, which can be changed by \
using the available options, is to rewrite only formulae of type 1 and 2. \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 4. 2.  Generalized Rewriting", "Subsection",
  CellTags->"c:22"],

Cell["\<\
The application of one general rewriting step to a proof situation \
consists of a preparatory step in which the  rewrite rules are generated from \
the knowledge base and the actual rewriting of a single formula (goal or \
assumption). For the rewriting step, the first successful attempt from the \
ones listed below is taken:\
\>", "Text"],

Cell["\<\
syntactic rewriting of the goal using the rules for goal reduction,\
\
\>", "BItem1"],

Cell["\<\
semantic rewriting of the goal using one of the rules for goal \
reduction,\
\>", "BItem1"],

Cell["\<\
syntactic rewriting of the knowledge using the rules for knowledge \
expansion.\
\>", "BItem1"],

Cell["\<\
The syntactic rewriting of the knowledge consists of one \"useful\" \
syntactic rewriting of an assumption, i.e. we do not rewrite all assumptions \
in one general rewriting step. Here, useful means that the newly generated \
assumption is neither trivial, e.g. a=a, nor contained already in the \
knowledge. The assumptions are considered for rewriting in the order they are \
given in the knowledge.\
\>", "Text"],

Cell["\<\
If none of the attempts succeeded, the rewriting step failed. \
Otherwise, a new proof situation is generated with either a new goal instead \
of the old one or with a new assumption added to the initial knowledge \
(placed just before the assumption from which it was generated). \
\>", "Text"],

Cell["\<\
The default behavior in choosing and rewriting a formula is the one \
we described above. Via the options, the user can disable semantic rewriting, \
or restrict the formulae considered as candidates for rewriting or change the \
order in which rewriting is attempted: first rewriting of the knowledge base \
and only afterwards rewriting the goal. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. 4. 3.  Some more Details about Generating the Rewrite \
Rules\
\>", "Subsection",
  CellTags->"c:23"],

Cell["\<\
For obtaining good results by using rewriting, the rule generation \
process is a bit more complicated than what we described in Section 3.1. \
There are formulae of rewrite type for which we generate no, less, or more \
rewrite rules than what was previously said. This depends on the structure of \
the formula.\
\>", "Text"],

Cell["\<\
For optimizing the rule generation process, only those rules are created for \
which the left hand side is a rewriting candidate, see Section 3.4.1. Also, \
once the rewrite rules were generated for a formula they are stored and \
retrieved when needed.\
\>", "Text"],

Cell["\<\
It can happen that some formulae generate cyclic rules, e.g. when \
the right\[Dash]hand side is an instance of the left\[Dash]hand side. Via an \
option, the user can specify whether he wants to use cyclic rules or not. The \
default behavior is not to use them. In case they are used, some sort of \
control is used which reduces the possibility of generating cycles by keeping \
track of the formulae to which they were applied once. \
\>", "Text"],

Cell["\<\
The formulae for which we generate more rules than the ones \
mentioned in Section 3.1 are the implications. The extra rules arise from \
considering some other formulae equivalent with the initial implication, \
formulae which are either implications or conjunctions of implications, and \
generating the rewrite rules for all of them. In Figure 3.2 we give a list of \
which other  implications we consider for each implication we are dealing \
with. \
\>", "Text"],

Cell[TextData[{
  "Syntactic rewriting is applied in the following way: Rules are considered \
one after the other in the order they are given. If a rule is cyclic than it \
is applied only once. Otherwise, the rule is applied as long as it is \
possible and the resulting formula is still a rewriting candidate. \
Furthermore, care is taken that in the application of a rewrite rule, only \
subformulae of positive polarity are rewritten. For example, the formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] A\)]],
  " will not be rewritten by the rule A\[Rule]B."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(Closed\ \ Formula\), \
\(Additional\ \ Implications\ \ Considered\)},
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \[ScriptCapitalB])\)\), \(\[ForAll] \+\(x\_1, \[Ellipsis], \
x\_n\)\((\[Not] \[ScriptCapitalB] \[Implies] \[Not] \[ScriptCapitalA])\)\)},
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \((\[ScriptCapitalB] \[Implies] \[ScriptCapitalC])\))\)\), \(\
\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \[And] \
\[ScriptCapitalB] \[Implies] \[ScriptCapitalC])\)\ \ and\ \(\[ForAll] \
\+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalB] \[Implies] \((\
\[ScriptCapitalA] \[Implies] \[ScriptCapitalC])\))\)\)\)},
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \((\[ScriptCapitalB] \[DoubleLeftRightArrow] \[ScriptCapitalC])\))\
\)\), \(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \((\[ScriptCapitalB] \[Implies] \[ScriptCapitalC])\))\)\ and\ \(\
\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \[Implies] \((\
\[ScriptCapitalC] \[Implies] \[ScriptCapitalB])\))\)\)\)},
          {\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \[ForAll] \+\(y\_1, \[Ellipsis], y\_m\)\((\[ScriptCapitalB] \
\[Implies] \[ScriptCapitalC])\))\)\), \(\[ForAll] \+\(x\_1, \[Ellipsis], \
x\_n, y\_1, \[Ellipsis], y\_m\)\((\[ScriptCapitalA]' \[Implies] \((\
\[ScriptCapitalB] \[Implies] \[ScriptCapitalC])\))\)\n
            \((\[ScriptCapitalA]'\ obtained\ by\ renaming\ in\ \
\[ScriptCapitalA]\ \ the\ possible\ \[IndentingNewLine]occurrences\ of\ y\_1, \
\[Ellipsis], y\_m)\)\)}
          }], TraditionalForm]], "2ColumnTable"],

Cell["\<\
Figure 3.2 Additional Implications Considered for Rewrite Rule \
Generation.\
\>", "Figure",
  CellTags->"fig:eq-impl"],

Cell["\<\
Since the rules we generate are not necessarily forming a \
terminating system, it may happen that rewriting never ends. This is, of \
course, a drawback which will be handled more carefully in a future version \
of Theorema. At this moment, our focus was on finding rewrite rules that give \
easy\[Dash]to\[Dash]understand proofs in practically interesting cases. \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 4. 4.  Some more Details about Semantic Rewriting", "Subsection",
  CellTags->{"sec:find-sm", "c:24"}],

Cell["\<\
Semantic rewriting comes into play if the innermost formula of the \
goal is a literal \[ScriptCapitalL] which could not be rewritten \
syntactically using the set of rules for goal expansion \[ScriptCapitalR]. \
What we do is described in the following example.\
\>", "Text"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\)]],
  " be the ground literal ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]a + b\[RightBracketingBar] < 
        c\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " constants) and suppose the list of rules \[ScriptCapitalR] contains, say \
at the first position, the rule"
}], "Text"],

Cell[BoxData[
    \(\[LeftBracketingBar]x_ + y_\[RightBracketingBar] < 
        a_ + \ b_ \[Rule] \[LeftBracketingBar]x\[RightBracketingBar] < 
          a \[And] \[LeftBracketingBar]y\[RightBracketingBar] < \
\(\(b\)\(.\)\)\)], "DisplayFormula",
  SingleLetterItalics->False],

Cell[TextData[{
  "Note that, in rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are free variables. In fact the rule was derived from the assumption"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x, y, a, b\)\(\((\[LeftBracketingBar]x + 
                  y\[RightBracketingBar] < 
              a + \ b \[DoubleLeftArrow] \((\[LeftBracketingBar]x\
\[RightBracketingBar] < a \[And] \[LeftBracketingBar]y\[RightBracketingBar] < 
                  b)\))\)\(.\)\)\)], "DisplayFormula"],

Cell["The algorithm for semantic rewriting does the following:", "Text"],

Cell[TextData[{
  "We compute for each rule a matching measure with respect to the formula we \
want to rewrite. This is done by constructing a \"",
  "matching skeleton\"",
  " between the formula and the left\[Dash]hand side of the rule. The \
skeleton is reproducing the tree structure of the two expressions up to which \
they match and in the leafs it contains the non\[Dash]matching pairs. For \
example, the matching skeleton between ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]a + b\[RightBracketingBar] < 
        c\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]x_ + y_\[RightBracketingBar] < 
        a_ + \ b_\)]],
  " looks like this:"
}], "BItem1"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\[EmptySquare]\ \ \ \ \ \ \ \ \ \ \
\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ /\ \ \ \
\ \ \ \ \ \ \(\(\\\[IndentingNewLine]\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\
\[IndentingNewLine]\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\
\[EmptySquare]\)\)\ \ \ \ \ \ \ \ \ \ \ \ \(\({c, 
          a_ + b_}\)\(.\)\)\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "This skeleton shows that there exists a syntactic match for the head and \
the first argument while the second argument has the nonmatching pair ",
  Cell[BoxData[
      \(TraditionalForm\`{c, a_ + b_}\)]],
  ". Some information on the length of the parts that matched is also stored. \
From the skeletons, a \"matching measure\" is computed which is based on the \
depth of the matching parts and the depth where the disagreement arises."
}], "ContinueBItem1"],

Cell[TextData[{
  "The rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_i\)]],
  " with a best fitting according to the measure is chosen, say ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1\)]],
  " in our case. "
}], "BItem1"],

Cell[TextData[{
  "Given the rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_i\)]],
  " and the formula \[ScriptCapitalL], an existential formula is constructed \
which is the result of applying ",
  "semantic",
  " rewriting to \[ScriptCapitalL].  In our example, the resulting \
existential formula is:"
}], "BItem1"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Exists] \+\(a1, b1\)\)\+\(a1 + b1 = c\)\
\[LeftBracketingBar]a1\[RightBracketingBar] < 
          a \[And] \[LeftBracketingBar]b1\[RightBracketingBar] < \(\(b\)\(.\)\
\)\)], "DisplayFormula"],

Cell["\<\
Note that renaming of variables was done so that no naming conflict \
occurs.\
\>", "ContinueBItem1"],

Cell["\<\
In the course of using this technique in actual proofs, the \
technique will not only be applied to proof situations with ground literal \
goals but also in situations where the innermost formula of a goal is a \
literal, for example\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(a, b\)\[LeftBracketingBar]a + 
            b\[RightBracketingBar] < \(\(c\)\(.\)\)\)], "DisplayFormula"],

Cell["In this case, the goal will be reduced to", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(a, b\)\(\(\[Exists] \+\(a1, b1\)\)\+\(a1 \
+ b1 = c\)\(\[ForAll] \+\(a, b\)\[LeftBracketingBar]a1\[RightBracketingBar] < 
              a\)\) \[And] \[LeftBracketingBar]b1\[RightBracketingBar] < \
\(\(b\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
It is often helpful to reduce such a goal to the stronger \
goal\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Exists] \+\(a1, b1\)\)\+\(a1 + b1 = c\)\(\[ForAll] \
\+\(a, b\)\[LeftBracketingBar]a1\[RightBracketingBar] < 
            a\) \[And] \[LeftBracketingBar]b1\[RightBracketingBar] < \
\(\(b\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
because, by this, the goal is transformed into a \"solve problem\". \
In obtaining the stronger version was used the well\[Dash]known formula\
\>", \
"Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\)\+\
\[ScriptCapitalA]\(\(\[Exists] \+\(y\_1, \[Ellipsis], y\_m\)\)\+\
\[ScriptCapitalB] \[ScriptCapitalC] \[DoubleLeftArrow] \(\(\[Exists] \
\+\(y\_1, \[Ellipsis], y\_m\)\)\+\[ScriptCapitalB]\(\(\[ForAll] \+\(x\_1, \
\[Ellipsis], x\_n\)\)\+\[ScriptCapitalA] \[ScriptCapitalC]\)\)\)\)\(,\)\)\)], \
"DisplayFormula"],

Cell[TextData[{
  "where the free variables of \[ScriptCapitalA] are among ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  ", the free variables of \[ScriptCapitalB] are among ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1, \[Ellipsis], y\_m\)]],
  " and the free variables in  \[ScriptCapitalC] are among ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\_1, \[Ellipsis], x\_n\),
            "TraditionalForm"], ","}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1, \[Ellipsis], y\_m\)]],
  ". "
}], "Text"],

Cell["\<\
Note that in one semantic rewriting of a formula no syntactic \
rewriting is applied on the resulting formula even if this is possible. The \
syntactic rewriting will have to be applied in a later general rewriting \
step. It can also happen that semantic rewriting fails.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 4. 5.  Bookkeeping", "Subsection",
  CellTags->"c:25"],

Cell["\<\
The rules for rewriting goal and knowledge are not generated each \
time a general rewriting step is applied. They are stored in a global \
variable. At each application of a general  rewriting step, this variable is \
updated by adding rules for the assumptions for which they were not yet \
generated. Due to the use of labels of formulae, which are also inherited by \
the rewrite rules, it is easy to select from the big pool of inference rules \
at each rewriting step only the ones corresponding to the knowledge base of \
the current proof situation.\
\>", "Text"],

Cell["\<\
For preventing cycles or repetition of the same simplifications, we \
store the information about which formula was rewritten by which formula (we \
memorize their labels). As this information is dependent on the position of \
the proof situation within the proof object, it is stored together with each \
proof situation.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. 5.  Related Work", "Section",
  CellTags->"c:26"],

Cell["\<\
The main differences between general rewriting and standard \
rewriting are:\
\>", "Text"],

Cell["\<\
The formulae used for rewriting are not only equalities but also \
equivalences and implications. Hence the reductions we make are not always \
producing equivalent formulae.\
\>", "BItem1"],

Cell["\<\
In addition to syntactic rewriting we also make use of semantic \
rewriting. This feature makes  rewriting more powerful than the standard \
rewriting.\
\>", "BItem1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.  Solving in Natural Deduction Style", "Chapter",
  CellTags->{"sec:solving", "c:27"}],

Cell["\<\
Using natural deduction rules together with general rewriting had \
positive effects for the speed, ease, naturalness and readability of the \
proofs in specific domains generated by Theorema as compared to the proofs \
obtained by only using the predicate logic natural deduction rules. Still, \
for proofs of formulae involving alternating quantifiers as, for example, in \
elementary analysis, natural deduction together with rewriting is not yet \
sufficient. The strategy developed in Theorema in generating these proofs \
involved significant user interaction for inventing \"solving terms\" at \
crucial moments in the process of proof generation.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Decomposition Strategy for Proving Goals Involving \
Alternating Quantifiers). ",
    FontWeight->"Bold"],
  " Suppose we have in the knowledge base the continuity definition"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<continuity\>\"", ",", \(any[f, x]\), ",", GridBox[{
            {\(continuous[f, 
                  x]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\[Epsilon]\)\+\
\(\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \
\+y\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - f[x]\[RightBracketingBar] < \[Epsilon]\)\)\)\), 
              "\"\<cont\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"continuity "],

Cell["and the goal to be proved is", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<sum continuity\>\"", ",", \(any[f, g, x]\), ",", GridBox[{
              {\((\((continuous[f, x] \[And] 
                        continuous[g, x])\)\n\t\[DoubleLongRightArrow]
                    continuous[f + g, x])\), "\"\<cont+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "."}]], "Input",
  CellTags->"sum continuity"],

Cell["\<\
This type of proof was approached in Theorema, when using only \
natural deduction rules and rewriting, by decomposing the definition into \
intermediate definitions having one quantifier less. For this example the \
following definitions were generated:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity 2-ary\>\"", ",", \(any[f, x]\), ",", GridBox[{
              {\(continuous[f, 
                    x]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\[Epsilon]\)\
\+\(\[Epsilon] > 0\)continuous[f, x, \[Epsilon]]\)\), "\"\<cont2\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->{"continuity 2-ary", "continuity 3-ary", "continuity 4-ary"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity 3-ary\>\"", ",", \(any[f, x, \[Epsilon]]\), ",", 
          GridBox[{
              {\(continuous[f, 
                    x, \[Epsilon]]\[DoubleLongLeftRightArrow]\(\(\[Exists] \+\
\[Delta]\)\+\(\[Delta] > 0\)continuous[f, x, \[Epsilon], \[Delta]]\)\), 
                "\"\<cont3\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity 4-ary\>\"", ",", \(any[f, x, \[Epsilon], \[Delta]]\), 
          ",", GridBox[{
              {\(continuous[f, 
                    x, \[Epsilon], \[Delta]]\[DoubleLongLeftRightArrow]\(\(\
\[ForAll] \+y\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \
\[Delta]\)\[LeftBracketingBar]f[y] - 
                          f[x]\[RightBracketingBar] < \[Epsilon]\)\), 
                "\"\<cont4\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "."}]], "Input"],

Cell["\<\
After the definition decomposition, the user had to invent suitable \
intermediate propositions for each level starting from the lowest one. For \
this example, suitable propositions could be:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<4-ary continuity\>\"", 
          ",", \(any[f, x, \[Epsilon]1, \[Delta]1, 
            g, \[Epsilon]2, \[Delta]2]\), ",", GridBox[{
              {\(\((continuous[f, 
                        x, \[Epsilon]1, \[Delta]1] \[And] \
\[IndentingNewLine]continuous[g, x, \[Epsilon]2, \[Delta]2])\) \[Implies] \n\t
                  continuous[f + g, x, \[Epsilon]1 + \[Epsilon]2, 
                    min[\[Delta]1, \[Delta]2]]\), "\"\<cont4:+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"2-ary continuity", "3-ary continuity", "4-ary continuity"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<3-ary continuity\>\"", 
          ",", \(any[f, x, \[Epsilon]1, g, \[Epsilon]2]\), ",", GridBox[{
              {\(\((continuous[f, 
                        x, \[Epsilon]1] \[And] \[IndentingNewLine]continuous[
                        g, x, \[Epsilon]2])\) \[Implies] \n\t
                  continuous[f + g, x, \[Epsilon]1 + \[Epsilon]2]\), 
                "\"\<cont3:+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  LimitsPositioningTokens->{}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<2-ary continuity\>\"", ",", \(any[f, g, x]\), ",", GridBox[{
              {\((\((continuous[f, x] \[And] 
                        continuous[g, x])\)\n\t\[DoubleLongRightArrow]
                    continuous[f + g, x])\), "\"\<cont2:+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  LimitsPositioningTokens->{}],

Cell["\<\
Note that, at this point, solving terms are invented (minimum of \
deltas and sum of epsilons). Once the intermediate propositions were given by \
the user, he can call Theorema to prove first the lowest level one \
(\"4\[Dash]ary continuity\"), then add this property to the knowledge base \
and prove the proposition one level up, and so on until the initial \
proposition is proved. We will show the proofs of these propositions, \
automatically generated by Theorema, in  Section 8.1.1.1.   \
\[EmptySquare]\
\>", "Text"],

Cell[TextData[{
  "The difficulty in generating proofs involving alternating quantifiers by \
just natural deduction and rewriting consists in finding good \"solving terms\
\". In fact, ",
  "semantic",
  " rewriting has the effect that prove problems are reduced to solve \
problems in a natural way. Thus, adding solvers was the next natural step to \
do. Actually, having a common frame for proving, solving and computing was \
one of the initial general goals of Theorema, see ",
  ButtonBox["[18]",
    ButtonData:>"Buchb:96c",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1996, Proving, Solving, Computing"],
  ", ",
  ButtonBox["[23]",
    ButtonData:>"Buchb_al:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and T. Jebelean and F. Kriftner and M. Marin and E. \
Tomuta and D. Vasaru, 19 ..."],
  ". Also, research on solvers for special domains has a long tradition in \
our institute and some of this work is now available as Mathematica functions \
in Mathematica Version 3 and 4: Buchberger's Groebner Bases method (see ",
  ButtonBox["[15]",
    ButtonData:>"Buchb:70",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1970, An Algorithmical Criterion for the Solvability of \
Algebraic Systems o ..."],
  "), Collins' Cylindrical Algebraic Decomposition method for real closed \
fields (see ",
  ButtonBox["[37]",
    ButtonData:>"Collins:75",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. E. Collins, 1975, Quantifier Elimination for Real Closed Fields by \
Cylindrical Algebrai ..."],
  ", ",
  ButtonBox["[86]",
    ButtonData:>"Strzebonski:99",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "A. Strzebonski, 1999, Solving Equations and Inequalities with \
Mathematica"],
  ") and the Gosper\[Dash]Zeilberger method for combinatorial identities with \
the extension of Paule\[Dash]Schorn (see ",
  ButtonBox["[99]",
    ButtonData:>"Zeilberger:90",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "D. Zeilberger, 1990, A Holonomic Systems Approach to Special Function \
Identities"],
  ", ",
  ButtonBox["[77]",
    ButtonData:>"Paule_Schorn:95",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "P. Paule and M. Schorn, 1995, A Mathematica Version of Zeilberger's \
Algorithm for Proving  ..."],
  "). For our work, we were mainly interested in Collins' cad\[Dash]method as \
the solving subproblems arising from proofs with alternating quantifiers were \
mainly over reals."
}], "Text"],

Cell["\<\
Thus, we developed a set of general solving natural deduction rules \
that can be applied in two ways: either to reduce a solving problem to a \
problem that can be solved by Collins' cad-method or can be used to simplify \
general solve problems.\
\>", "Text"],

Cell[CellGroupData[{

Cell["4. 1.  General Solving Inference Rules", "Section",
  CellTags->{"sec:gsr", "c:28"}],

Cell[TextData[{
  "We introduce a new type of constants, namely the \
\"solve\[Dash]constants\". The solve\[Dash]constants will always be marked by \
a '*' superscript: ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^*\)\)]],
  ". They are in some sense similar to the metavariables used in other \
systems. Let ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalL]\_Th\%*\)\)]],
  " be the language ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_Th\)]],
  " extended by the solve\[Dash]constants. We extend the notions of terms, \
formulae,  instances, substitutions over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalL]\_Th\%*\)\)]],
  " appropriately. For the rest of this section formulae over ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_Th\)]],
  " will be called \"p\[Dash]formulae\" (from \"prove formulae\") and the \
ones over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalL]\_Th\%*\) - \[ScriptCapitalL]\_Th\
\)]],
  " \"s\[Dash]formulae\" (from \"solve formulae\")."
}], "Text"],

Cell["\<\
According to whether the goal is a p\[Dash]formula or an \
s\[Dash]formula, the proof situations are classified in \
\"p\[Dash]proof\[Dash]situations\" and \"s\[Dash]proof\[Dash]situations\". We \
say that proof generation entered a \"solve mode\" when the current proof\
\[Dash]situation is an s\[Dash]proof\[Dash]situation and we say the proof is \
in a \"prove mode\" otherwise. Typically, proof generation will go through \
several cycles of prove/solve modes. The interpretation of an s\[Dash]proof\
\[Dash]situation is: solve the goal under the given knowledge. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Definition (Solve).", "TB"],
  StyleBox[" Let \[ScriptCapitalF] be a closed s\[Dash]formula and let ", 
    "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " be the solve\[Dash]constants occurring in \[ScriptCapitalF]. We say that \
\[ScriptCapitalF]  is \"solvable under a knowledge \[ScriptCapitalK]\" if \
there exists terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_Th\)]],
  " such that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[ScriptCapitalF]", "[", 
          RowBox[{
            RowBox[{
              FormBox[\(x\_1\%*\),
                "TraditionalForm"], 
              "\[LeftArrow]", \(\[ScriptCapitalT]\_1\)}], ",", "\[Ellipsis]", 
            ",", 
            RowBox[{
              FormBox[\(x\_n\%*\),
                "TraditionalForm"], 
              "\[LeftArrow]", \(\[ScriptCapitalT]\_n\)}]}], "]"}], 
        TraditionalForm]]],
  " holds under \[ScriptCapitalK]. (We call ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " \"solving terms for \[ScriptCapitalF]  with respect to ",
  StyleBox[" ", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " under \[ScriptCapitalK]\".)"
}], "Definition"],

Cell["\<\
We say that \[ScriptCapitalF] was \"constructively\" solved if we \
found explicit solving terms for \[ScriptCapitalF] under \[ScriptCapitalK] \
and \"unconstructively\" solved if we do not have such terms but their \
existence was proved by some unconstructive black\[Dash]box solver/prover. In \
our system we will have a mixture of this two types of solving, namely we \
will try to give explicit solving terms as much as possible but we will be \
satisfied also with a proof of their existence.\
\>", "Text"],

Cell["\<\
Once the new type of constants are introduced, we have to define \
inference rules for dealing with them. All inference rules for proving \
existential formulae apply also in the case of unconstructively solving a \
formula.  In particular, also syntactic general rewriting is applicable. In \
the following we give inference rules for:\
\>", "Text"],

Cell["introducing solve\[Dash]constants,", "BItem1"],

Cell["\<\
simplifying goals containing solve\[Dash]constants,\
\>", "BItem1"],

Cell["\<\
partial and complete solving of goals containing \
solve\[Dash]constants (eliminating solve\[Dash]constants).\
\>", "BItem1"],

Cell["\<\
We have no inference rules acting on knowledge because, due to the \
way we apply the inference rules, the solve\[Dash]constants will appear only \
in the goal.\
\>", "Text"],

Cell["\<\
We make the following convention: Proving a formula \
\[ScriptCapitalG] whose type, p\[Dash]formula or s\[Dash]formula, is not \
specified means either proving \[ScriptCapitalG] if \[ScriptCapitalG] is a p\
\[Dash]formula or solving \[ScriptCapitalG] if \[ScriptCapitalG] is a \
s\[Dash]formula.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
4. 1. 1.  Rules for Introducing Solve\[Dash]Constants\
\>", \
"Subsection",
  CellTags->"c:29"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.1",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Reduce Existential Formulae to Solving). ",
    FontWeight->"Bold"],
  " For proving closed formula  \[ScriptCapitalG] of the form"
}], "InferenceRule",
  CellTags->"r:prex"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Exists] \+\(x\_1, \[Ellipsis], x\_n\)\
\[ScriptCapitalF]\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "introduce new solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " and solve s\[Dash]formula  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF][
        x\_1 \[LeftArrow] \(x\_1\%*\), \[Ellipsis], 
        x\_n \[LeftArrow] \(x\_n\%*\)]\)]],
  "."
}], "Text"],

Cell["\<\
The correctness of the rule follows from the definition of solving.\
\
\>", "ProofBegin"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. 1. 2.  Rules for Simplifying Goals with \
Solve\[Dash]Constants\
\>", "Subsection",
  CellTags->"c:30"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.2",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Pushing Universal Quantifiers Inside). ",
    FontWeight->"Bold"],
  "For solving s\[Dash]formula \[ScriptCapitalG] containing \
s\[Dash]subformula \[ScriptCapitalS] of positive polarity of the form"
}], "InferenceRule",
  CellTags->"r:push"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\
\[ScriptCapitalA] \[Implies] \[ScriptCapitalB] \[And] \
\[ScriptCapitalC])\)\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "where none of the variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  " occurs free in \[ScriptCapitalB], it is sufficient to solve \
s\[Dash]formula  "
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptCapitalG][\(\[ScriptCapitalS]\^+\) \
\[LeftArrow] \((\[ScriptCapitalB] \[And] \[ForAll] \+\(x\_1, \[Ellipsis], \
x\_n\)\((\[ScriptCapitalA] \[Implies] \[ScriptCapitalC])\))\)]\)\(.\)\)\)], \
"DisplayFormula"],

Cell["\<\
The correctness of the rule follows from Rule 3.2 for rewriting \
using implications and the well\[Dash]known rule:\
\>", "ProofBegin"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\((\[ScriptCapitalB] \[And] \[ForAll] \+\(x\_1, \
\[Ellipsis], x\_n\)\((\[ScriptCapitalA] \[Implies] \[ScriptCapitalC])\))\) \
\[Implies] \[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \
\[Implies] \[ScriptCapitalB] \[And] \[ScriptCapitalC])\)\)\(,\)\)\)], \
"DisplayFormula"],

Cell[TextData[{
  "where \[ScriptCapitalB] is a closed formula and the free variables of \
\[ScriptCapitalA] and \[ScriptCapitalC] are among ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.3",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Subformula is Assumption).",
    FontWeight->"Bold"],
  "  For solving the closed s\[Dash]formula \[ScriptCapitalG] under the \
knowledge that the closed p\[Dash]formula \[ScriptCapitalA] holds and \
\[ScriptCapitalA] occurs in \[ScriptCapitalG] as a subformula, it is \
sufficient to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG][\[ScriptCapitalA] \[LeftArrow] 
          True]\)]],
  "."
}], "InferenceRule",
  CellTags->"r:subf-as"],

Cell[TextData[{
  "The correctness of the rule follows from Rule 3.2 using as equivalence for \
rewriting ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] \[DoubleLeftRightArrow] True\)]],
  ". "
}], "ProofBegin"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.4",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Split into Independent Subproblems).",
    FontWeight->"Bold"],
  " For solving the closed s\[Dash]formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\)]],
  " of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] \[And] \[ScriptCapitalB]\)]],
  ", where the solve\[Dash]constants of \[ScriptCapitalA] are disjunct to the \
solve\[Dash]constants of \[ScriptCapitalB], it is sufficient to solve \
\[ScriptCapitalA] and to solve \[ScriptCapitalB]."
}], "InferenceRule",
  CellTags->"r:isub"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. 1. 3.  Rules for Eliminating Solve\[Dash]Constants \
(Solving)\
\>", "Subsection",
  CellTags->"c:31"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.5",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Solve by Matching with Assumption). ",
    FontWeight->"Bold"],
  " Suppose we have in the knowledge base a closed p\[Dash]formula \
\[ScriptCapitalA]. If \[ScriptCapitalG] is a closed s\[Dash]formula \
containing a positive occurrence ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalS]\^+\)\)]],
  " of an s\[Dash]subformula with the solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " for which there exists ground terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " in \[ScriptCapitalL] such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS][\(x\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_n]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\)]],
  ", then, for solving \[ScriptCapitalG] it is sufficient to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalG][\(x\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_n]\)[\(\[ScriptCapitalA]\^+\) \[LeftArrow] True]\)]],
  "."
}], "InferenceRule",
  CellTags->"r:match-asm"],

Cell["\<\
The correctness of the rule follows from observing that the formula\
\
\>", "ProofBegin"],

Cell[BoxData[
    \(TraditionalForm\`\((\[Exists] \+\(x\_1, \[Ellipsis], x\_n, y\_1, \
\[Ellipsis], y\_m\)\[ScriptCapitalG])\) \[DoubleLeftArrow] \((\ \[Exists] \
\+\(y\_1, \[Ellipsis], y\_m\)\[ScriptCapitalG][
            x\_1 \[LeftArrow] \[ScriptCapitalT]\_1, \[Ellipsis], 
            x\_n \[LeftArrow] \[ScriptCapitalT]\_n])\)\)], "DisplayFormula",
  CellFrameLabels->{{None, "(*)"}, {None, None}}],

Cell[TextData[{
  "holds, if the free variables of \[ScriptCapitalG] are among ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n, \ y\_1, \[Ellipsis], 
      y\_m\)]],
  " and the ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " are ground terms, and also"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\((\[Exists] \+\(y\_1, \[Ellipsis], y\_m\)\
\[ScriptCapitalF])\) \[DoubleLeftArrow] \((\[ScriptCapitalA] \[And] \[Exists] \
\+\(y\_1, \[Ellipsis], y\_m\)\[ScriptCapitalF][\[ScriptCapitalA] \[LeftArrow] 
                True])\)\)], "DisplayFormula"],

Cell[TextData[{
  "holds, if the free variables of \[ScriptCapitalF] are among ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1, \[Ellipsis], y\_m\)]],
  " and \[ScriptCapitalA] is a closed formula.  \[EmptySquare]"
}], "Text"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.6",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Solve by Matching with Right\[Dash]hand Side of Assumed \
Implication). ",
    FontWeight->"Bold"],
  " Suppose we have in the knowledge base the closed p\[Dash]formula"
}], "InferenceRule",
  CellTags->"r:match-impl"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ForAll] \+\(y\_1, \[Ellipsis], y\_m\)\((\
\[ScriptCapitalB] \[DoubleLeftArrow] \[ScriptCapitalA])\)\)\(,\)\)\)], \
"DisplayFormula"],

Cell[TextData[{
  "where the free variables of \[ScriptCapitalA] are among the free variables \
of \[ScriptCapitalB]. Let \[ScriptCapitalG] is a closed s\[Dash]formula \
containing a positive occurrence ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalS]\^+\)\)]],
  " of an s\[Dash]subformula with the solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ". If there exists ground terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " in \[ScriptCapitalL] and a substitution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = {y\_1 \[Rule] \[ScriptCapitalS]\_1, \
\[Ellipsis], y\_m \[Rule] \[ScriptCapitalS]\_m}\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS][\(x\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\[Sigma]\)]],
  " are identical, then, for solving \[ScriptCapitalG] it is sufficient to \
solve ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG][\(x\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_n])\)[\(\[ScriptCapitalB]\[Sigma]\^+\) \[LeftArrow] \[ScriptCapitalA]\
\[Sigma]]\)]],
  "."
}], "Text"],

Cell["\<\
The correctness of the rule follows by similar arguments as the \
previous one, by using (*) and the implication\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\((\[Exists] \+\(y\_1, \[Ellipsis], y\_m\)\
\[ScriptCapitalF])\) \[DoubleLeftArrow] \((\((\[ScriptCapitalB] \
\[DoubleLeftArrow] \[ScriptCapitalA])\) \[And] \[Exists] \+\(y\_1, \
\[Ellipsis], y\_m\)\[ScriptCapitalF][\[ScriptCapitalB] \[LeftArrow] \
\[ScriptCapitalA]])\)\)], "DisplayFormula"],

Cell[TextData[{
  "which holds if the free variables of \[ScriptCapitalF] are among ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1, \[Ellipsis], y\_m\)]],
  " and \[ScriptCapitalB] \[DoubleLeftArrow] \[ScriptCapitalA] is a closed \
formula. \[EmptySquare]"
}], "Text"],

Cell["\<\
We give an example showing the use of this rule. (The example is \
taken from the proof of convergency of the sum of sequences.) Suppose the \
goal \[ScriptCapitalG] to be solved is\
\>", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\((y\_0\%\("*"\) + t\_0\%\("*"\) = a\_2\%\("*"\))\), "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ">", "0"}], "\[Implies]", 
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["\[Epsilon]2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["\[Delta]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          StyleBox["\[Epsilon]2",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "=", 
                        StyleBox["\[Epsilon]",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "\[And]", 
                    RowBox[{
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["n",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], " "}]], 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["n",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "\[GreaterEqual]", 
                            StyleBox["N",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "\[Implies]", 
                          RowBox[{
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox[\(f\_0\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "[", 
                                    StyleBox["n",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], 
                                  "-", \(y\_0\%\("*"\)\)}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Delta]",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[And]", 
                            RowBox[{
                              RowBox[{"\[LeftBracketingBar]", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox[\(g\_0\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "[", 
                                    StyleBox["n",
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "]"}], 
                                  "-", \(t\_0\%\("*"\)\)}], 
                                "\[RightBracketingBar]"}], "<", 
                              StyleBox["\[Epsilon]2",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}]}], ")"}]}]}], ")"}]}]}],
             ")"}]}]}], TraditionalForm]], "DisplayFormula"],

Cell["and in the knowledge base we have ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            StyleBox[",",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox["n",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "-", 
                      StyleBox[\(a\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "\[DoubleLeftArrow]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ">", "0"}], "\[And]", 
                  RowBox[{
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[GreaterEqual]", 
                    RowBox[{
                      StyleBox[\(N\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox["\[Epsilon]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}]}]}], ")"}]}], ")"}], "."}]}],
       TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "Note that Rule 4.6 is applicable: take ",
  Cell[BoxData[
      \(TraditionalForm\`y\_0\%\("*"\)\)]],
  " to be ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], TraditionalForm]]],
  " and consider the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Epsilon] \[Rule] \[Delta], \ n \[Rule] n}\)]],
  ". Hence, for solving \[ScriptCapitalG] it is sufficient to solve"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", \(t\_0\%\("*"\)\)}], 
            "=", \(a\_2\%\("*"\)\)}], ")"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["\[Epsilon]2",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["N",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "+", 
                            StyleBox["\[Epsilon]2",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}], "\[And]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{
                                StyleBox["\[Delta]",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], ">", "0"}], "\[And]", 
                              RowBox[{
                                StyleBox["n",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "\[GreaterEqual]", 
                                RowBox[{
                                  StyleBox[\(N\_0\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "[", 
                                  StyleBox["\[Delta]",
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "]"}]}], "\[And]", 
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(g\_0\),
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "[", 
                                      StyleBox["n",
                                        FontWeight->"Plain",
                                        FontSlant->"Italic",
                                        Background->None], "]"}], 
                                    "-", \(t\_0\%\("*"\)\)}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Epsilon]2",
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], "."}]}]}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.7",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Solve Universal Implications by Matching Sides). ",
    FontWeight->"Bold"],
  "Let us consider the closed s-formula \[ScriptCapitalG] that has a closed s\
\[Dash]subformula \[ScriptCapitalS] of positive polarity "
}], "InferenceRule",
  CellTags->"r:univ-impl"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\
\[ScriptCapitalA] \[Implies] \[ScriptCapitalB])\)\)], "DisplayFormula"],

Cell[TextData[{
  "where, \[ScriptCapitalA] contains the solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_1\%*\), \[Ellipsis], \(y\_m\%*\)\)]],
  ", and there exists ground terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_m\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL]\_Th\)]],
  " not containing any of the solve\[Dash]constants  ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_1\%*\), \[Ellipsis], \(y\_m\%*\)\)]],
  ", such that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA][\(y\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(y\_m\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_m]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\)]],
  ". Then, for proving \[ScriptCapitalG], it suffices to prove ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG][\(\[ScriptCapitalS]\^+\) \
\[LeftArrow] \((\(y\_1\%*\) = \(\[ScriptCapitalT]\_1 \[And] \[Ellipsis] \
\[And] \(y\_m\%*\) = \[ScriptCapitalT]\_m\))\)]\)]],
  "."
}], "Text"],

Cell["The correctness of the rule follows from  Rule 3.2 and", "ProofBegin"],

Cell[BoxData[
    \(TraditionalForm\`\((\(y\_1\%*\) = \(\[ScriptCapitalT]\_1 \[And] \
\[Ellipsis] \[And] \(y\_m\%*\) = \[ScriptCapitalT]\_m\))\) \[Implies] \
\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\[ScriptCapitalA] \[Implies] \
\[ScriptCapitalB])\) . \ \ \ \[EmptySquare]\)], "DisplayFormula"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.8",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Apply Solution). ",
    FontWeight->"Bold"],
  "For solving the closed s\[Dash]formula \[ScriptCapitalG] of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] \[And] \((\(x\_n\%*\) = \
\[ScriptCapitalT])\)\)]],
  ", where the term \[ScriptCapitalT] does not contain any occurrence of ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_n\%*\)\)]],
  ", it suffices to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA][\(x\_n\%*\) \[LeftArrow] \
\[ScriptCapitalT]]\)]],
  "."
}], "InferenceRule",
  CellTags->"r:apply"],

Cell["The correctness of the rule follows from (*).", "ProofBegin"],

Cell[TextData[{
  StyleBox["Rule",
    FontWeight->"Bold"],
  " ",
  StyleBox["4.9",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Solve Subproblem). ",
    FontWeight->"Bold"],
  "Let \[ScriptCapitalG] be a closed s-formula of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA] \[And] \[ScriptCapitalB]\)]],
  ", where \[ScriptCapitalA] contains the solve\[Dash]constants  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ", and \[ScriptCapitalB] contains some other solve\[Dash]constants which \
are not among ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " are solving terms for \[ScriptCapitalA],  in order to solve \
\[ScriptCapitalG] it suffices to solve ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalB]\ [\(x\_1\%*\) \[LeftArrow] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] \[ScriptCapitalT]\
\_n]\)]],
  "."
}], "InferenceRule",
  CellTags->"r:ssub"],

Cell["\<\
The correctness of the rule follows from (*) and Rule  4.5.  \
\[EmptySquare]\
\>", "ProofBegin"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. 2.  Using Special Solvers", "Section",
  CellTags->"c:32"],

Cell["\<\
The inference rules we gave can bring a solving problem to a \
simpler form and, in some easy cases, may even solve it. A more systematic \
general predicate logic solver is currently worked out in a different \
subproject of Theorema. (For example, a general resolution prover may always \
be applied here.)  However, in the context of special theories one can apply \
a stronger solver. As a general strategy one can try to  split the solving \
problem into independent subproblems and call a suitable special solver for \
each of the subproblems. When the special solvers are not implemented in \
Theorema, this procedure requires three phases: \
\>", "Text"],

Cell["\<\
Identify a suitable solving subproblem and translate it into a \
format acceptable by the special solver.\
\>", "BItem1"],

Cell["Call the solver for the subproblem.", "BItem1"],

Cell["\<\
Translate the solver's result and use it for simplifying the \
initial solve problem.\
\>", "BItem1"],

Cell["\<\
We integrated into Theorema a special solver for reals which is \
implemented in Mathematica. At first we wanted to use the implementation in \
Mathematica of Collins' cad\[Dash]method. However, the Mathematica function \
does not solve a formula with respect to some given assumptions (which is the \
type of solving problems we have), it does not accept parameters and it only \
works with quantifier\[Dash]free formulae. Hence, one would need to do some \
complicated preprocessing of the problem and postprocessing of the result in \
order to extract the solution. However, one can still make use of the cad\
\[Dash]method implementation by using the function FullSimplify in \
Mathematica. Namely, if the variables are declared to be reals, than \
FullSimplify will use internally the cad\[Dash]method. The advantage of using \
FullSimplify is that it accepts also additional assumptions.\
\>", "Text"],

Cell[TextData[{
  "Due to the restricted Mathematica implementation of the cad method, we \
will only call the special solver when the goal is a quantifier\[Dash]free s\
\[Dash]formula. However, as soon as we have available a better implementation \
of the cad\[Dash]method in Mathematica or even in another system we can drop \
the restriction. In fact, in a different subproject of Theorema, work is \
being done to integrate QEPCAD, an implementation in C++ of an improved \
version of the cad\[Dash]method by Hong (",
  ButtonBox["[38]",
    ButtonData:>"Collins_Hong:91",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "G. E. Collins and H. Hong, 1991, Partial Cylindrical Algebraic \
Decomposition for Quantifie ..."],
  "), within the system."
}], "Text"],

Cell[CellGroupData[{

Cell["4. 2. 1.  Identify Subproblem and Translate", "Subsection",
  CellTags->{"sec:id-subp", "c:33"}],

Cell["\<\
Given an s\[Dash]proof situation (\[ScriptCapitalG],\
\[ScriptCapitalK]) where \[ScriptCapitalG] is a quantifier\[Dash]free formula \
in conjunctive form containing solve\[Dash]constants ranging over reals, we \
identify suitable subproblems over the reals and translate them into problems \
solvable by the Mathematica function FullSimplify. We will describe the steps \
we do in parallel with an example.\
\>", "Text"],

Cell["Let us consider that the goal to be proved is ", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{\(\(\[Delta]\_3\%*\)\^\*"\<\"\"\>"\), "*", 
                  RowBox[{"(", 
                    RowBox[{\(\[Epsilon]\_1\%*\), "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox[\(x\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "\[RightBracketingBar]"}], 
                  "*", \(\[Epsilon]\_1\%*\)}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          "\[And]", \(\(\[Delta]\_3\%*\) > 0\), 
          "\[And]", \(\(\[Epsilon]\_1\%*\) > 0\), 
          "\[And]", \(\[Delta]\_2\%*\)}], 
        "=", \(max[\[Delta]\_0[\(\[Epsilon]\_1\%*\)], \
\[Delta]\_1[\(\[Delta]\_3\%*\)]]\)}], TraditionalForm]], "DisplayFormula"],

Cell["and the knowledge contains as ground formulae", "Text"],

Cell[BoxData[{
    FormBox[
      RowBox[{\(continuous[f\_0, 
          x\_0], \[IndentingNewLine]continuous[g\_0, y\_0]\ \ \ \ and\), 
        " "}], TraditionalForm], "\n", 
    FormBox[
      RowBox[{" ", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ">", "0"}]}], 
      TraditionalForm]}], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`g\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_1\)]],
  ", max  are constant real functions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_0\)]],
  " is a real constant and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\_3\%*\)\^\*"\<\"\"\>"\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_1\%*\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\_2\%*\)\)]],
  " are real solve\[Dash]constants. The steps we do for identifying a \
subproblem over the reals and translating it to a problem solvable by \
FullSimplify are:"
}], "Text"],

Cell[TextData[{
  "Rearrange \[ScriptCapitalG] to the equivalent form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad \[And] \
\[ScriptCapitalG]\_rest\)]],
  ", where: "
}], "ContinueBItem1",
  CellDingbat->"1."],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " is obtained by grouping all conjuncts of \[ScriptCapitalG] which are \
logical combinations of polynomial equalities and inequalities in the solve\
\[Dash]constants of type real. Let ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " be the solve\[Dash]constants of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  "."
}], "BItem2"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_rest\)]],
  " contains the remaining \[ScriptCapitalG] conjuncts."
}], "BItem2"],

Cell[TextData[{
  "In our example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_rest\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\_2\%*\) = 
        max[\[Delta]\_0[\(\[Epsilon]\_1\%*\)], \
\[Delta]\_1[\(\[Delta]\_3\%*\)]]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " is"
}], "ContinueBItem1"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{\(\(\[Delta]\_3\%*\)\^\*"\<\"\"\>"\), "*", 
                RowBox[{"(", 
                  RowBox[{\(\[Epsilon]\_1\%*\), "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox[\(x\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "\[RightBracketingBar]"}],
                     "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "\[RightBracketingBar]"}], 
                "*", \(\[Epsilon]\_1\%*\)}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], 
        "\[And]", \(\(\[Delta]\_3\%*\) > 0\), 
        "\[And]", \(\(\[Epsilon]\_1\%*\) > 0. \)}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "(Note that a conjunct of  the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            FormBox[\(\(\[Epsilon]\_1\%*\) + f\_0[x\_0]\),
              "TraditionalForm"], "\[RightBracketingBar]"}], ">", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], TraditionalForm]]],
  " will not be selected in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " as it is neither a polynomial equality nor a polynomial inequality in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\_1\%*\)\)]],
  ".) "
}], "ContinueBItem1"],

Cell[TextData[{
  "Replace all constant terms in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " which are not plain constants by new constants and construct the \
knowledge ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\^\[FivePointedStar]\)]],
  " by adding to \[ScriptCapitalK] the corresponding equalities between the \
newly introduced constants and the terms they replaced. Add also to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalK]\^*\)\)]],
  " any other formulae needed to keep ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalK]\^*\)\)]],
  " equivalent to \[ScriptCapitalK] (formulae describing relations between \
the newly introduced constants, or between the newly introduced constants and \
the constants present in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  "). In the example, the new ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " is"
}], "ContinueBItem1",
  CellDingbat->"2."],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"(", 
          
          RowBox[{\(\(\[Delta]\_3\%*\)\^\*"\<\"\"\>"*\((\(\[Epsilon]\_1\%*\) \
+ b + 1)\) + a*\(\[Epsilon]\_1\%*\)\), "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], 
        "\[And]", \(\(\[Delta]\_3\%*\) > 0\), 
        "\[And]", \(\(\[Epsilon]\_1\%*\) > 0\)}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\^\[FivePointedStar]\)]],
  " is obtained by adding to \[ScriptCapitalK] the new assumptions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "\[RightBracketingBar]"}]}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"b", "=", 
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "\[RightBracketingBar]"}]}], 
        TraditionalForm]]],
  ". (Note that, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " contained also a subterm ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "[", 
            StyleBox[\(x\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "]"}], "+", "1"}], TraditionalForm]]],
  ", then a new constant ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " would be introduced for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "[", 
          StyleBox[\(x\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "]"}], TraditionalForm]]],
  " with the corresponding new assumptions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "[", 
          StyleBox[\(x\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "]"}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a = \[LeftBracketingBar]c\[RightBracketingBar]\)]],
  ".)"
}], "ContinueBItem1"],

Cell[TextData[{
  "Select from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\^\[FivePointedStar]\)]],
  " all the ground formulae involving the constants occurring in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " which are logical combinations of polynomial equalities and inequalities \
over the reals and consider their conjunction ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad\)]],
  ". For each newly introduced constant in step 2, if it is possible to \
deduce their sign then add the corresponding inequalities to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad\)]],
  ". In the example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad\)]],
  " will contain after the first selection the assumption  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], ">", "0"}]]],
  ", and then ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterEqual] 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b \[GreaterEqual] 0\)]],
  " will be added to it."
}], "ContinueBItem1",
  CellDingbat->"3."],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " be"
}], "ContinueBItem1",
  CellDingbat->"4."],

Cell[BoxData[
    \(TraditionalForm\`\[Exists] \+\(x\_1, \[Ellipsis], x\_n\)\
\[ScriptCapitalG]\_cad[\(x\_1\%*\) \[LeftArrow] 
          x\_1, \[Ellipsis], \(x\_n\%*\) \[LeftArrow] 
          x\_n]\)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  " are new variables. In the example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " is "
}], "ContinueBItem1"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Exists] \+\(x, y\)\), 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(y\^\*"\<\"\"\>"*\((x + b + 1)\) + a*x\), "=", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "\[And]", \(y > 0\), 
              "\[And]", \(x > 0\)}], ")"}], "."}]}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "Construct ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_f\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad\)]],
  " by adding the type information that each constant and variable is real (\
\[EmptySquare]\[Element]Reals). Call the FullSimplify function for ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_f\)]],
  ". For the example, FullSimplify function will be called as follows:"
}], "ContinueBItem1",
  CellDingbat->"5."],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[\[Exists] \_\({x, y}, x \[Element] Reals \[And] y \
\[Element] Reals\)\((x \((y + b + 1)\) + a\ y == \[Epsilon]\_0 \[And] 
            x > 0 \[And] 
            y > 0)\), \[IndentingNewLine]\[Epsilon]\_0 \[Element] 
          Reals \[And] b \[Element] Reals \[And] 
        a \[Element] Reals\  \[And] \[Epsilon]\_0 > 0 \[And] 
        a \[GreaterEqual] 0 \[And] b \[GreaterEqual] 0, 
      ComplexityFunction -> EliminateQuantifiers]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
where the Complexity Function we use returns 0 for all quantifier \
free formulae and 1 for the others (without the use of this complexity \
function FullSimplify does not always work). Hence, we know that a solution \
of the subproblem exists.  \
\>", "ContinueBItem1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. 2. 2.  Interpreting the Result", "Subsection",
  CellTags->"c:34"],

Cell[TextData[{
  "Let \[ScriptCapitalA] be the formula returned by FullSimplify. \
\[ScriptCapitalA] will either be the initial formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " or a quantifier\[Dash]free (i.e. solve\[Dash]constant free) formula \
equivalent with ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  ". Depending on \[ScriptCapitalA] and the initial proof situation (\
\[ScriptCapitalG],\[ScriptCapitalK]) we either report failure in using the \
special prover or we construct a proof situation which is a simplified \
version of (\[ScriptCapitalG],\[ScriptCapitalK])."
}], "Text"],

Cell["The cases for which we report failure are the following:", "Text"],

Cell[TextData[{
  "No simplification happened, i.e. \[ScriptCapitalA] is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  "."
}], "BItem1"],

Cell["\<\
The simplification returned False, i.e. \[ScriptCapitalA] is the \
constant False: In this case, the goal is unsolvable hence the whole proof \
situation can be disproved. As we do not yet work with disproved values in \
Theorema, we will just report failure of the proof.\
\>", "BItem1"],

Cell[TextData[{
  "Formula \[ScriptCapitalA] is not the constant True and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_rest\)]],
  " is not solved with respect to the solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ". (We say that \[ScriptCapitalF] is solved with respect to the \
solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " if either \[ScriptCapitalF] is a p-formula or by substituting any values \
for the ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  " into ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalF]\)]],
  ", the resulting formula can be immediately solved for all the \
solve\[Dash]constants. For example, a formula ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^*\) = 
        f[\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)]\)]],
  " is solved while a formula A[",
  Cell[BoxData[
      \(TraditionalForm\`\(y\^*\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  "] is not yet solved with respect to the solve\[Dash]constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ".) We did not treat yet this case as it did not yet appear in the proofs \
we were doing. In the further development of Theorema we will extend the \
cooperation between provers and solvers."
}], "BItem1"],

Cell["\<\
In all other cases, we construct the new proof situation  as \
follows:\
\>", "Text"],

Cell[TextData[{
  "If \[ScriptCapitalA]  is the constant True and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_rest\)]],
  " is a p\[Dash]formula, we return the new proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalA] \[And] \[ScriptCapitalG]\_rest, \
\ \[ScriptCapitalK])\)\)]],
  "."
}], "BItem1"],

Cell[TextData[{
  "If \[ScriptCapitalA] is the constant True and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_rest\)]],
  " is an s\[Dash]formula, solved with respect to the solve\[Dash]constants \
",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\%*\), \[Ellipsis], \(x\_n\%*\)\)]],
  ", we return the new proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalA], \ \[ScriptCapitalK])\)\)]],
  "."
}], "BItem1"],

Cell[TextData[{
  "If \[ScriptCapitalA] is identical to True, we could either be satisfied \
with the answer that the existential formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " is true or we might want to obtain a solution. For the time being, these \
are the levels we offer:"
}], "BItem1"],

Cell[TextData[{
  "In case we are satisfied with knowing that the existential formula is \
true, we introduce some new constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&^\)\_1, \[Ellipsis], \(x\&^\)\_n\)]],
  " and assert that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalG]\_cad\) \[Sigma]\)]],
  " is true where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = {\(x\_1\%*\) \[Rule] \(x\&^\)\_1, \
\[Ellipsis], \(x\_n\%*\) \[Rule] \(x\&^\)\_n}\)]],
  "."
}], "BItem2"],

Cell[TextData[{
  "For a certain class of solve problems, see below, we give explicit solving \
terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " such that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalG]\_cad\) \[Sigma]\)]],
  " is true with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = {\(x\_1\%*\) \[Rule] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[Rule] \
\[ScriptCapitalT]\_n}\)]],
  "."
}], "BItem2"],

Cell[TextData[{
  "For the same class of solve problems as above, we give the most general \
solution  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_1, \[Ellipsis], \[ScriptCapitalT]\
\_n\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalG]\_cad\) \[Sigma]\)]],
  " is true where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma] = {\(x\_1\%*\) \[Rule] \
\[ScriptCapitalT]\_1, \[Ellipsis], \(x\_n\%*\) \[Rule] \
\[ScriptCapitalT]\_n}\)]],
  "."
}], "BItem2"],

Cell[TextData[{
  "In all these cases, the simplified proof situation generated is ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[ScriptCapitalG]\_rest\) \[Sigma], \ \(\
\[ScriptCapitalG]\_cad\) \[Sigma] \[Union] \[ScriptCapitalK])\)\)]],
  "."
}], "ContinueBItem1"],

Cell["\<\
For obtaining the explicit solutions we are use the implementation \
of the cad\[Dash]method available in  Mathematica as follows: \
\>", "Text"],

Cell[TextData[{
  "We apply the cad\[Dash]method to the formula ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad \[And] \[ScriptCapitalG]\_cad\
\)]],
  " with respect to the non-numeric constants occurring in the formula: ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1, \[Ellipsis], c\_\(m + n\)\)]],
  ", where the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(m + i\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, \[Ellipsis], n\)]],
  ", stand for the solve\[Dash]constants and the constants ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, \[Ellipsis], m\)]],
  " stand for the other non\[Dash]numeric constants occurring in the formula. \
The order in which are given the directions for the cad\[Dash]decomposition \
is important. (Note that the solution set of  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad \[And] \[ScriptCapitalG]\_cad\
\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad \[Implies] \
\[ScriptCapitalG]\_cad\)]],
  ", under the knowledge ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad\)]],
  ", are identical. This follows from:"
}], "BItem1"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ForAll] \+\(y\_1, \[Ellipsis], y\_m\)\((\
\[ScriptCapitalA] \[Implies] \[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((\((\
\[ScriptCapitalA] \[Implies] \[ScriptCapitalB])\) \[DoubleLeftRightArrow] \((\
\[ScriptCapitalA] \[And] \[ScriptCapitalB])\))\))\)\)\(,\)\)\)], \
"DisplayFormula"],

Cell[TextData[{
  "where the free variables of \[ScriptCapitalA] are among ",
  Cell[BoxData[
      \(TraditionalForm\`y\_1, \[Ellipsis], y\_m\)]],
  " and the free variables of \[ScriptCapitalB] are among ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n, y\_1, \[Ellipsis], 
      y\_m\)]],
  ".) "
}], "ContinueBItem1"],

Cell[TextData[{
  "The solutions are generated explicitly only for the class of solve \
problems where the cylindrical decomposition of the region defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalK]\_cad \[And] \[ScriptCapitalG]\_cad\
\)]],
  " with respect to the directions ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1, \[Ellipsis], c\_\(m + n\)\)]],
  " is"
}], "BItem1"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptCapitalR]\_1[
        c\_1] \[And] \[ScriptCapitalR]\_1[c\_1, 
        c\_2] \[And] \[Ellipsis] \[And] \[ScriptCapitalR]\_\(m + n\)[
        c\_1, \[Ellipsis], c\_\(m + n\)]\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "with the formulae ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalR]\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, \[Ellipsis], m + n\)]],
  " being either of the form ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i \[Tilde] \[ScriptCapitalT]\_i\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Tilde]\)\(\(\[Element]\)\({\(=\)\(\(,\)\(\(<\)\
\(\(,\)\(\(>\)\(\(,\)\(\(\[LessEqual]\)\(\(,\)\(\[GreaterEqual]\)\)\)\)\)\)\)\
\)}\)\)\)\)]],
  ", or of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_i \[Tilde] 
        c\_i \[TildeTilde] \(\[ScriptCapitalT]\_i\%*\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Tilde]\)\(\(,\)\(\(\[TildeTilde]\)\(\(\
\[Element]\)\({\(<\)\(\(,\)\(\(>\)\(\(,\)\(\(\[LessEqual]\)\(\(,\)\(\
\[GreaterEqual]\)\)\)\)\)\)}\)\)\)\)\)\)]],
  ", and the terms ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ScriptCapitalT]\_i\%*\)\)]],
  " contain only occurrences of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1, \[Ellipsis], c\_\(i - 1\)\)]],
  "(no occurrences of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i, \[Ellipsis], c\_\(m + n\)\)]],
  "). For this class of problems, under the knowledge that ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " holds (recall that we generate solutions only for this case), we have"
}], "ContinueBItem1"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalK]\_cad \[DoubleLeftRightArrow] \(\((\
\[ScriptCapitalR]\_1 \[And] \[Ellipsis] \[And] \[ScriptCapitalR]\_m)\)\(.\)\)\
\)], "DisplayFormula"],

Cell[TextData[{
  "(Note that the direction \"\[DoubleLeftArrow]\" holds always, while for \
the direction \"\[Implies]\" the assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\%\[FivePointedStar]\)]],
  " is needed.) Hence, the solution set of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_cad\)]],
  " is given by"
}], "ContinueBItem1"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalR]\_\(m + 1\) \[And] \[Ellipsis] \[And] \
\(\(\[ScriptCapitalR]\_\(m + n\)\)\(.\)\)\)], "DisplayFormula"],

Cell["\<\
The example from the previous section falls into the class of solve \
problems for which we generate explicit solutions. The corresponding call to \
the cad\[Dash]method is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Experimental`CylindricalAlgebraicDecomposition[\[Epsilon]\_0 > 0 \[And] 
        a \[GreaterEqual] 0 \[And] b \[GreaterEqual] 0 \[And] 
        x \((y + b + 1)\) + a\ y == \[Epsilon]\_0 \[And] x > 0 \[And] 
        y > 0, {\[Epsilon]\_0, a, b, x, y}]\)], "Input"],

Cell[BoxData[
    \(\[Epsilon]\_0 > 0 && a \[GreaterEqual] 0 && b \[GreaterEqual] 0 && 
      0 < x < \[Epsilon]\_0\/\(1 + b\) && 
      y == \(\(-x\) - b\ x + \[Epsilon]\_0\)\/\(a + x\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The last two conjuncts in the formula give us the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". Replacing back the newly introduced constants ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " by their values, ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " by the solve\[Dash]constants for which they stand the general solution of \
the initial solve problem is: "
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"0", "<", \(\[Delta]\_3\%*\), \( < \^\*"\<\"\"\>"\), 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            RowBox[{"1", "+", 
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "\[RightBracketingBar]"}]}]]}], 
        ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{\(\[Epsilon]\_1\%*\), "=", 
          FractionBox[
            RowBox[{
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "-", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox[\(x\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], 
                      "\[RightBracketingBar]"}]}], ")"}], 
                "*", \(\[Delta]\_3\%*\)}]}], 
            RowBox[{\(\[Delta]\_3\%*\), "+", 
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "\[RightBracketingBar]"}]}]]}], 
        ",", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(\(\[Delta]\_2\%*\) = \(\(max[\[Delta]\_0[\(\
\[Epsilon]\_1\%*\)], \[Delta]\_1[\(\[Delta]\_3\%*\)]]\)\(.\)\)\)}], 
      TraditionalForm]], "DisplayFormula"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4. 3.  Implementation", "Section",
  CellTags->"c:35"],

Cell[TextData[{
  "The solver combining the inference rules for solving is implemented as the \
Mathematica function ",
  StyleBox["NDS", "SR"],
  " (",
  StyleBox["N",
    FontWeight->"Bold"],
  "atural ",
  StyleBox["D",
    FontWeight->"Bold"],
  "eduction ",
  StyleBox["S",
    FontWeight->"Bold"],
  "olver), consisting of a collection of Mathematica definitions of the form: \
"
}], "Text"],

Cell[BoxData[
    \(\(\(\((NDS[Input] /; Precondition)\) := 
      Output\)\(,\)\)\)], "DisplayFormula"],

Cell["where", "Text"],

Cell[TextData[{
  StyleBox["Input:", "MR"],
  " is a proof situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG], \[ScriptCapitalK])\)\)]],
  " where either \[ScriptCapitalG] is an existential formula or an \
s\[Dash]formula. "
}], "BItem1"],

Cell[TextData[{
  StyleBox["Precondition:", "MR"],
  " checks if the solving inference rules can be applied."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Output:", "MR"],
  " is one of the following:"
}], "BItem1"],

Cell[TextData[{
  "An ",
  StyleBox["AND\[Dash]", "SR"],
  "situation with the s\[Dash]proof\[Dash]situation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ScriptCapitalG]', \[ScriptCapitalK])\)\)]],
  " where \[ScriptCapitalG]' is a simplified or partially solved version of \
\[ScriptCapitalG]."
}], "BItem2"],

Cell["\<\
True, if a solution for \[ScriptCapitalG] was found (either by the \
general inference rules or by a special prover).\
\>", "BItem2"],

Cell[TextData[{
  StyleBox["Null,", "SR"],
  " if either \[ScriptCapitalG] could not be simplified or no special prover \
could be applied to it or \[ScriptCapitalG] has no solutions."
}], "BItem2"],

Cell[TextData[{
  StyleBox["Remark (Natural Language Explanation).", "IT"],
  " We provided skeletons for each NDS definition with the text to be used \
when explaining the corresponding natural deduction solving step or call to a \
special solver (see last section with the example proofs)."
}], "Remark"],

Cell[TextData[{
  StyleBox["Order of Application.", "TB"],
  " The solving inference rules are applied in the following order:"
}], "Text"],

Cell["\<\
introduce solve\[Dash]constants (Rule  4.1),\
\>", "BItem1"],

Cell["push universal quantifiers inside (Rule  4.2),", "BItem1"],

Cell["\<\
replace subformulae which are assumptions by True (Rule  \
4.3),\
\>", "BItem1"],

Cell["\<\
solve by matching with assumptions (Rule 4.5), applied only when \
the match is between universal formulae (the chances of obtaining good \
solutions seem to be higher),\
\>", "BItem1"],

Cell["\<\
apply solutions (Rule 4.8, only when the solving terms are \
constants),\
\>", "BItem1"],

Cell["solve universal implications by matching sides (Rule 4.7),", "BItem1"],

Cell["\<\
solve by matching with right\[Dash]hand side of assumed implication \
(Rule 4.6),\
\>", "BItem1"],

Cell["\<\
solve partially by calling a special solver for a ground subproblem \
(Rules  4.4,  4.9,  4.8).\
\>", "BItem1"],

Cell["\<\
The syntactic general rewriting of the goal with respect to the \
knowledge is meant to be applied via the GRS simplifier, see Section 3.4. \
When given a solve situation as input, GRS will  switch to solve mode. The \
difference between the solve mode and the prove mode is that GRS will accept \
also universally quantified formulae as rewritable candidates for goal, see \
Section 3.4.1.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Combining with other Provers.", "TB"],
  " It is possible to use the NDS solver also standalone as it can reduce \
proof situations to trivial ones. However, it is not very powerful. As many \
of the inference rules are reducing the goal in a \"sufficient\" manner it \
can happen that we obtain a trivial problem to solve, namely the goal is \
False. Due to this it is a good strategy to combine NDS with other provers in \
such a way that if it fails, other alternatives are tried."
}], "Text"],

Cell[TextData[{
  StyleBox["Variety of Solution Forms", "TB"],
  ". For the problems where we also give explicit solutions we provide \
several options: "
}], "Text"],

Cell["\<\
The general solution is given as it is returned by the \
implementation of the cad\[Dash]method, namely inequations and equations (see \
previous section).\
\>", "BItem1"],

Cell["\<\
The general solution is given as a set of equations with parameters \
(intervals are given by equations depending on a real parameter).\
\>", \
"BItem1"],

Cell["\<\
An example solution is given, generated as follows: for closed \
intervals we take the middle point, for half infinite intervals we take the \
point at distance one from the finite end, for equations we take the right\
\[Dash]hand side.\
\>", "BItem1"],

Cell["\<\
Other possible presentations of explicit solutions for the example \
in Section  4.2.1 are\
\>", "Text"],

Cell["General solution as equations:", "BItem1"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Delta]\_3\%\("*"\) = \(\((\(-1\) + t1\_0)\)\^2\ \
\[Epsilon]\_0\)\/\(\((1 + \
\[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\)\ \((1 + \
t1\_0\^2)\)\)\)\(,\)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[Epsilon]\_1\%\("*"\) = \(2\ \((1 + \
\[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\)\ t1\_0\ \
\[Epsilon]\_0\)\/\(\[LeftBracketingBar]f\_0[x\_0]\[RightBracketingBar]\ \((1 \
+ \[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\)\ \((1 + t1\_0\^2)\) \
+ \((\(-1\) + t1\_0)\)\^2\ \[Epsilon]\_0\)\)\(,\)\)\)], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`\(\[Delta]\_2\%*\) = \(\(max[\[Delta]\_0[\(\((\(-1\) + \
t1\_0)\)\^2\ \[Epsilon]\_0\)\/\(\((1 + \[LeftBracketingBar]g\_0[x\_0]\
\[RightBracketingBar])\)\ \((1 + t1\_0\^2)\)\)], \
\[IndentingNewLine]\[Delta]\_1[\(2\ \((1 + \[LeftBracketingBar]g\_0[x\_0]\
\[RightBracketingBar])\)\ t1\_0\ \
\[Epsilon]\_0\)\/\(\[LeftBracketingBar]f\_0[x\_0]\[RightBracketingBar]\ \((1 \
+ \[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\)\ \((1 + t1\_0\^2)\) \
+ \((\(-1\) + t1\_0)\)\^2\ \[Epsilon]\_0\)]]\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(t1\_0\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  " is some arbitrary real number."
}], "ContinueBItem1"],

Cell["An example solution:", "BItem1"],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{\(\[Delta]\_3\%\("*"\)\), "=", 
            RowBox[{\(1\/2\), "*", 
              FractionBox[
                StyleBox[\(\[Epsilon]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                RowBox[{"1", "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox[\(x\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], 
                    "\[RightBracketingBar]"}]}]]}]}], ","}]}], 
      TraditionalForm]], "DisplayFormula"],

Cell[BoxData[
    \(TraditionalForm\`\[Epsilon]\_1\%\("*"\) = \(\((1 + \
\[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\)\ \[Epsilon]\_0\)\/\(2\ \
\[LeftBracketingBar]f\_0[x\_0]\[RightBracketingBar]\ \((1 + \
\[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\) + \[Epsilon]\_0\)\)], \
"DisplayFormula"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Delta]\_2\%*\), "=", 
        RowBox[{
          RowBox[{"max", "[", 
            RowBox[{
              RowBox[{\(\[Delta]\_0\), "[", 
                RowBox[{\(1\/2\), "*", 
                  FractionBox[
                    StyleBox[\(\[Epsilon]\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], 
                    RowBox[{"1", "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], 
                        "\[RightBracketingBar]"}]}]]}], "]"}], 
              ",", \(\[Delta]\_1[\(\((1 + \[LeftBracketingBar]g\_0[x\_0]\
\[RightBracketingBar])\)\ \[Epsilon]\_0\)\/\(2\ \
\[LeftBracketingBar]f\_0[x\_0]\[RightBracketingBar]\ \((1 + \
\[LeftBracketingBar]g\_0[x\_0]\[RightBracketingBar])\) + \[Epsilon]\_0\)]\)}],
             "]"}], "."}]}], TraditionalForm]], "DisplayFormula"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.  Case Distinction", "Chapter",
  CellTags->{"sec:case", "c:36"}],

Cell["\<\
In Theorema, the user has the possibility to define functions and \
predicates by cases. For this, the construct \"CaseDistinction\" is provided. \
One could, of course, simulate these definitions by using only the language \
of (higher-order) predicate logic. However, in accordance with the general \
Theorema philosophy, having an extra language construct - together with extra \
inference rules for it - makes the generation of human\[Dash]like proofs \
easier.\
\>", "Text"],

Cell["\<\
In Section 5.1 we describe the syntax of the case construct. The \
extra inference rules for the case construct are given in Section 5.2 and \
their implementation in Section 5.3.\
\>", "Text"],

Cell[CellGroupData[{

Cell["5. 1.  Syntax of Formulae with Case Distinction", "Section",
  CellTags->{"sec:syn-case", "c:37"}],

Cell["\<\
Formulae using the case distinction construct have the following \
general syntax:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`Lhs \[RightArrowLeftArrow] \
\[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \[ScriptCapitalC]\_1, \ \
\[Ellipsis]\ , \ 
        Rhs\_m \[DoubleLeftArrow] \[ScriptCapitalC]\_m\
\[RightDoubleBracketingBar]\)], "NumberedEquation",
  CellTags->"eq:casei"],

Cell["where:", "Text"],

Cell["\[FilledSmallSquare] \[RightArrowLeftArrow] \[Element] {=, :=, \
\[DoubleLeftRightArrow], :\[DoubleLeftRightArrow]};", "BulletText"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      \(TraditionalForm\`{\[ScriptCapitalC]\_i | \ i = 1, \ \[Ellipsis], 
        m}\)]],
  " are formulae; we will sometimes call them conditions and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " the number of cases;"
}], "BulletText"],

Cell[TextData[{
  "\[FilledSmallSquare] if \[RightArrowLeftArrow] \[Element] {\
\[DoubleLeftRightArrow], :\[DoubleLeftRightArrow]} then ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\)]],
  " is an atomic formula and ",
  Cell[BoxData[
      \(TraditionalForm\`{Rhs\_i | \ i = 1, \[Ellipsis], m}\)]],
  " are formulae;"
}], "BulletText"],

Cell[TextData[{
  "\[FilledSmallSquare]  if \[RightArrowLeftArrow] \[Element] {=, :=} then  \
",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{Rhs\_i | \ i = 1, \[Ellipsis], m}\)]],
  " are terms;"
}], "BulletText"],

Cell[TextData[{
  "\[FilledSmallSquare] the formulae/terms in the right hand side contain no \
other free variables than the free variables of ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\)]],
  ";"
}], "BulletText"],

Cell[TextData[{
  "\[FilledSmallSquare] none of the ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\[ScriptCapitalC]\_i, 
        Rhs\_i | \ i = 1, \ \[Ellipsis], m}\)]],
  " contain case distinction constructs \[LeftDoubleBracketingBar]\
\[MediumSpace]\[RightDoubleBracketingBar]."
}], "BulletText"],

Cell[TextData[{
  "Such formulae will be called \"",
  "case formulae\"",
  ". We do not allow the case formulae to occur inside other formulae except \
that they may be wrapped by universal quantifiers. A subset of the formulae \
defined by the above syntax are the explicit definitions, where ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\)]],
  " has the form ",
  Cell[BoxData[
      \(TraditionalForm\`p[x\_1, \ \[Ellipsis], x\_n]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`f[x\_1, \ \[Ellipsis], x\_n]\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " being a new predicate or a new function, respectively. Inductive \
definitions can also be given in the same syntax."
}], "Text"],

Cell[TextData[{
  StyleBox["Admissible variants of the syntax.  ", "TB"],
  "For the sake of similarity with the usual mathematical notation, Theorema \
also provides the possibility of writing the formula (5.",
  "3",
  ") in the equivalent form:"
}], "Paragraph"],

Cell[BoxData[
    FormBox[
      RowBox[{"Lhs", " ", "\[RightArrowLeftArrow]", 
        StyleBox[
          RowBox[{"{", GridBox[{
                {\(Rhs\_1\), "\[DoubleLeftArrow]", \(\[ScriptCapitalC]\_1\)},
                {"\[Ellipsis]", " ", " "},
                {\(Rhs\_m\), 
                  "\[DoubleLeftArrow]", \(\(\[ScriptCapitalC]\_m\)\(\ \)\(,\)\
\)}
                },
              ColumnAlignments->{Left}]}],
          SpanMaxSize->Infinity]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "where the expression after the opening brace must be put into a ",
  "Mathematica",
  " \"grid\". Moreover, for the particular case when ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_m\)]],
  " is the truth symbol ",
  StyleBox["True", "SR"],
  ", the following variants of the notation are possible:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`Lhs \[RightArrowLeftArrow] \
\[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \[ScriptCapitalC]\_1, \ \
\[Ellipsis]\ , \ Rhs\_m\[RightDoubleBracketingBar]\)], "NumberedEquation",
  CellTags->"eq:casec"],

Cell["or", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"Lhs", " ", "\[RightArrowLeftArrow]", 
        StyleBox[
          RowBox[{"{", 
            RowBox[{GridBox[{
                  {\(Rhs\_1\), 
                    "\[DoubleLeftArrow]", \(\[ScriptCapitalC]\_1\)},
                  {"\[Ellipsis]", " ", " "},
                  {\(Rhs\_m\), " ", " "}
                  },
                ColumnAlignments->{Left}], "."}]}],
          SpanMaxSize->Infinity]}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_m\)]],
  " is True, the case formulae are called \"",
  "complete case formulae\"",
  ". Otherwise they are called incomplete case formulae."
}], "Text"],

Cell[TextData[{
  StyleBox["Example (Well-formed case formulae in Theorema).", "TB"],
  " Some examples of well\[Dash]formed case formulae"
}], "Example"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\[LeftBracketingBar]x\[RightBracketingBar]\), 
            ":=", \(\(\[LeftDoubleBracketingBar]x \[DoubleLeftArrow] 
                x \[GreaterEqual] 
                  0, \(-x\)\[RightDoubleBracketingBar]\)\(\ \)\(,\)\)},
          {
            StyleBox[\(\[LeftBracketingBar]x\[RightBracketingBar]\),
              GridBoxOptions->{ColumnAlignments->{Right}}], "=", 
            RowBox[{"{", 
              RowBox[{GridBox[{
                    {"x", "\[DoubleLeftArrow]", \(x \[GreaterEqual] 0\)},
                    {\(-x\), " ", " "}
                    },
                  ColumnAlignments->{Left}], " ", ","}]}]},
          {
            StyleBox["A",
              GridBoxOptions->{ColumnAlignments->{Right}}], 
            "\[DoubleLeftRightArrow]", \(\(\[LeftDoubleBracketingBar]B \
\[DoubleLeftArrow] C, \ 
              D \[DoubleLeftArrow] 
                E\ \[RightDoubleBracketingBar]\)\(\ \)\(,\)\)},
          {
            
            StyleBox[\(\[ForAll] \+\(x, y, y\&_\)is\[Dash]sorted[\
\[LeftAngleBracket]x, y, y\&_\[RightAngleBracket]]\),
              GridBoxOptions->{
              ColumnAlignments->{
                Right}}], \(\(\ \)\(\(:\)\(\[DoubleLeftRightArrow]\)\)\), \
\(\(\[LeftDoubleBracketingBar]is\[Dash]sorted[\[LeftAngleBracket]y, 
                      y\&_\[RightAngleBracket]] \[DoubleLeftArrow] 
                  x \[LessEqual] y, 
                False\[RightDoubleBracketingBar]\)\(.\)\)}
          },
        ColumnAlignments->{Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula"],

Cell["Examples of formulae which we do not allow in our language:", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(P \[Or] Q\),
              GridBoxOptions->{ColumnAlignments->{Right}}], 
            "\[DoubleLeftRightArrow]", \(\(\[LeftDoubleBracketingBar]B \
\[DoubleLeftArrow] C, \ 
              D \[DoubleLeftArrow] 
                E\ \[RightDoubleBracketingBar]\)\(\ \)\(,\)\)},
          {
            StyleBox[\(p[x, y] \[Implies] q[x, y]\),
              GridBoxOptions->{ColumnAlignments->{Right}}], 
            "\[DoubleLeftRightArrow]", \(\[LeftDoubleBracketingBar]B \
\[DoubleLeftArrow] C, \ 
                D \[DoubleLeftArrow] 
                  E\ \[RightDoubleBracketingBar] . \ \ \ \ \[EmptySquare]\)}
          },
        ColumnAlignments->{Right, Center, Left}], 
      TraditionalForm]], "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. 2.  Inference Rules", "Section",
  CellTags->{"sec:inf-case", "c:38"}],

Cell["\<\
In this section we will present the inference rules associated with \
formulae containing case distinction. For the implementation details see \
Section 5.3.0. \
\>", "Text"],

Cell["\<\
We split the inference rules into three types: rules for \
simplifying case formulae, rules for proving case formulae and rules for \
using case formulae as assumptions. For the ease of presentation, the last \
two types of rules will only be given for the particular instance of case \
formulae with two cases. The generalization of the rules is straightforward. \
(Note that we assumed that all formulae that appear in proofs are either \
ground formulae or closed formulae.)\
\>", "Text"],

Cell["\<\
In the prover, the inference rules will be applied in the sequence \
they are given below.\
\>", "Text"],

Cell[CellGroupData[{

Cell["5. 2. 1.  Simplifying Ground Case Formulae", "Subsection",
  CellTags->"c:39"],

Cell[TextData[{
  StyleBox["Rule 5.1",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Eliminate Case Distinction).",
    FontWeight->"Bold"],
  " If \[ScriptCapitalK] is a knowledge base and \[ScriptCapitalF] a ground \
case formula of the form (5.",
  "3",
  ") (occurring as goal or as part of the knowledge base) and"
}], "InferenceRule",
  CellTags->"r:elim-cd"],

Cell[TextData[{
  "(c1)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  "is the truth symbol ",
  StyleBox["True", "TR"],
  " or"
}], "BulletText"],

Cell[TextData[{
  "(c2)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  "has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT] = \[ScriptCapitalT]\)]],
  ", for some term ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  " or"
}], "BulletText"],

Cell[TextData[{
  "(c3)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  " is contained in the knowledge base \[ScriptCapitalK],"
}], "BulletText"],

Cell[TextData[{
  "then, formula \[ScriptCapitalF] is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\  \[RightArrowLeftArrow] \ \ Rhs\_1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Rule 5.2",
    FontWeight->"Bold"],
  " ",
  StyleBox["(Reduce Case Distinction).",
    FontWeight->"Bold"],
  " If \[ScriptCapitalK] is a knowledge base, \[ScriptCapitalF] a ground case \
formula of the form (5.",
  "3",
  ") and "
}], "InferenceRule",
  CellTags->"r:red-cd"],

Cell[TextData[{
  "(c1)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  "is the truth symbol ",
  StyleBox["False", "SR"],
  " or"
}], "BulletText"],

Cell[TextData[{
  "(c2)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  "has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT] \[NotEqual] \[ScriptCapitalT]\)]],
  ", for some term ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalT]\)]],
  " or"
}], "BulletText"],

Cell[TextData[{
  "(c3)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \[ScriptCapitalC]\_1\)]],
  " is in the knowledge base \[ScriptCapitalK],"
}], "BulletText"],

Cell[" \[ScriptCapitalF]  is replaced by", "Text"],

Cell[BoxData[
    \(TraditionalForm\`Lhs \[RightArrowLeftArrow] \
\[LeftDoubleBracketingBar]Rhs\_2 \[DoubleLeftArrow] \ \[ScriptCapitalC]\_2, \ \
\[Ellipsis]\ , \ 
        Rhs\_m \[DoubleLeftArrow] \[ScriptCapitalC]\_m\
\[RightDoubleBracketingBar]\)], "DisplayFormula"],

Cell[TextData[{
  "(in case ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1\)]],
  ", \[ScriptCapitalF] is replaced by ",
  StyleBox["True", "SR"],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. 2. 2.  Proving Case Formulae", "Subsection",
  CellTags->"c:40"],

Cell[TextData[{
  StyleBox["Rule 5.3", "TB"],
  " ",
  StyleBox["(Prove Case Formulae).",
    FontWeight->"Bold"],
  "  In order to prove the ground formula"
}], "InferenceRule",
  CellTags->"r:prove-cd"],

Cell[BoxData[
    \(TraditionalForm\`\(\(Lhs \[RightArrowLeftArrow] \
\[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \[ScriptCapitalC]\_1, 
        Rhs\_2 \[DoubleLeftArrow] \[ScriptCapitalC]\_2\
\[RightDoubleBracketingBar]\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "prove Lhs \[RightArrowLeftArrow] ",
  Cell[BoxData[
      \(TraditionalForm\`Rhs\_1\)]],
  " under the assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[ScriptCapitalC]\_1\)\)\)]],
  " and prove ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs \[RightArrowLeftArrow] Rhs\_2\)]],
  " under the assumption ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \[ScriptCapitalC]\_1 \[And] \[ScriptCapitalC]\
\_2\)]],
  ". "
}], "Text"],

Cell["\<\
If we want to prove a universally quantified case formula one has \
first to apply the \"arbitrary but fixed\" rule for universally quantified \
formulae and then the above rule can be applied.\
\>", "ProofBegin"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. 2. 3.  Using Case Formulae", "Subsection",
  CellTags->"c:41"],

Cell[TextData[{
  StyleBox["Rule 5.4", "TB"],
  " ",
  StyleBox["(Transforming the Goal by a Case Formula).",
    FontWeight->"Bold"],
  "  In order to prove \[ScriptCapitalG] when we have in the knowledge base \
\[ScriptCapitalK] the closed formula"
}], "InferenceRule",
  CellTags->"r:transf-g-cd"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((Lhs \
\[RightArrowLeftArrow] \[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \
\[ScriptCapitalC]\_1, 
            Rhs\_2 \[DoubleLeftArrow] \[ScriptCapitalC]\_2\
\[RightDoubleBracketingBar])\)\)\(,\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "for which there exists a subformula (subterm) \[ScriptCapitalS] of \
\[ScriptCapitalG] and a substitution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " for the variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\ \[Sigma]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\)]],
  ","
}], "Text"],

Cell[TextData[{
  "(c1)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\ \[Sigma]\)]],
  " and prove ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\ [\[ScriptCapitalS] \[LeftArrow] \
\((Rhs\_1\ \[Sigma])\)]\)]],
  ", then"
}], "BulletText"],

Cell[TextData[{
  "(c2)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_1\ \[Sigma])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_2\ \[Sigma]\)]],
  " and prove ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\ [\[ScriptCapitalS] \[LeftArrow] \
\((Rhs\_2\ \[Sigma])\)]\)]],
  " and, finally,"
}], "BulletText"],

Cell[TextData[{
  "(c3)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_1\ \[Sigma])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_2\ \[Sigma])\)\)]],
  " and prove ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ScriptCapitalG]\)\(\ \)\)\)]],
  "."
}], "BulletText"],

Cell[TextData[{
  StyleBox["Note:", "IT"],
  " In the implementation we only apply this rule for cases when \
\[ScriptCapitalG] is a literal."
}], "Remark"],

Cell[TextData[{
  StyleBox["Rule 5.5", "TB"],
  " ",
  StyleBox["(Transforming an Assumption by a Case Formula).",
    FontWeight->"Bold"],
  " If we have in the knowledge base formula"
}], "InferenceRule",
  CellTags->"r:transf-as-cd"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\_1, \[Ellipsis], x\_n\)\((Lhs \
\[RightArrowLeftArrow] \[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \
\[ScriptCapitalC]\_1, 
            Rhs\_2 \[DoubleLeftArrow] \[ScriptCapitalC]\_2\
\[RightDoubleBracketingBar])\)\)], "DisplayFormula"],

Cell[TextData[{
  "and formula \[ScriptCapitalA] for which there exists a subformula \
(subterm) \[ScriptCapitalS] of \[ScriptCapitalA] and a substitution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " for the variables ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1, \[Ellipsis], x\_n\)]],
  " such that  ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs\ \[Sigma]\)]],
  " is identical to ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalS]\)]],
  ", then, in order to prove \[ScriptCapitalG],"
}], "Text"],

Cell[TextData[{
  "(c1)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\ \[Sigma]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\ [\[ScriptCapitalS] \[LeftArrow] \
\((Rhs\_1\ \[Sigma])\)]\)]],
  " and prove \[ScriptCapitalG], then"
}], "BulletText"],

Cell[TextData[{
  "(c2)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_1\ \[Sigma])\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_2\ \[Sigma]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalA]\ [\[ScriptCapitalS] \[LeftArrow] \
\((Rhs\_2\ \[Sigma])\)]\)]],
  " and prove \[ScriptCapitalG],  and finally,"
}], "BulletText"],

Cell[TextData[{
  "(c3)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_1\ \[Sigma])\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \((\[ScriptCapitalC]\_2\ \[Sigma])\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ScriptCapitalA]\)\(\ \)\)\)]],
  " and prove \[ScriptCapitalG]."
}], "BulletText"],

Cell[TextData[{
  StyleBox["Note:", "IT"],
  " In the implementation we only apply this rule for cases when \
\[ScriptCapitalA] is a literal."
}], "Remark"],

Cell[TextData[{
  StyleBox["Rule 5.6", "TB"],
  " ",
  StyleBox["(Use of Ground Case Formulae).",
    FontWeight->"Bold"],
  " If we have in the knowledge base a ground case formula"
}], "InferenceRule",
  CellTags->"r:use-cd"],

Cell[BoxData[
    \(TraditionalForm\`\(\(Lhs \[RightArrowLeftArrow] \
\[LeftDoubleBracketingBar]Rhs\_1 \[DoubleLeftArrow] \ \[ScriptCapitalC]\_1, 
        Rhs\_2 \[DoubleLeftArrow] \[ScriptCapitalC]\_2\
\[RightDoubleBracketingBar]\)\(,\)\)\)], "DisplayFormula"],

Cell["in order to prove \[ScriptCapitalG]", "Text"],

Cell[TextData[{
  "(c1)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs \[RightArrowLeftArrow] Rhs\_1\)]],
  " and prove \[ScriptCapitalG], then"
}], "BulletText"],

Cell[TextData[{
  "(c2)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \[ScriptCapitalC]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Lhs \[RightArrowLeftArrow] Rhs\_2\)]],
  " and prove \[ScriptCapitalG],  and finally,"
}], "BulletText"],

Cell[TextData[{
  "(c3)  assume  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \[ScriptCapitalC]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Not] \[ScriptCapitalC]\_2\)]],
  " and prove \[ScriptCapitalG]."
}], "BulletText"],

Cell[TextData[{
  StyleBox["Remark.", "IT"],
  " When we have a complete case formula among the assumptions, in all the \
rules that make use of it the third case can be dropped. The justification is \
that for complete case formulae, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalC]\_2\)]],
  " is True and hence in the last case, among the assumptions one has False. \
As from False one can trivially deduce anything, this last case can be \
omitted."
}], "Remark"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. 3.  Implementation", "Section",
  CellTags->{"sec:cdp", "c:42"}],

Cell[TextData[{
  "The prover combining the above inference rules is implemented as a \
Mathematica function CDP (",
  StyleBox["C",
    FontWeight->"Bold"],
  "ase ",
  StyleBox["D",
    FontWeight->"Bold"],
  "istinction ",
  StyleBox["P",
    FontWeight->"Bold"],
  "rover) given by definitions of the form:"
}], "Text"],

Cell[BoxData[
    \(\((CDP[Input] /; Precondition)\) := Output; \)], "DisplayFormula"],

Cell["where", "Text"],

Cell[TextData[{
  StyleBox["Input:", "MR"],
  " is a proof situation where either the goal or the assumptions contain a \
case formula."
}], "BItem1"],

Cell[TextData[{
  StyleBox["Precondition:", "MR"],
  " is a condition that either checks the applicability of the inference \
rules to the proof situation or restricts the set of proof situations to \
which we apply the inference rules. These last type of precondition is \
dictated by the heuristics we use in the rule application. More details will \
be given later. "
}], "BItem1"],

Cell[TextData[{
  StyleBox["Output:", "MR"],
  " an ",
  StyleBox["AND\[Dash]", "SR"],
  "situation with:"
}], "BItem1"],

Cell["\<\
one proof situation if the inference rule applied was a \
simplification rule;\
\>", "BItem2"],

Cell[TextData[{
  "as many proof situations as the number of cases which result after \
applying a rule which is not a simplification one. (For example, if the goal \
is a ground incomplete case formula with two cases, the ",
  StyleBox["AND\[Dash]", "SR"],
  "situation will contain three new proof situations.)"
}], "BItem2"],

Cell[TextData[{
  StyleBox["Remark (Natural Language Explanation).", "IT"],
  " For each definition of CDP we provided skeletons with the text to be used \
when explaining in natural language the application of the corresponding \
inference rule."
}], "Remark"],

Cell[TextData[{
  StyleBox["Example (Rule Implementation Sketch). ",
    FontWeight->"Bold"],
  "We show a simplified version of the implementation of Rule 5.4 as a \
Mathematica function definition:"
}], "Example"],

Cell[BoxData[
    \(CDP[\[Bullet]lf[gl_, goal_], 
          kb : \[Bullet]asml[___, \[IndentingNewLine]asm : \[Bullet]lf[
                  al_, \[ForAll] \+\((r___)\)lhs_ := \
\[LeftDoubleBracketingBar]___\[RightDoubleBracketingBar]], ___]] /; 
        is\[Dash]literal[
            goal] \[And] \((candidates = 
                instancesInOf[goal, lhs, r])\) =!= {} := 
      Module[{subf, caseExtr, proofSit}, \[IndentingNewLine]subf = 
          selectSubFormula[candidates, goal]; \ 
        caseExtr = 
          extractCases[goal, asm, subf]; \[IndentingNewLine]proofSit = 
          Map[Psit[#\[LeftDoubleBracket]1\[RightDoubleBracket], 
                Join[#\[LeftDoubleBracket]2\[RightDoubleBracket], kb]] &, 
            caseExtr]; \[IndentingNewLine]ProofStep[
          Prinfo[\[Cent]MatchGoalCase, gl, al, caseExtr], 
          Sequence @@ proofSit]]\)], "Input"],

Cell[TextData[{
  "Without going into the details of the internal data structures we use in \
the implementation, this function, roughly does the following: Given a proof \
situation with a universally quantified case formula as assumption (the ",
  StyleBox["Input", "MR"],
  " component), if the goal is a literal containing instances of the left\
\[Dash]hand side of the case formula (the ",
  StyleBox["Precondition", "MR"],
  " component which ensures the applicability of Rule 5.4) an \
AND\[Dash]situation is generated containing the corresponding new proof \
situations (the ",
  StyleBox["Output", "MR"],
  " component).  First, a suitable term in the goal for applying the \
definition by cases is selected. Using this subterm, ",
  StyleBox["extractCases", "TR"],
  " will construct the new goals and additional assumptions for each of the \
resulting proof situations and then the new proof situations are constructed \
using ",
  StyleBox["Psit", "TR"],
  ". The AND\[Dash]situation having as successors the new proof situations is \
constructed by  ",
  StyleBox["ProofStep", "TR"],
  StyleBox[".", "MR"],
  "   \[EmptySquare]"
}], "Text"],

Cell[TextData[{
  "For making the description of the ",
  StyleBox["CDP", "TR"],
  " prover complete, we still have to specify:"
}], "Text"],

Cell["the order in which the inference rules are applied,", "BItem1"],

Cell["\<\
how are the rules applied (one at a time, all in one stroke, etc.),\
\
\>", "BItem1"],

Cell["\<\
which substitution is taken in the Rules 5.4,  5.5,  if there are \
multiple choices.\
\>", "BItem1"],

Cell["\<\
Heuristics come into play when making these choices. The current \
ones in the Theorema system are presented in the following. They are trying \
to follow one of the main principles in Theorema, namely keeping proofs \
simple and as near to the human\[Dash]like thinking as possible. In this \
view, all decisions we took were made in such a way that the number of case \
splits stays small.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Order of Rules and How to Apply Them. ", "TB"],
  "Mathematica applies the definitions of a function starting from the \
specific ones to the more general ones (recall that we use patterns in the \
function definitions). When definitions are of the \"same\" degree of \
specificity, Mathematica will apply them in the order they were given. For \
the order fixed, the first definition which applies is the one that \
Mathematica will use. Relying on this behavior, the definitions for ",
  StyleBox["CDP", "TR"],
  " are ordered in dependence of their operational meaning as follows:"
}], "Paragraph"],

Cell["\<\
\[FilledSmallSquare] simplify goal (using one of the Rules 5.1,  \
5.2),\
\>", "BulletText"],

Cell["\<\
\[FilledSmallSquare] simplify assumption (using one of the Rules  \
5.1,  5.2),\
\>", "BulletText"],

Cell["\<\
\[FilledSmallSquare] prove case formula (Rule  5.3),\
\>", \
"BulletText"],

Cell["\<\
\[FilledSmallSquare] transform goal by case formula (Rule  \
5.4),\
\>", "BulletText"],

Cell["\<\
\[FilledSmallSquare] transform assumption by case formula (Rule  \
5.5),\
\>", "BulletText"],

Cell["\<\
\[FilledSmallSquare] use ground case formula (Rule  5.6).\
\>", \
"BulletText"],

Cell["\<\
The simplification rules for case formulae are the first to be \
tried out as they do not introduce any branching of the proof. Also, rules of \
the same type are first applied on goal and only afterwards they will be \
tried on the assumptions. This gives a more goal\[Dash]oriented proof with \
less generation of unuseful knowledge.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Multiple Choices of Substitutions. ", "TB"],
  "In the application of the Rules 5.4 and 5.5 there may be several different \
candidate subterms (subformulae). The choice is open here: one could take the \
leftmost or rightmost or innermost subterm. We chose to apply the definition \
by cases to the subterms which have the maximum number of occurrences and \
among those we take the innermost, leftmost one. The reasons behind this \
choice are:"
}], "Paragraph"],

Cell["\<\
By taking the candidate subterm with maximum occurrences we are \
trying to lower as much as possible the number of occurrences of the notion \
defined by cases in the newly generated formulae. \
\>", "BItem1"],

Cell["\<\
By taking the innermost candidate subterm, in case of nested \
candidates, we are trying to keep small the number of formulae containing \
occurrences of the notion defined by cases. \
\>", "BItem1"],

Cell[TextData[{
  StyleBox["Example (Nesting of Terms defined by Case Distinction):", "TB"],
  " Suppose we have the definition of maximum "
}], "Example"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[ForAll] \+\(x, y\)max[x, y]\), ":=", 
        RowBox[{"{", GridBox[{
              {"x", "\[DoubleLeftArrow]", \(x \[GreaterEqual] y\)},
              {"y", " ", " "}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula"],

Cell["and we want to prove the ground goal:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`max[a, 
        max[b, c]] = \(\(max[max[a, b], c]\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "The definition of maximum will be applied first to the subterm ",
  Cell[BoxData[
      \(TraditionalForm\`max[b, c]\)]],
  " and the proof will be split in two cases:"
}], "Text"],

Cell[TextData[{
  "(c1) Assume ",
  Cell[BoxData[
      \(TraditionalForm\`b \[GreaterEqual] c\)]],
  ", show ",
  Cell[BoxData[
      \(TraditionalForm\`max[a, b] = max[max[a, b], c]\)]],
  "; "
}], "BulletText"],

Cell[TextData[{
  "(c2) Assume ",
  Cell[BoxData[
      \(TraditionalForm\`b \[NotGreaterEqual] c\)]],
  ", show ",
  Cell[BoxData[
      \(TraditionalForm\`max[a, c] = max[max[a, b], c]\)]],
  ". "
}], "BulletText"],

Cell[TextData[{
  "Note that if we had chosen the leftmost candidate subterm to apply the \
definition, ",
  Cell[BoxData[
      \(TraditionalForm\`max[a, max[b, c]]\)]],
  ", the notion defined by cases, max, will occur both in the newly generated \
goal as in the newly generated assumption. (The automatically generated proof \
for this proof situation is given in Section 8.2).  \[EmptySquare]"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.  Induction", "Chapter",
  CellTags->{"sec:ind", "c:43"}],

Cell[TextData[{
  "In Theorema we also have provers for inductive theories. These are \
theories where an induction principle is valid (see ",
  ButtonBox["[67]",
    ButtonData:>"Manna_Waldinger:85",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Z. Manna and R. Waldinger, 1985, The Logical Basis for Computer \
Programming"],
  " for details on special theories). This principle can be formulated as an \
axiom schema, i.e. an infinite set of axioms. Instead of using the induction \
principle by adding the axiom schema explicitly in the knowledge base, in \
Theorema, as in other theorem proving systems, we formulate induction as a \
special inference rule. "
}], "Text"],

Cell["\<\
In the following, we will describe the inductive inference rule for \
the domain of natural numbers (Section 6.1), the inductive inference rule for \
sequences (Section 6.2) and their implementation (Section 6.3).\
\>", "Text"],

Cell[CellGroupData[{

Cell["6. 1.  Natural Numbers", "Section",
  CellTags->{"sec:nn", "c:44"}],

Cell[TextData[{
  "Let us consider the domain of natural numbers \[DoubleStruckCapitalN] \
inductively defined by 0 and a successor function  ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ": 0, ",
  Cell[BoxData[
      \(TraditionalForm\`s[0]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s[s[0]]\)]],
  ", \[Ellipsis]. In Theorema, the notation used for the successor function \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[EmptySquare]\^+\)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[EmptySquare] + 1\)]],
  ". (In fact, other notation can be chosen by the syntax extension \
facilities in Theorema.) The induction principle can be stated as follows:"
}], "Text"],

Cell[TextData[{
  StyleBox["Rule 6.1", "TB"],
  " ",
  StyleBox["(Induction over Natural Numbers).",
    FontWeight->"Bold"],
  "  In order to prove the closed formula"
}], "InferenceRule"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+n \[ScriptCapitalF]\)], "DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " occurs free in \[ScriptCapitalF], we prove first"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(\(\[ScriptCapitalF][
        n \[LeftArrow] 0]\)\(.\)\)\)], "DisplayFormula"],

Cell["Then we assume ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalF][
      n \[LeftArrow] n\_0]\)], "DisplayFormula"],

Cell["and prove", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"\[ScriptCapitalF]", "[", 
        RowBox[{"n", "\[LeftArrow]", 
          SuperscriptBox[
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "]"}], 
      TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "(where ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], TraditionalForm]]],
  " is a new constant)."
}], "Text"],

Cell[TextData[{
  StyleBox["Example (Proving by Induction on Natural Numbers).", "TB"],
  " In order to prove the commutativity of natural numbers addition"
}], "Example"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(m, n \[Element] \
\[DoubleStruckCapitalN]\)\((m + n = n + m)\)\)], "DisplayFormula"],

Cell[TextData[{
  "by induction on ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", proceed as follows:"
}], "Text"],

Cell["\[FilledSmallSquare] Induction Base: Prove", "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(n \[Element] \[DoubleStruckCapitalN]\)\(\
\((0 + n = n + 0)\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "\[FilledSmallSquare] Induction Hypothesis:  Choose a new constant ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  " and assume"
}], "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(n \[Element] \
\[DoubleStruckCapitalN]\)m\_0 + n = n + \(\(m\_0\)\(.\)\)\)], "DisplayFormula"],

Cell["\[FilledSmallSquare] Induction Conclusion: Prove", "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(n \[Element] \
\[DoubleStruckCapitalN]\)\(m\_0\^+\) + n = 
      n + \(m\_0\^+\) . \ \ \ \[EmptySquare]\)], "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. 2.  Induction on Sequences", "Section",
  CellTags->{"sec:tuple", "c:45"}],

Cell[TextData[{
  "In Theorema, as in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", we allow \"sequence variables\". This is a concept which is not normally \
used in formal mathematics. We use overbarred identifiers like ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\&_\)]],
  ", \[Ellipsis] as sequence variable identifiers. The essential feature of \
sequence variables is that we may substitute not only one term for them but \
zero, one, two, \[Ellipsis] terms. "
}], "Text"],

Cell["For example, in the definition", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\((1)\), \
\(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]] : \(\(\
\[DoubleLeftRightArrow]\)\(True\)\)\)},
          {\((2)\), \
\(is\[Dash]sorted[\[LeftAngleBracket]x\[RightAngleBracket]] : \(\(\
\[DoubleLeftRightArrow]\)\(True\)\)\)},
          {\((3)\), \(\(is\[Dash]sorted[\[LeftAngleBracket]x, y, 
                  z\&_\[RightAngleBracket]] : \
\(\(\[DoubleLeftRightArrow]\)\(x \[GreaterEqual] y\)\) \[And] 
                is\[Dash]sorted[\[LeftAngleBracket]y, 
                    z\&_\[RightAngleBracket]]\)\(,\)\)}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "for \"",
  Cell[BoxData[
      \(TraditionalForm\`z\&_\)]],
  "\", we may substitute arbitrarily many terms:"
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(is\[Dash]sorted[\[LeftAngleBracket]x, 
                  y\[RightAngleBracket]] : \(\(\[DoubleLeftRightArrow]\)\(x \
\[GreaterEqual] y\)\) \[And] 
                is\[Dash]sorted[\[LeftAngleBracket]y\[RightAngleBracket]]\)\(,\
\)\)},
          {\(\(is\[Dash]sorted[\[LeftAngleBracket]x, y, 
                  u\[RightAngleBracket]] : \(\(\[DoubleLeftRightArrow]\)\(x \
\[GreaterEqual] y\)\) \[And] 
                is\[Dash]sorted[\[LeftAngleBracket]y, 
                    u\[RightAngleBracket]]\)\(,\)\)},
          {\(is\[Dash]sorted[\[LeftAngleBracket]x, y, u, v, 
                  w\[RightAngleBracket]] : \(\(\[DoubleLeftRightArrow]\)\(x \
\[GreaterEqual] y\)\) \[And] \(\(is\[Dash]sorted[\[LeftAngleBracket]y, u, v, 
                      w\[RightAngleBracket]]\)\(.\)\)\)}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula"],

Cell["Even,", "Text"],

Cell[BoxData[
    \(TraditionalForm\`is\[Dash]sorted[\[LeftAngleBracket]\[Alpha], \[Beta], 
          a, b\&_, c, 
          d\&_\[RightAngleBracket]] : \(\(\[DoubleLeftRightArrow]\)\(\[Alpha] \
\[GreaterEqual] \[Beta]\)\) \[And] 
        is\[Dash]sorted[\[LeftAngleBracket]\[Beta], a, b\&_, c, 
            d\&_\[RightAngleBracket]]\)], "DisplayFormula"],

Cell["\<\
is a formula that results from (3) by an admissible substitution!\
\
\>", "Text"],

Cell["\<\
Sequence variables are particularly useful for introducing \
operations of \"flexible arity\" as, for example, the function \"\
\[LeftAngleBracket],\[RightAngleBracket]\" that creates \"tuples\". \
Thus,\
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[LeftAngleBracket]\[RightAngleBracket]\)\(,\)\)},
          {\(\(\[LeftAngleBracket]1, 
                2\[RightAngleBracket]\)\(\ \ \)\(and\)\(\ \)\)},
          {\(\[LeftAngleBracket]2, 1, 1, 1, 2\[RightAngleBracket]\)}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula"],

Cell["\<\
are all terms with function symbols \"\[LeftAngleBracket],\
\[RightAngleBracket]\" and the following is a typical inductive definition on \
tuples: \
\>", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {\(\(merge[\[LeftAngleBracket]\[RightAngleBracket], B] := 
              B\)\(,\)\)},
          {\(\(merge[A, \[LeftAngleBracket]\[RightAngleBracket]] := 
              A\)\(,\)\)},
          {
            
            RowBox[{\(merge[\[LeftAngleBracket]a, 
                  x\&_\[RightAngleBracket], \[LeftAngleBracket]b, 
                  y\&_\[RightAngleBracket]]\), ":=", 
              RowBox[{"{", GridBox[{
                    {\(a\[Cup]
                        merge[\[LeftAngleBracket]x\&_\[RightAngleBracket], \
\[LeftAngleBracket]b, y\&_\[RightAngleBracket]]\), 
                      "\[DoubleLeftArrow]", \(a \[GreaterEqual] b\)},
                    {\(b\[Cup]
                        merge[\[LeftAngleBracket]a, 
                            x\&_\[RightAngleBracket], \[LeftAngleBracket]y\&_\
\[RightAngleBracket]]\), \(\(\ \)\(.\)\), " "}
                    },
                  ColumnAlignments->{Left}]}]}]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula"],

Cell["\<\
Sequence variables suggest the following induction principle in a \
natural way (formulated here as an inference rule):\
\>", "Text"],

Cell[TextData[{
  StyleBox["Rule 6.2", "TB"],
  " ",
  StyleBox["(Induction over Sequences).",
    FontWeight->"Bold"],
  "  In order to prove the closed formula"
}], "InferenceRule"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\&_\)\[ScriptCapitalF]\)], \
"DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  " occurs free in \[ScriptCapitalF], prove first"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalF][\(x\&_\)\(\[LeftArrow]\)\ ]\)], \
"DisplayFormula"],

Cell[TextData[{
  "obtained by removing all occurrences of ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  " in \[ScriptCapitalF]."
}], "Text"],

Cell["Then assume ", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalF][
      x\&_ \[LeftArrow] \(x\_0\)\&_]\)], "DisplayFormula"],

Cell["and prove", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\[ScriptCapitalF][
      x\&_ \[LeftArrow] a\_0, \(x\_0\)\&_]\)], "DisplayFormula"],

Cell[TextData[{
  "(where ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(a\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], TraditionalForm]]],
  " is a new constant and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_0\)\&_\)]],
  " is a new sequence constant)."
}], "Text"],

Cell[TextData[{
  StyleBox["Example (Proving by Induction over Sequences).", "TB"],
  " In order to prove that the length of concatenation of two tuples is the \
sum of the lengths of the initial tuples "
}], "Example"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x\&_, y\&_\)\[LeftBracketingBar]\
\[LeftAngleBracket]x\&_\[RightAngleBracket] \[CupCap] \[LeftAngleBracket]y\&_\
\[RightAngleBracket]\[RightBracketingBar] = \[LeftBracketingBar]\
\[LeftAngleBracket]x\&_\[RightAngleBracket]\[RightBracketingBar] + \
\[LeftBracketingBar]\[LeftAngleBracket]y\&_\[RightAngleBracket]\
\[RightBracketingBar]\)], "DisplayFormula"],

Cell[TextData[{
  "by induction on the sequence variable ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  ", proceed as follows:"
}], "Text"],

Cell["\[FilledSmallSquare] Induction Base: Prove ", "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(y\&_\)\[LeftBracketingBar]\
\[LeftAngleBracket]\[RightAngleBracket] \[CupCap] \[LeftAngleBracket]y\&_\
\[RightAngleBracket]\[RightBracketingBar] = \[LeftBracketingBar]\
\[LeftAngleBracket]\[RightAngleBracket]\[RightBracketingBar] + \(\(\
\[LeftBracketingBar]\[LeftAngleBracket]y\&_\[RightAngleBracket]\
\[RightBracketingBar]\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "\[FilledSmallSquare] Induction Hypothesis:  Choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_0\)\&_\)]],
  " new sequence constant and assume"
}], "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(y\&_\)\[LeftBracketingBar]\
\[LeftAngleBracket]\(x\_0\)\&_\[RightAngleBracket] \[CupCap] \
\[LeftAngleBracket]y\&_\[RightAngleBracket]\[RightBracketingBar] = \
\[LeftBracketingBar]\[LeftAngleBracket]\(x\_0\)\&_\[RightAngleBracket]\
\[RightBracketingBar] + \(\(\[LeftBracketingBar]\[LeftAngleBracket]y\&_\
\[RightAngleBracket]\[RightBracketingBar]\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "\[FilledSmallSquare] Induction Conclusion: Choose ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0\)]],
  " new constant and prove "
}], "BulletText"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(y\&_\)\[LeftBracketingBar]\
\[LeftAngleBracket]a\_0, \(x\_0\)\&_\[RightAngleBracket] \[CupCap] \
\[LeftAngleBracket]y\&_\[RightAngleBracket]\[RightBracketingBar] = \
\[LeftBracketingBar]\[LeftAngleBracket]a\_0, \(x\_0\)\&_\[RightAngleBracket]\
\[RightBracketingBar] + \[LeftBracketingBar]\[LeftAngleBracket]y\&_\
\[RightAngleBracket]\[RightBracketingBar] . \ \ \ \[EmptySquare]\)], \
"DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. 3.  Implementation", "Section",
  CellTags->{"sec:ip", "c:46"}],

Cell[TextData[{
  "Each induction inference rule is considered as one prover. The provers are \
implemented as the Mathematica functions: ",
  StyleBox["NIP", "SR"],
  " (",
  StyleBox["N",
    FontWeight->"Bold"],
  "atural Numbers ",
  StyleBox["I",
    FontWeight->"Bold"],
  "nduction ",
  StyleBox["P",
    FontWeight->"Bold"],
  "rover) and ",
  StyleBox["SIP", "SR"],
  " (",
  StyleBox["S",
    FontWeight->"Bold"],
  "equence ",
  StyleBox["I",
    FontWeight->"Bold"],
  "nduction ",
  StyleBox["P",
    FontWeight->"Bold"],
  "rover) with the components:"
}], "Text"],

Cell[TextData[{
  StyleBox["Input:", "MR"],
  " is a proof situation (\[ScriptCapitalG],\[ScriptCapitalK]) where the goal \
\[ScriptCapitalG] is a universally quantified formula. "
}], "BItem1"],

Cell[TextData[{
  StyleBox["Preconditions: A", "MR"],
  "t least one of the outermost universally quantified variables of \
\[ScriptCapitalG] should be of the type natural number, in the case of ",
  StyleBox["NIP, ", "SR"],
  "sequence, in the case of ",
  StyleBox["SIP", "SR"],
  ". Note that, in the NIP prover, all ordinary variables with simple range \
specification are considered by default of type natural number.  "
}], "BItem1"],

Cell[TextData[{
  StyleBox["Output:", "MR"],
  " is an ",
  StyleBox["AND\[Dash]", "SR"],
  "situation containing the new proof situations: the induction base and the \
induction step. Both proof situations have one universally quantified \
variable less in the goal than \[ScriptCapitalG]. "
}], "BItem1"],

Cell[TextData[{
  StyleBox["Remark (Natural Language Explanation).", "IT"],
  " We also provided skeletons with the text to be used when explaining the \
application of induction (see last section for examples)."
}], "Remark"],

Cell[TextData[{
  StyleBox["Example: ", "TB"],
  "Let (\[ScriptCapitalG],\[ScriptCapitalK]) be a proof situation with the \
goal of the form:"
}], "Example"],

Cell[BoxData[
    \(TraditionalForm\`\[ForAll] \+\(x, y\)\[ScriptCapitalP]\)], \
"DisplayFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  " occur free in \[ScriptCapitalP]. The ",
  StyleBox["NIP", "SR"],
  " prover will return an ",
  StyleBox["AND\[Dash]", "SR"],
  "situation containing two proof situations:"
}], "Example"],

Cell[TextData[{
  "the induction base proof situation (",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalG]\_\[ScriptB]\)]],
  ",\[ScriptCapitalK])"
}], "BItem1"],

Cell[TextData[{
  "the induction step proof situation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(\[ScriptCapitalG]\_c\),
              "TraditionalForm"], 
            ",", \(\[ScriptCapitalG]\_\[ScriptH] \[Union] \
\[ScriptCapitalK]\)}], ")"}], TraditionalForm]]]
}], "BItem1"],

Cell["where", "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(\(\[ScriptCapitalG]\_\[ScriptB] = \[ForAll] \+y \
\[ScriptCapitalP][x \[LeftArrow] 0]\)\(,\)\),
              "TraditionalForm"]},
          {\(\(\[ScriptCapitalG]\_\[ScriptH] = \[ForAll] \+y \
\[ScriptCapitalP][x \[LeftArrow] x\_0]\)\(,\)\)},
          {\(\[ScriptCapitalG]\_\[ScriptC] = \[ForAll] \+y \[ScriptCapitalP][
                  x \[LeftArrow] \(x\_0\^+\)]\)}
          },
        ColumnAlignments->{"="}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "(",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)]],
  " is a new constant).   \[EmptySquare]"
}], "Text"],

Cell["\<\
From the provers specification, one can easily see that the \
induction basic provers are not powerful enough for completing a proof: when \
the goal has no universally quantified variables these induction provers are \
not applicable. However, by combining them with other provers that can handle \
goals which are not universally quantified we can obtain a proof. Examples of \
such provers are: the simplifier prover for equalities and the predicate \
logic prover. \
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.  Level of Proof Details", "Chapter",
  CellTags->{"sec:pos", "c:47"}],

Cell["\<\
We provide two options for the Prove function: \"proof\[Dash]object\
\[Rule]\" and \"presentation\[Rule]\", by which the user can determine the \
amount of proof details generated and shown. Recall that proof generation is \
done in Theorema in two steps: search and show (Section 2.4). The option \
\"proof\[Dash]object\[Rule]\" has influence on the proof object generated \
during the search step and, consequently, as the natural language \
representation is obtained by postprocessing this proof object, will also \
influence the result of the show step. The \"presentation\[Rule]\" option \
affects only the natural language representation by influencing the \
postprocessing of the proof object produced in the search step. Possible \
values for these options are: \"NoDetails\", \"NoPending\", \"NoFailed\", \
\"SuccessBranch\" and \"AllDetails\". The default value of these options is \
\"AllDetails\". Roughly, their effect is:\
\>", "Text"],

Cell["\"AllDetails\": All details of the proof are given.", "BItem1"],

Cell["\<\
\"NoPending\": No information on the pending proof situations is \
given.\
\>", "BItem1"],

Cell["\<\
\"NoFailed\": No information on the unsuccessful proof attempts is \
given.\
\>", "BItem1"],

Cell["\<\
\"SuccessBranch\": Only information on the part of the proof which \
led to success is given.\
\>", "BItem1"],

Cell["\<\
\"NoDetails\":  Only the result (proved or failed)of the proof is \
given.\
\>", "BItem1"],

Cell[TextData[{
  StyleBox["\"Proof\[Dash]object\[Rule]\" Option.",
    FontWeight->"Bold"],
  " The option \"proof\[Dash]object\[Rule]\" influences the quantity of \
information stored in the proof object during its generation in the search \
step. The less details are desired, the less information will be stored in \
the proof object. In detail, here is how the different values influence the \
content of the proof object:"
}], "Paragraph"],

Cell["\<\
\"AllDetails\": The proof object returned by the Prove call will \
store the complete information on how the proof was found.\
\>", "BItem1"],

Cell["\<\
\"NoPending\": The proof object will store the information related \
to the actual proof attempts done while searching the proof: both the ones \
that failed as the one that led to success. No information on the pending \
proof situations which represent non\[Dash]explored alternatives are \
kept.\
\>", "BItem1"],

Cell["\<\
\"NoFailed\": No trace of the failed attempts is stored in the \
proof\[Dash]object.\
\>", "BItem1"],

Cell["\<\
\"SuccessBranch\": The proof object will store only the trace of \
the inference rules and intermediate proof situations which actually led to a \
success.\
\>", "BItem1"],

Cell["\<\
\"NoDetails\":  The proof object will store only the result (proved \
or failed) of the proof and nothing else. No information on the inference \
rules applied or on the intermediate generated proof situations will be \
stored.\
\>", "BItem1"],

Cell[TextData[{
  StyleBox["\"Presentation\[Rule]\" Option.",
    FontWeight->"Bold"],
  " Once a proof object was generated in the search step the natural language \
representation is obtained by postprocessing the proof object. Depending on \
the value of the option \"presentation\[Rule]\" all or part of the \
information stored in the proof object will be translated to the natural \
language. Note that, in the show step, the maximum amount of information \
which can be transformed into natural language representation is the one \
stored in the proof object. If, for example, the proof object was generated \
with the \"NoDetails\" value for the option \"proof\[Dash]object\[Rule]\" the \
only information available in the proof object is the result of the proof. \
Hence, no matter what the value of the \"presentation\[Rule]\" option will \
be, the natural language representation of the proof will only contain this \
information. A detailed description on the effects of the option \
\"presentation\[Rule]\" is given below."
}], "Paragraph"],

Cell["\<\
\"AllDetails\": All the information stored in the proof object is \
translated to natural language.\
\>", "BItem1"],

Cell["\<\
\"NoPending\": The information in the proof object about possible \
pending proof\[Dash]situations is ignored and the natural language \
representation will be generated for the rest of the proof object. Note that, \
if the proof object was generated with the \"SuccessBranch\" value for the \
option \"proof\[Dash]object\[Rule]\", it will contain no pending proof \
situations. In this particular case, an \"AllDetails\" value for the \
\"presentation\[Rule]\" option will produce the same proof in natural \
language as for the value \"NoPending\".\
\>", "BItem1"],

Cell["\<\
\"NoFailed\": The information in the proof object about possible \
failed attempts is ignored and the natural language representation will be \
generated for the rest of the proof object.\
\>", "BItem1"],

Cell["\<\
\"SuccessBranch\": The natural language representation is generated \
only for the part of proof\[Dash]object which actually led to a \
success.\
\>", "BItem1"],

Cell["\<\
\"NoDetails\": The presentation of the proof will consist of one \
sentence reporting whether the proof succeeded or failed. \
\>", "BItem1"],

Cell[TextData[{
  StyleBox["Implementation of the above Options:",
    FontWeight->"Bold"],
  " We provided a function CompressDetailLevel which takes a proof object and \
eliminates the parts which are not needed for the desired detail level. For \
example, if the desired detail level is not \"AllDetails\" or \"NoPending\", \
failed alternatives from an OR\[Dash]situation are eliminated from the proof \
object. When the \"proof\[Dash]object\[Rule]\" option is used, the function \
eliminating unnecessary information will be applied to the intermediate proof \
object after each application of an inference rule. In case the \
\"presentation\[Rule]\" option is used,  the compression is done only at the \
end of the proof object generation phase, without modifying the proof object \
but by generating the natural language representation for a compressed \
version of it."
}], "Paragraph"],

Cell["\<\
Most probably, users will be mainly interested in the \
\"SuccessBranch\" level. The \"NoDetails\" level can be useful if one wants \
to check only whether certain properties are valid without going through the \
details of the proof. Not showing pending proof situations is useful when one \
wants to know which were the actual attempts (successful and failed) pursued \
before completing the proof. Another useful possibility is to use the default \
value of the \"proof\[Dash]object\[Rule]\" option in a Prove call, require no \
display of the natural language representation of the proof, save the proof \
object and view it later with the function Show (see 2.4) at different layers \
of detail specified by the option \"presentation\[Rule]\".\
\>", "Paragraph"],

Cell["\<\
We will now give examples of different Prove calls and the proof \
they generate for one fixed proof situation and prover. The difference \
between the Prove calls is in the values of the options \"proof\[Dash]object\
\[Rule]\" and \"presentation\[Rule]\". The property we prove is one of the \
exponential function. The prover NNEqIndProver that generates the proofs is a \
family of provers (see 2.4) combining two smaller provers: the simplification \
prover and the natural number  induction prover. The member of this family of \
provers we use is specified by the option \"ProverOptions\[Rule]\". Namely, \
as simplifier should be used a polynomial simplifier which has built\[Dash]in \
knowledge on the successor, addition and multiplication functions over \
natural numbers (associativity, commutativity, distributivity, neutral \
elements).\
\>", "Text"],

Cell[CellGroupData[{

Cell["7. 1.  A complete proof", "Section",
  CellTags->"c:48"],

Cell["\<\
In this section we give the Prove call using the default values for \
the \"proof\[Dash]object\[Rule]\" and \"presentation\[Rule]\" options \
(\"AllDetails\") together with the automatically generated proof. The proof \
object contains one failed branch and two pending proof situations. The \
presentation with all the alternatives makes it cumbersome to read the proof.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Prove", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<multiply terms with same exponents\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"using", "\[Rule]", 
                  RowBox[{
                    StyleBox["Definition",
                      FontWeight->"Bold"], "[", "\"\<exponentiation\>\"", 
                    "]"}]}], ",", 
                "\[IndentingNewLine]", \(by \[Rule] NNEqIndProver\), ",", 
                "\[IndentingNewLine]", \(ProverOptions \[Rule] \
{SpecialSimplifier \[Rule] \
\(\(PolynomialSimplifier\)\([\)\({\(+\(\(,\)\(0\)\(,\)\(\(*\)\(\(,\)\(0\^+\)\(\
,\)\(SuperPlus\)\)\)\)\)}\)\)\)}]}], "}"}], ",", 
          "\[IndentingNewLine]", \(in\[Dash]notebook \[Rule] \
"\<Current\>"\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp base *)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"exp base *"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp 0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "0"], ":=", \(0\^+\)}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"exp 0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp .)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]], ":=", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"exp ."],

Cell["\<\
As there are several methods which can be applied, we have \
different choices to proceed with the proof.\
\>", "TmaText"],

Cell["Alternative proof 1: failed.", "TmaText"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["exp base *",
      ButtonData:>"exp base *",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails. (The Simplifier was unable to transform the proof situation.)"
}], "TmaText"],

Cell["Alternative proof 2: proved.", "TmaText"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["exp base *",
      ButtonData:>"exp base *",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "0"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell["\<\
As there are several methods which can be applied, we have \
different choices to proceed with the proof.\
\>", "TmaText"],

Cell["Alternative proof 1: proved.", "TmaText"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"], "*", 
          SuperscriptBox[
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "0"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"], "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Alternative proof 2: pending.", "TmaText"],

Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  Background->GrayLevel[0.659998]],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell["\<\
As there are several methods which can be applied, we have \
different choices to proceed with the proof.\
\>", "TmaText"],

Cell["Alternative proof 1: proved.", "TmaText"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]], "*", 
          SuperscriptBox[
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Alternative proof 2: pending.", "TmaText"],

Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  Background->GrayLevel[0.659998]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. 2.  Proof without Pending Nodes", "Section",
  CellTags->"c:49"],

Cell["\<\
Here we give the call and generated proof for the value \"NoPending\
\" of the option \"proof\[Dash]object\[Rule]\". In the presentation, one can \
see only those actual attempts done before the proof was completed.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Prove", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<multiply terms with same exponents\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"using", "\[Rule]", 
                  RowBox[{
                    StyleBox["Definition",
                      FontWeight->"Bold"], "[", "\"\<exponentiation\>\"", 
                    "]"}]}], ",", 
                "\[IndentingNewLine]", \(by \[Rule] NNEqIndProver\), ",", 
                "\[IndentingNewLine]", \(ProverOptions \[Rule] \
{SpecialSimplifier \[Rule] \
\(\(PolynomialSimplifier\)\([\)\({\(+\(\(,\)\(0\)\(,\)\(\(*\)\(\(,\)\(0\^+\)\(\
,\)\(SuperPlus\)\)\)\)\)}\)\)\)}]}], "}"}], 
          ",", \(proof\[Dash]object \[Rule] "\<NoPending\>"\), 
          ",", \(in\[Dash]notebook \[Rule] "\<Current\>"\)}], "]"}], 
      ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp base *)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"exp base *"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp 0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "0"], ":=", \(0\^+\)}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"exp 0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp .)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]], ":=", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"exp ."],

Cell["\<\
As there are several methods which can be applied, we have \
different choices to proceed with the proof.\
\>", "TmaText"],

Cell["Alternative proof 1: failed.", "TmaText"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["exp base *",
      ButtonData:>"exp base *",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails. (The Simplifier was unable to transform the proof situation.)"
}], "TmaText"],

Cell["Alternative proof 2: proved.", "TmaText"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["exp base *",
      ButtonData:>"exp base *",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "0"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"], "*", 
          SuperscriptBox[
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "0"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"], "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]], "*", 
          SuperscriptBox[
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. 3.  Showing the Success Branch ", "Section",
  CellTags->"c:50"],

Cell["\<\
A Prove call where one wants only to see the explanation of the \
inference rules that led to success is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Prove", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<multiply terms with same exponents\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"using", "\[Rule]", 
                  RowBox[{
                    StyleBox["Definition",
                      FontWeight->"Bold"], "[", "\"\<exponentiation\>\"", 
                    "]"}]}], ",", 
                "\[IndentingNewLine]", \(by \[Rule] NNEqIndProver\), ",", 
                "\[IndentingNewLine]", \(ProverOptions \[Rule] \
{SpecialSimplifier \[Rule] \
\(\(PolynomialSimplifier\)\([\)\({\(+\(\(,\)\(0\)\(,\)\(\(*\)\(\(,\)\(0\^+\)\(\
,\)\(SuperPlus\)\)\)\)\)}\)\)\)}]}], "}"}], 
          ",", \(presentation \[Rule] "\<SuccessBranch\>"\), 
          ",", \(in\[Dash]notebook \[Rule] "\<Current\>"\)}], "]"}], 
      ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp base *)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"exp base *"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp 0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "0"], ":=", \(0\^+\)}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"exp 0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(exp .)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]], ":=", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"exp ."],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["exp base *",
      ButtonData:>"exp base *",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "0"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "0"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"], "*", 
          SuperscriptBox[
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "0"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "0"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"], "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "*", 
        SuperscriptBox[
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "0"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "0"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp 0",
      ButtonData:>"exp 0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]], "*", 
              SuperscriptBox[
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]], "*", 
          SuperscriptBox[
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "TmaText"],

Cell["Simplification of the lhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"],

Cell["Simplification of the rhs term:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], 
        SuperscriptBox[
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["exp .",
      ButtonData:>"exp .",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "*", 
            SuperscriptBox[
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simplifier",
      ButtonData:>"Special Simplifier",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_2\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Expression"],
  "\[RightFloor]"
}], "TmaText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. 4.  Showing only the Result of the Proof", "Section",
  CellTags->"c:51"],

Cell["\<\
The only further possibility of compressing the detail level which \
the user can choose at the time of calling Prove is level \"NoDetails\". For \
our example, the call and resulting proof will be:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"Prove", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<multiply terms with same exponents\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"using", "\[Rule]", 
                  RowBox[{
                    StyleBox["Definition",
                      FontWeight->"Bold"], "[", "\"\<exponentiation\>\"", 
                    "]"}]}], ",", 
                "\[IndentingNewLine]", \(by \[Rule] NNEqIndProver\), ",", 
                "\[IndentingNewLine]", \(ProverOptions \[Rule] \
{SpecialSimplifier \[Rule] \
\(\(PolynomialSimplifier\)\([\)\({\(+\(\(,\)\(0\)\(,\)\(\(*\)\(\(,\)\(0\^+\)\(\
,\)\(SuperPlus\)\)\)\)\)}\)\)\)}]}], "}"}], 
          ",", \(presentation \[Rule] "\<NoDetails\>"\), ",", 
          " ", \(in\[Dash]notebook \[Rule] "\<Current\>"\)}], "]"}], 
      ";"}]], "Input"],

Cell["The proof succeeded.", "TmaText"]
}, Open  ]],

Cell["\<\
Note that, once the proof is generated in a notebook with cell \
grouping set to manual, one can have further compressions of the detail level \
by closing some of the cells. For the proof we showed, one could for example \
click close the whole induction base proof and/or the simplification details. \
\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.  Provers", "Chapter",
  CellTags->{"sec:provers", "c:52"}],

Cell["\<\
As described in Section 2.5, a user of the Theorema system receives \
the provers as black\[Dash]box provers. In the forthcoming version of the \
Theorema system, the user will have the possibility to program himself the \
provers. \
\>", "Text"],

Cell["\<\
One can choose to combine all the inference rules in just one \
general prover. In Theorema we chose the approach of providing special \
provers for special types of problems. Depending on the type of formulae \
contained in the goal and knowledge base and on the type of variables, one \
can specify what kind of proving techniques should be used. For example, if \
the goal and assumptions are equalities over natural numbers then it seems \
natural to use a prover combining natural numbers induction with equality \
rewriting instead of a general prover. If the goal and knowledge base contain \
predicates defined by case statements, then a suitable prover should contain \
both case distinction inference rules and predicate logic rules. \
\>", "Text"],

Cell[TextData[{
  StyleBox["Remark. ", "IT"],
  "All proofs we present in this chapter were ",
  StyleBox["completely automatically generated",
    FontSlant->"Italic"],
  " by the provers called in the corresponding calls, both the text and the \
formulae within the proofs. (Recall that for each inference rule which we \
described in the previous sections we also provided the skeleton with the \
text to be used when generating the natural language proof.) In order to make \
it easier visible, the automatically generated proof is given in italics. All \
the examples we present, unless specified otherwise, are generated with the \
\"presentation\[Rule]\" option set on \"SuccessBranch\" and the \
\"in\[Dash]notebook\[Rule]\" option set on \"Current\". We will give comments \
on the depth of the complete proof\[Dash]object generated and the number of \
failed branches and pending proof situations. "
}], "Remark"],

Cell[CellGroupData[{

Cell["\<\
8. 1.  Prove\[Dash]Compute\[Dash]Solve Provers for Predicate \
Logic\
\>", "Section",
  CellTags->{"sec:pcs", "c:53"}],

Cell[TextData[{
  "The Prove\[Dash]Compute\[Dash]Solve type of provers are the most important \
part of this work as they integrate aspects of proving, simplifying/computing \
and solving. As stated by Buchberger in (",
  ButtonBox["[18]",
    ButtonData:>"Buchb:96c",
    ButtonStyle->"Hyperlink",
    ButtonNote->"B. Buchberger, 1996, Proving, Solving, Computing"],
  "), providing a uniform frame for these activities was the goal which he \
wanted to achieve with the software system which later was called Theorema \
(",
  ButtonBox["[23]",
    ButtonData:>"Buchb_al:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and T. Jebelean and F. Kriftner and M. Marin and E. \
Tomuta and D. Vasaru, 19 ..."],
  ")."
}], "Text"],

Cell["\<\
These provers were designed for the particular class of problems we \
were interested in, namely proving rewrite properties of notions involving \
alternating quantifiers such as:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`p[x, 
        y]\  \[DoubleLeftRightArrow] \(\(\[ForAll] \+a\)\+\(A[a]\)\(\(\
\[Exists] \+b\)\+\(B[b]\)\(\(\[ForAll] \+c\)\+\(C[c]\)\[Ellipsis]\ q[a, b, 
                c, \[Ellipsis], x, y]\)\)\)\)], "DisplayFormula"],

Cell["\<\
For example, there are many notions of this form in mathematical \
analysis: limits, continuity, boundedness, etc. The exploration of the \
theories involving these notions usually starts by proving some of their \
rewrite properties which will be used either in computing with the notions or \
in more complicated proofs. By rewrite properties of notions we mean \
properties like: sum of limits is limit of sum, product of bounded functions \
is bounded, composition of continuous functions is continuous, etc. \
Buchberger observed that one can see the proofs of such rewrite properties as \
a process cycling through prove, compute and solve phases. If one considers \
the knowledge base as consisting of rewrite\[Dash]formulae and \
non\[Dash]rewrite\[Dash]formulae, see Section 3.0, then the three phases can \
be described as follows:\
\>", "Text"],

Cell["\<\
Prove: Apply the usual natural deduction rules for propositional \
and predicate logic to the goal and the non\[Dash]rewrite\[Dash]formulae in \
the knowledge base.\
\>", "BItem1"],

Cell["\<\
Compute: Use the rewrite\[Dash]formulae of knowledge base for \
simplifying the goal and knowledge base.\
\>", "BItem1"],

Cell["\<\
Solve: If the goal is an existential formula or the proof situation \
is a solve problem (see  Section 4.1.0), some general or special solvers can \
be used.\
\>", "BItem1"],

Cell["\<\
The switch between the phases was thought to be done whenever no \
more modifications of the proof situations occur within a phase. This would \
have the disadvantage that, for example, if a proof situation is reduced to a \
trivial one in a compute phase, instead of applying natural deduction rules \
which will recognize it as such, this trivial proof situation will \
continuously be modified as long as possible by applying general rewriting to \
it. After doing various hand proofs in mathematical analysis, we were able to \
generalize and formalize two prove\[Dash]solve\[Dash]compute strategies in \
the Theorema system. These strategies do not have anymore the disadvantage we \
described above. The provers implementing these strategies are PCS and PSC, \
provers which also give very nice proofs for properties other than the ones \
we were initially interested.\
\>", "Text"],

Cell["\<\
Before having available solvers within our system, i.e. when \
Theorema was using Mathematica version 3,  we relied for the solve part on \
the few simple rules of the predicate logic prover for proving existential \
formulae. Hence the solve phase was basically part of the prove phase. At \
that time, a PC (Prove-Compute) prover, the predecessor of PCS and PSC, was \
developed which combined only the natural deduction rules for predicate logic \
with general rewriting. This prover was successfully used as an alternative \
to the predicate logic prover and delivered in many cases more \
human\[Dash]like proofs than the predicate logic prover. However, for both \
provers (PC and predicate logic prover) the proofs involving existential \
quantifiers were a difficult task that involved significant user interaction \
(for inventing the \"solving terms\" at crucial moments in the proof process \
generation). \
\>", "Text"],

Cell["\<\
In this section we will describe the provers PC, PCS, PSC and give \
some examples of proofs generated by them. Note that all these provers have \
options. Hence, they represent families of provers.\
\>", "Text"],

Cell[CellGroupData[{

Cell["8. 1. 1. The PC Prover", "Subsection",
  CellTags->"c:54"],

Cell["\<\
This alternative to the predicate logic prover combines natural \
deduction rules for propositional and predicate logic with general rewriting. \
The strategy of PC is to cycle through prove and compute phases as follows:\
\
\>", "Text"],

Cell["\<\
Prove: Apply as long as possible natural deduction rules for \
propositional and predicate logic to the goal and the non\[Dash]rewrite \
formulae of the knowledge base of the intermediate proof situations.\
\>", \
"BItem1"],

Cell["\<\
Compute: Apply one general rewriting step to one formula from the \
proof situation. \
\>", "BItem1"],

Cell["\<\
For the prove phase we use a subset of natural deduction rules for \
propositional and predicate logic without equality (combined in a prover \
called BasicND), while for the compute phase we use the GRS simplifier. This \
combination of inference rules makes the PC prover particularly appropriate \
for proof situations where implications and equivalences are present. The \
treatment of equalities is also handled but in a restricted way. Namely, they \
are used for rewriting. Hence, for proving equalities either one adds more \
inference rules that deal with equalities or one needs to explicitly add some \
knowledge on the equality  predicate. \
\>", "Text"],

Cell["\<\
The options PC provides influence the way rewriting is applied, in \
fact they are inherited from the GRS simplifier which is one of the \
components of PC. The options which have other default values than the ones \
of GRS are described in the following. One such option specifies in which \
order should the rewriting be attempted: goal or knowledge base. The default \
behavior is to always attempt to rewrite an assumption before the goal. This \
heuristic showed to give good results in many examples we tried out. There \
are some proofs where, by simplifying first the goal, the proof looks nicer. \
However, the risk is that we simplify the goal too much, i.e. we arrive to a \
sufficient goal which cannot be proved. When simplifying knowledge we do not \
run through such a risk. Another option which the user can set is whether to \
use semantic rewriting or not. The default is not to use it as this will just \
introduce solve proof\[Dash]situations which are difficult or impossible to \
solve by the set of inference rules we combined in PC. \
\>", "Text"],

Cell[TextData[{
  "In Section 8.1.1.1 we illustrate the use of PC for proving properties \
involving notions with alternating quantifiers and in Section 8.1.1.2 we give \
examples of proofs in set\[Dash]theory where PC is performing much better \
than Otter (",
  ButtonBox["[70]",
    ButtonData:>"McCune_Wos:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. McCune and L. Wos, 1997, Otter: The CADE-13 Competition \
incarnations"],
  "), one of the best resolution provers. "
}], "Text"],

Cell[CellGroupData[{

Cell["8. 1. 1. 1.  Using PC together with Decomposition Strategy", \
"Subsubsection",
  CellTags->{"sec:PC-dec", "c:55"}],

Cell["\<\
The strategy developed in Theorema for proving rewrite properties \
of notions with alternating quantifiers, before more solving capabilities \
were added to the system, was to recursively decompose the notions into \
intermediate ones with one quantifier less until we have only ground \
formulae, find their corresponding rewrite properties for each level and \
prove them by using the property for the levels below. Such an decomposition \
strategy was illustrated in Section 4 and in this section we give the \
corresponding proofs generated by PC. We comment the proofs also with respect \
to the results one would obtain by using the predicate logic prover.\
\>", \
"Text"],

Cell[TextData[{
  StyleBox["Example (Sum Continuity by PC). ",
    FontWeight->"Bold"],
  " For proving the \"4-ary continuity\" proposition we need the definition \
for addition of functions:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<function sum\>\"", ",", \(any[f, g, x]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(\((f + g)\)[x] = f[x] + g[x]\), "\"\<f+g\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"function product", "function sum"}],

Cell["\<\
and some properties on minimum and absolute value, properties which \
we assume were proved when the theory of real numbers with minimum and \
absolute value was explored:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<distance of sum\>\"", 
          ",", \(any[x, y, z, t, \[Delta], \[Epsilon]]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(\((\[LeftBracketingBar]\((y + t)\) - \((x + 
                              z)\)\[RightBracketingBar] < \((\[Delta] + \
\[Epsilon])\))\)\[DoubleLongLeftArrow]\n\t\((\[LeftBracketingBar]y - 
                            x\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]t - z\[RightBracketingBar] < \[Epsilon])\)\), 
                "\"\<dist+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->{"distance of sum", "less, minimum"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<less, minimum\>\"", ",", \(any[m, n, p]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(m < min[n, p] \[Implies] \((m < n \[And] m < p)\)\), 
                "\"\<<min\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input"],

Cell["\<\
The call for proving the \"4\[Dash]ary continuity\" intermediate \
property by PC and the automatically generated proof is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<4-ary continuity\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity 4-ary\>\"", 
                  "]"}], ",", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<function sum\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<distance of sum\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<less, minimum\>\"", 
                  "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", \(by \[Rule] PC\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont4:+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", "\[IndentingNewLine]", 
              StyleBox["\[Delta]1",
                FontFamily->"Times"], ",", 
              StyleBox["\[Delta]2",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]1",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]2",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Delta]1",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Delta]2",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "+", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  RowBox[{
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"], "+", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"]}], ",", 
                  RowBox[{"min", "[", 
                    RowBox[{
                      StyleBox["\[Delta]1",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Delta]2",
                        FontFamily->"Times"]}], "]"}]}], "]"}]}], ")"}]}], 
        ","}]], "Conclusion"]
}], "Conclusion",
  CellTags->"cont4:+"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["\[Delta]",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ",", 
                  StyleBox["\[Delta]",
                    FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
              "\[IndentingNewLine]", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}], "\[Implies]", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}], ","}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"cont4"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f+g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["g",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "+", 
                  StyleBox["g",
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox["x",
                FontFamily->"Times"], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}], "+", 
              RowBox[{
                StyleBox["g",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"f+g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(dist+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["t",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"], ",", 
            StyleBox["z",
              FontFamily->"Times"], ",", 
            StyleBox["\[Delta]",
              FontFamily->"Times"], ",", 
            StyleBox["\[Epsilon]",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}], "\[And]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["t",
                      FontFamily->"Times"], "-", 
                    StyleBox["z",
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "+", 
                      StyleBox["t",
                        FontFamily->"Times"]}], ")"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "+", 
                      StyleBox["z",
                        FontFamily->"Times"]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], "+", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dist+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(<min)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "<", 
              RowBox[{"min", "[", 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], ",", 
                  StyleBox["p",
                    FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                StyleBox["n",
                  FontFamily->"Times"]}], "\[And]", 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                StyleBox["p",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"<min"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]1\_0\),
              FontFamily->"Times"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]2\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"]}], ",", 
          RowBox[{"min", "[", 
            RowBox[{
              StyleBox[\(\[Delta]1\_0\),
                FontFamily->"Times"], ",", 
              StyleBox[\(\[Delta]2\_0\),
                FontFamily->"Times"]}], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont4",
      ButtonData:>"cont4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]1\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], "-", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}]}], 
                "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]1\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont4",
      ButtonData:>"cont4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]2\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], "-", 
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}]}], 
                "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]2\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont4",
      ButtonData:>"cont4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              RowBox[{"min", "[", 
                RowBox[{
                  StyleBox[\(\[Delta]1\_0\),
                    FontFamily->"Times"], ",", 
                  StyleBox[\(\[Delta]2\_0\),
                    FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "+", 
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"]}], ")"}], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "+", 
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"]}], ")"}], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox[\(\[Epsilon]1\_0\),
                  FontFamily->"Times"], "+", 
                StyleBox[\(\[Epsilon]2\_0\),
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"5"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], "-", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
        RowBox[{"min", "[", 
          RowBox[{
            StyleBox[\(\[Delta]1\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]2\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "]"}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], "<",
         
        RowBox[{
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["<min",
      ButtonData:>"<min",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]2\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["dist+",
      ButtonData:>"dist+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(y\_0\),
                    FontFamily->"Times"], "]"}], "+", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(y\_0\),
                    FontFamily->"Times"], "]"}]}], ")"}], "-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "]"}], "+", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "]"}]}], ")"}]}], 
          "\[RightBracketingBar]"}], "<", 
        RowBox[{
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f+g",
      ButtonData:>"f+g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(y\_0\),
                    FontFamily->"Times"], "]"}], "+", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(y\_0\),
                    FontFamily->"Times"], "]"}]}], ")"}], "-", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "]"}], "+", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "]"}]}], ")"}]}], 
          "\[RightBracketingBar]"}], "<", 
        RowBox[{
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["dist+",
      ButtonData:>"dist+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]2\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "\[RightBracketingBar]"}], 
          "<", 
          StyleBox[\(\[Epsilon]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]2\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]1\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "-", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]2\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["<min",
      ButtonData:>"<min",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], "-", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
        RowBox[{"min", "[", 
          RowBox[{
            StyleBox[\(\[Delta]1\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]2\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell["\<\
The proof object of the previous proof has depth 9, no failed \
branches and no pending proof situations. The same proof done by the \
predicate logic prover which uses only natural deduction rules of predicate \
logic has a proof object of depth 24 and it takes double the time. The proof \
produced by the predicate logic prover is in fact very similar with the proof \
that PC would produce under the settings that the goal should be first \
rewritten instead of the knowledge base. Also the depth of the final proof \
object is the same. Now we can move on to the property for \"3\[Dash]ary \
continuity\". Here we need the relationship between minimum and \
greater:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<minimum, greater\>\"", ",", \(any[m, n, p]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(min[n, p] > 
                    m\  \[DoubleLeftArrow] \((n > m \[And] p > m)\)\), 
                "\"\<min>\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->"minimum, greater"],

Cell["\<\
The Prove call and the generated proof are:
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<3-ary continuity\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity 3-ary\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", "\"\<4-ary continuity\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<minimum, greater\>\"", 
                  "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", \(by \[Rule] PC\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont3:+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]1",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]2",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "+", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  RowBox[{
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"], "+", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"]}]}], "]"}]}], ")"}]}], ","}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"cont3:+"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
              "\[IndentingNewLine]", 
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ">", "0"}], "\[And]", 
                    RowBox[{"continuous", "[", 
                      RowBox[{
                        StyleBox["f",
                          FontFamily->"Times"], ",", 
                        StyleBox["x",
                          FontFamily->"Times"], ",", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"], ",", 
                        StyleBox["\[Delta]",
                          FontFamily->"Times"]}], "]"}]}], ")"}]}]}], ")"}]}],
         ","}]], "Assumption"]
}], "Assumption",
  CellTags->"cont3"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont4:+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["\[Delta]1",
                FontFamily->"Times"], ",", "\[IndentingNewLine]", 
              StyleBox["\[Delta]2",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]1",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]2",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Delta]1",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Delta]2",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "+", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  RowBox[{
                    StyleBox["\[Epsilon]1",
                      FontFamily->"Times"], "+", 
                    StyleBox["\[Epsilon]2",
                      FontFamily->"Times"]}], ",", 
                  RowBox[{"min", "[", 
                    RowBox[{
                      StyleBox["\[Delta]1",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Delta]2",
                        FontFamily->"Times"]}], "]"}]}], "]"}]}], ")"}]}], 
        ","}]], "Assumption"]
}], "Assumption",
  CellTags->"cont4:+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(min>)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}], "\[And]", 
              RowBox[{
                StyleBox["p",
                  FontFamily->"Times"], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"min", "[", 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], ",", 
                  StyleBox["p",
                    FontFamily->"Times"]}], "]"}], ">", 
              StyleBox["m",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"min>"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont3",
      ButtonData:>"cont3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}], "\[And]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(\[Epsilon]1\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont3",
      ButtonData:>"cont3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}], "\[And]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(\[Epsilon]2\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"5"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_1\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]\_1\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["6.1",
      ButtonData:>"6.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["4.1",
      ButtonData:>"4.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["min>",
      ButtonData:>"min>",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"min", "[", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]\_1\),
              FontFamily->"Times"]}], "]"}], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["6.2",
      ButtonData:>"6.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["4.2",
      ButtonData:>"4.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["cont4:+",
      ButtonData:>"cont4:+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"]}], ",", 
          RowBox[{"min", "[", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], ",", 
              StyleBox[\(\[Delta]\_1\),
                FontFamily->"Times"]}], "]"}]}], "]"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont3",
      ButtonData:>"cont3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}], "\[And]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"]}], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                RowBox[{
                  StyleBox[\(\[Epsilon]1\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(\[Epsilon]2\_0\),
                    FontFamily->"Times"]}], ",", 
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " it is sufficient to prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"min", "[", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], ",", 
              StyleBox[\(\[Delta]\_1\),
                FontFamily->"Times"]}], "]"}], ">", "0"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontFamily->"Times"], "+", 
              StyleBox[\(g\_0\),
                FontFamily->"Times"]}], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            RowBox[{
              StyleBox[\(\[Epsilon]1\_0\),
                FontFamily->"Times"], "+", 
              StyleBox[\(\[Epsilon]2\_0\),
                FontFamily->"Times"]}], ",", 
            RowBox[{"min", "[", 
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"]}], "]"}]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["10.1",
      ButtonData:>"10.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"min", "[", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(\[Delta]\_1\),
              FontFamily->"Times"]}], "]"}], ">", "0"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10.1",
      ButtonData:>"10.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["10.2",
      ButtonData:>"10.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontFamily->"Times"]}], ",", 
          RowBox[{"min", "[", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], ",", 
              StyleBox[\(\[Delta]\_1\),
                FontFamily->"Times"]}], "]"}]}], "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10.2",
      ButtonData:>"10.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell["\<\
The proof object of the previous proof has depth 15, no failed \
branches and one pending proof situation (an alternative to prove formula \
(9)). We are left now with the proof of the initial proposition. For proving \
it, we will use a variant of the \"3\[Dash]ary\" property, namely:\
\>", \
"Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary continuity of sum: variant\>\"", ",", 
        "\[IndentingNewLine]", \(any[f, x, g, \[Epsilon]]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\((continuous[f, x, \[Epsilon]/2] \[And] 
                    continuous[g, 
                      x, \[Epsilon]/2])\)\n\t\[DoubleLongRightArrow]
                continuous[f + g, x, \[Epsilon]]\), "\"\<cont3:+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"3-ary continuity of sum: variant"],

Cell["and some property of division with positive numbers", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{"\"\<positiveness\>\"", ",", "\n", "\t", GridBox[{
              {\(\(\[ForAll] \+a\)\+\(a > 0\)\((a/2)\) > 0\), "\"\</2>\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "."}]], "Input",
  CellTags->"positiveness"],

Cell["Now we can call PC:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<2-ary continuity\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "->", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity 2-ary\>\"", 
                  "]"}], ",", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", 
                  "\"\<3-ary continuity of sum: variant\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Proposition",
                    FontWeight->"Bold"], "[", "\"\<positiveness\>\"", "]"}]}],
               "}"}]}], ",", "\[IndentingNewLine]", \(by -> PC\)}], "]"}], 
      ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont2:+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              "\[IndentingNewLine]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "+", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"]}], "]"}]}], ")"}]}], ","}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"cont2:+"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                  RowBox[{"continuous", "[", 
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Times"], ",", 
                      StyleBox["x",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], "]"}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"cont2"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont3:+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    FractionBox[
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"], "2"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    FractionBox[
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"], "2"]}], "]"}]}], "\[Implies]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "+", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], "]"}]}], ")"}]}], ","}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"cont3:+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(/2>)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["a",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{
              FractionBox[
                StyleBox["a",
                  FontFamily->"Times"], "2"], ">", "0"}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"/2>"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont2",
      ButtonData:>"cont2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont2",
      ButtonData:>"cont2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont2",
      ButtonData:>"cont2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(g\_0\),
                    FontFamily->"Times"]}], ",", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"5"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "+", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont3:+",
      ButtonData:>"cont3:+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"], "2"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"], "2"]}], "]"}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"], "2"]}], "]"}], "\[And]", 
        RowBox[{
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"], "2"], ">", "0"}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        FractionBox[
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"], "2"], ">", "0"}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["/2>",
      ButtonData:>"/2>",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True]
}, Open  ]],

Cell["\<\
The proof object of the previous proof has depth 10, no pending \
alternatives and no failed branch. \[EmptySquare]\
\>", "Text"],

Cell["\<\
Proving the continuity of a function product along these lines was \
rather difficult by using the PC prover as one had to find a good variant for \
the \"3\[Dash]ary\" proposition to be used in the proof of the \
\"2\[Dash]ary\" one. \
\>", "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
8. 1. 1. 2.  Set\[Dash]Theory Proofs by PC\
\>", "Subsubsection",
  CellTags->{"sec:PC-otter", "c:56"}],

Cell["\<\
We give some proofs from set\[Dash]theory where the PC prover \
performs much better than Otter, one of the \
state\[Dash]of\[Dash]the\[Dash]art resolution provers for first order logic \
with equality. The reason is that PC is particularly suited for dealing with \
proof situations containing implications and equivalences. When also \
equalities come into play, as Otter has built\[Dash]in knowledge on equality, \
then Otter will perform better.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 1. ",
    FontWeight->"Bold"],
  " Let us consider some definitions from set\[Dash]theory:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<inclusion\>\"", ",", \(any[A, B]\), ",", "\n", "\t\t", GridBox[{
              {\(\((A \[SubsetEqual] 
                      B)\)\[DoubleLongLeftRightArrow]\(\[ForAll] \+x\((\((x \
\[Element] A)\)\[DoubleLongRightArrow]\((x \[Element] B)\))\)\)\), 
                "\"\<\[SubsetEqual]:\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->{
  "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
    "Union"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<union\>\"", ",", \(any[x, A]\), ",", "\n", "\t\t", GridBox[{
              {\(\((x \[Element] \
\(\[Union]A\))\)\[DoubleLongLeftRightArrow]\(\[Exists] \+Y\((\((x \[Element] 
                            Y)\) \[And] \((Y \[Element] A)\))\)\)\), 
                "\"\<\[Union]:\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<powerset\>\"", ",", \(any[x, A]\), ",", "\n", "\t\t", GridBox[{
              {\(\((x \[Element] \[ScriptCapitalP][
                        A])\)\[DoubleLongLeftRightArrow]\((x \[SubsetEqual] 
                      A)\)\), "\"\<P:\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input"],

Cell["\<\
and prove that the unary union of the powerset of a set A is \
included in A.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<union of powerset is included...\>\"", ",", \(any[A]\), ",", "\n", 
        "\t\t", GridBox[{
            {\(\(\[Union]\[ScriptCapitalP][A]\) \[SubsetEqual] A\), 
              "\"\<P\[Union]\[SubsetEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Union of powerset is included..."],

Cell["\<\
The knowledge base consists of only equivalences. Let us use PC for \
proving the proposition:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", 
            "\"\<union of powerset is included...\>\"", "]"}], ",", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<inclusion\>\"", "]"}], ",",
                 "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<union\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<powerset\>\"", "]"}]}], 
              "}"}]}], ",", "\[IndentingNewLine]", \(by \[Rule] PC\)}], "]"}],
       ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(P\[Union]\[SubsetEqual])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{\(\[Union]\[ScriptCapitalP][A]\), "\[SubsetEqual]", 
            StyleBox["A",
              FontFamily->"Times"]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"P\[Union]\[SubsetEqual]"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[SubsetEqual]:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["B",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontFamily->"Times"], "\[SubsetEqual]", 
              StyleBox["B",
                FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["A",
                      FontFamily->"Times"]}], "\[Implies]", 
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["B",
                      FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[SubsetEqual]:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[Union]:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], "\[Element]", 
            RowBox[{\(\[Union]A\), "\[DoubleLeftRightArrow]", 
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["Y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "\[Element]", 
                      StyleBox["Y",
                        FontFamily->"Times"]}], "\[And]", 
                    RowBox[{
                      StyleBox["Y",
                        FontFamily->"Times"], "\[Element]", 
                      StyleBox["A",
                        FontFamily->"Times"]}]}], ")"}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[Union]:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(P:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], "\[Element]", 
            RowBox[{\(\[ScriptCapitalP][A]\), "\[DoubleLeftRightArrow]", 
              StyleBox["x",
                FontFamily->"Times"]}], "\[SubsetEqual]", 
            StyleBox["A",
              FontFamily->"Times"]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"P:"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["P\[Union]\[SubsetEqual]",
      ButtonData:>"P\[Union]\[SubsetEqual]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Union]", 
          RowBox[{"\[ScriptCapitalP]", "[", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"], "]"}]}], "\[SubsetEqual]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[SubsetEqual]:",
      ButtonData:>"\[SubsetEqual]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[Union]", 
                RowBox[{"\[ScriptCapitalP]", "[", 
                  StyleBox[\(A\_0\),
                    FontFamily->"Times"], "]"}]}]}], "\[Implies]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[Union]", 
          RowBox[{"\[ScriptCapitalP]", "[", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"], "]"}]}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"3"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["Y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(x\_0\),
                FontFamily->"Times"], "\[Element]", 
              StyleBox["Y",
                FontFamily->"Times"]}], "\[And]", 
            RowBox[{
              StyleBox["Y",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[ScriptCapitalP]", "[", 
                StyleBox[\(A\_0\),
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "\[Element]", 
          StyleBox[\(Y\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          StyleBox[\(Y\_0\),
            FontFamily->"Times"], "\[Element]", 
          RowBox[{"\[ScriptCapitalP]", "[", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"], "]"}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"6"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6.2",
      ButtonData:>"6.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["P:",
      ButtonData:>"P:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Y\_0\),
          FontFamily->"Times"], "\[SubsetEqual]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[SubsetEqual]:",
      ButtonData:>"\[SubsetEqual]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(Y\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6.1",
      ButtonData:>"6.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"]
}, Open  ]],

Cell["\<\
The proof object has depth 9, no failed or pending branches. The \
above proof is generated by Theorema in 4 seconds while Otter needs 38 \
seconds on machines which are more powerful than the one we run Theorema on. \
Considering that Theorema is implemented in Mathematica, an interpreted \
language, while Otter is written in C makes this difference even more \
significant.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 2. ",
    FontWeight->"Bold"],
  " Let us redefine the powerset such that we only use member function:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<powerset\>\"", ",", \(any[x, A]\), ",", "\n", "\t\t", GridBox[{
            {\(\((x \[Element] \[ScriptCapitalP][
                      A])\)\[DoubleLongLeftRightArrow]\(\[ForAll] \+y\((\((y \
\[Element] x)\) \[Implies] \((y \[Element] A)\))\)\)\), "\"\<\[Union]:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Powerset"],

Cell["and let us consider the definition of set equality:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<set equality\>\"", ",", \(any[A, B]\), ",", "\n", "\t\t", 
        GridBox[{
            {\(\((A \[HumpEqual] 
                    B)\)\[DoubleLongLeftRightArrow]\(\[ForAll] \+x\((x \
\[Element] A)\) \[DoubleLeftRightArrow] \((x \[Element] B)\)\)\), 
              "\"\<seq:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Set equality"],

Cell["Suppose we want to prove:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<fixpoint property\>\"", ",", \(any[A]\), ",", "\n", "\t\t", 
        GridBox[{
            {\(\((A \[HumpEqual] \[ScriptCapitalP][\(\[Union]A\)])\)\
\[DoubleLongLeftRightArrow]\ \(\[Exists] \+B 
                    A \[HumpEqual] \[ScriptCapitalP][B]\)\), "\"\<FP\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Fixpoint property"],

Cell["\<\
The call and proof generated by PC, together with the time it took \
is given below. Otter gives up to prove this proposition after 4 hours \
because it reaches the maximum bound set on time.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<fixpoint property\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<set equality\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<union\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<powerset\>\"", "]"}]}], 
              "}"}]}], ",", "\[IndentingNewLine]", \(by \[Rule] PC\), ",", 
          "\[IndentingNewLine]", \(ProverOptions -> {GRWTarget \[Rule] \
{"\<goal\>", "\<kb\>"}, \[IndentingNewLine]RWBooleanLiteralCombinations \
\[Rule] False}\)}], "]"}], "//", "Timing"}]], "Input",
  CellTags->"Examples"],

Cell[" ", "Text"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(FP)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontFamily->"Times"], 
              "\[HumpEqual]", \(\[ScriptCapitalP][\(\[Union]A\)]\)}], 
            "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["B",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["A",
                    FontFamily->"Times"], "\[HumpEqual]", 
                  RowBox[{"\[ScriptCapitalP]", "[", 
                    StyleBox["B",
                      FontFamily->"Times"], "]"}]}], ")"}]}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"FP"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(seq:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["B",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontFamily->"Times"], "\[HumpEqual]", 
              StyleBox["B",
                FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["A",
                      FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["B",
                      FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"seq:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[Union]:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"Union", "[", 
                StyleBox["A",
                  FontFamily->"Times"], "]"}]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["Y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["Y",
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{
                    StyleBox["Y",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["A",
                      FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Union]:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[Union]:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[ScriptCapitalP]", "[", 
                StyleBox["A",
                  FontFamily->"Times"], "]"}]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "\[Implies]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "\[Element]", 
                    StyleBox["A",
                      FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"\[Union]:"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["FP",
      ButtonData:>"FP",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(A\_0\),
            FontFamily->"Times"], "\[HumpEqual]", 
          RowBox[{"\[ScriptCapitalP]", "[", 
            RowBox[{"\[Union]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}], "]"}]}], "\[DoubleLeftRightArrow]", 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["B",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(A\_0\),
                FontFamily->"Times"], "\[HumpEqual]", 
              RowBox[{"\[ScriptCapitalP]", "[", 
                StyleBox["B",
                  FontFamily->"Times"], "]"}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " in both directions."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Direction from left to right:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_0\),
          FontFamily->"Times"], "\[HumpEqual]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          RowBox[{"\[Union]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"3"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["B",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(A\_0\),
              FontFamily->"Times"], "\[HumpEqual]", 
            RowBox[{"\[ScriptCapitalP]", "[", 
              StyleBox["B",
                FontFamily->"Times"], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is an instance of it."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Direction from right to left:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["B",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(A\_0\),
              FontFamily->"Times"], "\[HumpEqual]", 
            RowBox[{"\[ScriptCapitalP]", "[", 
              StyleBox["B",
                FontFamily->"Times"], "]"}]}], ")"}]}]], "Assumption"],
  " "
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"5"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_0\),
          FontFamily->"Times"], "\[HumpEqual]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          RowBox[{"\[Union]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(A\_0\),
          FontFamily->"Times"], "\[HumpEqual]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          StyleBox[\(B\_0\),
            FontFamily->"Times"], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["seq:",
      ButtonData:>"seq:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[Element]", 
                StyleBox[\(A\_0\),
                  FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
              StyleBox["x",
                FontFamily->"Times"]}], "\[Element]", 
            RowBox[{"\[ScriptCapitalP]", "[", 
              RowBox[{"\[Union]", 
                StyleBox[\(A\_0\),
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "\[Element]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "\[Element]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          RowBox[{"\[Union]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " in both directions."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Direction from left to right:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  " "
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          RowBox[{"\[Union]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[Union]", 
                StyleBox[\(A\_0\),
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(x\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"14"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[Union]", 
          StyleBox[\(A\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["Y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(y\_0\),
                FontFamily->"Times"], "\[Element]", 
              StyleBox["Y",
                FontFamily->"Times"]}], "\[And]", 
            RowBox[{
              StyleBox["Y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"16"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " it is sufficient to prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(y\_0\),
            FontFamily->"Times"], "\[Element]", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "\[Element]", 
          StyleBox[\(A\_0\),
            FontFamily->"Times"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"17"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["17.1",
      ButtonData:>"17.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(x\_0\),
          FontFamily->"Times"]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["17.1",
      ButtonData:>"17.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["17.2",
      ButtonData:>"17.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["17.2",
      ButtonData:>"17.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Direction from right to left:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          RowBox[{"\[Union]", 
            StyleBox[\(A\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"12"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(A\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[Union]", 
                StyleBox[\(A\_0\),
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"18"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["seq:",
      ButtonData:>"seq:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[Element]", 
              RowBox[{"\[ScriptCapitalP]", "[", 
                StyleBox[\(B\_0\),
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"19"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          StyleBox[\(B\_0\),
            FontFamily->"Times"], "]"}]}]], "Conclusion"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(x\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(B\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"20"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_1\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(x\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"21"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_1\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(B\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"22"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_1\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[Union]", 
          StyleBox[\(A\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(23)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["Y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(y\_1\),
                FontFamily->"Times"], "\[Element]", 
              StyleBox["Y",
                FontFamily->"Times"]}], "\[And]", 
            RowBox[{
              StyleBox["Y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(A\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"23"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(24)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(y\_1\),
            FontFamily->"Times"], "\[Element]", 
          StyleBox[\(Y\_0\),
            FontFamily->"Times"]}], "\[And]", 
        RowBox[{
          StyleBox[\(Y\_0\),
            FontFamily->"Times"], "\[Element]", 
          StyleBox[\(A\_0\),
            FontFamily->"Times"]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"24"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["24.2",
      ButtonData:>"24.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(Y\_0\),
          FontFamily->"Times"], "\[Element]", 
        RowBox[{"\[ScriptCapitalP]", "[", 
          StyleBox[\(B\_0\),
            FontFamily->"Times"], "]"}]}]], "Assumption"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Union]:",
      ButtonData:>"\[Union]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(25)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(Y\_0\),
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[Element]", 
              StyleBox[\(B\_0\),
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"25"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["25",
      ButtonData:>"25",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(26)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_1\),
          FontFamily->"Times"], "\[Element]", 
        StyleBox[\(Y\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"26"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["26",
      ButtonData:>"26",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["24.1",
      ButtonData:>"24.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \({14.860000000000014`\ Second, \[SkeletonIndicator]\ ProofObject\ \
\[SkeletonIndicator]}\)], "Output"],

Cell["\<\
The proof object generated has depth 16, no failed branches and one \
pending proof situation resulting from an alternative in proving the \
existential goal (16). If equality sign is used for the set equality, the PC \
needs 12 seconds for the proof, the generated proof object has depth 15, no \
failed branch and one pending proof situation. For the case when the equal \
sign is used for set equality, Otter proves the above property in 40 seconds.\
\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. 1. 2.  Provers with Solving Capabilities: PCS and PSC ", "Subsection",
  CellTags->"c:57"],

Cell["\<\
With the release of Mathematica version 4, where Collins' special \
solver for equalities and inequalities over reals was made available, we \
added also better solving capabilities to our system, see  Section 4.0, \
capabilities which we made available via the provers PCS and PSC.\
\>", "Text"],

Cell["\<\
The strategy we apply via these provers is a bit different from the \
three phases view we described before. Giving a closer look to many hand \
proofs we observed that we can see each proof as a cycle through two \
different modes: a prove mode and a solve mode where the mode is defined by \
the type of the goal of the proof situation (p\[Dash] or s\[Dash]formula). \
Let us define a \"p\[Dash]phase\" (prove phase) to be the application of \
natural deduction rules using the non\[Dash]rewrite\[Dash]formulae in the \
knowledge base, except the inference rules that try to prove existential \
goals, and a \"c\[Dash]phase\" (compute phase) to be the application of \
general rewriting by making use of the rewrite\[Dash]formulae in the \
knowledge base. Each of the two modes can be seen then as a cycling through p\
\[Dash] and c\[Dash]phases with the addition that in the solve mode there can \
also exist \"s\[Dash]phases\" (solve phases) where values for  \
solve\[Dash]constants are found (by a general or special solver). \
\>", \
"Text"],

Cell["\<\
In prove mode, the p\[Dash]phase is obtained, as in PC, by applying \
almost the same subset of the natural deduction rules for propositional and \
predicate logic BasicND. The differences are:\
\>", "Text"],

Cell["\<\
The inference rule that tries to prove existential goals by \
matching with literal assumptions is not applied. This rule is taken out as \
solving will be handled differently than in PC. \
\>", "BItem1"],

Cell["\<\
An inference rule that introduces Skolem functions in assumptions \
is added to BasicND. This rule plays a crucial role in the automatic \
generation of proofs of rewrite\[Dash]properties of notions involving \
alternating quantifiers.\
\>", "BItem1"],

Cell["\<\
In the solve mode, p\[Dash] and s\[Dash]phases are obtained by \
applying the NDS solver. In both modes, the c\[Dash]phase is done by applying \
GRS. The difference between the two modes is that in solve mode, GRS will \
also rewrite universally quantified goals. (This does not happen in prove \
mode as there we treat universally quantified goals by natural deduction \
rules. As in the solve mode these rules are not applied, we make rewriting \
more powerful.)\
\>", "Text"],

Cell["\<\
Depending with which phase we start in each mode one can construct \
several strategies. After various experiments we individuated two strategies \
that give good proofs with not too much search.\
\>", "Text"],

Cell["The strategy applied by PCS is:", "Text"],

Cell["\<\
Prove mode: It will apply the same inference rules (minus the one \
for proving existential goals), in the same way, as the PC prover. When proof \
situations remain unchanged in the prove mode, a switch to the solve mode is \
done.\
\>", "BItem1"],

Cell["\<\
Solve mode: For each proof situation an OR\[Dash]situation is \
created with two alternatives: on the first one general rewriting is applied \
and on the second one the NDS solver is applied. (The proof search will \
always go on the first alternative and, in case of failure the second \
alternative will be tried). Hence in the solve mode, preference is given to \
general rewriting. When the goal does not contain any more \
solve\[Dash]constants, the proof switches back to prove mode.\
\>", "BItem1"],

Cell["\<\
Usually, when switching from prove mode to solve mode, the first \
inference rules which will be applicable in the solve mode will be the ones \
from NDS, namely the ones introducing the solve\[Dash]constants in an \
existential goal. \
\>", "Text"],

Cell["The strategy applied by PSC is:", "Text"],

Cell["\<\
Prove mode:  It will apply the same inference rules (minus the one \
for proving existential goals), in the same way, as the PC prover until the \
goal becomes an existential formula. (Hence, not as long as possible). At \
this point, the proof switches to solve mode.\
\>", "BItem1"],

Cell["\<\
Solve mode: For each proof situation the NDS solver will be applied \
as much as possible (hence, an alternation of p\[Dash] and s\[Dash]phases \
will result in the proof). Then, one general rewriting step is applied to the \
intermediate proof situations and the procedure is repeated. Switching back \
to prove mode is done in the same conditions as for PCS.\
\>", "BItem1"],

Cell["\<\
Due to this strategy, for properties of rewrite type, PSC generates \
proofs with smaller proof\[Dash]objects than PCS and faster (For the same set \
of inference rules, PSC creates no extra OR\[Dash]situations as PCS does). As \
a matter of personal taste, we prefer the proofs generated by PCS as opposed \
to the ones generated by PSC. However, in the next section we will also \
present examples which are not anymore of rewrite type where PCS can still \
deliver proofs while PSC fails. The reason is the PSC strategy which switches \
to solve mode as soon as the goal is an existential formula. In a solve mode \
there are very few deduction steps done for enlarging the knowledge base \
hence if the knowledge base was not yet \"completely\" expanded in a prove \
mode, it can well happen that in the solve mode the proof gets stuck, i.e. no \
applicable inference rules are found. \
\>", "Text"],

Cell["\<\
All options from GRS are possible options for PCS and PSC. Another \
possible option, inherited from NDS is \"SolveLevel\[Rule]\" which specifies \
whether the solution returned by the special prover should be given \
explicitly or not and in which form (for explicit solutions).\
\>", "Text"],

Cell[TextData[{
  "We will illustrate the way the provers work with the example of continuity \
of function product. This proof is already beyond the limit of what the \
majority of current theorem proving systems can do. (Exceptions are the Omega \
system (",
  ButtonBox["[72]",
    ButtonData:>"melis-limit:98",
    ButtonStyle->"Hyperlink",
    ButtonNote->"E. Melis, 1998, The Limit Domain"],
  ") and Bledsoe's special\[Dash]purpose prover IMPLY (",
  ButtonBox["[10]",
    ButtonData:>"Bledsoe_Boyer_Henneman:72",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "W. W. Bledsoe, R. S. Boyer and W. T. Henneman, 1972, Computer Proofs \
of Limit Theorems"],
  ").)"
}], "Text"],

Cell[TextData[{
  StyleBox["Example (Product Continuity by PCS). ",
    FontWeight->"Bold"],
  " Let us consider the definition of continuity given in the previous \
example. We want to prove the following rewrite property of the continuity \
notion:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<continuity of product\>\"", ",", \(any[f, g, x]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\((continuous[f, x] \[And] 
                    continuous[g, x])\)\n\t\[DoubleLongRightArrow]
                continuous[f*g, x]\), "\"\<cont*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"continuity of product"],

Cell["\<\
For this we will need the definition of a function product, and \
some extra knowledge as in the sum continuity example: properties for \
distance of products and minimum. \
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Definition",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<function product\>\"", ",", \(any[f, g, x]\), ",", 
            "\[IndentingNewLine]", GridBox[{
                {\(\((f*g)\)[x] = f[x]*g[x]\), "\"\<f*g\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Lemma",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<distance of product\>\"", 
            ",", \(any[x, y, z, t, \[Delta], \[Epsilon]]\), ",", GridBox[{
                {\(\((\[LeftBracketingBar]\((y*t)\) - \((x*
                                z)\)\[RightBracketingBar] < \((\[Delta]*\((\
\[Epsilon] + \[LeftBracketingBar]z\[RightBracketingBar] + 
                                  1)\) + \[LeftBracketingBar]x\
\[RightBracketingBar]*\[Epsilon])\))\)\[DoubleLongLeftArrow]\n\t\((\
\[LeftBracketingBar]y - 
                              x\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]t - z\[RightBracketingBar] < \[Epsilon])\)\), 
                  "\"\<dist*\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Lemma",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<minimum, greater\>\"", ",", \(any[m, n, p]\), ",", 
            "\[IndentingNewLine]", GridBox[{
                {\(min[n, p] > 
                      m \[DoubleLeftRightArrow] \((n > m \[And] p > m)\)\), 
                  "\"\<min>\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<minimum, less\>\"", ",", \(any[m, n, p]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(\((m < n \[And] m < p)\) \[DoubleLeftRightArrow] 
                  m < min[n, p]\), "\"\<<min\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]}], "Input",
  CellTags->{
  "distance of product", "fprod", "function product", "minimum, greater", 
    "minimum, less"}],

Cell[TextData[{
  "Note that, compared to the continuity of sum example (proved with PC), we \
need less explicit knowledge and we can generate in one stroke the proof \
without need of going through notion decomposition. The option \"",
  Cell[BoxData[
      FormBox[Cell["SolveLevel\[Rule]3"], TraditionalForm]]],
  "\" specifies that we want to have the general solution of the problem \
solved by CAD, as given by the Collins method."
}], "Text"],

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<continuity of product\>\"", "]"}], 
        ",", 
        RowBox[{"using", "->", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<continuity\>\"", "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<function product\>\"", "]"}],
               ",", 
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<distance of product\>\"", 
                "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<minimum, greater\>\"", "]"}],
               ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<minimum, less\>\"", "]"}]}], 
            "}"}]}], ",", "\[IndentingNewLine]", \(by -> PCS\), ",", 
        "\[IndentingNewLine]", \(ProverOptions \[Rule] {SolveLevel \[Rule] 
              3}\)}], "]"}]], "Input"],

Cell[" ", "Text"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              "\[IndentingNewLine]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "*", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"]}], "]"}]}], ")"}]}], ","}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"cont*"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"cont"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f*g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["g",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "*", 
                  StyleBox["g",
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox["x",
                FontFamily->"Times"], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}], "*", 
              RowBox[{
                StyleBox["g",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"f*g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(dist*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["y",
                FontFamily->"Times"], ",", 
              StyleBox["z",
                FontFamily->"Times"], ",", 
              StyleBox["t",
                FontFamily->"Times"], ",", 
              StyleBox["\[Delta]",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "*", 
                      StyleBox["t",
                        FontFamily->"Times"]}], "-", 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "*", 
                      StyleBox["z",
                        FontFamily->"Times"]}]}], "\[RightBracketingBar]"}], 
                "<", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], "*", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"], "+", 
                        RowBox[{"\[LeftBracketingBar]", 
                          StyleBox["z",
                            FontFamily->"Times"], "\[RightBracketingBar]"}], 
                        "+", "1"}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      StyleBox["x",
                        FontFamily->"Times"], "\[RightBracketingBar]"}], "*", 
                    
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]}]}], "\[DoubleLeftArrow]", 
              "\[IndentingNewLine]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox["x",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Delta]",
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["t",
                          FontFamily->"Times"], "-", 
                        StyleBox["z",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]}], ")"}]}], ")"}]}], ","}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"dist*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(min>)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"min", "[", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], ",", 
                    StyleBox["p",
                      FontFamily->"Times"]}], "]"}], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}]}], "\[And]", 
            RowBox[{
              StyleBox["p",
                FontFamily->"Times"], ">", 
              StyleBox["m",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"min>"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(<min)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "<", 
              StyleBox["n",
                FontFamily->"Times"]}], "\[And]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                StyleBox["p",
                  FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                RowBox[{"min", "[", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], ",", 
                    StyleBox["p",
                      FontFamily->"Times"]}], "]"}]}]}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"<min"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "*", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "-", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "-", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_1\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Delta]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "*", 
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"]}], ")"}], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "*", 
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"]}], ")"}], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}]}], 
                "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"11"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox[\(\[Delta]\_2\%\("*"\)\),
                  FontFamily->"Times"]}], "\[Implies]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontFamily->"Times"]}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"12"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f*g",
      ButtonData:>"f*g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox[\(\[Delta]\_2\%\("*"\)\),
                  FontFamily->"Times"]}], "\[Implies]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "*", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}]}], "-", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], "*", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontFamily->"Times"]}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"13"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["dist*",
      ButtonData:>"dist*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_2\%\("*"\)\),
                  FontFamily->"Times"], ">", "0"}], "\[And]", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox[\(\[Delta]\_2\%\("*"\)\),
                        FontFamily->"Times"]}], "\[Implies]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Delta]",
                          FontFamily->"Times"]}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}]}], ")"}]}]}], ")"}], 
          "."}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  ", ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_3\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"]}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["8.2",
      ButtonData:>"8.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{\(\[Epsilon]\_1\%\("*"\)\), "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_2\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.2",
      ButtonData:>"5.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                        FontFamily->"Times"], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_2\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          "\[IndentingNewLine]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Delta]\_3\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Delta]\_3\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}], "\[And]", 
                  
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["<min",
      ButtonData:>"<min",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                "\[IndentingNewLine]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    RowBox[{"min", "[", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Delta]\_3\%\("*"\)\),
                            FontFamily->"Times"], "]"}], ",", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}], "]"}]}]}]}], ")"}],
             "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"16"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{\(\[Epsilon]\_1\%\("*"\)\), "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{"min", "[", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Delta]\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(\[Delta]\_3\%\("*"\)\),
                          FontFamily->"Times"], "]"}], ",", 
                      RowBox[{
                        StyleBox[\(\[Delta]\_1\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], "]"}]}], "]"}]}]}], ")"}], 
            "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "Partially solving it, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          RowBox[{"min", "[", 
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "]"}], ",", 
              RowBox[{
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"], "]"}]}], "]"}], ">", "0"}], "\[And]", 
        
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(\[Delta]\_2\%\("*"\)\),
                FontFamily->"Times"], "=", 
              RowBox[{"min", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], "]"}], ",", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}], "]"}]}], ")"}], "."}]}]],
     "Conclusion"]
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["min>",
      ButtonData:>"min>",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                        FontFamily->"Times"], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_1\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}], 
          "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_3\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(\[Delta]\_2\%\("*"\)\),
                FontFamily->"Times"], "=", 
              RowBox[{"min", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], "]"}], ",", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}], "]"}]}], ")"}]}], ","}]],
     "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["8.1",
      ButtonData:>"8.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                        FontFamily->"Times"], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
              RowBox[{
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"], ">", "0"}]}], ")"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_3\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(\[Delta]\_2\%\("*"\)\),
                FontFamily->"Times"], "=", 
              RowBox[{"min", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], "]"}], ",", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}], "]"}]}], ")"}]}], ","}]],
     "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.1",
      ButtonData:>"5.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_3\%\("*"\)\),
                FontFamily->"Times"], ">", "0"}], "\[And]", 
            RowBox[{
              StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                FontFamily->"Times"], ">", "0"}]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(\[Delta]\_2\%\("*"\)\),
                FontFamily->"Times"], "=", 
              RowBox[{"min", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], "]"}], ",", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}], "]"}]}], ")"}], "."}]}]],
     "Conclusion"]
}], "Conclusion",
  CellTags->"19"],

Cell["Now,", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{\(\[Epsilon]\_1\%\("*"\)\), "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_3\%\("*"\)\),
                FontFamily->"Times"], ">", "0"}], "\[And]", 
            RowBox[{
              StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                FontFamily->"Times"], ">", "0"}]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"]
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "can be solved for ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_3\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " by a call to Collins cad\[Dash]method yielding the solution"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"0", "<", 
        StyleBox[\(\[Delta]\_3\%\("*"\)\),
          FontFamily->"Times"], 
        "<", \(\[Epsilon]\_0\/\(1 + \[LeftBracketingBar]g\_0[
                  x\_0]\[RightBracketingBar]\)\)}]], "Expression"],
  ","
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        FractionBox[
          RowBox[{
            
            RowBox[{\(-\((1 + \[LeftBracketingBar]g\_0[
                        x\_0]\[RightBracketingBar])\)\), " ", 
              StyleBox[\(\[Delta]\_3\%\("*"\)\),
                FontFamily->"Times"]}], "+", \(\[Epsilon]\_0\)}], 
          
          RowBox[{\(\[LeftBracketingBar]f\_0[x\_0]\[RightBracketingBar]\), 
            "+", 
            StyleBox[\(\[Delta]\_3\%\("*"\)\),
              FontFamily->"Times"]}]]}]], "Expression"],
  "."
}], "TmaText"],

Cell["Let us take", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_2\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{"min", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], "[", 
              StyleBox[\(\[Delta]\_3\%\("*"\)\),
                FontFamily->"Times"], "]"}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_1\),
                FontFamily->"Times"], "[", 
              FractionBox[
                RowBox[{
                  
                  RowBox[{\(-\((1 + \[LeftBracketingBar]g\_0[
                              x\_0]\[RightBracketingBar])\)\), " ", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"]}], "+", \(\[Epsilon]\_0\)}], 
                
                RowBox[{\(\[LeftBracketingBar]f\_0[
                      x\_0]\[RightBracketingBar]\), "+", 
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"]}]], "]"}]}], "]"}]}]], 
    "Expression"],
  ".   "
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is solved. Hence, we are done.    \[EmptySquare]"
}], "TmaText"],

Cell["\<\
The proof object generated for the proof in the previous example \
has depth 25, contains five failed branches which resulted by trying to \
simplify the goal without success (goals (11), (14), (16), (17) and (19)) and \
one pending proof situation. Looking at the successful proof we can \
individuate the modes and phases it goes through:\
\>", "Paragraph"],

Cell["\<\
Prove mode: starts with the generation of the first formula (1) and \
ends after the generation of formula (11). The succession of phases and the \
formulae generated in them is: p\[Dash]phase: (1), (2) (by applying \
\"arbitrary but fixed\" rule for proving universal formulae together with \
modus ponens); c\[Dash]phase: (3); p\[Dash]phase: (4), (5); c\[Dash]phase: \
(6); p\[Dash]phase: (7), (8); c\[Dash]phase: (9); p\[Dash]phase: (10), (11). \
\
\>", "BItem1"],

Cell["\<\
Solve mode: starts with the generation of formula (12) and extends \
till the end of the proof. The succession of phases and the formulae \
generated in them is: p\[Dash]phase: (12) (introduces a \
solve\[Dash]constant); c\[Dash]phase: syntactic rewriting in (13), semantic \
rewriting in (14); p\[Dash]phase: (15); c\[Dash]phase: the simplification of \
(15) to (16); p\[Dash]phase: (17); s\[Dash]phase: (18); c\[Dash]phase: the \
simplification of (18) to (19); s\[Dash]phase: (19) is solved via a special \
black\[Dash]box prover. \
\>", "BItem1"],

Cell["\<\
Many of the proofs we tried out follow more or less the same \
structure, namely there is a prove mode at the beginning followed by a solve \
mode with which the proof ends. This is however not always the case and we \
will give other examples where the proof goes through several such cycles. We \
will first consider the same problem but look at the proof generated by \
PSC.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Product Continuity by PSC). ",
    FontWeight->"Bold"],
  " We want to prove the same property as in the previous example by using \
PSC. This time we ask for the solve level 0, i.e. no explicit solutions for \
the problem solved by CAD are given."
}], "Example"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<continuity of product\>\"", 
            "]"}], ",", 
          RowBox[{"using", "->", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<function product\>\"", 
                  "]"}], ",", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<distance of product\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<minimum, greater\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<minimum, less\>\"", 
                  "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", \(by -> PSC\),
           ",", "\[IndentingNewLine]", \(ProverOptions \[Rule] {SolveLevel \
\[Rule] 0}\)}], "]"}], ";"}]], "Input"],

Cell[" ", "Text"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["f",
                FontFamily->"Times"], ",", 
              StyleBox["g",
                FontFamily->"Times"], ",", 
              StyleBox["x",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}], "\[And]", 
                RowBox[{"continuous", "[", 
                  RowBox[{
                    StyleBox["g",
                      FontFamily->"Times"], ",", 
                    StyleBox["x",
                      FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
              "\[IndentingNewLine]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox["f",
                      FontFamily->"Times"], "*", 
                    StyleBox["g",
                      FontFamily->"Times"]}], ",", 
                  StyleBox["x",
                    FontFamily->"Times"]}], "]"}]}], ")"}]}], ","}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"cont*"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"cont"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f*g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["g",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "*", 
                  StyleBox["g",
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox["x",
                FontFamily->"Times"], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}], "*", 
              RowBox[{
                StyleBox["g",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"f*g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(dist*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], ",", 
              StyleBox["y",
                FontFamily->"Times"], ",", 
              StyleBox["z",
                FontFamily->"Times"], ",", 
              StyleBox["t",
                FontFamily->"Times"], ",", 
              StyleBox["\[Delta]",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "*", 
                      StyleBox["t",
                        FontFamily->"Times"]}], "-", 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "*", 
                      StyleBox["z",
                        FontFamily->"Times"]}]}], "\[RightBracketingBar]"}], 
                "<", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], "*", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"], "+", 
                        RowBox[{"\[LeftBracketingBar]", 
                          StyleBox["z",
                            FontFamily->"Times"], "\[RightBracketingBar]"}], 
                        "+", "1"}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      StyleBox["x",
                        FontFamily->"Times"], "\[RightBracketingBar]"}], "*", 
                    
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]}]}], "\[DoubleLeftArrow]", 
              "\[IndentingNewLine]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox["x",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Delta]",
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["t",
                          FontFamily->"Times"], "-", 
                        StyleBox["z",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]}], ")"}]}], ")"}]}], ","}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"dist*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(min>)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"min", "[", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], ",", 
                    StyleBox["p",
                      FontFamily->"Times"]}], "]"}], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], ">", 
                StyleBox["m",
                  FontFamily->"Times"]}]}], "\[And]", 
            RowBox[{
              StyleBox["p",
                FontFamily->"Times"], ">", 
              StyleBox["m",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"min>"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(<min)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "<", 
              StyleBox["n",
                FontFamily->"Times"]}], "\[And]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                StyleBox["p",
                  FontFamily->"Times"]}], "\[DoubleLeftRightArrow]", 
              RowBox[{
                StyleBox["m",
                  FontFamily->"Times"], "<", 
                RowBox[{"min", "[", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], ",", 
                    StyleBox["p",
                      FontFamily->"Times"]}], "]"}]}]}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"<min"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "*", 
            StyleBox[\(g\_0\),
              FontFamily->"Times"]}], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "-", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "-", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_1\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Delta]",
                FontFamily->"Times"]}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "*", 
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"]}], ")"}], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontFamily->"Times"]}], ")"}], "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(f\_0\),
                              FontFamily->"Times"], "*", 
                            StyleBox[\(g\_0\),
                              FontFamily->"Times"]}], ")"}], "[", 
                        StyleBox["y",
                          FontFamily->"Times"], "]"}], "-", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(f\_0\),
                              FontFamily->"Times"], "*", 
                            StyleBox[\(g\_0\),
                              FontFamily->"Times"]}], ")"}], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontFamily->"Times"]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"12"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f*g",
      ButtonData:>"f*g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "*", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}]}], "-", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], "*", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}]}], 
                    "\[RightBracketingBar]"}], "<", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontFamily->"Times"]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["dist*",
      ButtonData:>"dist*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ",", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}]], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_2\%\("*"\)\),
                  FontFamily->"Times"], ">", "0"}], "\[And]", 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox[\(\[Delta]\_2\%\("*"\)\),
                        FontFamily->"Times"]}], "\[Implies]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Delta]",
                          FontFamily->"Times"]}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(g\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}]}], ")"}]}]}], ")"}], 
          "."}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  ", ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_3\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"]}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["8.2",
      ButtonData:>"8.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                        FontFamily->"Times"], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_2\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          "\[IndentingNewLine]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"]}], "\[And]", 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.2",
      ButtonData:>"5.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_3\%\("*"\)\),
                    FontFamily->"Times"], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                        FontFamily->"Times"], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(g\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}], 
                        "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], 
                    "\[RightBracketingBar]"}], "*", 
                  StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "=", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            StyleBox[\(\[Delta]\_2\%\("*"\)\),
              FontFamily->"Times"], ">", "0"}], "\[And]", 
          "\[IndentingNewLine]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Delta]\_3\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Delta]\_3\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}], "\[And]", 
                  
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], ">", "0"}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["<min",
      ButtonData:>"<min",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    RowBox[{"min", "[", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Delta]\_3\%\("*"\)\),
                            FontFamily->"Times"], "]"}], ",", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_1\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                            FontFamily->"Times"], "]"}]}], "]"}]}]}]}], ")"}],
             "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"16"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", "\[IndentingNewLine]", 
        
        RowBox[{
          StyleBox[\(\[Delta]\_2\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{"min", "[", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(\[Delta]\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(\[Delta]\_3\%\("*"\)\),
                          FontFamily->"Times"], "]"}], ",", 
                      RowBox[{
                        StyleBox[\(\[Delta]\_1\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                          FontFamily->"Times"], "]"}]}], "]"}]}]}], ")"}], 
            "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "Partially solving it, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", "\[IndentingNewLine]", 
        
        RowBox[{
          RowBox[{"min", "[", 
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "]"}], ",", 
              RowBox[{
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"], "]"}]}], "]"}], ">", "0"}], "\[And]", 
        
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(\[Delta]\_2\%\("*"\)\),
                FontFamily->"Times"], "=", 
              RowBox[{"min", "[", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Delta]\_3\%\("*"\)\),
                      FontFamily->"Times"], "]"}], ",", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_1\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}], "]"}]}], ")"}], "."}]}]],
     "Conclusion"]
}], "Conclusion",
  CellTags->"18"],

Cell["Now,", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_3\%\("*"\)\),
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_3\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "can be solved for ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_3\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " by a call to Collins cad\[Dash]method",
  " yielding a solution ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_3\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        StyleBox["\[Delta]3",
          FontFamily->"Times"]}]], "Expression"],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_1\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        StyleBox["\[Epsilon]3",
          FontFamily->"Times"]}]], "Expression"],
  "."
}], "TmaText"],

Cell["\<\
Hence, we can take \[Delta]3 and \[Epsilon]3 such that\
\>", \
"TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["\[Delta]3",
                  FontFamily->"Times"], "*", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\[Epsilon]3",
                      FontFamily->"Times"], "+", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"], "]"}], 
                      "\[RightBracketingBar]"}], "+", "1"}], ")"}]}], "+", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "\[RightBracketingBar]"}], 
                "*", 
                StyleBox["\[Epsilon]3",
                  FontFamily->"Times"]}]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox["\[Delta]3",
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox["\[Epsilon]3",
            FontFamily->"Times"], ">", "0."}]}]], "Assumption"]
}], "Assumption",
  CellTags->"19"],

Cell["Let us take", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_2\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          RowBox[{"min", "[", 
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Delta]3",
                  FontFamily->"Times"], "]"}], ",", 
              RowBox[{
                StyleBox[\(\[Delta]\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]3",
                  FontFamily->"Times"], "]"}]}], "]"}], "."}]}]], 
    "Expression"]
}], "TmaText"],

Cell["Now, we are left to prove ", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"min", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], "[", 
              StyleBox["\[Delta]3",
                FontFamily->"Times"], "]"}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_1\),
                FontFamily->"Times"], "[", 
              StyleBox["\[Epsilon]3",
                FontFamily->"Times"], "]"}]}], "]"}], ">", "0"}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"20"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["min>",
      ButtonData:>"min>",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], "[", 
            StyleBox["\[Delta]3",
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[Delta]\_1\),
              FontFamily->"Times"], "[", 
            StyleBox["\[Epsilon]3",
              FontFamily->"Times"], "]"}], ">", "0"}]}]], "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["8.1",
      ButtonData:>"8.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], "[", 
            StyleBox["\[Delta]3",
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox["\[Epsilon]3",
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.1",
      ButtonData:>"5.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(23)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[Delta]3",
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox["\[Epsilon]3",
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"23"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["23.1",
      ButtonData:>"23.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Delta]3",
          FontFamily->"Times"], ">", "0"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["23.1",
      ButtonData:>"23.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["23.2",
      ButtonData:>"23.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Epsilon]3",
          FontFamily->"Times"], ">", "0"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["23.2",
      ButtonData:>"23.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.3",
      ButtonData:>"19.3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ".   \[EmptySquare]"
}], "TmaText"],

Cell["\<\
The proof object generated in the previous example has depth 24, no \
failed branches and no pending proof situations. Clearly, the proof was \
generated in shorter time than the one by PCS. Also the structure of the \
proof is a bit different:\
\>", "Paragraph"],

Cell["\<\
Prove mode: starts with the generation of the first formula (1) and \
ends after the generation of formula (11). This part proceeds exactly in the \
same way as the one from PCS.\
\>", "BItem1"],

Cell["\<\
Solve mode: starts with the generation of formula (12) and ends \
with the generation of formula (20). The succession of phases and the \
formulae generated in them up to formula (18) is the same as the one from \
PCS, however from here the difference starts. An s\[Dash]phase is entered in \
which formula (18) is solved by a call to the Collins' special solver. In \
this phase, a new assumption is generated (19), and the new goal becomes \
(20).\
\>", "BItem1"],

Cell["\<\
Prove mode: extends to the end of the proof. We have a c-phase: \
generation of (23) from (20), followed by a p-phase: proof of (23) by proving \
the individual components.\
\>", "BItem1"],

Cell[TextData[{
  StyleBox["Example (Convergence of Sum of Sequences Proved by PCS). ",
    FontWeight->"Bold"],
  " Let us consider the definition of convergent sequences:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<convergence\>\"", ",", \(any[f]\), ",", "\n", "\t", GridBox[{
              {\(convergent[
                    f]\[DoubleLongLeftRightArrow]\(\[Exists] \+a\(\(\[ForAll] \
\+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\[Exists] \+N\(\(\[ForAll] \+n\)\+\(n \
\[GreaterEqual] N\)\[LeftBracketingBar]f[n] - 
                                a\[RightBracketingBar] < \
\[Epsilon]\)\)\)\)\), "\"\<conv\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"convergence", "convergent"}],

Cell["We want to prove:", "Text",
  CellTags->"convergence"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<convergence of sum\>\"", ",", \(any[f, g]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((convergent[f] \[And] 
                    convergent[g])\)\n\t\[DoubleLongRightArrow]
                convergent[f + g]\), "\"\<conv+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "2-ary limit of sum", "convergence of sum", "convergent", "limit"}],

Cell["\<\
As explicit knowledge we will use the definition of sum of \
sequences:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sequences sum\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((f + g)\)[x] = f[x] + g[x]\), "\"\<f+g\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}],

Cell["a property of the distance between sums:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", 
        ",", \(any[x, y, z, t, \[Delta], \[Epsilon]]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]\((x + z)\) - \((y + 
                            t)\)\[RightBracketingBar] < \((\[Delta] + \
\[Epsilon])\))\)\[DoubleLongLeftArrow]\n\t\((\[LeftBracketingBar]x - 
                          y\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]z - t\[RightBracketingBar] < \[Epsilon])\)\), 
              "\"\<dist+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"distance of sum"],

Cell["and a property of natural numbers sum:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum greater\>\"", ",", \(any[m, n, p]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((m \[GreaterEqual] n \[And] 
                    m \[GreaterEqual] p)\) \[DoubleLeftArrow] 
                m \[GreaterEqual] n + p\), "\"\<\[GreaterEqual]+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"sum greater"],

Cell["\<\
Let us now prove the proposition by using PCS. Here we want to have \
an example solution for the solve problem solved by CAD (SolveLevel\[Rule]1).\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<convergence of sum\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "->", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<convergence\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<sequences sum\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<distance of sum\>\"", 
                  "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<sum greater\>\"", "]"}]}], 
              "}"}]}], ",", "\[IndentingNewLine]", \(by -> PCS\), ",", 
          "\[IndentingNewLine]", \(ProverOptions \[Rule] {SolveLevel \[Rule] 
                1}\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(conv+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["g",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"convergent", "[", 
                StyleBox["f",
                  FontFamily->"Times"], "]"}], "\[And]", 
              RowBox[{"convergent", "[", 
                StyleBox["g",
                  FontFamily->"Times"], "]"}]}], "\[Implies]", 
            RowBox[{"convergent", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], "+", 
                StyleBox["g",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"conv+"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(conv)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"convergent", "[", 
              StyleBox["f",
                FontFamily->"Times"], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["a",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["N",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    UnderscriptBox[
                      UnderscriptBox["\[ForAll]", 
                        RowBox[{
                          StyleBox["n",
                            FontFamily->"Times"], " "}]], 
                      RowBox[{
                        StyleBox["n",
                          FontFamily->"Times"], "\[GreaterEqual]", 
                        StyleBox["N",
                          FontFamily->"Times"]}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox["f",
                                FontFamily->"Times"], "[", 
                              StyleBox["n",
                                FontFamily->"Times"], "]"}], "-", 
                            StyleBox["a",
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}], ")"}]}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"conv"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f+g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["g",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "+", 
                  StyleBox["g",
                    FontFamily->"Times"]}], ")"}], "[", 
              StyleBox["x",
                FontFamily->"Times"], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}], "+", 
              RowBox[{
                StyleBox["g",
                  FontFamily->"Times"], "[", 
                StyleBox["x",
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"f+g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(dist+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"], ",", 
            StyleBox["z",
              FontFamily->"Times"], ",", 
            StyleBox["t",
              FontFamily->"Times"], ",", 
            StyleBox["\[Delta]",
              FontFamily->"Times"], ",", 
            StyleBox["\[Epsilon]",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "+", 
                      StyleBox["z",
                        FontFamily->"Times"]}], ")"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "+", 
                      StyleBox["t",
                        FontFamily->"Times"]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], "+", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}]}], "\[DoubleLeftArrow]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["x",
                        FontFamily->"Times"], "-", 
                      StyleBox["y",
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Delta]",
                    FontFamily->"Times"]}], "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["z",
                        FontFamily->"Times"], "-", 
                      StyleBox["t",
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}]}], ")"}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"dist+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[GreaterEqual]+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"], ",", 
            StyleBox["p",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox["n",
                    FontFamily->"Times"]}], "\[And]", 
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox["p",
                    FontFamily->"Times"]}]}], ")"}], "\[DoubleLeftArrow]", 
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "\[GreaterEqual]", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], "+", 
                StyleBox["p",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"\[GreaterEqual]+"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"convergent", "[", 
          StyleBox[\(f\_0\),
            FontFamily->"Times"], "]"}], "\[And]", 
        RowBox[{"convergent", "[", 
          StyleBox[\(g\_0\),
            FontFamily->"Times"], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"convergent", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(g\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["conv",
      ButtonData:>"conv",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], " "}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["N",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox["N",
                    FontFamily->"Times"]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["n",
                          FontFamily->"Times"], "]"}], "-", 
                      StyleBox["a",
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["N",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], "\[GreaterEqual]", 
                StyleBox["N",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["n",
                        FontFamily->"Times"], "]"}], "-", 
                    StyleBox[\(a\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"4"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["n",
                FontFamily->"Times"], "\[GreaterEqual]", 
              RowBox[{
                StyleBox[\(N\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["n",
                      FontFamily->"Times"], "]"}], "-", 
                  StyleBox[\(a\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}], ")"}]}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"5"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["conv",
      ButtonData:>"conv",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], " "}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["N",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox["N",
                    FontFamily->"Times"]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontFamily->"Times"], "[", 
                        StyleBox["n",
                          FontFamily->"Times"], "]"}], "-", 
                      StyleBox["a",
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["N",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], "\[GreaterEqual]", 
                StyleBox["N",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["n",
                        FontFamily->"Times"], "]"}], "-", 
                    StyleBox[\(a\_1\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["n",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["n",
                FontFamily->"Times"], "\[GreaterEqual]", 
              RowBox[{
                StyleBox[\(N\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["n",
                      FontFamily->"Times"], "]"}], "-", 
                  StyleBox[\(a\_1\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}], ")"}]}]}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["conv",
      ButtonData:>"conv",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], " "}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["N",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox["N",
                    FontFamily->"Times"]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox[\(f\_0\),
                              FontFamily->"Times"], "+", 
                            StyleBox[\(g\_0\),
                              FontFamily->"Times"]}], ")"}], "[", 
                        StyleBox["n",
                          FontFamily->"Times"], "]"}], "-", 
                      StyleBox["a",
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}], ")"}]}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(a\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["N",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["n",
                        FontFamily->"Times"], "\[GreaterEqual]", 
                      StyleBox["N",
                        FontFamily->"Times"]}], "\[Implies]", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"(", 
                              RowBox[{
                                StyleBox[\(f\_0\),
                                  FontFamily->"Times"], "+", 
                                StyleBox[\(g\_0\),
                                  FontFamily->"Times"]}], ")"}], "[", 
                            StyleBox["n",
                              FontFamily->"Times"], "]"}], "-", 
                          StyleBox[\(a\_2\%\("*"\)\),
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}]}], ")"}]}]}]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f+g",
      ButtonData:>"f+g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], ">", "0"}], "\[Implies]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["N",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["n",
                      FontFamily->"Times"], " "}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["n",
                        FontFamily->"Times"], "\[GreaterEqual]", 
                      StyleBox["N",
                        FontFamily->"Times"]}], "\[Implies]", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox[\(f\_0\),
                                  FontFamily->"Times"], "[", 
                                StyleBox["n",
                                  FontFamily->"Times"], "]"}], "+", 
                              RowBox[{
                                StyleBox[\(g\_0\),
                                  FontFamily->"Times"], "[", 
                                StyleBox["n",
                                  FontFamily->"Times"], "]"}]}], ")"}], "-", 
                          StyleBox[\(a\_2\%\("*"\)\),
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}]}], ")"}]}]}]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["dist+",
      ButtonData:>"dist+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["t",
                FontFamily->"Times"], ",", 
              StyleBox["y",
                FontFamily->"Times"]}]], 
          RowBox[{
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "+", 
              StyleBox["t",
                FontFamily->"Times"]}], "=", 
            StyleBox[\(a\_2\%\("*"\)\),
              FontFamily->"Times"]}]], 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"]}]], 
                  RowBox[{
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], "+", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"]}], "=", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]], 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["N",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["n",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["n",
                            FontFamily->"Times"], "\[GreaterEqual]", 
                          StyleBox["N",
                            FontFamily->"Times"]}], "\[Implies]", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"\[LeftBracketingBar]", 
                              RowBox[{
                                RowBox[{
                                  StyleBox[\(f\_0\),
                                    FontFamily->"Times"], "[", 
                                  StyleBox["n",
                                    FontFamily->"Times"], "]"}], "-", 
                                StyleBox["y",
                                  FontFamily->"Times"]}], 
                              "\[RightBracketingBar]"}], "<", 
                            StyleBox["\[Delta]",
                              FontFamily->"Times"]}], "\[And]", 
                          RowBox[{
                            RowBox[{"\[LeftBracketingBar]", 
                              RowBox[{
                                RowBox[{
                                  StyleBox[\(g\_0\),
                                    FontFamily->"Times"], "[", 
                                  StyleBox["n",
                                    FontFamily->"Times"], "]"}], "-", 
                                StyleBox["t",
                                  FontFamily->"Times"]}], 
                              "\[RightBracketingBar]"}], "<", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}]}]}], ")"}]}]}]}]}], 
            ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"12"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(a\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  ", ",
  Cell[BoxData[
      StyleBox[\(t\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(y\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(y\_0\%\("*"\)\),
                FontFamily->"Times"], "+", 
              StyleBox[\(t\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(a\_2\%\("*"\)\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontFamily->"Times"], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontFamily->"Times"]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(f\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["n",
                                        FontFamily->"Times"], "]"}], "-", 
                                    StyleBox[\(y\_0\%\("*"\)\),
                                      FontFamily->"Times"]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Delta]",
                                  FontFamily->"Times"]}], "\[And]", 
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(g\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["n",
                                        FontFamily->"Times"], "]"}], "-", 
                                    StyleBox[\(t\_0\%\("*"\)\),
                                      FontFamily->"Times"]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Epsilon]4",
                                  FontFamily->"Times"]}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "Using ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we ",
  "can partially solve ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ". By taking ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        StyleBox[\(a\_0\),
          FontFamily->"Times"]}]], "Expression"],
  " and ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(t\_0\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        StyleBox[\(a\_1\),
          FontFamily->"Times"]}]], "Expression"],
  ", formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by "
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(a\_0\),
                FontFamily->"Times"], "+", 
              StyleBox[\(a\_1\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(a\_2\%\("*"\)\),
              FontFamily->"Times"]}], ")"}], "\[And]", "\[IndentingNewLine]", 
        
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontFamily->"Times"], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontFamily->"Times"]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(f\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["n",
                                        FontFamily->"Times"], "]"}], "-", 
                                    StyleBox[\(a\_0\),
                                      FontFamily->"Times"]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Delta]",
                                  FontFamily->"Times"]}], "\[And]", 
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(g\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["n",
                                        FontFamily->"Times"], "]"}], "-", 
                                    StyleBox[\(a\_1\),
                                      FontFamily->"Times"]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Epsilon]4",
                                  FontFamily->"Times"]}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}], "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(a\_0\),
                  FontFamily->"Times"], "+", 
                StyleBox[\(a\_1\),
                  FontFamily->"Times"]}], "=", 
              StyleBox[\(a\_2\%\("*"\)\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[And]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontFamily->"Times"], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontFamily->"Times"]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{
                                RowBox[{"\[LeftBracketingBar]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(f\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["n",
                                        FontFamily->"Times"], "]"}], "-", 
                                    StyleBox[\(a\_0\),
                                      FontFamily->"Times"]}], 
                                  "\[RightBracketingBar]"}], "<", 
                                StyleBox["\[Delta]",
                                  FontFamily->"Times"]}], "\[And]", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox["\[Epsilon]4",
                                      FontFamily->"Times"], ">", "0"}], 
                                  "\[And]", 
                                  RowBox[{
                                    StyleBox["n",
                                      FontFamily->"Times"], "\[GreaterEqual]",
                                     
                                    RowBox[{
                                      StyleBox[\(N\_1\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["\[Epsilon]4",
                                        FontFamily->"Times"], "]"}]}]}], 
                                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
        ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(a\_0\),
                  FontFamily->"Times"], "+", 
                StyleBox[\(a\_1\),
                  FontFamily->"Times"]}], "=", 
              StyleBox[\(a\_2\%\("*"\)\),
                FontFamily->"Times"]}], ")"}], "\[And]", 
          RowBox[{
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontFamily->"Times"], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontFamily->"Times"]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox["\[Delta]",
                                      FontFamily->"Times"], ">", "0"}], 
                                  "\[And]", 
                                  RowBox[{
                                    StyleBox["n",
                                      FontFamily->"Times"], "\[GreaterEqual]",
                                     
                                    RowBox[{
                                      StyleBox[\(N\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["\[Delta]",
                                        FontFamily->"Times"], "]"}]}]}], 
                                ")"}], "\[And]", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox["\[Epsilon]4",
                                      FontFamily->"Times"], ">", "0"}], 
                                  "\[And]", 
                                  RowBox[{
                                    StyleBox["n",
                                      FontFamily->"Times"], "\[GreaterEqual]",
                                     
                                    RowBox[{
                                      StyleBox[\(N\_1\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["\[Epsilon]4",
                                        FontFamily->"Times"], "]"}]}]}], 
                                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
        ","}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterEqual]+",
      ButtonData:>"\[GreaterEqual]+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(a\_0\),
                FontFamily->"Times"], "+", 
              StyleBox[\(a\_1\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(a\_2\%\("*"\)\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      "\[IndentingNewLine]", 
                      RowBox[{
                        UnderscriptBox["\[ForAll]", 
                          RowBox[{
                            StyleBox["n",
                              FontFamily->"Times"], " "}]], 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["N",
                                FontFamily->"Times"]}], "\[Implies]", 
                            RowBox[{
                              RowBox[{
                                StyleBox["\[Delta]",
                                  FontFamily->"Times"], ">", "0"}], "\[And]", 
                              
                              RowBox[{
                                StyleBox["\[Epsilon]4",
                                  FontFamily->"Times"], ">", "0"}], "\[And]", 
                              
                              RowBox[{
                                StyleBox["n",
                                  FontFamily->"Times"], "\[GreaterEqual]", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox[\(N\_0\),
                                      FontFamily->"Times"], "[", 
                                    StyleBox["\[Delta]",
                                      FontFamily->"Times"], "]"}], "+", 
                                  RowBox[{
                                    StyleBox[\(N\_1\),
                                      FontFamily->"Times"], "[", 
                                    StyleBox["\[Epsilon]4",
                                      FontFamily->"Times"], "]"}]}]}]}]}], 
                          ")"}]}]}], ")"}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(a\_0\),
                FontFamily->"Times"], "+", 
              StyleBox[\(a\_1\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(a\_2\%\("*"\)\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], ",", 
                      StyleBox["\[Epsilon]4",
                        FontFamily->"Times"], ",", 
                      StyleBox["N",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], "+", 
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"]}], "=", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}], ")"}], "\[And]", 
                      "\[IndentingNewLine]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["\[Delta]",
                              FontFamily->"Times"], ">", "0"}], "\[And]", 
                          RowBox[{
                            StyleBox["\[Epsilon]4",
                              FontFamily->"Times"], ">", "0"}], "\[And]", 
                          RowBox[{
                            UnderscriptBox["\[ForAll]", 
                              RowBox[{
                                StyleBox["n",
                                  FontFamily->"Times"], " "}]], 
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["n",
                                    FontFamily->"Times"], "\[GreaterEqual]", 
                                  StyleBox["N",
                                    FontFamily->"Times"]}], "\[Implies]", 
                                RowBox[{
                                  StyleBox["n",
                                    FontFamily->"Times"], "\[GreaterEqual]", 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[\(N\_0\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["\[Delta]",
                                        FontFamily->"Times"], "]"}], "+", 
                                    RowBox[{
                                      StyleBox[\(N\_1\),
                                        FontFamily->"Times"], "[", 
                                      StyleBox["\[Epsilon]4",
                                        FontFamily->"Times"], "]"}]}]}]}], 
                              ")"}]}]}], ")"}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"16"],

Cell[TextData[{
  "We ",
  "can partially solve ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ". By taking ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(a\_2\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          StyleBox[\(a\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(a\_1\),
            FontFamily->"Times"]}]}]], "Expression"],
  ", formula ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by "
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], " "}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ",", 
                    StyleBox["\[Epsilon]4",
                      FontFamily->"Times"], ",", 
                    StyleBox["N",
                      FontFamily->"Times"]}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["\[Delta]",
                            FontFamily->"Times"], "+", 
                          StyleBox["\[Epsilon]4",
                            FontFamily->"Times"]}], "=", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}], ")"}], "\[And]", 
                    "\[IndentingNewLine]", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["\[Delta]",
                            FontFamily->"Times"], ">", "0"}], "\[And]", 
                        RowBox[{
                          StyleBox["\[Epsilon]4",
                            FontFamily->"Times"], ">", "0"}], "\[And]", 
                        RowBox[{
                          UnderscriptBox["\[ForAll]", 
                            RowBox[{
                              StyleBox["n",
                                FontFamily->"Times"], " "}]], 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox["n",
                                  FontFamily->"Times"], "\[GreaterEqual]", 
                                StyleBox["N",
                                  FontFamily->"Times"]}], "\[Implies]", 
                              RowBox[{
                                StyleBox["n",
                                  FontFamily->"Times"], "\[GreaterEqual]", 
                                RowBox[{
                                  RowBox[{
                                    StyleBox[\(N\_0\),
                                      FontFamily->"Times"], "[", 
                                    StyleBox["\[Delta]",
                                      FontFamily->"Times"], "]"}], "+", 
                                  RowBox[{
                                    StyleBox[\(N\_1\),
                                      FontFamily->"Times"], "[", 
                                    StyleBox["\[Epsilon]4",
                                      FontFamily->"Times"], "]"}]}]}]}], 
                            ")"}]}]}], ")"}]}], ")"}]}]}], ")"}], "."}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"17"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"18"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ",", 
            StyleBox["\[Epsilon]4",
              FontFamily->"Times"], ",", 
            StyleBox["N",
              FontFamily->"Times"]}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], "+", 
                    StyleBox["\[Epsilon]4",
                      FontFamily->"Times"]}], "=", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontFamily->"Times"]}], ")"}], "\[And]", 
              "\[IndentingNewLine]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    StyleBox["\[Epsilon]4",
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["n",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox["n",
                            FontFamily->"Times"], "\[GreaterEqual]", 
                          StyleBox["N",
                            FontFamily->"Times"]}], "\[Implies]", 
                        RowBox[{
                          StyleBox["n",
                            FontFamily->"Times"], "\[GreaterEqual]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(N\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["\[Delta]",
                                FontFamily->"Times"], "]"}], "+", 
                            RowBox[{
                              StyleBox[\(N\_1\),
                                FontFamily->"Times"], "[", 
                              StyleBox["\[Epsilon]4",
                                FontFamily->"Times"], "]"}]}]}]}], ")"}]}]}], 
                ")"}]}], ")"}], "."}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"19"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  ", ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(N\_2\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_0\%\("*"\)\),
                FontFamily->"Times"], "+", 
              StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["n",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  StyleBox[\(N\_2\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  StyleBox["n",
                    FontFamily->"Times"], "\[GreaterEqual]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(N\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(\[Delta]\_0\%\("*"\)\),
                        FontFamily->"Times"], "]"}], "+", 
                    RowBox[{
                      StyleBox[\(N\_1\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
                        FontFamily->"Times"], "]"}]}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"20"],

Cell[TextData[{
  "Partially solving it, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_0\%\("*"\)\),
                FontFamily->"Times"], "+", 
              StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(N\_2\%\("*"\)\),
              FontFamily->"Times"], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(N\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Delta]\_0\%\("*"\)\),
                  FontFamily->"Times"], "]"}], "+", 
              RowBox[{
                StyleBox[\(N\_1\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
                  FontFamily->"Times"], "]"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"21"],

Cell["Now,", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Delta]\_0\%\("*"\)\),
                FontFamily->"Times"], "+", 
              StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"]}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "can be solved for ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " by a call to Collins cad\[Dash]method",
  " yielding a solution"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_0\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{\(1\/2\), "*", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"]}]}]], "Expression"],
  ","
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]4\_0\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{\(1\/2\), "*", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"]}]}]], "Expression"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Let us take", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(N\_2\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          RowBox[{
            StyleBox[\(N\_0\),
              FontFamily->"Times"], "[", 
            RowBox[{\(1\/2\), "*", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], "]"}], "+", 
          RowBox[{
            StyleBox[\(N\_1\),
              FontFamily->"Times"], "[", 
            RowBox[{\(1\/2\), "*", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], "]"}]}]}]], "Expression"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is solved. Hence, we are done.  \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The depth of the proof object generated in the previous example is \
29, there are seven failed branches, due to unsuccessful attempts of \
rewriting the goal, and one pending proof situation. The structure of the \
proof is the following:\
\>", "Paragraph"],

Cell["\<\
Prove mode: generation of formulae (1) to (9). The succession of \
phases (together with the new formulae generated in them) is: p\[Dash]phase: \
(1), (2); c\[Dash]phase: (3); p\[Dash]phase: (4), (5); c\[Dash]phase: (6); p\
\[Dash]phase: (7), (8); c\[Dash]phase: (9);\
\>", "BItem1"],

Cell["\<\
Solve mode: from generation of formulae (10) to (17). The \
succession of phases is: p\[Dash]phase: (10); c\[Dash]phase: (11), (12); p\
\[Dash]phase: (13); s\[Dash]phase: (14) (solve by unifying with assumptions); \
c\[Dash]phase: transform (14) in (15); p\[Dash]phase: (16); s\[Dash]phase: \
(17) by apply solution;\
\>", "BItem1"],

Cell["\<\
Prove mode: generation of formulae (18), (19) in one p\[Dash]phase;\
\
\>", "BItem1"],

Cell["\<\
Solve mode: starts with the generation of formula (20) and extends \
to the end of the proof in one s\[Dash]phase.\
\>", "BItem1"],

Cell["\<\
The same proof generated by PSC will produce a proof object of \
depth 21 with no pending proof situations and no failed branches. \
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
8. 1. 3.  Non\[Dash]Rewrite Type of Properties\
\>", "Subsection",
  CellTags->"c:58"],

Cell["\<\
Up to now we only showed proofs for rewrite type properties of \
notions with alternating quantifiers. The provers we provide can also be used \
to solve other types of properties. We will give first an example where the \
PSC fails and comment on how can one modify a little the strategy in order to \
make it work.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Failure of PSC). ",
    FontWeight->"Bold"],
  " The property we want to prove is the sign invariance of continuous \
functions:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Continuity, Sign\>\"", ",", \(any[f, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(f[x] > 0 \[And] 
                  continuous[f, 
                    x] \[Implies] \(\[Exists] \+\[Delta]\)\+\(\[Delta] > \
0\)\(\(\[ForAll] \+y\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \
\[Delta]\)f[y] > 0\)\), "\"\<cont, sign\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Continuity, Sign"],

Cell["\<\
except for the definition of continuity we need a property of the \
absolute value:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Absolute Value\>\"", ",", \(any[a, b, c]\), ",", "\n", "\t", 
        GridBox[{
            {\(\[LeftBracketingBar]a - b\[RightBracketingBar] < c \[Implies] 
                a > b - c\), "\"\<absv\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"Absolute Value"],

Cell["The proof attempt generated by PSC is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Continuity, Sign\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<Absolute Value\>\"", 
                  "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", \(by \[Rule] PSC\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont, sign)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "[", 
                  StyleBox["x",
                    FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], ",", 
                  StyleBox["x",
                    FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox["x",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Delta]",
                      FontFamily->"Times"]}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], ">", "0"}], ")"}]}]}]}], 
          ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"cont, sign"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(c2:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"c2:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(absv)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], ",", 
            StyleBox["b",
              FontFamily->"Times"], ",", 
            StyleBox["c",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["a",
                    FontFamily->"Times"], "-", 
                  StyleBox["b",
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["c",
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["a",
                FontFamily->"Times"], ">", 
              RowBox[{
                StyleBox["b",
                  FontFamily->"Times"], "-", 
                StyleBox["c",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"absv"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Delta]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["y",
                  FontFamily->"Times"], "]"}], ">", "0"}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  ", ",
  " such that"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox[\(\[Delta]\_0\%\("*"\)\),
                  FontFamily->"Times"]}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["y",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["c2:",
      ButtonData:>"c2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " fails. (The ",
  "GRS",
  " was unable to transform the proof situation.)   \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The reason why the proof failed is that the proof entered in a \
solve mode too early, before the knowledge base was expanded in the prove \
mode. At this point in the proof, a Skolem function should be introduced in \
formula (4) but this can only be done by the natural deduction rules which \
are not applied anymore as we are in solve mode.\
\>", "Text"],

Cell["\<\
One can design a strategy in between the ones of PCS and PSC such \
that this early switching does not happen. Namely, the prove mode should \
proceed the same as the one for PCS, switching to solve mode is done in the \
same conditions as for PCS. In solve mode the rules from NDS minus the ones \
introducing solve\[Dash]constants are applied as long as possible and then, \
for each proof situation, an OR\[Dash]situation is created with two \
alternatives. On the first alternative one general rewriting is attempted and \
on the second the rules introducing solve\[Dash]constants are applied. The \
proof object generated by such a strategy will be bigger than the one \
generated by PSC but smaller then the one generated by PCS. By using a prover \
with this modified strategy, PSCS, the proof of the sign invariance property \
will be:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Continuity, Sign\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity\>\"", "]"}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Lemma",
                    FontWeight->"Bold"], "[", "\"\<Absolute Value\>\"", 
                  "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", \(by \[Rule] PSCS\), ",", 
          "\[IndentingNewLine]", \(ProverOptions \[Rule] {RWQuantified \
\[Rule] True}\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont, sign)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "[", 
                  StyleBox["x",
                    FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], ",", 
                  StyleBox["x",
                    FontFamily->"Times"]}], "]"}]}], "\[Implies]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox["x",
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox["\[Delta]",
                      FontFamily->"Times"]}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], ">", "0"}], ")"}]}]}]}], 
          ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"cont, sign"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"cont"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(absv)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontFamily->"Times"], ",", 
            StyleBox["b",
              FontFamily->"Times"], ",", 
            StyleBox["c",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["a",
                    FontFamily->"Times"], "-", 
                  StyleBox["b",
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["c",
                FontFamily->"Times"]}], "\[Implies]", 
            RowBox[{
              StyleBox["a",
                FontFamily->"Times"], ">", 
              RowBox[{
                StyleBox["b",
                  FontFamily->"Times"], "-", 
                StyleBox["c",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"absv"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], "-", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Delta]",
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["y",
                  FontFamily->"Times"], "]"}], ">", "0"}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, by ",
  Cell[TextData[{
    "(",
    ButtonBox["absv",
      ButtonData:>"absv",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["y",
                    FontFamily->"Times"], "]"}], ">", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}], "-", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"]}]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], ">", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}], "-", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], ">", 
                        RowBox[{
                          RowBox[{
                            StyleBox[\(f\_0\),
                              FontFamily->"Times"], "[", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"], "]"}], "-", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"]}]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.2",
      ButtonData:>"5.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              StyleBox["\[Epsilon]",
                FontFamily->"Times"]}], "=", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], "]"}]}]}], ")"}]}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " and ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", "0"}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_1\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    RowBox[{
                      StyleBox[\(\[Delta]\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                        FontFamily->"Times"], "]"}]}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", "0"}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_1\%\("*"\)\),
                    FontFamily->"Times"]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                      FontFamily->"Times"], "]"}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "Partially solving it, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", "0"}], ")"}], "\[And]", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(\[Delta]\_1\%\("*"\)\),
              FontFamily->"Times"], "=", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], "[", \(\[Epsilon]\_0\%\("*"\)\), 
              "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell["Now,", "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
                FontFamily->"Times"]}], "=", "0"}], ")"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}]}]], "Conclusion"]
}], "TmaText"],

Cell[TextData[{
  "can be solved for ",
  Cell[BoxData[
      StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " by a call to Collins cad\[Dash]method",
  " yielding the solution"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], "[", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "]"}]}]], "Expression"],
  "."
}], "TmaText"],

Cell["Hence, we have that", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}], "-", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontFamily->"Times"], "[", 
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "]"}]}], "=", "0"}], ")"}], "\[And]", 
        
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}], ">", "0"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"10"],

Cell["Let us take", "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_1\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontFamily->"Times"], "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}], "]"}]}]], "Expression"],
  "."
}], "TmaText"],

Cell["Now, we are left to prove ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontFamily->"Times"], "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}], "]"}], ">", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.1",
      ButtonData:>"5.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], "[", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "]"}], ">", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"12"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ".   \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The proof object generated has depth 18, one failed branch and two \
pending proof situations. The succession of modes is: prove, solve, prove. \
The proof of the property generated by PCS has a proof object of depth 19, \
with four failed branches and three pending proof situations.\
\>", \
"Paragraph"],

Cell["\<\
We will conclude the part of the Prove\[Dash]Compute\[Dash]Solve \
provers with one more example.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Limit and Continuity). ",
    FontWeight->"Bold"],
  " Let us consider the definition of limit of a function at a point:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<limit at\>\"", ",", \(any[f, x, a]\), ",", GridBox[{
            {\(limit[f, x, 
                  a]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\[Epsilon]\)\+\
\(\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \
\+y\)\+\(0 < \[LeftBracketingBar]y - x\[RightBracketingBar] \[And] \
\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - a\[RightBracketingBar] < \[Epsilon]\)\)\)\), 
              "\"\<limf\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"limit at"],

Cell["and prove the following property:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity, limit\>\"", ",", \(any[f, x]\), ",", "\n", "\t", 
          GridBox[{
              {\(continuous[f, x] \[Implies] limit[f, x, f[x]]\), 
                "\"\<cont, lim\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]], "Input",
  CellTags->{"Continuity, Limit", "limit at"}],

Cell["\<\
The corresponding call and proof are given below. Note that there \
was no need for a special solver, the general solving rules were sufficient \
for completing the proof.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<Continuity, Limit\>\"", "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"using", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<limit at\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<continuity\>\"", "]"}]}], 
              "}"}]}], ",", "\[IndentingNewLine]", \(by \[Rule] PCS\)}], 
        "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont, lim)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"], ",", 
                RowBox[{
                  StyleBox["f",
                    FontFamily->"Times"], "[", 
                  StyleBox["x",
                    FontFamily->"Times"], "]"}]}], "]"}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"cont, lim"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(limf)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["a",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"], ",", 
                StyleBox["a",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"0", "<", 
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox["x",
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}]}], "\[And]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox["x",
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Delta]",
                          FontFamily->"Times"]}]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          StyleBox["a",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"limf"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontFamily->"Times"], ",", 
            StyleBox["x",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontFamily->"Times"], ",", 
                StyleBox["x",
                  FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}]], 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[Exists]", 
                    RowBox[{
                      StyleBox["\[Delta]",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    StyleBox["\[Delta]",
                      FontFamily->"Times"], ">", "0"}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], " "}]], 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox["y",
                            FontFamily->"Times"], "-", 
                          StyleBox["x",
                            FontFamily->"Times"]}], "\[RightBracketingBar]"}],
                       "<", 
                      StyleBox["\[Delta]",
                        FontFamily->"Times"]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["y",
                              FontFamily->"Times"], "]"}], "-", 
                          RowBox[{
                            StyleBox["f",
                              FontFamily->"Times"], "[", 
                            StyleBox["x",
                              FontFamily->"Times"], "]"}]}], 
                        "\[RightBracketingBar]"}], "<", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"cont"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"1"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontFamily->"Times"], ",", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"], ",", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["cont",
      ButtonData:>"cont",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", we can take an appropriate Skolem function such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
              RowBox[{
                UnderscriptBox[
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    RowBox[{
                      StyleBox[\(\[Delta]\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["\[Epsilon]",
                        FontFamily->"Times"], "]"}]}]], 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["y",
                            FontFamily->"Times"], "]"}], "-", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox[\(x\_0\),
                            FontFamily->"Times"], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox["\[Epsilon]",
                      FontFamily->"Times"]}], ")"}]}]}], ")"}], "."}]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is simplified to:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"], ">", "0"}], "\[Implies]", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], "]"}], ">", "0"}]}], ")"}]}], 
        "\[And]", "\[IndentingNewLine]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontFamily->"Times"], ">", "0"}], "\[Implies]", 
                RowBox[{
                  UnderscriptBox["\[ForAll]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], " "}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["y",
                              FontFamily->"Times"], "-", 
                            StyleBox[\(x\_0\),
                              FontFamily->"Times"]}], 
                          "\[RightBracketingBar]"}], "<", 
                        RowBox[{
                          StyleBox[\(\[Delta]\_0\),
                            FontFamily->"Times"], "[", 
                          StyleBox["\[Epsilon]",
                            FontFamily->"Times"], "]"}]}], "\[Implies]", 
                      RowBox[{
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox["y",
                                FontFamily->"Times"], "]"}], "-", 
                            RowBox[{
                              StyleBox[\(f\_0\),
                                FontFamily->"Times"], "[", 
                              StyleBox[\(x\_0\),
                                FontFamily->"Times"], "]"}]}], 
                          "\[RightBracketingBar]"}], "<", 
                        StyleBox["\[Epsilon]",
                          FontFamily->"Times"]}]}], ")"}]}]}], ")"}], 
            "."}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["limf",
      ButtonData:>"limf",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[Exists]", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], ">", "0"}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontFamily->"Times"], " "}]], 
              RowBox[{
                RowBox[{"0", "<", 
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}]}], 
                "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox["\[Delta]",
                    FontFamily->"Times"]}]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontFamily->"Times"]}], ")"}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"6"],

Cell["We assume", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell["and show", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["\[Delta]",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            StyleBox["\[Delta]",
              FontFamily->"Times"], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], " "}]], 
            RowBox[{
              RowBox[{"0", "<", 
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}]}], 
              "\[And]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                StyleBox["\[Delta]",
                  FontFamily->"Times"]}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox["y",
                      FontFamily->"Times"], "]"}], "-", 
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"], "]"}]}], 
                "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"8"],

Cell[TextData[{
  "We have to find  ",
  Cell[BoxData[
      StyleBox[\(\[Delta]\_1\%\("*"\)\),
        FontFamily->"Times"]], "Expression"],
  " such that"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"0", "<", 
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}]}], 
                "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "\[Implies]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox["y",
                        FontFamily->"Times"], "]"}], "-", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"], "]"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontFamily->"Times"]}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.2",
      ButtonData:>"5.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"0", "<", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}]}],
                   "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox[\(\[Delta]\_1\%\("*"\)\),
                      FontFamily->"Times"]}]}], "\[Implies]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(\[Epsilon]\_0\),
                      FontFamily->"Times"], ">", "0"}], "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    RowBox[{
                      StyleBox[\(\[Delta]\_0\),
                        FontFamily->"Times"], "[", 
                      StyleBox[\(\[Epsilon]\_0\),
                        FontFamily->"Times"], "]"}]}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"], ">", "0"}], "\[And]", "\[IndentingNewLine]",
         
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"0", "<", 
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}]}],
                   "\[And]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["y",
                          FontFamily->"Times"], "-", 
                        StyleBox[\(x\_0\),
                          FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                    "<", 
                    StyleBox[\(\[Delta]\_1\%\("*"\)\),
                      FontFamily->"Times"]}]}], "\[Implies]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  RowBox[{
                    StyleBox[\(\[Delta]\_0\),
                      FontFamily->"Times"], "[", 
                    StyleBox[\(\[Epsilon]\_0\),
                      FontFamily->"Times"], "]"}]}]}], ")"}], "."}]}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is reduced to"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_1\%\("*"\)\),
            FontFamily->"Times"], ">", "0"}], "\[And]", 
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], " "}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"0", "<", 
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}]}], 
                "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["y",
                        FontFamily->"Times"], "-", 
                      StyleBox[\(x\_0\),
                        FontFamily->"Times"]}], "\[RightBracketingBar]"}], 
                  "<", 
                  StyleBox[\(\[Delta]\_1\%\("*"\)\),
                    FontFamily->"Times"]}]}], "\[Implies]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], "-", 
                    StyleBox[\(x\_0\),
                      FontFamily->"Times"]}], "\[RightBracketingBar]"}], "<", 
                
                RowBox[{
                  StyleBox[\(\[Delta]\_0\),
                    FontFamily->"Times"], "[", 
                  StyleBox[\(\[Epsilon]\_0\),
                    FontFamily->"Times"], "]"}]}]}], ")"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"12"],

Cell[TextData[{
  "Partially solving it, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontFamily->"Times"], "[", 
            StyleBox[\(\[Epsilon]\_0\),
              FontFamily->"Times"], "]"}], ">", "0"}], "\[And]", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(\[Delta]\_1\%\("*"\)\),
              FontFamily->"Times"], "=", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontFamily->"Times"], "[", 
              StyleBox[\(\[Epsilon]\_0\),
                FontFamily->"Times"], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"13"],

Cell[TextData[{
  "We ",
  "can partially solve ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ". By taking ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Delta]\_1\%\("*"\)\),
          FontFamily->"Times"], "\[LeftArrow]", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontFamily->"Times"], "[", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"], "]"}]}]], "Expression"],
  ", formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is implied by "
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontFamily->"Times"], "[", 
          StyleBox[\(\[Epsilon]\_0\),
            FontFamily->"Times"], "]"}], ">", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"18"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["5.1",
      ButtonData:>"5.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontFamily->"Times"], ">", "0"}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"19"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ".    \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The proof object generated in the previous example has depth 22, \
five failed branches and no pending proof situations. It goes through prove \
mode from generating formula (1) to (8), solve mode formulae (9) to (18) and \
prove mode again till the end of the proof.\
\>", "Paragraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. 2.  Proving with Case Statements", "Section",
  CellTags->{"sec:max-as", "c:59"}],

Cell[TextData[{
  "Once one has in the knowledge base a definition by cases or the goal is a \
case formula, one has to call a prover which can deal with this construct. We \
provide the prover CasePC which is an extension of the PC prover. This \
extension consists in adding the CDP, see 5.3, to the provers combined and \
adding one more inference rule to the BasicND prover, rule which recognizes \
that a proof situation of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((a = a, \[ScriptCapitalK])\)\)]],
  " is trivial. (Without adding this last inference rule, for certain proofs, \
like the one below, one would need to add explicitly the knowledge about \
reflexivity of equality). The CDP prover is used in the p\[Dash]phase after \
the natural deduction rules. "
}], "Text"],

Cell["\<\
The CasePC prover, like PC, represents a family of provers. It \
provides the same options that GRS has with the exception of semantic \
rewriting: this will not be applied.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Associativity of Maximum). ",
    FontWeight->"Bold"],
  " Let us consider the maximum definition:"
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<maximum\>\"", ",", \(any[x, y]\), ",", "\n", "\t", GridBox[{
            {
              RowBox[{\(max[x, y]\), ":=", 
                FormBox[
                  StyleBox[
                    RowBox[{"{", GridBox[{
                          {"y", "\[DoubleLeftArrow]", \(x \[LessEqual] y\)},
                          {"x", " ", " "}
                          },
                        ColumnAlignments->{Left}]}],
                    SpanMaxSize->Infinity],
                  "Null"]}], "\"\<max\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->"Maximum"],

Cell["\<\
where \[LessEqual] is a total order and prove that maximum is \
associative: \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<maximum is associative\>\"", ",", \(any[x, y, z]\), ",", "\n", 
        "\t", GridBox[{
            {\(max[x, max[y, z]] = max[max[x, y], z]\), "\"\<max-A\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"maximum is associative", "Max is Upper Bound"}],

Cell["\<\
For the proof we will need some of the axioms of \[LessEqual]: \
\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["Axiom",
            FontWeight->"Bold"], "[", 
          RowBox[{
          "\"\<transitivity \[LessEqual]\>\"", ",", \(any[x, y, z]\), ",", 
            "\n", "\t", GridBox[{
                {\(\((x \[LessEqual] y)\) \[And] \((y \[LessEqual] 
                          z)\) \[Implies] \((x \[LessEqual] z)\)\), 
                  "\"\<trans \[LessEqual]\>\""}
                },
              ColumnAlignments->{Left}]}], "]"}], ";"}], 
      "\[IndentingNewLine]"}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox["Axiom",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<totality \[LessEqual]\>\"", ",", \(any[x, y]\), ",", "\n", "\t", 
          GridBox[{
              {\(\[Not] \((x \[LessEqual] y)\) \[Implies] y \[LessEqual] x\), 
                "\"\<tot \[LessEqual]\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], ";"}]}], "Input",
  CellTags->{
  "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
    "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}],

Cell["The Prove call is:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"Prove", "[", 
        RowBox[{
          RowBox[{
            StyleBox["Proposition",
              FontWeight->"Bold"], "[", "\"\<maximum is associative\>\"", 
            "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"using", "->", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{
                  StyleBox["Definition",
                    FontWeight->"Bold"], "[", "\"\<maximum\>\"", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Axiom",
                    FontWeight->"Bold"], "[", "\"\<totality \[LessEqual]\>\"",
                   "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["Axiom",
                    FontWeight->"Bold"], "[", 
                  "\"\<transitivity \[LessEqual]\>\"", "]"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", \(by -> CasePC\)}], "]"}], ";"}]], "Input"],

Cell["Prove:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max-A)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"], 
            StyleBox[",",
              FontFamily->"Times"], 
            StyleBox[" ",
              FontFamily->"Times"], 
            StyleBox["z",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], ",", 
                    StyleBox["z",
                      FontFamily->"Times"]}], "]"}]}], "]"}], "=", 
            RowBox[{"max", "[", 
              RowBox[{
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["x",
                      FontFamily->"Times"], ",", 
                    StyleBox["y",
                      FontFamily->"Times"]}], "]"}], ",", 
                StyleBox["z",
                  FontFamily->"Times"]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"max-A"],

Cell["under the assumptions:", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], ",", 
                StyleBox["y",
                  FontFamily->"Times"]}], "]"}], ":=", 
            FormBox[
              StyleBox[
                RowBox[{"{", GridBox[{
                      {
                        StyleBox["y",
                          FontFamily->"Times"], "\[DoubleLeftArrow]", 
                        RowBox[{
                          StyleBox["x",
                            FontFamily->"Times"], "\[LessEqual]", 
                          StyleBox["y",
                            FontFamily->"Times"]}]},
                      {
                        StyleBox["x",
                          FontFamily->"Times"], "\[DoubleLeftArrow]", 
                        "otherwise"}
                      },
                    ColumnAlignments->{Left}]}],
                SpanMaxSize->Infinity],
              "TraditionalForm"]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"max"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(tot \[LessEqual])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[NotLessEqual]", 
                StyleBox["y",
                  FontFamily->"Times"]}], ")"}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[LessEqual]", 
              StyleBox["x",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"tot \[LessEqual]"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(trans \[LessEqual])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"], ",", 
            StyleBox["z",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[LessEqual]", 
                StyleBox["y",
                  FontFamily->"Times"]}], "\[And]", 
              RowBox[{
                StyleBox["y",
                  FontFamily->"Times"], "\[LessEqual]", 
                StyleBox["z",
                  FontFamily->"Times"]}]}], "\[Implies]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[LessEqual]", 
              StyleBox["z",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"trans \[LessEqual]"],

Cell[TextData[{
  "For proving ",
  Cell[TextData[{
    "(",
    ButtonBox["max-A",
      ButtonData:>"max-A",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we take all variables arbitrary but fixed and prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox[\(y\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(z\_0\),
                  FontFamily->"Times"]}], "]"}]}], "]"}], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"]}], "]"}], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 1: ", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"2"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"]}], "]"}], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 1.1: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(y\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"7"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case  1.1.1: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"12"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(z\_0\),
          FontFamily->"Times"], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  " Note that for proving ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it is sufficient to prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(z\_0\),
          FontFamily->"Times"], "=", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "By the reflexivity of equality, formula",
  "  ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved."
}], "TmaText"],

Cell["Case 1.1.2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[NotLessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"14"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"16"],

Cell[TextData[{
  " Note that for proving ",
  Cell[TextData[{
    "(",
    ButtonBox["16",
      ButtonData:>"16",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it is sufficient to prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "=", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["trans \[LessEqual]",
      ButtonData:>"trans \[LessEqual]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"19"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " are contradictory."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 1.2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[NotLessEqual]", 
        StyleBox[\(y\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"9"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "By the reflexivity of equality, formula",
  "  ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved."
}], "TmaText"],

Cell["Case 2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[NotLessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(y\_0\),
              FontFamily->"Times"]}], "]"}], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            RowBox[{"max", "[", 
              RowBox[{
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], ",", 
                StyleBox[\(y\_0\),
                  FontFamily->"Times"]}], "]"}], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 2.1: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(y\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"20"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(y\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"21"],

Cell[TextData[{
  " Note that for proving ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", it is sufficient to prove:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(25)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "=", 
        StyleBox[\(y\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"25"],

Cell[TextData[{
  "By the reflexivity of equality, formula",
  "  ",
  Cell[TextData[{
    "(",
    ButtonBox["25",
      ButtonData:>"25",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved."
}], "TmaText"],

Cell["Case 2.2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[NotLessEqual]", 
        StyleBox[\(y\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"22"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(24)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "=", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontFamily->"Times"], ",", 
            StyleBox[\(z\_0\),
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"24"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["24",
      ButtonData:>"24",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["max",
      ButtonData:>"max",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 2.2.1: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(26)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"26"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(27)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "=", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"27"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["tot \[LessEqual]",
      ButtonData:>"tot \[LessEqual]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(31)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(x\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"31"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["31",
      ButtonData:>"31",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["26",
      ButtonData:>"26",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["trans \[LessEqual]",
      ButtonData:>"trans \[LessEqual]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(32)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(y\_0\),
          FontFamily->"Times"], "\[LessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"32"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["27",
      ButtonData:>"27",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because ",
  Cell[TextData[{
    "(",
    ButtonBox["32",
      ButtonData:>"32",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " are contradictory."
}], "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell["Case 2.2.2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(28)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "\[NotLessEqual]", 
        StyleBox[\(z\_0\),
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"28"],

Cell["Hence, we have to prove", "TmaText",
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(30)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(x\_0\),
          FontFamily->"Times"], "=", 
        StyleBox[\(x\_0\),
          FontFamily->"Times"]}]], "Conclusion"],
  "."
}], "Conclusion",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellTags->"30"],

Cell[TextData[{
  "By the reflexivity of equality, formula ",
  Cell[TextData[{
    "(",
    ButtonBox["30",
      ButtonData:>"30",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved.    \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The proof object generated in the previous example has depth 7, no \
failed branches and pending proof situations. Another user prover which can \
handle proof situations containing case formulae is described in Section \
8.3.2.\
\>", "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. 3.  Induction Provers", "Section",
  CellTags->"c:60"],

Cell[TextData[{
  "The first provers we constructed in Theorema were induction provers for \
proving equalities over natural numbers or tuples. These provers are: \
NNEqIndProver for equalities over natural numbers and TupleIndEqProver for \
equalities over tuples. (The first experimental implementations of these \
provers, in a previous version of Theorema, were described in ",
  ButtonBox["[22]",
    ButtonData:>"Buchb:97d",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger, 1997, The Theorema Prover for Equalities over the \
Natural Numbers"],
  ", ",
  ButtonBox["[27]",
    ButtonData:>"Buchb_Vasa:97",
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "B. Buchberger and D. Vasaru, 1997, An Induction Prover for Equalities \
over Lists: Implemen ..."],
  "). An example of proof generated by NNEqIndProver is given in Section 7. "
}], "Text"],

Cell["\<\
The strategy applied by the induction provers for equalities is: \
Given a proof situation, an OR\[Dash]situation is created with two \
alternatives: on the first one simplification (by equalities, not general \
rewriting)  is applied, on the second one induction is applied. This strategy \
ensures that no induction is applied when it is not necessary. It also has \
the benefit that it simplifies the goal, if possible, before applying \
induction. However, the strategy will produce more nodes in the proof object \
than a strategy which always applies induction and then simplification. For \
these provers, the size of the proof object does not grow so much as \
simplification contains very few inference rules and it is fast. Hence, in \
case of proofs which need induction, not much time is spent in pursuing a \
\"dead\[Dash]end\" alternative. For other combinations of inference rules, \
however, when apart from induction there are several other inference rules, \
this strategy might be very costly. \
\>", "Text"],

Cell["\<\
In the following we will describe two induction provers which \
extend the PC prover. One adds mathematical induction to PC: NNIndPC, and the \
other one adds sequence induction and case distinction inference rules to PC: \
TupleIndCasePC. Pursuing first non\[Dash]inductive alternatives is costly for \
these combinations of inference rules. Details on the strategy applied are \
given in the corresponding sections.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "8. 3. 1.  ",
  StyleBox["Add Mathematical Induction to PC",
    FontWeight->"Bold"]
}], "Subsection",
  CellTags->"c:61"],

Cell["\<\
The NNIndPC prover is obtained by adding to the PC prover the \
mathematical induction deduction rule. The strategy of the prover is to apply \
induction on the goal, if there are any suitable variables, then apply PC.  \
Hence, the prover will apply induction also when it is not necessary. The \
reason why we constructed this prover in this way was to avoid the loss of \
time for proving by PC a proof situation which would need induction.\
\>", \
"Example"],

Cell["\<\
An example proof generated by it, together with the Prove call, is:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<double is even\>\"", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<even\>\"", "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Theory",
                  FontWeight->"Bold"], "[", "\"\<Addition\>\"", "]"}]}], 
            "}"}]}], ",", "\[IndentingNewLine]", \(by \[Rule] NNIndPC\)}], 
      "]"}]], "Input",
  CellTags->{
  "Addition", "Addition from Left", "Addition of Zero from Left", "even"}],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"even", "[", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], "+", 
            StyleBox["x",
              FontFamily->"Times"]}], "]"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"3"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(even[0]\)], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"even", "[", 
              SuperscriptBox[
                StyleBox["x",
                  FontFamily->"Times"], "+"], "]"}], 
            "\[DoubleLeftRightArrow]", 
            RowBox[{"(", 
              RowBox[{"\[Not]", 
                RowBox[{"(", 
                  RowBox[{"even", "[", 
                    StyleBox["x",
                      FontFamily->"Times"], "]"}], ")"}]}], ")"}]}], ")"}]}]],
     "Assumption"],
  ","
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "+", "0"}], ":=", 
            StyleBox["m",
              FontFamily->"Times"]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + succ)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontFamily->"Times"], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontFamily->"Times"], "+"]}], ":=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Times"], "+", 
                  StyleBox["n",
                    FontFamily->"Times"]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + succ"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(succ + )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontFamily->"Times"], ",", 
            StyleBox["n",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontFamily->"Times"], "+"], "+", 
              StyleBox["n",
                FontFamily->"Times"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontFamily->"Times"], "+", 
                  StyleBox["n",
                    FontFamily->"Times"]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"succ + "],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["x",
        FontFamily->"Times"]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(even[0 + 0]\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(even[0]\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"even", "[", 
        RowBox[{
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"even", "[", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(x\_0\),
              FontFamily->"Times"], "+"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["succ + ",
      ButtonData:>"succ + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"even", "[", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(x\_0\),
                FontFamily->"Times"], "+", 
              SuperscriptBox[
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "+"]}], ")"}], "+"], "]"}]], 
    "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"\[Not]", 
        RowBox[{"(", 
          RowBox[{"even", "[", 
            RowBox[{
              StyleBox[\(x\_0\),
                FontFamily->"Times"], "+", 
              SuperscriptBox[
                StyleBox[\(x\_0\),
                  FontFamily->"Times"], "+"]}], "]"}], ")"}]}]], 
    "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox[" + succ",
      ButtonData:>" + succ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"\[Not]", 
        RowBox[{"(", 
          RowBox[{"even", "[", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], ")"}], "+"], "]"}], ")"}]}]], 
    "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"\[Not]", 
        RowBox[{"(", 
          RowBox[{"\[Not]", 
            RowBox[{"(", 
              RowBox[{"even", "[", 
                RowBox[{
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"], "+", 
                  StyleBox[\(x\_0\),
                    FontFamily->"Times"]}], "]"}], ")"}]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "We simplify the goal ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " to:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"even", "[", 
        RowBox[{
          StyleBox[\(x\_0\),
            FontFamily->"Times"], "+", 
          StyleBox[\(x\_0\),
            FontFamily->"Times"]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ".   \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
The proof object generated in the example has depth 4, no failed \
branches and no pending proof situations.\
\>", "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. 3. 2.  Induction and Case Distinction", "Subsection",
  CellTags->{"sec:indcdp", "c:62"}],

Cell["\<\
Here we will give an example of a proof generated by a prover which \
adds sequence induction to CasePC. Hence, it combines the same provers as \
CasePC with the addition of SIP, see Section 6.3. The strategy applied by the \
TupleIndCasePC prover is: Given a proof situation, an OR\[Dash]situation is \
created which has two alternatives. As first alternative, a proof by CasePC \
is attempted and, as second alternative, induction on sequence should be \
tried. Hence, no induction will be applied when not necessary but much time \
will be spent in pursuing dead\[Dash]end alternatives. \
\>", "Text"],

Cell["\<\
The general rewriting applied by this prover is first attempted on \
the goal and afterwards on the knowledge base. Only literal formulae are \
rewritten and no semantic rewriting is done. It has no options. In the \
following example we will show the generated proof of correctness of merge.\
\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example (Merge\[Dash]Sort). ",
    FontWeight->"Bold"],
  " Let us consider that we have given on tuples the predicate \
\"is\[Dash]sorted\" "
}], "Example"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<is\[Dash]sorted\>\"", ",", \(any[x, y, z\&_]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]]\), 
              "\"\<sorted\[LeftAngleBracket]\[RightAngleBracket]\>\""},
            {\(is\[Dash]sorted[\[LeftAngleBracket]x\[RightAngleBracket]]\), 
              "\"\<sorted\[LeftAngleBracket].\[RightAngleBracket]\>\""},
            {\(is\[Dash]sorted[\[LeftAngleBracket]x, y, 
                    z\&_\[RightAngleBracket]] \[DoubleLeftRightArrow] \((x \
\[GreaterEqual] y \[And] 
                    is\[Dash]sorted[\[LeftAngleBracket]y, 
                        z\&_\[RightAngleBracket]])\)\), 
              "\"\<sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]\>\
\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[TextData[{
  "the operation \"prepend\" (\"\[Cup]\") and the predicate \"\[GreaterTilde]\
\", where ",
  Cell[BoxData[
      \(TraditionalForm\`a \[GreaterTilde] Y\)]],
  " reads \"",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is greater or equal than all elements of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  "\". Suppose we know all properties of these notions and their interplay \
also with the \[GreaterEqual] predicate. Now we introduce a new notion \
\"merging of two tuples\": "
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<merge\>\"", ",", \(any[a, b, A, B, x\&_, y\&_]\), ",", GridBox[{
            {\(merge[\[LeftAngleBracket]\[RightAngleBracket], B] := B\), 
              "\"\<mr\>\""},
            {\(merge[A, \[LeftAngleBracket]\[RightAngleBracket]] := A\), 
              "\"\<ml\>\""},
            {
              RowBox[{
                RowBox[{"merge", "[", 
                  RowBox[{
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["a",
                          FontFamily->"Times"], ",", 
                        StyleBox[\(x\&_\),
                          FontFamily->"Times"]}], "\[RightAngleBracket]"}], 
                    ",", 
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox["b",
                          FontFamily->"Times"], ",", 
                        StyleBox[\(y\&_\),
                          FontFamily->"Times"]}], "\[RightAngleBracket]"}]}], 
                  "]"}], ":=", 
                FormBox[
                  StyleBox[
                    RowBox[{"{", GridBox[{
                          {
                            RowBox[{
                              StyleBox["a",
                                FontFamily->"Times"], "\[Cup]", 
                              RowBox[{"merge", "[", 
                                RowBox[{
                                  RowBox[{"\[LeftAngleBracket]", 
                                    StyleBox[\(x\&_\),
                                      FontFamily->"Times"], 
                                    "\[RightAngleBracket]"}], ",", 
                                  RowBox[{"\[LeftAngleBracket]", 
                                    RowBox[{
                                      StyleBox["b",
                                        FontFamily->"Times"], ",", 
                                      StyleBox[\(y\&_\),
                                        FontFamily->"Times"]}], 
                                    "\[RightAngleBracket]"}]}], "]"}]}], 
                            "\[DoubleLeftArrow]", 
                            RowBox[{
                              StyleBox["a",
                                FontFamily->"Times"], "\[GreaterEqual]", 
                              StyleBox["b",
                                FontFamily->"Times"]}]},
                          {
                            RowBox[{
                              StyleBox["b",
                                FontFamily->"Times"], "\[Cup]", 
                              RowBox[{"merge", "[", 
                                RowBox[{
                                  RowBox[{"\[LeftAngleBracket]", 
                                    RowBox[{
                                      StyleBox["a",
                                        FontFamily->"Times"], ",", 
                                      StyleBox[\(x\&_\),
                                        FontFamily->"Times"]}], 
                                    "\[RightAngleBracket]"}], ",", 
                                  RowBox[{"\[LeftAngleBracket]", 
                                    StyleBox[\(y\&_\),
                                      FontFamily->"Times"], 
                                    "\[RightAngleBracket]"}]}], "]"}]}], " ", 
                            " "}
                          },
                        ColumnAlignments->{Left}]}],
                    SpanMaxSize->Infinity],
                  "TraditionalForm"]}], "\"\<mi\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"conc", "even", "member"}],

Cell["\<\
and we want to prove that by merging two ordered tuples the result \
is an ordered tuple:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<merge\>\"", ",", \(any[x\&_, y\&_]\), ",", GridBox[{
            {\(is\[Dash]sorted[\[LeftAngleBracket]x\&_\[RightAngleBracket]] \
\[And] is\[Dash]sorted[\[LeftAngleBracket]y\&_\[RightAngleBracket]] \
\[Implies] \[IndentingNewLine]is\[Dash]sorted[
                  merge[\[LeftAngleBracket]x\&_\[RightAngleBracket], \
\[LeftAngleBracket]y\&_\[RightAngleBracket]]]\), "\"\<sort\[Dash]merge\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
Suppose that we already proved the relationship between merge and \
\[GreaterTilde]:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<merge,\[GreaterTilde]\>\"", ",", \(any[x, A, B]\), ",", GridBox[{
            {\(x \[GreaterTilde] A \[And] x \[GreaterTilde] B \[Implies] 
                x \[GreaterTilde] merge[A, B]\), 
              "\"\<\[GreaterTilde]\[Dash]merge\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
The knowledge we will use in the proof, except for the one given \
above is:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Axiom",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<totality\>\"", ",", \(any[x, y]\), ",", "\[IndentingNewLine]", 
        GridBox[{
            {\(\[Not] \((x \[GreaterEqual] y)\) \[Implies] 
                y \[GreaterEqual] x\), "\"\<\[GreaterEqual]tot\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge", 
    "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<subtuple is\[Dash]sorted\>\"", ",", \(any[x, y\&_]\), ",", 
        GridBox[{
            {\(is\[Dash]sorted[\[LeftAngleBracket]x, 
                    y\&_\[RightAngleBracket]] \[Implies] 
                is\[Dash]sorted[\[LeftAngleBracket]y\&_\[RightAngleBracket]]\)\
, "\"\<sub\[Dash]sort\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "is\[Dash]sorted", "member, merge", "merge", "prepend", 
    "subtuple is\[Dash]sorted"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sorted, \[GreaterTilde]\>\"", ",", \(any[x, y\&_]\), ",", 
        GridBox[{
            {\(is\[Dash]sorted[\[LeftAngleBracket]x, 
                    y\&_\[RightAngleBracket]] \[Implies] 
                x \[GreaterTilde] \[LeftAngleBracket]y\&_\[RightAngleBracket]\
\), "\"\<\[GreaterTilde],s\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
    "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<prepend, is\[Dash]sorted, \[GreaterTilde] \>\"", 
        ",", \(any[x, Y]\), ",", GridBox[{
            {\(is\[Dash]sorted[
                  x\[Cup]Y] \[DoubleLeftRightArrow] \((is\[Dash]sorted[
                      Y] \[And] x \[GreaterTilde] Y)\)\), 
              "\"\<\[Cup],\[GreaterTilde],s\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{
  "is\[Dash]sorted", "member", "merge", "prepend", 
    "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}],

Cell["\<\
As one of the notions involved is defined by case distinction the \
prover we call should be able to deal with such definitions. Also some of the \
definitions are inductive ones, an appropriate prover might need to apply \
tuple induction. Hence, it looks like TupleIndCasePC is a good candidate as \
appropriate prover. The Prove call and proof generated automatically \
is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Prove", "[", 
      RowBox[{
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "[", "\"\<merge\>\"", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"using", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<merge\>\"", "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<is\[Dash]sorted\>\"", "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<prepend, is\[Dash]sorted, \[GreaterTilde] \>\"", "]"}], 
              ",", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<sorted, \[GreaterTilde]\>\"",
                 "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", "\"\<merge,\[GreaterTilde]\>\"", 
                "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Proposition",
                  FontWeight->"Bold"], "[", 
                "\"\<subtuple is\[Dash]sorted\>\"", "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["Axiom",
                  FontWeight->"Bold"], "[", "\"\<totality\>\"", "]"}]}], 
            "}"}]}], ",", 
        "\[IndentingNewLine]", \(by \[Rule] TupleIndCasePC\)}], 
      "]"}]], "Input",
  LimitsPositioningTokens->{}],

Cell["Prove:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(sort\[Dash]merge)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(x\&_\),
              FontFamily->"Times"], ",", 
            StyleBox[\(y\&_\),
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(x\&_\),
                    FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}], 
              "\[And]", 
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(y\&_\),
                    FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}], 
            "\[Implies]", "\[IndentingNewLine]", 
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"merge", "[", 
                RowBox[{
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(x\&_\),
                      FontFamily->"Times"], "\[RightAngleBracket]"}], ",", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontFamily->"Times"], "\[RightAngleBracket]"}]}], "]"}],
               "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"sort\[Dash]merge"],

Cell["under the assumptions:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(mr)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["B",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"merge", "[", 
              RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), ",", 
                StyleBox["B",
                  FontFamily->"Times"]}], "]"}], ":=", 
            StyleBox["B",
              FontFamily->"Times"]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"mr"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(ml)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["A",
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"merge", "[", 
              RowBox[{
                StyleBox["A",
                  FontFamily->"Times"], 
                ",", \(\[LeftAngleBracket]\[RightAngleBracket]\)}], "]"}], ":=",
             
            StyleBox["A",
              FontFamily->"Times"]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"ml"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(mi)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["a",
                FontFamily->"Times"], ",", 
              StyleBox["b",
                FontFamily->"Times"], ",", "\[IndentingNewLine]", 
              StyleBox[\(x\&_\),
                FontFamily->"Times"], ",", 
              StyleBox[\(y\&_\),
                FontFamily->"Times"]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"merge", "[", 
                RowBox[{
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      StyleBox["a",
                        FontFamily->"Times"], ",", 
                      StyleBox[\(x\&_\),
                        FontFamily->"Times"]}], "\[RightAngleBracket]"}], ",",
                   
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      StyleBox["b",
                        FontFamily->"Times"], ",", 
                      StyleBox[\(y\&_\),
                        FontFamily->"Times"]}], "\[RightAngleBracket]"}]}], 
                "]"}], ":=", 
              FormBox[
                StyleBox[
                  RowBox[{"{", GridBox[{
                        {
                          RowBox[{
                            StyleBox["a",
                              FontFamily->"Times"], "\[Cup]", 
                            RowBox[{"merge", "[", 
                              RowBox[{
                                RowBox[{"\[LeftAngleBracket]", 
                                  StyleBox[\(x\&_\),
                                    FontFamily->"Times"], 
                                  "\[RightAngleBracket]"}], ",", 
                                RowBox[{"\[LeftAngleBracket]", 
                                  RowBox[{
                                    StyleBox["b",
                                      FontFamily->"Times"], ",", 
                                    StyleBox[\(y\&_\),
                                      FontFamily->"Times"]}], 
                                  "\[RightAngleBracket]"}]}], "]"}]}], 
                          "\[DoubleLeftArrow]", 
                          RowBox[{
                            StyleBox["a",
                              FontFamily->"Times"], "\[GreaterEqual]", 
                            StyleBox["b",
                              FontFamily->"Times"]}]},
                        {
                          RowBox[{
                            StyleBox["b",
                              FontFamily->"Times"], "\[Cup]", 
                            RowBox[{"merge", "[", 
                              RowBox[{
                                RowBox[{"\[LeftAngleBracket]", 
                                  RowBox[{
                                    StyleBox["a",
                                      FontFamily->"Times"], ",", 
                                    StyleBox[\(x\&_\),
                                      FontFamily->"Times"]}], 
                                  "\[RightAngleBracket]"}], ",", 
                                RowBox[{"\[LeftAngleBracket]", 
                                  StyleBox[\(y\&_\),
                                    FontFamily->"Times"], 
                                  "\[RightAngleBracket]"}]}], "]"}]}], " ", 
                          " "}
                        },
                      ColumnAlignments->{Left}]}],
                  SpanMaxSize->Infinity],
                "TraditionalForm"]}], ")"}]}], ","}]], "Assumption"]
}], "Assumption",
  CellTags->"mi"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(sorted\[LeftAngleBracket]\[RightAngleBracket])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]]\)], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"sorted\[LeftAngleBracket]\[RightAngleBracket]"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(sorted\[LeftAngleBracket].\[RightAngleBracket])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], " "}]], 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            StyleBox["x",
              FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"sorted\[LeftAngleBracket].\[RightAngleBracket]"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket])", 
    "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"], ",", 
            StyleBox[\(z\&_\),
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox["y",
                    FontFamily->"Times"], ",", 
                  StyleBox[\(z\&_\),
                    FontFamily->"Times"]}], "\[RightAngleBracket]"}], "]"}], 
            "\[DoubleLeftRightArrow]", 
            RowBox[{
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  RowBox[{
                    StyleBox["y",
                      FontFamily->"Times"], ",", 
                    StyleBox[\(z\&_\),
                      FontFamily->"Times"]}], "\[RightAngleBracket]"}], "]"}],
               "\[And]", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[GreaterEqual]", 
                StyleBox["y",
                  FontFamily->"Times"]}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[Cup],\[GreaterTilde],s)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["Y",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], "\[Cup]", 
                  StyleBox["Y",
                    FontFamily->"Times"]}], "]"}], "\[DoubleLeftRightArrow]", 
              
              RowBox[{"is\[Dash]sorted", "[", 
                StyleBox["Y",
                  FontFamily->"Times"], "]"}]}], "\[And]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[GreaterTilde]", 
              StyleBox["Y",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[Cup],\[GreaterTilde],s"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[GreaterTilde],s)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox[\(y\&_\),
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox[\(y\&_\),
                    FontFamily->"Times"]}], "\[RightAngleBracket]"}], "]"}], 
            "\[Implies]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[GreaterTilde]", 
              RowBox[{"\[LeftAngleBracket]", 
                StyleBox[\(y\&_\),
                  FontFamily->"Times"], "\[RightAngleBracket]"}]}]}], 
          ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[GreaterTilde],s"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[GreaterTilde]-merge)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["A",
              FontFamily->"Times"], ",", 
            StyleBox["B",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[GreaterTilde]", 
                StyleBox["A",
                  FontFamily->"Times"]}], "\[And]", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[GreaterTilde]", 
                StyleBox["B",
                  FontFamily->"Times"]}]}], "\[Implies]", 
            RowBox[{
              StyleBox["x",
                FontFamily->"Times"], "\[GreaterTilde]", 
              RowBox[{"merge", "[", 
                RowBox[{
                  StyleBox["A",
                    FontFamily->"Times"], ",", 
                  StyleBox["B",
                    FontFamily->"Times"]}], "]"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"\[GreaterTilde]-merge"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(sub\[Dash]sort)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox[\(y\&_\),
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox["x",
                    FontFamily->"Times"], ",", 
                  StyleBox[\(y\&_\),
                    FontFamily->"Times"]}], "\[RightAngleBracket]"}], "]"}], 
            "\[Implies]", 
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"\[LeftAngleBracket]", 
                StyleBox[\(y\&_\),
                  FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}], 
          ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"sub\[Dash]sort"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[GreaterEqual]tot)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontFamily->"Times"], ",", 
            StyleBox["y",
              FontFamily->"Times"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["x",
                  FontFamily->"Times"], "\[NotGreaterEqual]", 
                StyleBox["y",
                  FontFamily->"Times"]}], ")"}], "\[Implies]", 
            RowBox[{
              StyleBox["y",
                FontFamily->"Times"], "\[GreaterEqual]", 
              StyleBox["x",
                FontFamily->"Times"]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"\[GreaterEqual]tot"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["sort\[Dash]merge",
      ButtonData:>"sort\[Dash]merge",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox[\(x\&_\),
        FontFamily->"Times"]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(y\&_\),
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            
            RowBox[{\(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]]\
\), "\[And]", 
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(y\&_\),
                    FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}], 
            "\[Implies]", 
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"merge", "[", 
                RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), ",", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontFamily->"Times"], "\[RightAngleBracket]"}]}], "]"}],
               "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(is\[Dash]sorted[\[LeftAngleBracket]\[RightAngleBracket]]\), 
        "\[And]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(y\_1\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], 
          "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"6"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"merge", "[", 
          RowBox[{\(\[LeftAngleBracket]\[RightAngleBracket]\), ",", 
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(y\_1\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
          "]"}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["mr",
      ButtonData:>"mr",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(y\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["6.2",
      ButtonData:>"6.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(y\&_\),
              FontFamily->"Times"], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], 
                "]"}], "\[And]", 
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"\[LeftAngleBracket]", 
                  StyleBox[\(y\&_\),
                    FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}], 
            "\[Implies]", "\[IndentingNewLine]", 
            RowBox[{"is\[Dash]sorted", "[", 
              RowBox[{"merge", "[", 
                RowBox[{
                  RowBox[{"\[LeftAngleBracket]", 
                    OverscriptBox[
                      StyleBox[\(x\_1\),
                        FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], 
                  ",", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontFamily->"Times"], "\[RightAngleBracket]"}]}], "]"}],
               "]"}]}], ")"}]}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox[\(y\&_\),
              FontFamily->"Times"], " "}]], 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      StyleBox[
                        SubscriptBox[
                          StyleBox[\(x\&0\),
                            FontFamily->"Times"], "0"],
                        FontFamily->"Times"], ",", 
                      OverscriptBox[
                        StyleBox[\(x\_1\),
                          FontFamily->"Times"], "_"]}], 
                    "\[RightAngleBracket]"}], "]"}], "\[And]", 
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{"\[LeftAngleBracket]", 
                    StyleBox[\(y\&_\),
                      FontFamily->"Times"], "\[RightAngleBracket]"}], "]"}]}],
               "\[Implies]", "\[IndentingNewLine]", 
              RowBox[{"is\[Dash]sorted", "[", 
                RowBox[{"merge", "[", 
                  RowBox[{
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        StyleBox[
                          SubscriptBox[
                            StyleBox[\(x\&0\),
                              FontFamily->"Times"], "0"],
                          FontFamily->"Times"], ",", 
                        OverscriptBox[
                          StyleBox[\(x\_1\),
                            FontFamily->"Times"], "_"]}], 
                      "\[RightAngleBracket]"}], ",", 
                    RowBox[{"\[LeftAngleBracket]", 
                      StyleBox[\(y\&_\),
                        FontFamily->"Times"], "\[RightAngleBracket]"}]}], 
                  "]"}], "]"}]}], ")"}], "."}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox[\(y\&_\),
        FontFamily->"Times"]], "Expression"],
  "."
}], "TmaText"],

Cell["Induction Base: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            "]"}], "\[And]", \(is\[Dash]sorted[\[LeftAngleBracket]\
\[RightAngleBracket]]\)}], "\[Implies]", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"merge", "[", 
              RowBox[{
                RowBox[{"\[LeftAngleBracket]", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox[\(x\&0\),
                          FontFamily->"Times"], "0"],
                      FontFamily->"Times"], ",", 
                    OverscriptBox[
                      StyleBox[\(x\_1\),
                        FontFamily->"Times"], "_"]}], 
                  "\[RightAngleBracket]"}], 
                ",", \(\[LeftAngleBracket]\[RightAngleBracket]\)}], "]"}], 
            "]"}], "."}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "TmaText"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(x\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}], "\[And]", \(is\[Dash]sorted[\[LeftAngleBracket]\
\[RightAngleBracket]]\)}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"16"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            ",", \(\[LeftAngleBracket]\[RightAngleBracket]\)}], "]"}], "]"}]],
     "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["ml",
      ButtonData:>"ml",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["16.1",
      ButtonData:>"16.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell["Induction Step:", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            "]"}], "\[And]", 
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], 
            "]"}]}], "\[Implies]", "\[IndentingNewLine]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(x\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
              ",", 
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
            "]"}], "]"}]}]], "Assumption"],
  ""
}], "Assumption",
  CellTags->"14"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            "]"}], "\[And]", 
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(y\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            "]"}]}], "\[Implies]", 
        RowBox[{
          RowBox[{"is\[Dash]sorted", "[", 
            RowBox[{"merge", "[", 
              RowBox[{
                RowBox[{"\[LeftAngleBracket]", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox[\(x\&0\),
                          FontFamily->"Times"], "0"],
                      FontFamily->"Times"], ",", 
                    OverscriptBox[
                      StyleBox[\(x\_1\),
                        FontFamily->"Times"], "_"]}], 
                  "\[RightAngleBracket]"}], ",", 
                RowBox[{"\[LeftAngleBracket]", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox[\(y\&0\),
                          FontFamily->"Times"], "0"],
                      FontFamily->"Times"], ",", 
                    OverscriptBox[
                      StyleBox[\(y\_3\),
                        FontFamily->"Times"], "_"]}], 
                  "\[RightAngleBracket]"}]}], "]"}], "]"}], "."}]}]], 
    "Conclusion"]
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by the deduction rule."
}], "TmaText"],

Cell["We assume", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(x\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}], "\[And]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(y\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}]}]], "Assumption"],
  " "
}], "Assumption",
  CellTags->"19"],

Cell["and show", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            ",", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(y\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}], 
          "]"}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"20"],

Cell[TextData[{
  "We prove ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by case distinction using ",
  Cell[TextData[{
    "(",
    ButtonBox["mi",
      ButtonData:>"mi",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell["Case 1: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"21"],

Cell["Hence, we have to prove", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[Cup]", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], ",",
               
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(y\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(y\_3\),
                      FontFamily->"Times"], "_"]}], 
                "\[RightAngleBracket]"}]}], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"22"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Cup],\[GreaterTilde],s",
      ButtonData:>"\[Cup],\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(26)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], ",",
               
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(y\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(y\_3\),
                      FontFamily->"Times"], "_"]}], 
                "\[RightAngleBracket]"}]}], "]"}], "]"}], "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], ",",
               
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(y\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(y\_3\),
                      FontFamily->"Times"], "_"]}], 
                "\[RightAngleBracket]"}]}], "]"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"26"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["26",
      ButtonData:>"26",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["26.1",
      ButtonData:>"26.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], ",", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(y\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}], 
          "]"}], "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["26.1",
      ButtonData:>"26.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(27)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}], 
        "\[And]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(y\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"27"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["27",
      ButtonData:>"27",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["27.1",
      ButtonData:>"27.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(28)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}], 
        "\[Implies]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(x\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
              ",", 
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
            "]"}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"28"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(29)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"29"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["sub\[Dash]sort",
      ButtonData:>"sub\[Dash]sort",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(30)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"30"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["27.1",
      ButtonData:>"27.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["30",
      ButtonData:>"30",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["27.2",
      ButtonData:>"27.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["27.2",
      ButtonData:>"27.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["26.2",
      ButtonData:>"26.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], ",", 
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(y\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}], 
          "]"}]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["26.2",
      ButtonData:>"26.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde]-merge",
      ButtonData:>"\[GreaterTilde]-merge",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(31)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
        "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(y\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}]}]],
     "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"31"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["31",
      ButtonData:>"31",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["31.1",
      ButtonData:>"31.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["31.1",
      ButtonData:>"31.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(32)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"32"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["32",
      ButtonData:>"32",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["31.2",
      ButtonData:>"31.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["31.2",
      ButtonData:>"31.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]",
      ButtonData:>"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(33)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(y\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}], "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterEqual]", 
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"33"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["33",
      ButtonData:>"33",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["33.1",
      ButtonData:>"33.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["33.1",
      ButtonData:>"33.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["33.2",
      ButtonData:>"33.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["33.2",
      ButtonData:>"33.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell["Case 2: ", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(23)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[NotGreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"23"],

Cell["Hence, we have to prove", "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(25)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[Cup]", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(x\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
              ",", 
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
            "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"25"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["25",
      ButtonData:>"25",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[Cup],\[GreaterTilde],s",
      ButtonData:>"\[Cup],\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(34)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(x\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
              ",", 
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
            "]"}], "]"}], "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"merge", "[", 
            RowBox[{
              RowBox[{"\[LeftAngleBracket]", 
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox[\(x\&0\),
                        FontFamily->"Times"], "0"],
                    FontFamily->"Times"], ",", 
                  OverscriptBox[
                    StyleBox[\(x\_1\),
                      FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
              ",", 
              RowBox[{"\[LeftAngleBracket]", 
                OverscriptBox[
                  StyleBox[\(y\_3\),
                    FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
            "]"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"34"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["34",
      ButtonData:>"34",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["34.1",
      ButtonData:>"34.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            ",", 
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
          "]"}], "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["34.1",
      ButtonData:>"34.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(35)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(x\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}], "\[And]", 
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], 
          "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"35"],

Cell[TextData[{
  "We remove ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " because its implicand is identical to the goal ",
  Cell[TextData[{
    "(",
    ButtonBox["35",
      ButtonData:>"35",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["35",
      ButtonData:>"35",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["35.1",
      ButtonData:>"35.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["35.1",
      ButtonData:>"35.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["35.2",
      ButtonData:>"35.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(y\_3\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterEqual]tot",
      ButtonData:>"\[GreaterEqual]tot",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(36)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"36"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(37)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"37"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["sub\[Dash]sort",
      ButtonData:>"sub\[Dash]sort",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(38)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(x\_1\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"38"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(39)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(y\_3\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"39"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["sub\[Dash]sort",
      ButtonData:>"sub\[Dash]sort",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(40)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(y\_3\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}], "]"}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"40"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["35.2",
      ButtonData:>"35.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["40",
      ButtonData:>"40",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["34.2",
      ButtonData:>"34.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"merge", "[", 
          RowBox[{
            RowBox[{"\[LeftAngleBracket]", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox[\(x\&0\),
                      FontFamily->"Times"], "0"],
                  FontFamily->"Times"], ",", 
                OverscriptBox[
                  StyleBox[\(x\_1\),
                    FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
            ",", 
            RowBox[{"\[LeftAngleBracket]", 
              OverscriptBox[
                StyleBox[\(y\_3\),
                  FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}], 
          "]"}]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["34.2",
      ButtonData:>"34.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde]-merge",
      ButtonData:>"\[GreaterTilde]-merge",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(41)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(x\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}], 
        "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterTilde]", 
          RowBox[{"\[LeftAngleBracket]", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"41"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["41",
      ButtonData:>"41",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["41.1",
      ButtonData:>"41.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}]}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["41.1",
      ButtonData:>"41.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Conclusion"],
  ","
}], "TmaText"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]",
      ButtonData:>"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(42)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"is\[Dash]sorted", "[", 
          RowBox[{"\[LeftAngleBracket]", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox[\(x\&0\),
                    FontFamily->"Times"], "0"],
                FontFamily->"Times"], ",", 
              OverscriptBox[
                StyleBox[\(x\_1\),
                  FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
          "]"}], "\[And]", 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(y\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"], "\[GreaterEqual]", 
          StyleBox[
            SubscriptBox[
              StyleBox[\(x\&0\),
                FontFamily->"Times"], "0"],
            FontFamily->"Times"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"42"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["42",
      ButtonData:>"42",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["42.1",
      ButtonData:>"42.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(x\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(x\_1\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["42.1",
      ButtonData:>"42.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.1",
      ButtonData:>"19.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["42.2",
      ButtonData:>"42.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterEqual]tot",
      ButtonData:>"\[GreaterEqual]tot",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(43)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterEqual]", 
        StyleBox[
          SubscriptBox[
            StyleBox[\(x\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"43"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["42.2",
      ButtonData:>"42.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["43",
      ButtonData:>"43",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "TmaText"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["41.2",
      ButtonData:>"41.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          SubscriptBox[
            StyleBox[\(y\&0\),
              FontFamily->"Times"], "0"],
          FontFamily->"Times"], "\[GreaterTilde]", 
        RowBox[{"\[LeftAngleBracket]", 
          OverscriptBox[
            StyleBox[\(y\_3\),
              FontFamily->"Times"], "_"], "\[RightAngleBracket]"}]}]], 
    "Expression",
    FontColor->GrayLevel[0]],
  ":"
}], "TmaText"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["41.2",
      ButtonData:>"41.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterTilde],s",
      ButtonData:>"\[GreaterTilde],s",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "TmaText"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(44)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]sorted", "[", 
        RowBox[{"\[LeftAngleBracket]", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox[\(y\&0\),
                  FontFamily->"Times"], "0"],
              FontFamily->"Times"], ",", 
            OverscriptBox[
              StyleBox[\(y\_3\),
                FontFamily->"Times"], "_"]}], "\[RightAngleBracket]"}], 
        "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"44"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["44",
      ButtonData:>"44",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["19.2",
      ButtonData:>"19.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ".   \[EmptySquare]"
}], "TmaText"]
}, Open  ]],

Cell["\<\
Generating the proof from the previous example took 456 seconds. \
The proof\[Dash]object generated has depth 27, four failed branches of \
maximum depth six (in the proofs we gave up to now, a failing branch \
consisted usually of just one node) and 32 pending proof situations. If we \
used a different prover where the induction is the first inference rule used \
on a proof situation, hence induction will be applied also when not \
necessary, the time would reduce to 293 seconds. The proof object generated \
by this alternative prover has depth 24, no failed branches and 24 pending \
proof situations. The part which led to success in this last proof object \
will however be bigger than the one in the proof object generated in the \
previous example  as double induction is applied also for the proof of the \
induction base. \
\>", "Paragraph"],

Cell["\<\
The proof of the above example was generated for a particular case \
of theory exploration where certain notions were already introduced and all \
properties related to them were considered known. One can choose to have a \
different theory exploration where different notions are introduced before \
the merge notion. Such an example is to have the membership predicate instead \
of the \[GreaterTilde] predicate. (Note that the definition of the \
\[GreaterTilde] predicate does involve membership but we do not need to use \
it for the above proof.) The correctness proof of merge will use then \
properties of the membership predicate and transitivity of the \
\[GreaterEqual] predicate. The proof will be longer for this theory \
exploration.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. 4.  Future Work", "Section",
  CellTags->"c:63"],

Cell["\<\
The current mechanism for combining provers in Theorema is not very \
flexible. This mechanism will change with the forthcoming version of the \
system which will both make it simpler and easier to use as it will also give \
the user the possibility to program his own provers by combining existing \
ones. In this future version of Theorema (Version 2), a prover programmer \
will be able to create, from provers in the Theorema library, his own provers \
which are suited for the proof situations that he has in mind.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Appendix: 
Theory Exploration in Elementary Mathematical Analysis\
\>", "Chapter",
  CellTags->"c:64"],

Cell["\<\
We illustrate here an example of theory exploration. We start from \
a given theory in which we assume that all \"interesting \" properties were \
already proved. We then go through several cycles of introducing a new notion \
and exploring its relationship with already known notions.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A. 1.  Given knowledge", "Section",
  CellTags->"c:65"],

Cell["\<\
The theory of \[DoubleStruckCapitalR] with the functions and \
predicates: +, - (unary and binary), *, /, <, >, \[GreaterEqual], \
\[LessEqual], \[LeftBracketingBar]\[RightBracketingBar] (absolute value), \
max, min. We consider this theory completely explored.\
\>", "BItem1"],

Cell[TextData[{
  "The notion of function of one variable over real numbers  (",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^\[DoubleStruckCapitalR]\)]],\

  "), the notion of sum of functions (+) and the notion of equality of \
functions (\[HumpEqual]):"
}], "BItem1"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<function equality\>\"", ",", \(any[f, g]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\((f \[HumpEqual] 
                    g)\) \[DoubleLeftRightArrow] \(\[ForAll] \+x\((f[x] = 
                      g[x])\)\)\), "\"\<\[HumpEqual]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  CellTags->{"fsum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 2.  Introducing the Limit Predicate", "Section",
  CellTags->"c:66"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<function has limit at a point\>\"", ",", \(any[f, x, a]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(limit[f, x, 
                  a] \[DoubleLeftRightArrow] \(\(\[ForAll] \+\[Epsilon]\)\+\(\
\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\
\)\+\(0 < \[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - a\[RightBracketingBar] < \[Epsilon]\)\)\)\), 
              "\"\<L\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["A. 2. 1.  Rewrite Property", "Subsection",
  CellTags->"c:67"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<sum of functions has limit\>\"", ",", 
          "\[IndentingNewLine]", \(any[f, g, x, a, b]\), ",", 
          "\[IndentingNewLine]", GridBox[{
              {\(limit[f, x, a] \[And] 
                    limit[g, x, b] \[Implies] \[IndentingNewLine]limit[f + g, 
                    x, a + b]\), "\"\<L[+]\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "."}]], "Input"],

Cell["\<\
This property can be proved by PCS given the following knowledge: \
the definition of limit, the definition of sum of functions and the \
additional lemmas (which were already proved at the level of complete \
exploration of \[DoubleStruckCapitalR] with the notions \[LeftBracketingBar]\
\[RightBracketingBar], <, >, min):\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<distance of sum\>\"", 
          ",", \(any[x, y, z, t, \[Delta], \[Epsilon]]\), ",", GridBox[{
              {\(\((\[LeftBracketingBar]\((x + z)\) - \((y + 
                              t)\)\[RightBracketingBar] < \((\[Delta] + \
\[Epsilon])\))\)\[DoubleLongLeftArrow]\n\t\((\[LeftBracketingBar]x - 
                            y\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]z - t\[RightBracketingBar] < \[Epsilon])\)\), 
                "\"\<\[LeftBracketingBar]\[RightBracketingBar]+\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["Lemma",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<mininum, greater\>\"", ",", \(any[m, M1, M2]\), ",", GridBox[{
              {\(min[M1, M2] > 
                    m \[DoubleLeftRightArrow] \((M1 > m \[And] M2 > m)\)\), 
                "\"\<min>\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<less, minimum\>\"", ",", \(any[m, M1, M2]\), ",", GridBox[{
            {\(m < min[M1, M2] \[Implies] \((m < M1 \[And] m < M2)\)\), 
              "\"\<<min\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]}], "Input",
  LimitsPositioningTokens->{},
  CellTags->{
  "2-ary limit of sum", "distance of sum", "fsum", "limit", "limit of sum"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A. 2. 2.  Non\[Dash]Rewrite Properties\
\>", "Subsection",
  CellTags->"c:68"],

Cell["\<\
The following are properties of non\[Dash]rewrite type of the limit \
predicate:  \
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<limit, bounded except\>\"", ",", \(any[f, x, a]\), ",", "\n", 
          "  ", GridBox[{
              {\(limit[f, x, 
                    a] \[Implies] \(\[Exists] \+M\)\+\(M > 0\)\(\(\[Exists] \
\+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\)\+\(0 < \
\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y]\[RightBracketingBar] \[LessEqual] M\)\)\), 
                "\"\<Lb\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<limit, bounded below except\>\"", ",", \(any[f, x, a]\), 
        ",", \(with[a \[NotEqual] 0]\), ",", "\n", "  ", GridBox[{
            {\(limit[f, x, 
                  a] \[Implies] \(\[Exists] \+\[Delta]\)\+\(\[Delta] > \
0\)\(\(\[ForAll] \+y\)\+\(0 < \[LeftBracketingBar]y - x\[RightBracketingBar] \
< \[Delta]\)\[LeftBracketingBar]f[
                          y]\[RightBracketingBar] > \[LeftBracketingBar]a\
\[RightBracketingBar]\/2\)\), "\"\<Lbb\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]}], "Input"],

Cell["\<\
Both of them can be proved by PCS given the definition of limit \
predicate and one suitable property of the absolute value, namely\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<absolute value, bound above\>\"", ",", \(any[a, b, c]\), ",", "\n",
         "  ", GridBox[{
            {\(\[LeftBracketingBar]a - b\[RightBracketingBar] < 
                  c \[Implies] \[LeftBracketingBar]a\[RightBracketingBar] < 
                  c + \[LeftBracketingBar]b\[RightBracketingBar]\), 
              "\"\<aba\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Absolute Value", "Continuity, Sign"}],

Cell["and", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<absolute value, bound below\>\"", ",", \(any[a, b, c]\), ",", "\n",
         "  ", GridBox[{
            {\(\[LeftBracketingBar]a - b\[RightBracketingBar] < 
                  c \[Implies] \[LeftBracketingBar]a\[RightBracketingBar] > \
\[LeftBracketingBar]b\[RightBracketingBar] - c\), "\"\<abb\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->{"Absolute Value", "Continuity, Sign"}],

Cell["respectively. ", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 3.  Introducing the Limit Function", "Section",
  CellTags->"c:69"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<limit of function at a point\>\"", ",", \(any[f, x, a]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(limit[f, x] := \(\( \[SuchThat] \+a\)\(limit[f, x, a]\)\)\), 
              "\"\<lim\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["The only property of the limit function is of rewrite type:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<limit of sum\>\"", ",", \(any[f, g, x]\), ",", "\n", "  ", 
        GridBox[{
            {\(limit[f + g, x] = limit[f, x] + limit[g, x]\), "\"\<lim\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This proposition cannot yet be proved as we do not have a prover \
which handles the \"the\" quantifier. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 4.  Introducing the Local Continuity Predicate", "Section",
  CellTags->"c:70"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<function continuous at a point\>\"", ",", \(any[f, x]\), ",", "\n",
         "  ", GridBox[{
            {\(continuous[f, 
                  x] \[DoubleLeftRightArrow] \(\(\[ForAll] \+\[Epsilon]\)\+\(\
\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\
\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \[Delta]\)\
\[LeftBracketingBar]f[y] - f[x]\[RightBracketingBar] < \[Epsilon]\)\)\)\), 
              "\"\<C\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["A. 4. 1.  Rewrite Property", "Subsection",
  CellTags->"c:71"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum is continuous\>\"", ",", \(any[f, g, x]\), ",", "\n", "  ", 
        GridBox[{
            {\(continuous[f, x] \[And] 
                  continuous[g, x] \[Implies] \[IndentingNewLine]continuous[
                  f + g, x]\), "\"\<C[+]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This proposition can be automatically proved by PCS using the \
definition of continuity, the definition of function sum and the same three \
lemmas used for proving that the sum of two functions which have limit at a \
point has also limit.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A. 4. 2.  Non\[Dash]Rewrite Properties\
\>", "Subsection",
  CellTags->"c:72"],

Cell["\<\
The reason why the proof of the previous property needs almost the \
same knowledge as the corresponding proof for limit is that the following \
equivalent form for continuity exists:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<continuous and limit\>\"", ",", \(any[f, x]\), ",", "\n", "  ", 
        GridBox[{
            {\(continuous[f, x] \[DoubleLeftRightArrow] limit[f, x, f[x]]\), 
              "\"\<C\[Dash]L\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This left\[Dash]to\[Dash]right direction of this equivalence can be \
proved by PC or PCS by using only the definitions of the two notions: \
continuity and limit, and no extra knowledge. For the other direction, both \
PC and PCS fail. The difficult point in the proof is to pass from a universal \
quantifier ranging on a neighborhood of a point x, excepting x, to the \
universal quantifier ranging over the whole neighborhood. It might be that \
with a better special solver (which also accepts quantified solve problems) \
PCS would succeed. As for PC, it needs much more knowledge on the real \
numbers. \
\>", "Text"],

Cell["\<\
Hence, also the other properties of limit will specialize in this \
case to:\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity, bounded except\>\"", ",", \(any[f, x]\), ",", "\n", 
          "  ", GridBox[{
              {\(continuous[f, 
                    x] \[Implies] \(\[Exists] \+M\)\+\(M > 0\)\(\(\[Exists] \
\+\[Delta]\)\+\(\[Delta] > 0\)\(\(\[ForAll] \+y\)\+\(\[LeftBracketingBar]y - \
x\[RightBracketingBar] < \[Delta]\)\[LeftBracketingBar]f[
                              y]\[RightBracketingBar] \[LessEqual] M\)\)\), 
                "\"\<cb\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity, bounded below except\>\"", ",", 
          "\[IndentingNewLine]", \(any[f, x]\), 
          ",", \(with[f[x] \[NotEqual] 0]\), ",", "\n", "  ", GridBox[{
              {\(continuous[f, 
                    x] \[Implies] \(\[Exists] \+\[Delta]\)\+\(\[Delta] > \
0\)\(\(\[ForAll] \+y\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \
\[Delta]\)\[LeftBracketingBar]f[
                            y]\[RightBracketingBar] > \
\[LeftBracketingBar]f[x]\[RightBracketingBar]\/2\)\), "\"\<cbb\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<continuity,sign\>\"", ",", \(any[f, x]\), ",", \(with[f[x] > 0]\), 
        ",", "\n", "  ", GridBox[{
            {\(continuous[f, 
                  x] \[Implies] \(\[Exists] \+\[Delta]\)\+\(\[Delta] > \
0\)\(\(\[ForAll] \+y\)\+\(\[LeftBracketingBar]y - x\[RightBracketingBar] < \
\[Delta]\)f[y] > 0\)\), "\"\<cs\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]}], "Input"],

Cell["\<\
The proofs of these properties can be done by PCS either by using \
only the continuity definition and the same corresponding lemmas on absolute \
values as the ones used for the limit properties, or by using the equivalent \
formulation of continuity and the corresponding properties for limit.\
\>", \
"Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 5.  Introducing the Increment Function", "Section",
  CellTags->"c:73"],

Cell["\<\
We define a function that measures the increment at a point of \
another function:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<function increment at a point\>\"", ",", \(any[f, x, h]\), ",", 
        "\n", "  ", GridBox[{
            {\(\(\[Delta][f, x]\)[h] := f[x + h] - f[x]\), 
              "\"\<\[Delta]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["A. 5. 1.  Rewrite Property", "Subsection",
  CellTags->"c:74"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<increment function of sum\>\"", ",", \(any[f, g, x]\), ",", "\n", 
        "  ", GridBox[{
            {\(\[Delta][f + g, 
                  x] \[HumpEqual] \[Delta][f, x] + \[Delta][g, x]\), 
              "\"\<\[Delta]+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
We can prove the above property by PC giving as knowledge the \
definition of \[Delta], \[HumpEqual] and a property of addition and \
subtraction of real numbers:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<addition, subtraction\>\"", ",", \(any[a, b, c, d]\), ",", "\n", 
        "  ", GridBox[{
            {\(\((a + b)\) - \((c + d)\) = \((a - c)\) + \((b - d)\)\), 
              "\"\<+-\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A. 5. 2.  Non\[Dash]Rewrite Properties\
\>", "Subsection",
  CellTags->"c:75"],

Cell["\<\
One property of the increment function is that it has zero as a \
root:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<increment function has a zero root\>\"", ",", 
        "\[IndentingNewLine]", \(any[f, x]\), ",", "\n", "  ", GridBox[{
            {\(\(\[Delta][f, x]\)[0] = 0\), "\"\<\[Delta],0\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[TextData[{
  "This property can either be proved by the basic simplifier prover we have \
in Theorema given the definition of \[Delta] and the property that ",
  Cell[BoxData[
      \(TraditionalForm\`\(-x\)\)]],
  " is inverse element to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " with respect to addition, or by the polynomial simplifier with numbers \
which uses Mathematica internally for doing computations. The polynomial \
simplifier needs no extra knowledge except the definition of \[Delta]."
}], "Text"],

Cell["\<\
Properties which relate the new increment function notion to the \
old notions are:\
\>", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["Proposition",
          FontWeight->"Bold"], "[", 
        RowBox[{
        "\"\<continuity, continuity of increment\>\"", ",", 
          "\[IndentingNewLine]", \(any[f, x]\), ",", "\n", GridBox[{
              {\(\(\ \ \)\(continuous[f, x] \[DoubleLeftRightArrow] 
                  continuous[\[Delta][f, x], 0]\)\), 
                "\"\<C\[Dash]C\[Dash]\[Rho]\>\""}
              },
            ColumnAlignments->{Left}]}], "]"}], "\[IndentingNewLine]"}], "\n",
   
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<continuity, limit of increment\>\"", ",", \(any[f, x]\), ",", "\n",
         "  ", GridBox[{
            {\(continuous[f, x] \[DoubleLeftRightArrow] 
                limit[\[Delta][f, x], 0, 0]\), 
              "\"\<C\[Dash]L\[Dash]\[Rho]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]}], "Input"],

Cell["\<\
The above properties can be proved by PCS. For the first one it \
needs the definition of continuity and the property: \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<subtraction, zero\>\"", ",", \(any[a]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(a - 0 = a\), "\"\<-0\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"addition, subtraction, division"],

Cell["\<\
The second property is proved using as knowledge the first \
property, the property giving an equivalent formulation of continuity in \
terms of limit and the fact that 0 is a root for \[Delta].\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 6.  Introducing the Local Differentiability Predicate", "Section",
  CellTags->"c:76"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<differentiable at a point\>\"", ",", \(any[f, x]\), ",", "\n", 
        "  ", GridBox[{
            {\(differentiable[f, 
                  x] \[DoubleLeftRightArrow] \(\[Exists] \+a\(\(\[ForAll] \+\
\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\(\[Exists] \+\[Delta]\)\+\(\[Delta] > \
0\)\(\(\[ForAll] \+y\)\+\(0 < \[LeftBracketingBar]y - x\[RightBracketingBar] \
< \[Delta]\)\[LeftBracketingBar]\(f[y] - f[x]\)\/\(y - x\) - 
                              a\[RightBracketingBar] < \[Epsilon]\)\)\)\)\), 
              "\"\<D\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["A. 6. 1.  Rewrite Property", "Subsection",
  CellTags->"c:77"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<differentiability of sum\>\"", ",", \(any[f, g, x]\), ",", 
        GridBox[{
            {\(differentiable[f, x] \[And] 
                  differentiable[g, 
                    x] \[Implies] \[IndentingNewLine]differentiable[f + g, 
                  x]\), "\"\<D[+]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
We can prove this by PCS giving as knowledge the definition of the \
differentiability predicate and function sum, together with the same three \
lemmas needed for proving \"limit of sum\" and the extra lemma: \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<addition, subtraction, division\>\"", ",", \(any[a, b, c, d, e]\), 
        ",", "\[IndentingNewLine]", GridBox[{
            {\(\(\((a + b)\) - \((c + d)\)\)\/e = \(a - c\)\/e + \(b - d\)\/e\
\), "\"\<+-/\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  CellTags->"addition, subtraction, division"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A. 6. 2.  Non\[Dash]Rewrite Properties\
\>", "Subsection",
  CellTags->"c:78"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<differentiability and continuity\>\"", ",", \(any[f, x]\), ",", 
        GridBox[{
            {\(differentiable[f, x] \[Implies] continuous[f, x]\), 
              "\"\<D\[Dash]C\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
The above property cannot be proved by PCS as it cannot reduce it \
to a quantifier\[Dash]free solving problem on which to call the available \
implementation of Collins' special solver. However, when a better \
implementation of Collins' method will be available within Theorema (hence, \
no quantifier\[Dash]free restriction), by using it as special solver instead \
of the current implementation of Collins' method, PCS will be able to prove \
the above property.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 7.  Introducing the Increment Ratio Function", "Section",
  CellTags->"c:79"],

Cell["\<\
We introduce the function giving the increment ratio of another \
function at a point: \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<increment ratio function\>\"", ",", \(any[f, x, h]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\(\[CapitalDelta][f, x]\)[h] := \(f[x + h] - f[x]\)\/h\), 
              "\"\<\[CapitalDelta]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["A. 7. 1.  Rewrite Property", "Subsection",
  CellTags->"c:80"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<increment ratio function of sum\>\"", ",", \(any[f, g, x]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\[CapitalDelta][f + g, 
                  x] \[HumpEqual] \[CapitalDelta][f, x] + \[CapitalDelta][g, 
                    x]\), "\"\<\[CapitalDelta]+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This property can be proved by PC given the definitions of \
\[CapitalDelta] and sum of functions and the property \"addition, \
subtraction, division\".\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A. 7. 2.  Non\[Dash]Rewrite Properties\
\>", "Subsection",
  CellTags->"c:81"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<differentiable at a point\>\"", ",", \(any[f, x]\), ",", GridBox[{
            {\(differentiable[f, 
                  x] \[DoubleLeftRightArrow] \(\[Exists] \+a 
                    lim[\[CapitalDelta][f, x], 0, a]\)\), 
              "\"\<D\[Dash]L\[Dash]\[CapitalDelta]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This property can be proved by PCS by using just the definitions of \
the notions involved and the property \"subtract, zero\".\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A. 8.  Introducing the Derivative Function", "Section",
  CellTags->"c:82"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<derivative\>\"", ",", \(any[f, x]\), 
        ",", \(with[differentiable[f, x]]\), ",", "\[IndentingNewLine]", 
        GridBox[{
            {\(\(D[f]\)[
                  x] := \(\( \[SuchThat] \+a\)\(lim[\[CapitalDelta][f, x], 0, 
                    a]\)\)\), "\"\<diff\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
The only property of the derivative function is of rewrite \
type:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<derivative of sum\>\"", ",", \(any[f, g, x]\), ",", 
        "\[IndentingNewLine]", GridBox[{
            {\(\(D[f + g]\)[x] = \(D[f]\)[x] + \(D[g]\)[x]\), 
              "\"\<diff+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input"],

Cell["\<\
This property can be proved by PC given the definition of D, \
\[CapitalDelta] and rewrite property of \[CapitalDelta] given above. \
\>", \
"Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Chapter",
  TaggingRules:>"GeneratedReference",
  CellTags->{"References", "c:83"}],

Cell[TextData[{
  "P. B. Andrews, M. Bishop, S. Issar, D. Nesmith, F. Pfenning and H. Xi. \
TPS: A Theorem Proving System for Classical Type Theory. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 16(3):321\[Dash]353, 1996. ",
  ButtonBox["http://gtps.math.cmu.edu/tps.html",
    ButtonData:>{
      URL[ "http://gtps.math.cmu.edu/tps.html"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->" [1]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"TPS"],

Cell[TextData[{
  "A. Armando, A. Coglio and F. Giunchiglia. The Control Component of Open \
Mechanized Reasoning Systems. In A. Armando and T. Jebelean, editor, ",
  StyleBox["Proceedings of CALCULEMUS: Systems for Integrated Computation and \
Deduction",
    FontSlant->"Italic"],
  ", Electronics Notes in Theoretical Computer Science, Trento, Italy, \
Elsevier, 1999. ",
  ButtonBox["http://www.mrg.dist.unige.it/omrs/",
    ButtonData:>{
      URL[ "http://www.mrg.dist.unige.it/omrs/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->" [2]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"omrs:99"],

Cell[TextData[{
  "C. Ballarin, K. Homann and J. Calmet. Theorems and Algorithms: An \
Interface between Isabelle and Maple. In A. H. M. Levelt, editor, ",
  StyleBox["Proceedings of International Symposium on Symbolic and Algebraic \
Computation (ISSAC'95)",
    FontSlant->"Italic"],
  ", pages 150\[Dash]157, Berkeley CA, ACM Press, 1995. "
}], "Text",
  CellDingbat->" [3]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BallarinEtAl1995"],

Cell[TextData[{
  "C. Ballarin and L.C. Paulson. Reasoning about Coding Theory: The Benefits \
we get from Computer Algebra. In ",
  StyleBox["Proceedings of the International Conference AISC'98: Plattsburgh, \
New York, USA, September 1998",
    FontSlant->"Italic"],
  ", LNCS/LNAI 1476, pages 55\[Dash]66, Springer Verlag, 1998. "
}], "Text",
  CellDingbat->" [4]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"BallarinPaulson1998"],

Cell[TextData[{
  "M. Beeson. Logic and Computation in Mathpert: An Expert System for \
Learning Mathematics. In ",
  StyleBox["Computers and Mathematics",
    FontSlant->"Italic"],
  ", pages 202\[Dash]214. Springer, 1989. "
}], "Text",
  CellDingbat->" [5]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Beeson:89"],

Cell[TextData[{
  "M. Beeson. Automatic Generation of Epsilon-Delta Proofs of Continuity. In \
J. Calmet and J. Plaza, editor, ",
  StyleBox["Artificial Intelligence and Symbolic Computation",
    FontSlant->"Italic"],
  ", LNCS/LNAI 1476, pages 67\[Dash]83, ",
  "Springer Verlag",
  ", 1998. "
}], "Text",
  CellDingbat->" [6]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Beeson:98"],

Cell[TextData[{
  "C. Benzm\[UDoubleDot]ller, L. Cheikhrouhou, D. Fehrer, A. Fiedler, X. \
Huang, M. Kerber, M. Kohlhase, K. Konrad, A. Meier, E. Melis, W. \
Schaarschmidt, J. Siekmann and V. Sorge. Omega: Towards a Mathematical \
Assistant. In ",
  StyleBox["Proceedings of CADE-14, James Cook University, Australia, 1997",
    FontSlant->"Italic"],
  ", LNAI 1249, ",
  "Springer Verlag",
  ", 1997. ",
  ButtonBox["http://www.ags.uni-sb.de/~omega/",
    ButtonData:>{
      URL[ "http://www.ags.uni-sb.de/~omega/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->" [7]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Benzmueller_al:97"],

Cell[TextData[{
  "P. G. Bertoli, J. Calmet, F. Giunchiglia and K. Homann. Specification and \
Integration of Theorem Provers and Computer Algebra Systems. In ",
  StyleBox["Proceedings of AISC'98: Plattsburgh, New York, USA, September \
1998",
    FontSlant->"Italic"],
  ", LNCS/LNAI 1476, pages 94\[Dash]106, ",
  "Springer Verlag",
  ", 1998. "
}], "Text",
  CellDingbat->" [8]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"AISC98*94"],

Cell[TextData[{
  "W. W. Bledsoe. Challenge Problems in Elementary Analysis. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 6:341\[Dash]359, 1990. "
}], "Text",
  CellDingbat->" [9]\[ThinSpace]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Bledsoe:90"],

Cell[TextData[{
  "W. W. Bledsoe, R. S. Boyer and W. T. Henneman. Computer Proofs of Limit \
Theorems. ",
  StyleBox["Artificial Intelligence",
    FontSlant->"Italic"],
  ", 3(1):27\[Dash]60, 1972. "
}], "Text",
  CellDingbat->"[10]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Bledsoe_Boyer_Henneman:72"],

Cell[TextData[{
  "W. W. Bledsoe and P. Bruell. A Man-Machine Theorem-Proving System. ",
  StyleBox["Artificial Intelligence",
    FontSlant->"Italic"],
  ", 5(1):51\[Dash]72, 1974. "
}], "Text",
  CellDingbat->"[11]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Bledsoe_Bruell:74"],

Cell[TextData[{
  "R. S. Boyer and J. S. Moore. ",
  StyleBox["A Computational Logic HandBook",
    FontSlant->"Italic"],
  ", volume 23, series Perspectives in Computing. Academic Press, New York, \
1988. "
}], "Text",
  CellDingbat->"[12]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Boyer:88a"],

Cell[TextData[{
  "R. S. Boyer and J. S. Moore. ",
  StyleBox["A Computational Logic",
    FontSlant->"Italic"],
  ", series ACM monograph series. Academic Press, New York, 1979. "
}], "Text",
  CellDingbat->"[13]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Boyer_Moore:79"],

Cell[TextData[{
  "R. E. Bryant. Symbolic Boolean Manipulation with Ordered Binary-Decision \
Diagrams. ",
  StyleBox["ACM Computer Surveys",
    FontSlant->"Italic"],
  ", 24(3):293\[Dash]318, Sept 1992. "
}], "Text",
  CellDingbat->"[14]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"OBDD"],

Cell[TextData[{
  "B. Buchberger. An Algorithmical Criterion for the Solvability of Algebraic \
Systems of Equations (German). ",
  StyleBox["Aequationes mathematicae",
    FontSlant->"Italic"],
  ", 4(3):374\[Dash]383, 1970. "
}], "Text",
  CellDingbat->"[15]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:70"],

Cell[TextData[{
  "B. Buchberger. Editorial. ",
  StyleBox["Journal of Symbolic Computation",
    FontSlant->"Italic"],
  ", 1(1):1\[Dash]6, 1985. "
}], "Text",
  CellDingbat->"[16]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:85c"],

Cell[TextData[{
  "B. Buchberger. Mathematical Software Systems: The Future (German). In ",
  StyleBox["Informatik-Spektrum",
    FontSlant->"Italic"],
  ", pages 193\[Dash]220. Springer, Heidelberg, 1996. "
}], "Text",
  CellDingbat->"[17]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:96b"],

Cell[TextData[{
  "B. Buchberger. Proving, Solving, Computing. In ",
  StyleBox["Proceedings of the Multiparadigm Logic Programming Workshop, Bonn \
GMD, September 5, 1996",
    FontSlant->"Italic"],
  ", 1996. Invited Talk. "
}], "Text",
  CellDingbat->"[18]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:96c"],

Cell[TextData[{
  "B. Buchberger. Mathematica as a Rewrite Language. In T. Ida, A. Ohori and \
M. Takeichi, editor, ",
  StyleBox["Proceedings of the Second Fuji International Worshop on \
Functional and Logic Programming, Shonan Village, Nov 1-4, 1996",
    FontSlant->"Italic"],
  ", pages 1\[Dash]13, World Scientific, Singapore, 1997. "
}], "Text",
  CellDingbat->"[19]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:96d"],

Cell[TextData[{
  "B. Buchberger. Using Mathematica for Doing Simple Mathematical Proofs. In \
",
  StyleBox["Proceedings of the 4th Mathematica Users' Conference, Tokyo, \
November 2, 1996",
    FontSlant->"Italic"],
  ", pages 80\[Dash]96, Wolfram Media Publishing, 1996. "
}], "Text",
  CellDingbat->"[20]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:96e"],

Cell[TextData[{
  "B. Buchberger. Mathematica: A System for Doing Mathematics by Computer?. \
In ",
  StyleBox["Advances in the Design of Symbolic Computation Systems",
    FontSlant->"Italic"],
  ", pages 2\[Dash]20. Springer, New York - Vienna, 1997. "
}], "Text",
  CellDingbat->"[21]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:97a"],

Cell[TextData[{
  "B. Buchberger. The Theorema Prover for Equalities over the Natural \
Numbers. In ",
  StyleBox["Proceedings of the First International Theorema Workshop, \
Hagenberg, Austria, June 9-10, 1997",
    FontSlant->"Italic"],
  ", RISC-Reports series No. 97-20, 1997. "
}], "Text",
  CellDingbat->"[22]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb:97d"],

Cell[TextData[{
  "B. Buchberger, T. Jebelean, F. Kriftner, M. Marin, E. Tomuta and D. \
Vasaru. An Overview of the Theorema Project. In ",
  StyleBox["Proceedings of the International Symposium on Symbolic and \
Algebraic Computation (ISSAC) , Maui, Hawaii, 1997",
    FontSlant->"Italic"],
  ", ACM Press, 1997. "
}], "Text",
  CellDingbat->"[23]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_al:97"],

Cell["\<\
B. Buchberger, C. Dupre, T. Jebelean, F. Kriftner, K. Nakagawa, D. \
Vasaru, W. Windsteiger. Theorema: A Progress Report. RISC-Report 99-42, \
RISC-Linz, Austria, 1999. \
\>", "Text",
  CellDingbat->"[24]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_all:99"],

Cell[TextData[{
  "B. Buchberger, G. E. Collins and B. Kutzler. Algebraic Methods in \
Computational Geometry. ",
  StyleBox["Annual Reviews in Computer Science",
    FontSlant->"Italic"],
  ", 3:85\[Dash]119, 1988. "
}], "Text",
  CellDingbat->"[25]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_Coll_Kutz:88"],

Cell[TextData[{
  "B. Buchberger. Theory Exploration versus Theorem Proving. In A. Armando \
and T. Jebelean, editor, ",
  StyleBox["Proceedings of CALCULEMUS: Systems for Integrated Computation and \
Deduction",
    FontSlant->"Italic"],
  ", Electronics Notes in Theoretical Computer Science, Trento, Italy, \
Elsevier, 1999. "
}], "Text",
  CellDingbat->"[26]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_expl:99"],

Cell[TextData[{
  "B. Buchberger and D. Vasaru. An Induction Prover for Equalities over \
Lists. In ",
  StyleBox["Proceedings of the First International Theorema Workshop, \
Hagenberg, Austria, June 9-10, 1997",
    FontSlant->"Italic"],
  ", RISC-Reports series No. 97-20, 1997. "
}], "Text",
  CellDingbat->"[27]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_Vasa:97"],

Cell[TextData[{
  "B. Buchberger and W. Windsteiger. The Theorema Language: Implementing \
Object- and Meta-Level Usage of Symbols in the Theorema System. In ",
  StyleBox["Proceedings of the Second International Theorema Workshop",
    FontSlant->"Italic"],
  ", RISC report 98-10, 1998. "
}], "Text",
  CellDingbat->"[28]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Buchb_WW:98"],

Cell[TextData[{
  "A. Bundy, F. van Harmelen, C. Horn and A. Smaill. The Oyster-Clam system. \
In M. E. Stickel, editor, ",
  StyleBox["Proceedings of CADE-10, Kaiserslautern, Germany, 1990",
    FontSlant->"Italic"],
  ", LNAI 449, pages 647\[Dash]648, ",
  "Springer Verlag",
  ", 1990. "
}], "Text",
  CellDingbat->"[29]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Bundy:90"],

Cell["\<\
A. Bundy. A Survey of Automatic Deduction. Research Paper 950, \
University of Edinburgh, Division of Informatics, April 1999. \
\>", "Text",
  CellDingbat->"[30]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Bundy_AD:99"],

Cell[TextData[{
  "A. Bundy, A. Stevens, F. van Harmelen, A. Ireland and A. D. Smaill. \
Rippling: a Heuristic for Guiding Inductive Proofs. ",
  StyleBox["Journal of Artificial Intelligence",
    FontSlant->"Italic"],
  ", 62(2):185\[Dash]253, 1993. "
}], "Text",
  CellDingbat->"[31]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Rippling"],

Cell[TextData[{
  StyleBox["Computeralgebra in Deutschland: Bestandsaufnahme, \
M\[ODoubleDot]glichkeiten, Perspektiven",
    FontSlant->"Italic"],
  ", Fachgruppe Computeralgebra der GI, DMV, GAM, 1993. "
}], "Text",
  CellDingbat->"[32]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"CA"],

Cell[TextData[{
  "O. Caprotti and A. M. Cohen. Integrating Computational and Deduction \
Systems Using OpenMath. In A. Armando and T. Jebelean, editor, ",
  StyleBox["Proceedings of CALCULEMUS: Systems for Integrated Computation and \
Deduction",
    FontSlant->"Italic"],
  ", Electronics Notes in Theoretical Computer Science, Trento, Italy, \
Elsevier, 1999. ",
  ButtonBox["http://www.nag.co.uk/projects/openmath/omsoc/",
    ButtonData:>{
      URL[ "http://www.nag.co.uk/projects/openmath/omsoc/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[33]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"openmath:99"],

Cell[TextData[{
  "B. W. Char, K. O. Geddes, G. H. Gonnet, B. L. Leong, M.B. Monagan and S.M. \
Watt. ",
  StyleBox["Maple V Language Reference Manual",
    FontSlant->"Italic"],
  ", ",
  "Springer Verlag",
  ", 1992. "
}], "Text",
  CellDingbat->"[34]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"maple"],

Cell[TextData[{
  "S-C. Chou. ",
  StyleBox["Mechanical Geometric Theorem Proving",
    FontSlant->"Italic"],
  ", Reidel Pub. Co., Dordrecht, 1988. "
}], "Text",
  CellDingbat->"[35]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Chou:88"],

Cell[TextData[{
  "E. M. Clarke and X. Zhao. Analytica - A Theorem Prover for Mathematica. ",
  StyleBox["The Mathematica Journal",
    FontSlant->"Italic"],
  ", 3(1):56\[Dash]71, 1993. "
}], "Text",
  CellDingbat->"[36]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Clarke_Zhao:93"],

Cell[TextData[{
  "G. E. Collins. Quantifier Elimination for Real Closed Fields by \
Cylindrical Algebraic Decomposition. In ",
  StyleBox["Second GI Conference on Automata Theory and Formal Languages",
    FontSlant->"Italic"],
  ", LNCS 33, pages 134\[Dash]183, ",
  "Springer Verlag",
  ", Berlin, 1975. "
}], "Text",
  CellDingbat->"[37]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Collins:75"],

Cell[TextData[{
  "G. E. Collins and H. Hong. Partial Cylindrical Algebraic Decomposition for \
Quantifier Elimination. ",
  StyleBox["Journal of Symbolic Computation",
    FontSlant->"Italic"],
  ", 12(3):299\[Dash]328, 1991. "
}], "Text",
  CellDingbat->"[38]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Collins_Hong:91"],

Cell[TextData[{
  "R. L. Constable et al. ",
  StyleBox["Implementing Mathematics with the Nuprl Proof Development System",
    
    FontSlant->"Italic"],
  ", Prentice-Hall, 1986. "
}], "Text",
  CellDingbat->"[39]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Constable:86"],

Cell[TextData[{
  "D. C. Cooper. Theorem Proving in Arithmetic without Multiplication. In ",
  StyleBox["Machine Intelligence 7",
    FontSlant->"Italic"],
  ", pages 91\[Dash]99, Edinburgh University Press, 1972. "
}], "Text",
  CellDingbat->"[40]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Cooper"],

Cell[TextData[{
  "B. I. Dahn, J. Gehne, Th. Honigmann and A. Wolf. Integration of Automated \
and Interactive Theorem Proving in ILF. In ",
  StyleBox["Proceedings of CADE-14",
    FontSlant->"Italic"],
  ", pages 57\[Dash]60, ",
  "Springer Verlag",
  ", 1997. "
}], "Text",
  CellDingbat->"[41]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"ILF"],

Cell[TextData[{
  "J. H. Davenport, Y. Siret and E. Tournier. ",
  StyleBox["Computer Algebra: Systems and Algorithms for Algebraic \
Computation",
    FontSlant->"Italic"],
  ", Academic Press, London, 1988. "
}], "Text",
  CellDingbat->"[42]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Davenport_all:88"],

Cell[TextData[{
  "A. Dolzmann and Th. Sturm. Redlog: Computer Algebra Meets Computer Logic. \
",
  StyleBox["ACM SIGSAM Bulletin",
    FontSlant->"Italic"],
  ", 31(2):2\[Dash]9, Jun 1997. ",
  ButtonBox["http://www.fmi.unipassau.de/~redlog",
    ButtonData:>{
      URL[ "http://www.fmi.unipassau.de/~redlog"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[43]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"RedLog:97"],

Cell[TextData[{
  "B. Dutertre. Elements of Mathematical Analysis in PVS. In ",
  StyleBox["TPHOLs'96, Turku, Finland, 27-30 August",
    FontSlant->"Italic"],
  ", 1996. "
}], "Text",
  CellDingbat->"[44]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Dutertre:96"],

Cell[TextData[{
  "W. D. Farmer, J. D. Guttman and F. J. Thayer. IMPS: An Interactive \
Mathematical Proof System. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 11(2):213\[Dash]248, 1993. "
}], "Text",
  CellDingbat->"[45]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Farmer_al:93"],

Cell[TextData[{
  "R. Gamboa. ",
  StyleBox["Mechanically Verifying Real-Valued Algorithms in ACL2",
    FontSlant->"Italic"],
  ". PhD. Thesis, University of Texas, May 1999. "
}], "Text",
  CellDingbat->"[46]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Gamboa"],

Cell["\<\
S. Garland and J. V. Guttag. A Guide to LP, the Larch Prover. SRC \
082, Digital Equipment Corp., Sys Res Ctr, 1991. \
\>", "Text",
  CellDingbat->"[47]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Garland_Guttag:91"],

Cell["\<\
F. Giunchiglia, P. Pecchiari and C. Talcott. Reasoning Theories: \
Towards an Architecture for Open Mechanized Reasoning Systems. 9409-15, IRST, \
Trento, Italy, 1994. Submitted to Journal of Automated Reasoning. \
\>", \
"Text",
  CellDingbat->"[48]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"omrs"],

Cell[TextData[{
  "M. J. C. Gordon and T. F. Melham. ",
  StyleBox["Introduction to HOL: A Theorem Proving Environment for Higher \
Order Logic",
    FontSlant->"Italic"],
  ", Cambridge University Press, 1993. "
}], "Text",
  CellDingbat->"[49]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Gordon:93"],

Cell[TextData[{
  "J. Harrison. ",
  StyleBox["Theorem Proving with the Real Numbers",
    FontSlant->"Italic"],
  ", ",
  "Springer Verlag",
  ", 1998. PhD. Thesis. "
}], "Text",
  CellDingbat->"[50]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Harrison-thesis"],

Cell[TextData[{
  "J. Harrison and L. Thery. Extending the HOL Theorem Prover with a Computer \
Algebra System to Reason about the Reals. In ",
  StyleBox["HUG'93 HOL User's Group Workshop",
    FontSlant->"Italic"],
  ", pages 174\[Dash]184, 1993. "
}], "Text",
  CellDingbat->"[51]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"hol-cas1"],

Cell[TextData[{
  "A. C. Hearn. ",
  StyleBox["REDUCE. User's Manual Verison 3.6",
    FontSlant->"Italic"],
  ". RAND, 1995. ",
  ButtonBox["http://www.uni-koeln.de/REDUCE/",
    ButtonData:>{
      URL[ "http://www.uni-koeln.de/REDUCE/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[52]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Reduce"],

Cell[TextData[{
  "L. Hines. STR+VE and Integers. In A. Bundy, editor, ",
  StyleBox["Proceedings of CADE-12",
    FontSlant->"Italic"],
  ", LNAI 814, pages 416\[Dash]430, ",
  "Springer Verlag",
  ", 1994. "
}], "Text",
  CellDingbat->"[53]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Hines"],

Cell[TextData[{
  "K. Homann. ",
  StyleBox["Symbolisches Loesen mathematischer Probleme durch Kooperation \
algorithMischer und deduktiver Systeme (in German)",
    FontSlant->"Italic"],
  ". Universitaet Karlsruhe, 1996. "
}], "Text",
  CellDingbat->"[54]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Homann:96"],

Cell[TextData[{
  "K. Homman and J. Calmet. Structures for Symbolic Mathematical Reasoning \
and Computation. In J. Calmet and C. Limongelli, editor, ",
  StyleBox["Proceedings of the International Symposium on Design and \
Implementation of Symbolic Computation Systems (DISCO 96)",
    FontSlant->"Italic"],
  ", LNCS 1128, pages 217\[Dash]228, Springer, 1996. "
}], "Text",
  CellDingbat->"[55]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Homann_Calmet:96"],

Cell[TextData[{
  "X. Huang. Translating Machine-Generated Resolution Proofs into ND-Proofs \
at the Assertion Level. In ",
  StyleBox["Proceedings of Pricai-96",
    FontSlant->"Italic"],
  ", LNAI, Springer, 1996. "
}], "Text",
  CellDingbat->"[56]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Huang:96"],

Cell[TextData[{
  "G. Huet and G. Kahn and C. Paulin-Mohring. ",
  StyleBox["The Coq Proof Assistant. A Tutorial. Version 5.10",
    FontSlant->"Italic"],
  ". INRIA-Rocquencourt, CNRS-ENS Lyon, 1994. ",
  ButtonBox["http://coq.inria.fr",
    ButtonData:>{
      URL[ "http://coq.inria.fr"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[57]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Huet_all:94"],

Cell[TextData[{
  "A. Ireland and A. Bundy. Productive Use of Failure in Inductive Proof. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 16(1-2):79\[Dash]111, 1996. "
}], "Text",
  CellDingbat->"[58]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Ireland_Bundy:96"],

Cell[TextData[{
  "IRST and Univ. Edinburgh and Univ. Karlsruhe and Univ. Nijmegen and Univ. \
Roma 3 and Univ. Saarbr\[UDoubleDot]cken and INRIA and LEIBNIZ-Grenoble. ",
  StyleBox["Calculemus - Systems for Integrated Computation and Deduction",
    FontSlant->"Italic"],
  ". 1997. Proposal for a TMR European project. "
}], "Text",
  CellDingbat->"[59]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Calculemus"],

Cell[TextData[{
  "P. B. Jackson. ",
  StyleBox["Enhancing the Nuprl Proof Development System and Applying it to \
Computational Abstract Algebra",
    FontSlant->"Italic"],
  ". Dept. of Computer Science, Cornell University, Ithaca, New York, 1995. "
}], "Text",
  CellDingbat->"[60]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Jackson:95"],

Cell[TextData[{
  "P. Janicic, A. Bundy and I. Green. A Framework for the Flexible \
Integration of a Class of Decision Procedures into Theorem Provers. In ",
  StyleBox["Proceedings of CADE-16",
    FontSlant->"Italic"],
  ", 1999. "
}], "Text",
  CellDingbat->"[61]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Janicic:99"],

Cell[TextData[{
  "M. Kaufmann and J. Moore. An Industrial Strength Theorem Prover for a \
Logic Based on Common Lisp. ",
  StyleBox["IEEE Transactions on Software Engineering",
    FontSlant->"Italic"],
  ", 23(4):203\[Dash]213, April 1997. "
}], "Text",
  CellDingbat->"[62]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"ACL2:97"],

Cell[TextData[{
  "M. Kaufmann and J. Moore. ",
  StyleBox["The ACL2 User's Manual",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www.cs.utexas.edu/users/moore/acl2/",
    ButtonData:>{
      URL[ "http://www.cs.utexas.edu/users/moore/acl2/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[63]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"ACL2-manual"],

Cell[TextData[{
  "M. Kerber, M. Kohlhase and V. Sorge. Integrating Computer Algebra with \
Proof Planning. In J. Calmet and C. Limongelli, editor, ",
  StyleBox["Proceedings of the International Symposium Design and \
Implementation of Symbolic Computation Systems (DISCO '96)",
    FontSlant->"Italic"],
  ", LNCS 1128, Karlsruhe, Germany, Springer Verlag, Berlin, September 18-20 \
1996. "
}], "Text",
  CellDingbat->"[64]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"KeKoSo96b"],

Cell[TextData[{
  "M. Kerber, M. Kohlhase and V. Sorge. Integrating Computer Algebra Into \
Proof Planning. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 21(3):327\[Dash]355, 1998. "
}], "Text",
  CellDingbat->"[65]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"KeKoSo98"],

Cell[TextData[{
  "D. W. Loveland. Automatic Deduction. Some Achievements and Future \
Directions. Report of a Workshop on the Future Directions of Automated \
Deduction, April 20-21, 1996, Chicago, 1997. ",
  ButtonBox["http://www.cs.duke.edu/AutoDedFD/",
    ButtonData:>{
      URL[ "http://www.cs.duke.edu/AutoDedFD/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[66]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Loveland:97"],

Cell[TextData[{
  "Z. Manna and R. Waldinger. ",
  StyleBox["The Logical Basis for Computer Programming",
    FontSlant->"Italic"],
  ", volume Volume 1: Deductive Reasoning, Addison-Wesley Publishing Company, \
1985. "
}], "Text",
  CellDingbat->"[67]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Manna_Waldinger:85"],

Cell[TextData[{
  "W. McCune. ",
  StyleBox["EQP Web Page",
    FontSlant->"Italic"],
  ". ",
  ButtonBox["http://www-unix.mcs.anl.gov/AR/eqp/",
    ButtonData:>{
      URL[ "http://www-unix.mcs.anl.gov/AR/eqp/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[68]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"EQP"],

Cell[TextData[{
  "W. McCune. Solution of the Robbins Problem. ",
  StyleBox["Journal of Automated Reasoning,",
    FontSlant->"Italic"],
  ", 19(3):263\[Dash]276, 1997. "
}], "Text",
  CellDingbat->"[69]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCune_Robbins"],

Cell[TextData[{
  "W. McCune and L. Wos. Otter: The CADE-13 Competition incarnations. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 18(2):211\[Dash]220, 1997. "
}], "Text",
  CellDingbat->"[70]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"McCune_Wos:97"],

Cell[TextData[{
  "E. Melis and U. Leron. A Proof Presentation Suitable for Teaching Proofs. \
In ",
  StyleBox["Proceedings of the 9th International Conference on Artificial \
Intelligence in Education",
    FontSlant->"Italic"],
  ", 1999. "
}], "Text",
  CellDingbat->"[71]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Melis_Leron:99"],

Cell[TextData[{
  "E. Melis. The Limit Domain. In R. Simmons, M. Veloso and S. Smith, editor, \
",
  StyleBox["Proceedings of AIPS-98",
    FontSlant->"Italic"],
  ", 1998. "
}], "Text",
  CellDingbat->"[72]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"melis-limit:98"],

Cell["\<\
E. Melis. Progress in Proof Planning: Planning Limit Theorems \
Automatically. Tech. Report Universitaet des Saarlandes, Fachbereich \
Informatik, Saarbruecken, Germany, Oct 1997. \
\>", "Text",
  CellDingbat->"[73]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Melis_rep"],

Cell[TextData[{
  "M. Moser, O. Ibens, R. Letz, J. Steinbach, C. Goller, J. Schumann and K. \
Mayr. SETHEO and E-SETHEO: The CADE-13 Systems. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 18:237\[Dash]246, 1997. "
}], "Text",
  CellDingbat->"[74]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Setheo"],

Cell[TextData[{
  "The OpenMath, Consortium. ",
  StyleBox["The OpenMath Standard",
    FontSlant->"Italic"],
  ". OpenMath Deliverable 1.3.2a, February 1999. ",
  ButtonBox["http://www.nag.co.uk/projects/OpenMath.htm",
    ButtonData:>{
      URL[ "http://www.nag.co.uk/projects/OpenMath.htm"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellDingbat->"[75]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"OMD132a"],

Cell["\<\
S. Owre, J. M. Rushby and N. Shankar. PVS: An Integrated Approach \
to Specification and Verification. Tech Report SRI International, 1992. \
\
\>", "Text",
  CellDingbat->"[76]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"PVS:92"],

Cell[TextData[{
  "P. Paule and M. Schorn. A Mathematica Version of Zeilberger's Algorithm \
for Proving Binomial Coefficient Identities. ",
  StyleBox["Journal of Symbolic Computation",
    FontSlant->"Italic"],
  ", 20:673\[Dash]698, 1995. "
}], "Text",
  CellDingbat->"[77]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Paule_Schorn:95"],

Cell[TextData[{
  "L. C. Paulson. Isabelle: The next 700 theorem provers. In ",
  StyleBox["Logic and Computer Science",
    FontSlant->"Italic"],
  ", pages 361\[Dash]385. Academic Press, 1990. "
}], "Text",
  CellDingbat->"[78]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"paulson_90isabelle"],

Cell[TextData[{
  "L. C. Paulson. ",
  StyleBox["Introduction to Isabelle",
    FontSlant->"Italic"],
  ". Computer Laboratory, University of Cambridge, 1996. "
}], "Text",
  CellDingbat->"[79]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Paulson:96a"],

Cell[TextData[{
  "PTP-97. ",
  StyleBox["First International Workshop on Proof Transformation and \
Presentation, Schloss Dagstuhl, Germany, 8-10 April",
    FontSlant->"Italic"],
  ". 1997. "
}], "Text",
  CellDingbat->"[80]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Dagstuhl:97"],

Cell[TextData[{
  "QED Group. The QED Manifesto. In A. Bundy, editor, ",
  StyleBox["Proceedings of CADE-12",
    FontSlant->"Italic"],
  ", LNAI 814, pages 238\[Dash]251, ",
  "Springer Verlag",
  ", 1994. "
}], "Text",
  CellDingbat->"[81]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"QED"],

Cell[TextData[{
  "J. D. C. Richardson, A. Smaill and I. M. Green. System Description: Proof \
Planning in Higher-order Logic with \.03Lambda-Clam. In C. Kirchner and H. \
Kirchner, editor, ",
  StyleBox["Proceedings of CADE-15",
    FontSlant->"Italic"],
  ", LNCS 1421, pages 647\[Dash]648, Springer Verlag, 1998. "
}], "Text",
  CellDingbat->"[82]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"lambdaClam:98"],

Cell[TextData[{
  "J. A. Robinson. A Machine-oriented Logic based on the Resolution \
Principle. ",
  StyleBox["Journal of the Association for Computing Machines",
    FontSlant->"Italic"],
  ", 12(1):23\[Dash]41, 1965. "
}], "Text",
  CellDingbat->"[83]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Robinson:65"],

Cell[TextData[{
  "P. Rudnicki. ",
  StyleBox["An Overview of the MIZAR Project",
    FontSlant->"Italic"],
  ". Available at ftp://menaik.cs.ualberta.ca/pub/Mizar/, 1992. "
}], "Text",
  CellDingbat->"[84]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Rudnicki:92"],

Cell[TextData[{
  "B. P. Shults. ",
  StyleBox["Discoveries and Experiments in the Automation of Mathematical \
Reasoning",
    FontSlant->"Italic"],
  ". PhD Thesis, University of Texas at Austin, 1997. "
}], "Text",
  CellDingbat->"[85]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Shults_thesis"],

Cell[TextData[{
  "A. Strzebonski. Solving Equations and Inequalities with Mathematica. In ",
  StyleBox["Proceedings of the Mathematica Developer Conference",
    FontSlant->"Italic"],
  ", 1999. "
}], "Text",
  CellDingbat->"[86]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Strzebonski:99"],

Cell[TextData[{
  "P. Suppes and J. Sheehan. CAI Course in Axiomatic Set Theory. In P. \
Suppes, editor, ",
  StyleBox["University-level Computer Assisted Instruction at Standford: \
1968-1980",
    FontSlant->"Italic"],
  ", pages 3\[Dash]80, Standford, CA, Standford University, Institute for \
Mathematical Studies in the Social Sciences. 1981. "
}], "Text",
  CellDingbat->"[87]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Suppes:81"],

Cell[TextData[{
  "P. Suppes and J. McDonald. Student Use of an Interactive Theorem Prover. \
In ",
  StyleBox["Automated Theorem Proving: After 25 Years",
    FontSlant->"Italic"],
  ", volume 29 of Contemporary Mathematics, pages 315\[Dash]360. American \
Mathematical Society, Providence, 1984. "
}], "Text",
  CellDingbat->"[88]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Suppes:84"],

Cell[TextData[{
  "P. Suppes and S. Takahashi. An Interactive Calculus Theorem-prover for \
Continuity Properties. ",
  StyleBox["Journal of Symbolic Computation",
    FontSlant->"Italic"],
  ", 7(6):573\[Dash]590, June 1989. "
}], "Text",
  CellDingbat->"[89]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Suppes_Ta:89"],

Cell[TextData[{
  "C. Suttner, G. Sutcliffe and T. Yemenis. The TPTP Problem Library. In A. \
Bundy, editor, ",
  StyleBox["Proceedings of CADE-12, Nancy, France",
    FontSlant->"Italic"],
  ", LNAI 814, pages 252\[Dash]266, ",
  "Springer Verlag",
  ", 1994. "
}], "Text",
  CellDingbat->"[90]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"TPTP"],

Cell[TextData[{
  "Y. Tetsuya, A. Bundy, I. Green, T. Walsh and D. Basin. Coloured Rippling: \
An Extension of a Theorem Proving Heuristic. In A. G. Cohn, editor, ",
  StyleBox["Proceedings of the Eleventh European Conference on Artificial \
Intelligence (ECAI-94)",
    FontSlant->"Italic"],
  ", pages 85\[Dash]89, John Wiley, 1994. "
}], "Text",
  CellDingbat->"[91]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"ColorRippl"],

Cell[TextData[{
  "L. Thery. A Certified Version of Buchberger's Algorithm. In C. Kirchner \
and H. Kirchner, editor, ",
  StyleBox["Proceedings of CADE-15, Lindau, Germany, 5-10 July, 1998",
    FontSlant->"Italic"],
  ", LNAI 1421, pages 349\[Dash]364, Springer Berlin, 1998. "
}], "Text",
  CellDingbat->"[92]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Thery"],

Cell[TextData[{
  "E. Tomuta. ",
  StyleBox["An Architecture for Combining Provers and its Applications in the \
Theorema System",
    FontSlant->"Italic"],
  ". PhD Thesis, RISC, Johannes-Kepler University, 1998. RISC Report 98-14. "
}], "Text",
  CellDingbat->"[93]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Tomuta:98"],

Cell[TextData[{
  "A. Trybulec and H. Blair. Computer Aided Reasoning with Mizar. In ",
  StyleBox["Proceedings of 9th IJCAI",
    FontSlant->"Italic"],
  ", LNCS 193, Springer Verlag, 1985. "
}], "Text",
  CellDingbat->"[94]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Trybulec_Blair:85"],

Cell[TextData[{
  "C. Weidenbach. SPASS: Version 0.49. ",
  StyleBox["Journal of Automated Reasoning",
    FontSlant->"Italic"],
  ", 1993. Special Issue on the CADE-13 ATP System Competition. "
}], "Text",
  CellDingbat->"[95]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Spass"],

Cell[TextData[{
  "F. Winkler. ",
  StyleBox["Polynomial Algorithms in Computer Algebra",
    FontSlant->"Italic"],
  ", ",
  "Springer Verlag",
  ", Wien New York, 1996. "
}], "Text",
  CellDingbat->"[96]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Winkler:96"],

Cell[TextData[{
  "S. Wolfram. ",
  StyleBox["The Mathematica Book",
    FontSlant->"Italic"],
  ", Wolfram Media and Cambridge University Press, 1996. "
}], "Text",
  CellDingbat->"[97]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wolfram:96"],

Cell[TextData[{
  "W. Wu. The Char-Set Method and its Applications to Automated Reasoning. In \
W. McCune, editor, ",
  StyleBox["Proceedings of CADE-14",
    FontSlant->"Italic"],
  ", pages 1\[Dash]4, ",
  "Springer Verlag",
  ", 1997. "
}], "Text",
  CellDingbat->"[98]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Wu:97"],

Cell[TextData[{
  "D. Zeilberger. A Holonomic Systems Approach to Special Function \
Identities. ",
  StyleBox["Journal of Computational and Applied Mathematics",
    FontSlant->"Italic"],
  ", 32:321\[Dash]368, 1990. "
}], "Text",
  CellDingbat->"[99]",
  CellMargins->{{20, 2}, {7, 7}},
  TaggingRules:>"GeneratedReference",
  CellTags->"Zeilberger:90"]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{915, 895},
WindowMargins->{{40, Automatic}, {Automatic, 40}},
PrintingPageRange->{1, 2},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, None}, {
    None, Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{99, 99}, {108, 108}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "fpiroi"}, \
"tezaa.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
Magnification->1.5,
StyleDefinitions -> "ThesisStyle.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1739, 51, 54, 1, 227, "Chapter",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[1818, 56, 49, 1, 76, "Section",
      CellTags->"c:2"]},
  "c:3"->{
    Cell[10086, 283, 79, 1, 76, "Section",
      CellTags->"c:3"]},
  "c:4"->{
    Cell[10890, 303, 75, 1, 64, "Subsection",
      CellTags->"c:4"]},
  "c:5"->{
    Cell[12845, 360, 74, 1, 64, "Subsection",
      CellTags->"c:5"]},
  "c:6"->{
    Cell[25885, 702, 77, 1, 67, "Subsection",
      CellTags->"c:6"]},
  "sec:relw"->{
    Cell[42935, 1161, 77, 1, 105, "Subsection",
      CellTags->{"sec:relw", "c:7"}]},
  "c:7"->{
    Cell[42935, 1161, 77, 1, 105, "Subsection",
      CellTags->{"sec:relw", "c:7"}]},
  "c:8"->{
    Cell[51022, 1345, 57, 1, 48, "Section",
      CellTags->"c:8"]},
  "sec:prel"->{
    Cell[58441, 1498, 69, 1, 229, "Chapter",
      CellTags->{"sec:prel", "c:9"}]},
  "c:9"->{
    Cell[58441, 1498, 69, 1, 229, "Chapter",
      CellTags->{"sec:prel", "c:9"}]},
  "c:10"->{
    Cell[58535, 1503, 54, 1, 78, "Section",
      CellTags->"c:10"]},
  "c:11"->{
    Cell[78238, 1812, 54, 1, 78, "Section",
      CellTags->"c:11"]},
  "sec:term"->{
    Cell[81680, 1930, 71, 1, 78, "Section",
      CellTags->{"sec:term", "c:12"}]},
  "c:12"->{
    Cell[81680, 1930, 71, 1, 78, "Section",
      CellTags->{"sec:term", "c:12"}]},
  "sec:Tps"->{
    Cell[84416, 2001, 84, 1, 78, "Section",
      CellTags->{"sec:Tps", "c:13"}]},
  "c:13"->{
    Cell[84416, 2001, 84, 1, 78, "Section",
      CellTags->{"sec:Tps", "c:13"}]},
  "fig:Tmasession"->{
    Cell[92942, 2215, 95, 1, 22, "Figure",
      CellTags->"fig:Tmasession"]},
  "sec:up"->{
    Cell[93074, 2221, 94, 1, 78, "Section",
      CellTags->{"sec:up", "c:14"}]},
  "c:14"->{
    Cell[93074, 2221, 94, 1, 78, "Section",
      CellTags->{"sec:up", "c:14"}]},
  "sec:pp"->{
    Cell[95548, 2280, 107, 1, 78, "Section",
      CellTags->{"sec:pp", "c:15"}]},
  "c:15"->{
    Cell[95548, 2280, 107, 1, 78, "Section",
      CellTags->{"sec:pp", "c:15"}]},
  "eq:bp-def"->{
    Cell[98480, 2355, 326, 12, 45, "NumberedEquation",
      CellTags->"eq:bp-def"]},
  "sec:grw"->{
    Cell[101230, 2436, 73, 1, 229, "Chapter",
      CellTags->{"sec:grw", "c:16"}]},
  "c:16"->{
    Cell[101230, 2436, 73, 1, 229, "Chapter",
      CellTags->{"sec:grw", "c:16"}]},
  "sec:rw-idea"->{
    Cell[102426, 2462, 72, 1, 78, "Section",
      CellTags->{"sec:rw-idea", "c:17"}]},
  "c:17"->{
    Cell[102426, 2462, 72, 1, 78, "Section",
      CellTags->{"sec:rw-idea", "c:17"}]},
  "fig:rules"->{
    Cell[104959, 2535, 130, 4, 22, "Figure",
      CellTags->"fig:rules"]},
  "c:18"->{
    Cell[111696, 2736, 61, 1, 78, "Section",
      CellTags->"c:18"]},
  "r:rw-eq"->{
    Cell[112385, 2756, 355, 14, 75, "InferenceRule",
      CellTags->"r:rw-eq"]},
  "r:rw-impl"->{
    Cell[114765, 2832, 302, 11, 75, "InferenceRule",
      CellTags->"r:rw-impl"]},
  "sec:sem-match"->{
    Cell[117778, 2937, 83, 1, 78, "Section",
      CellTags->{"sec:sem-match", "c:19"}]},
  "c:19"->{
    Cell[117778, 2937, 83, 1, 78, "Section",
      CellTags->{"sec:sem-match", "c:19"}]},
  "sec:rw-impl"->{
    Cell[123779, 3105, 77, 1, 78, "Section",
      CellTags->{"sec:rw-impl", "c:20"}]},
  "c:20"->{
    Cell[123779, 3105, 77, 1, 78, "Section",
      CellTags->{"sec:rw-impl", "c:20"}]},
  "sec:rw-cand"->{
    Cell[127037, 3216, 116, 1, 67, "Subsection",
      CellTags->{"sec:rw-cand", "c:21"}]},
  "c:21"->{
    Cell[127037, 3216, 116, 1, 67, "Subsection",
      CellTags->{"sec:rw-cand", "c:21"}]},
  "c:22"->{
    Cell[128908, 3272, 73, 1, 67, "Subsection",
      CellTags->"c:22"]},
  "c:23"->{
    Cell[130795, 3325, 114, 4, 67, "Subsection",
      CellTags->"c:23"]},
  "fig:eq-impl"->{
    Cell[134824, 3406, 129, 4, 22, "Figure",
      CellTags->"fig:eq-impl"]},
  "sec:find-sm"->{
    Cell[135384, 3424, 111, 1, 67, "Subsection",
      CellTags->{"sec:find-sm", "c:24"}]},
  "c:24"->{
    Cell[135384, 3424, 111, 1, 67, "Subsection",
      CellTags->{"sec:find-sm", "c:24"}]},
  "c:25"->{
    Cell[142557, 3626, 63, 1, 67, "Subsection",
      CellTags->"c:25"]},
  "c:26"->{
    Cell[143602, 3652, 58, 1, 78, "Section",
      CellTags->"c:26"]},
  "sec:solving"->{
    Cell[144195, 3676, 94, 1, 277, "Chapter",
      CellTags->{"sec:solving", "c:27"}]},
  "c:27"->{
    Cell[144195, 3676, 94, 1, 277, "Chapter",
      CellTags->{"sec:solving", "c:27"}]},
  "continuity "->{
    Cell[145203, 3698, 622, 13, 154, "Input",
      CellTags->"continuity "]},
  "sum continuity"->{
    Cell[145875, 3715, 490, 12, 109, "Input",
      CellTags->"sum continuity"]},
  "continuity 2-ary"->{
    Cell[146649, 3736, 535, 12, 109, "Input",
      CellTags->{
      "continuity 2-ary", "continuity 3-ary", "continuity 4-ary"}]},
  "continuity 3-ary"->{
    Cell[146649, 3736, 535, 12, 109, "Input",
      CellTags->{
      "continuity 2-ary", "continuity 3-ary", "continuity 4-ary"}]},
  "continuity 4-ary"->{
    Cell[146649, 3736, 535, 12, 109, "Input",
      CellTags->{
      "continuity 2-ary", "continuity 3-ary", "continuity 4-ary"}]},
  "2-ary continuity"->{
    Cell[148564, 3788, 770, 17, 202, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity"}]},
  "3-ary continuity"->{
    Cell[148564, 3788, 770, 17, 202, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity"}]},
  "4-ary continuity"->{
    Cell[148564, 3788, 770, 17, 202, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity"}]},
  "sec:gsr"->{
    Cell[153800, 3922, 90, 1, 78, "Section",
      CellTags->{"sec:gsr", "c:28"}]},
  "c:28"->{
    Cell[153800, 3922, 90, 1, 78, "Section",
      CellTags->{"sec:gsr", "c:28"}]},
  "c:29"->{
    Cell[158700, 4050, 105, 4, 67, "Subsection",
      CellTags->"c:29"]},
  "r:prex"->{
    Cell[158808, 4056, 304, 11, 75, "InferenceRule",
      CellTags->"r:prex"]},
  "c:30"->{
    Cell[159737, 4093, 116, 4, 67, "Subsection",
      CellTags->"c:30"]},
  "r:push"->{
    Cell[159856, 4099, 372, 12, 75, "InferenceRule",
      CellTags->"r:push"]},
  "r:subf-as"->{
    Cell[161621, 4152, 587, 18, 102, "InferenceRule",
      CellTags->"r:subf-as"]},
  "r:isub"->{
    Cell[162440, 4180, 657, 19, 102, "InferenceRule",
      CellTags->"r:isub"]},
  "c:31"->{
    Cell[163134, 4204, 115, 4, 67, "Subsection",
      CellTags->"c:31"]},
  "r:match-asm"->{
    Cell[163252, 4210, 1380, 36, 156, "InferenceRule",
      CellTags->"r:match-asm"]},
  "r:match-impl"->{
    Cell[166013, 4286, 348, 12, 75, "InferenceRule",
      CellTags->"r:match-impl"]},
  "r:univ-impl"->{
    Cell[182209, 4672, 392, 12, 75, "InferenceRule",
      CellTags->"r:univ-impl"]},
  "r:apply"->{
    Cell[184242, 4728, 683, 22, 102, "InferenceRule",
      CellTags->"r:apply"]},
  "r:ssub"->{
    Cell[184998, 4754, 1106, 31, 129, "InferenceRule",
      CellTags->"r:ssub"]},
  "c:32"->{
    Cell[186263, 4796, 67, 1, 78, "Section",
      CellTags->"c:32"]},
  "sec:id-subp"->{
    Cell[189025, 4857, 102, 1, 67, "Subsection",
      CellTags->{"sec:id-subp", "c:33"}]},
  "c:33"->{
    Cell[189025, 4857, 102, 1, 67, "Subsection",
      CellTags->{"sec:id-subp", "c:33"}]},
  "c:34"->{
    Cell[204560, 5316, 75, 1, 67, "Subsection",
      CellTags->"c:34"]},
  "c:35"->{
    Cell[219208, 5728, 60, 1, 78, "Section",
      CellTags->"c:35"]},
  "sec:case"->{
    Cell[228214, 5993, 73, 1, 229, "Chapter",
      CellTags->{"sec:case", "c:36"}]},
  "c:36"->{
    Cell[228214, 5993, 73, 1, 229, "Chapter",
      CellTags->{"sec:case", "c:36"}]},
  "sec:syn-case"->{
    Cell[229010, 6014, 104, 1, 78, "Section",
      CellTags->{"sec:syn-case", "c:37"}]},
  "c:37"->{
    Cell[229010, 6014, 104, 1, 78, "Section",
      CellTags->{"sec:syn-case", "c:37"}]},
  "eq:casei"->{
    Cell[229226, 6022, 295, 6, 45, "NumberedEquation",
      CellTags->"eq:casei"]},
  "eq:casec"->{
    Cell[233101, 6145, 244, 4, 45, "NumberedEquation",
      CellTags->"eq:casec"]},
  "sec:inf-case"->{
    Cell[236758, 6243, 79, 1, 78, "Section",
      CellTags->{"sec:inf-case", "c:38"}]},
  "c:38"->{
    Cell[236758, 6243, 79, 1, 78, "Section",
      CellTags->{"sec:inf-case", "c:38"}]},
  "c:39"->{
    Cell[237670, 6269, 84, 1, 67, "Subsection",
      CellTags->"c:39"]},
  "r:elim-cd"->{
    Cell[237757, 6272, 364, 11, 75, "InferenceRule",
      CellTags->"r:elim-cd"]},
  "r:red-cd"->{
    Cell[238960, 6321, 305, 11, 75, "InferenceRule",
      CellTags->"r:red-cd"]},
  "c:40"->{
    Cell[240467, 6384, 73, 1, 67, "Subsection",
      CellTags->"c:40"]},
  "r:prove-cd"->{
    Cell[240543, 6387, 204, 7, 48, "InferenceRule",
      CellTags->"r:prove-cd"]},
  "c:41"->{
    Cell[241741, 6428, 71, 1, 67, "Subsection",
      CellTags->"c:41"]},
  "r:transf-g-cd"->{
    Cell[241815, 6431, 300, 8, 75, "InferenceRule",
      CellTags->"r:transf-g-cd"]},
  "r:transf-as-cd"->{
    Cell[244079, 6509, 236, 7, 75, "InferenceRule",
      CellTags->"r:transf-as-cd"]},
  "r:use-cd"->{
    Cell[246401, 6586, 227, 7, 75, "InferenceRule",
      CellTags->"r:use-cd"]},
  "sec:cdp"->{
    Cell[248324, 6652, 73, 1, 78, "Section",
      CellTags->{"sec:cdp", "c:42"}]},
  "c:42"->{
    Cell[248324, 6652, 73, 1, 78, "Section",
      CellTags->{"sec:cdp", "c:42"}]},
  "sec:ind"->{
    Cell[257569, 6927, 65, 1, 229, "Chapter",
      CellTags->{"sec:ind", "c:43"}]},
  "c:43"->{
    Cell[257569, 6927, 65, 1, 229, "Chapter",
      CellTags->{"sec:ind", "c:43"}]},
  "sec:nn"->{
    Cell[258586, 6954, 73, 1, 78, "Section",
      CellTags->{"sec:nn", "c:44"}]},
  "c:44"->{
    Cell[258586, 6954, 73, 1, 78, "Section",
      CellTags->{"sec:nn", "c:44"}]},
  "sec:tuple"->{
    Cell[261943, 7075, 83, 1, 78, "Section",
      CellTags->{"sec:tuple", "c:45"}]},
  "c:45"->{
    Cell[261943, 7075, 83, 1, 78, "Section",
      CellTags->{"sec:tuple", "c:45"}]},
  "sec:ip"->{
    Cell[270683, 7326, 72, 1, 78, "Section",
      CellTags->{"sec:ip", "c:46"}]},
  "c:46"->{
    Cell[270683, 7326, 72, 1, 78, "Section",
      CellTags->{"sec:ip", "c:46"}]},
  "sec:pos"->{
    Cell[274795, 7465, 78, 1, 229, "Chapter",
      CellTags->{"sec:pos", "c:47"}]},
  "c:47"->{
    Cell[274795, 7465, 78, 1, 229, "Chapter",
      CellTags->{"sec:pos", "c:47"}]},
  "c:48"->{
    Cell[282706, 7644, 62, 1, 78, "Section",
      CellTags->"c:48"]},
  "exp base \[RawStar]"->{
    Cell[284220, 7685, 1919, 58, 55, "Conclusion",
      CellTags->"exp base \[RawStar]"],
    Cell[313535, 8759, 1919, 58, 55, "Conclusion",
      CellTags->"exp base \[RawStar]"],
    Cell[341818, 9787, 1919, 58, 55, "Conclusion",
      CellTags->"exp base \[RawStar]"]},
  "exp 0"->{
    Cell[286186, 7747, 616, 22, 52, "Assumption",
      CellTags->"exp 0"],
    Cell[315501, 8821, 616, 22, 52, "Assumption",
      CellTags->"exp 0"],
    Cell[343784, 9849, 616, 22, 52, "Assumption",
      CellTags->"exp 0"]},
  "exp ."->{
    Cell[286805, 7771, 1397, 44, 57, "Assumption",
      CellTags->"exp ."],
    Cell[316120, 8845, 1397, 44, 57, "Assumption",
      CellTags->"exp ."],
    Cell[344403, 9873, 1397, 44, 57, "Assumption",
      CellTags->"exp ."]},
  "1"->{
    Cell[289119, 7860, 1356, 43, 55, "Conclusion",
      CellTags->"1"],
    Cell[318434, 8934, 1356, 43, 55, "Conclusion",
      CellTags->"1"],
    Cell[346212, 9941, 1356, 43, 55, "Conclusion",
      CellTags->"1"],
    Cell[394402, 11439, 969, 30, 43, "Assumption",
      CellTags->"1"],
    Cell[427462, 12552, 807, 26, 43, "Assumption",
      CellTags->"1"],
    Cell[449891, 13381, 641, 22, 43, "Assumption",
      CellTags->"1"],
    Cell[469790, 14142, 400, 14, 43, "Conclusion",
      CellTags->"1"],
    Cell[485677, 14728, 879, 27, 52, "Conclusion",
      CellTags->"1"],
    Cell[535111, 16498, 641, 22, 43, "Assumption",
      CellTags->"1"],
    Cell[619792, 18949, 641, 22, 43, "Assumption",
      CellTags->"1"],
    Cell[699943, 21369, 445, 16, 43, "Assumption",
      CellTags->"1"],
    Cell[774078, 23564, 582, 20, 43, "Assumption",
      CellTags->"1"],
    Cell[788377, 24001, 582, 20, 43, "Assumption",
      CellTags->"1"],
    Cell[823323, 25115, 397, 15, 43, "Assumption",
      CellTags->"1"],
    Cell[861167, 26348, 880, 28, 43, "Conclusion",
      CellTags->"1"],
    Cell[885714, 27401, 174, 8, 43, "Assumption",
      CellTags->"1"]},
  "4"->{
    Cell[290889, 7924, 909, 30, 43, "Conclusion",
      CellTags->"4"],
    Cell[320019, 8991, 909, 30, 43, "Conclusion",
      CellTags->"4"],
    Cell[347797, 9998, 909, 30, 43, "Conclusion",
      CellTags->"4"],
    Cell[398570, 11593, 1423, 41, 57, "Assumption",
      CellTags->"4"],
    Cell[430617, 12676, 699, 23, 43, "Assumption",
      CellTags->"4"],
    Cell[452734, 13502, 844, 27, 52, "Assumption",
      CellTags->"4"],
    Cell[471835, 14226, 305, 12, 43, "Conclusion",
      CellTags->"4"],
    Cell[489346, 14879, 398, 14, 43, "Conclusion",
      CellTags->"4"],
    Cell[539094, 16644, 2291, 63, 99, "Assumption",
      CellTags->"4"],
    Cell[623775, 19095, 2291, 63, 99, "Assumption",
      CellTags->"4"],
    Cell[703341, 21499, 1600, 48, 67, "Assumption",
      CellTags->"4"],
    Cell[777612, 23695, 2046, 58, 75, "Assumption",
      CellTags->"4"],
    Cell[794904, 24225, 2114, 59, 99, "Assumption",
      CellTags->"4"],
    Cell[827127, 25256, 2346, 61, 99, "Assumption",
      CellTags->"4"],
    Cell[871966, 26846, 310, 12, 105, "Assumption",
      CellTags->"4"],
    Cell[889305, 27544, 178, 8, 43, "Conclusion",
      CellTags->"4"],
    Cell[925384, 28706, 1438, 38, 85, "Assumption",
      CellTags->"4"]},
  "2"->{
    Cell[294834, 8101, 1780, 54, 55, "Assumption",
      CellTags->"2"],
    Cell[323690, 9153, 1780, 54, 55, "Assumption",
      CellTags->"2"],
    Cell[351468, 10160, 1780, 54, 55, "Assumption",
      CellTags->"2"],
    Cell[395454, 11475, 913, 29, 43, "Conclusion",
      CellTags->"2"],
    Cell[428352, 12584, 682, 23, 43, "Conclusion",
      CellTags->"2"],
    Cell[450615, 13409, 495, 18, 43, "Conclusion",
      CellTags->"2"],
    Cell[470555, 14178, 817, 26, 52, "Conclusion",
      CellTags->"2"],
    Cell[487471, 14799, 603, 21, 52, "Conclusion",
      CellTags->"2"],
    Cell[535835, 16526, 495, 18, 43, "Conclusion",
      CellTags->"2"],
    Cell[620516, 18977, 495, 18, 43, "Conclusion",
      CellTags->"2"],
    Cell[700471, 21391, 397, 15, 43, "Conclusion",
      CellTags->"2"],
    Cell[774693, 23588, 1242, 39, 75, "Conclusion",
      CellTags->"2"],
    Cell[788992, 24025, 1242, 39, 75, "Conclusion",
      CellTags->"2"],
    Cell[823803, 25136, 564, 20, 43, "Conclusion",
      CellTags->"2"],
    Cell[862523, 26404, 307, 12, 43, "Assumption",
      CellTags->"2"],
    Cell[885891, 27411, 772, 26, 52, "Assumption",
      CellTags->"2"]},
  "3"->{
    Cell[296698, 8162, 1917, 57, 58, "Conclusion",
      CellTags->"3"],
    Cell[325554, 9214, 1917, 57, 58, "Conclusion",
      CellTags->"3"],
    Cell[353332, 10221, 1917, 57, 58, "Conclusion",
      CellTags->"3"],
    Cell[396757, 11528, 1423, 41, 57, "Assumption",
      CellTags->"3"],
    Cell[429424, 12631, 925, 29, 52, "Assumption",
      CellTags->"3"],
    Cell[451500, 13451, 844, 27, 52, "Assumption",
      CellTags->"3"],
    Cell[471406, 14208, 396, 14, 43, "Assumption",
      CellTags->"3"],
    Cell[486990, 14779, 398, 14, 43, "Assumption",
      CellTags->"3"],
    Cell[536718, 16568, 2096, 60, 75, "Assumption",
      CellTags->"3"],
    Cell[621399, 19019, 2096, 60, 75, "Assumption",
      CellTags->"3"],
    Cell[701256, 21430, 1817, 53, 67, "Assumption",
      CellTags->"3"],
    Cell[776120, 23638, 1156, 35, 58, "Conclusion",
      CellTags->"3"],
    Cell[792751, 24155, 1923, 56, 75, "Assumption",
      CellTags->"3"],
    Cell[824751, 25180, 2096, 60, 75, "Assumption",
      CellTags->"3"],
    Cell[862928, 26422, 726, 24, 43, "Conclusion",
      CellTags->"3"],
    Cell[885180, 27379, 487, 18, 52, "Conclusion",
      CellTags->"3"],
    Cell[922105, 28575, 1046, 29, 96, "Conclusion",
      CellTags->"3"]},
  "5"->{
    Cell[299029, 8240, 1415, 45, 46, "Conclusion",
      CellTags->"5"],
    Cell[327700, 9285, 1415, 45, 46, "Conclusion",
      CellTags->"5"],
    Cell[355478, 10292, 1415, 45, 46, "Conclusion",
      CellTags->"5"],
    Cell[400388, 11658, 2071, 56, 93, "Conclusion",
      CellTags->"5"],
    Cell[431706, 12723, 925, 29, 52, "Assumption",
      CellTags->"5"],
    Cell[453973, 13553, 960, 30, 52, "Conclusion",
      CellTags->"5"],
    Cell[472484, 14260, 770, 25, 52, "Assumption",
      CellTags->"5"],
    Cell[488660, 14852, 603, 21, 52, "Assumption",
      CellTags->"5"],
    Cell[541634, 16723, 2898, 72, 105, "Assumption",
      CellTags->"5"],
    Cell[626315, 19174, 2898, 72, 105, "Assumption",
      CellTags->"5"],
    Cell[705221, 21563, 1505, 45, 69, "Assumption",
      CellTags->"5"],
    Cell[797217, 24298, 2759, 70, 105, "Assumption",
      CellTags->"5"],
    Cell[829722, 25333, 2898, 72, 105, "Assumption",
      CellTags->"5"],
    Cell[890466, 27611, 340, 13, 43, "Assumption",
      CellTags->"5"],
    Cell[926906, 28751, 2046, 50, 111, "Conclusion",
      CellTags->"5"]},
  "c:49"->{
    Cell[312120, 8719, 73, 1, 78, "Section",
      CellTags->"c:49"]},
  "c:50"->{
    Cell[340517, 9749, 73, 1, 78, "Section",
      CellTags->"c:50"]},
  "c:51"->{
    Cell[368295, 10756, 82, 1, 78, "Section",
      CellTags->"c:51"]},
  "sec:provers"->{
    Cell[370102, 10808, 67, 1, 229, "Chapter",
      CellTags->{"sec:provers", "c:52"}]},
  "c:52"->{
    Cell[370102, 10808, 67, 1, 229, "Chapter",
      CellTags->{"sec:provers", "c:52"}]},
  "sec:pcs"->{
    Cell[372150, 10850, 128, 4, 78, "Section",
      CellTags->{"sec:pcs", "c:53"}]},
  "c:53"->{
    Cell[372150, 10850, 128, 4, 78, "Section",
      CellTags->{"sec:pcs", "c:53"}]},
  "c:54"->{
    Cell[376970, 10959, 64, 1, 105, "Subsection",
      CellTags->"c:54"]},
  "sec:PC-dec"->{
    Cell[379926, 11026, 121, 2, 63, "Subsubsection",
      CellTags->{"sec:PC-dec", "c:55"}]},
  "c:55"->{
    Cell[379926, 11026, 121, 2, 63, "Subsubsection",
      CellTags->{"sec:PC-dec", "c:55"}]},
  "function product"->{
    Cell[380953, 11050, 457, 12, 72, "Input",
      CellTags->{"function product", "function sum"}],
    Cell[519516, 16051, 2357, 60, 372, "Input",
      CellTags->{
      "distance of product", "fprod", "function product", "minimum, greater", 
        "minimum, less"}]},
  "function sum"->{
    Cell[380953, 11050, 457, 12, 72, "Input",
      CellTags->{"function product", "function sum"}]},
  "distance of sum"->{
    Cell[381611, 11070, 773, 17, 109, "Input",
      CellTags->{"distance of sum", "less, minimum"}],
    Cell[688576, 21031, 728, 17, 109, "Input",
      CellTags->"distance of sum"],
    Cell[991736, 31232, 1625, 40, 259, "Input",
      CellTags->{
      "2-ary limit of sum", "distance of sum", "fsum", "limit", 
        "limit of sum"}]},
  "less, minimum"->{
    Cell[381611, 11070, 773, 17, 109, "Input",
      CellTags->{"distance of sum", "less, minimum"}]},
  "cont4:+"->{
    Cell[384187, 11142, 2625, 68, 199, "Conclusion",
      CellTags->"cont4:+"],
    Cell[423555, 12438, 2625, 68, 199, "Assumption",
      CellTags->"cont4:+"]},
  "cont4"->{
    Cell[386909, 11216, 2555, 65, 117, "Assumption",
      CellTags->"cont4"]},
  "f+g"->{
    Cell[389467, 11283, 1237, 40, 58, "Assumption",
      CellTags->"f+g"],
    Cell[694843, 21211, 1237, 40, 58, "Assumption",
      CellTags->"f+g"]},
  "dist+"->{
    Cell[390707, 11325, 2413, 68, 78, "Assumption",
      CellTags->"dist+"],
    Cell[696083, 21253, 2501, 70, 93, "Assumption",
      CellTags->"dist+"]},
  "<min"->{
    Cell[393123, 11395, 1195, 38, 57, "Assumption",
      CellTags->"<min"],
    Cell[533806, 16453, 1221, 39, 57, "Assumption",
      CellTags->"<min"],
    Cell[618487, 18904, 1221, 39, 57, "Assumption",
      CellTags->"<min"]},
  "6"->{
    Cell[402543, 11720, 670, 22, 43, "Assumption",
      CellTags->"6"],
    Cell[432899, 12768, 699, 23, 43, "Assumption",
      CellTags->"6"],
    Cell[455017, 13589, 300, 12, 43, "Assumption",
      CellTags->"6"],
    Cell[473472, 14299, 559, 19, 43, "Assumption",
      CellTags->"6"],
    Cell[490012, 14909, 411, 15, 43, "Assumption",
      CellTags->"6"],
    Cell[544920, 16819, 2096, 60, 75, "Assumption",
      CellTags->"6"],
    Cell[629601, 19270, 2096, 60, 75, "Assumption",
      CellTags->"6"],
    Cell[707114, 21632, 1817, 53, 67, "Assumption",
      CellTags->"6"],
    Cell[800317, 24390, 2312, 66, 75, "Conclusion",
      CellTags->"6"],
    Cell[833013, 25429, 2490, 69, 75, "Conclusion",
      CellTags->"6"],
    Cell[872374, 26864, 726, 24, 105, "Conclusion",
      CellTags->"6"],
    Cell[890890, 27631, 413, 15, 43, "Conclusion",
      CellTags->"6"],
    Cell[923185, 28608, 484, 15, 43, "Assumption",
      CellTags->"6"]},
  "7"->{
    Cell[403296, 11748, 1165, 36, 43, "Conclusion",
      CellTags->"7"],
    Cell[434164, 12823, 443, 16, 43, "Assumption",
      CellTags->"7"],
    Cell[455400, 13607, 573, 20, 43, "Conclusion",
      CellTags->"7"],
    Cell[474829, 14363, 714, 24, 52, "Assumption",
      CellTags->"7"],
    Cell[490816, 14948, 832, 26, 52, "Conclusion",
      CellTags->"7"],
    Cell[547296, 16895, 2291, 63, 99, "Assumption",
      CellTags->"7"],
    Cell[631977, 19346, 2291, 63, 99, "Assumption",
      CellTags->"7"],
    Cell[709199, 21701, 1600, 48, 67, "Assumption",
      CellTags->"7"],
    Cell[802922, 24470, 2151, 57, 90, "Conclusion",
      CellTags->"7"],
    Cell[835587, 25504, 300, 12, 43, "Assumption",
      CellTags->"7"],
    Cell[864082, 26472, 357, 14, 43, "Assumption",
      CellTags->"7"],
    Cell[889824, 27574, 174, 8, 43, "Conclusion",
      CellTags->"7"],
    Cell[923702, 28627, 501, 15, 43, "Conclusion",
      CellTags->"7"]},
  "8"->{
    Cell[408834, 11952, 1417, 42, 43, "Assumption",
      CellTags->"8"],
    Cell[435179, 12871, 911, 29, 43, "Assumption",
      CellTags->"8"],
    Cell[456351, 13651, 475, 17, 43, "Assumption",
      CellTags->"8"],
    Cell[475875, 14409, 305, 12, 43, "Assumption",
      CellTags->"8"],
    Cell[491936, 14990, 617, 20, 43, "Conclusion",
      CellTags->"8"],
    Cell[549836, 16974, 2898, 72, 105, "Assumption",
      CellTags->"8"],
    Cell[634517, 19425, 2898, 72, 105, "Assumption",
      CellTags->"8"],
    Cell[711079, 21765, 1505, 45, 69, "Assumption",
      CellTags->"8"],
    Cell[805268, 24541, 2068, 56, 90, "Conclusion",
      CellTags->"8"],
    Cell[835970, 25522, 2104, 60, 75, "Conclusion",
      CellTags->"8"],
    Cell[864537, 26492, 572, 20, 43, "Conclusion",
      CellTags->"8"],
    Cell[893520, 27753, 514, 18, 43, "Conclusion",
      CellTags->"8"],
    Cell[924542, 28664, 370, 13, 43, "Conclusion",
      CellTags->"8"]},
  "9"->{
    Cell[416267, 12217, 670, 22, 43, "Conclusion",
      CellTags->"9"],
    Cell[436485, 12924, 1167, 35, 52, "Conclusion",
      CellTags->"9"],
    Cell[457204, 13692, 475, 17, 43, "Assumption",
      CellTags->"9"],
    Cell[493427, 15054, 396, 14, 43, "Conclusion",
      CellTags->"9"],
    Cell[553127, 17070, 2470, 68, 75, "Conclusion",
      CellTags->"9"],
    Cell[637808, 19521, 2470, 68, 75, "Conclusion",
      CellTags->"9"],
    Cell[712977, 21834, 2012, 57, 67, "Conclusion",
      CellTags->"9"],
    Cell[807553, 24611, 1192, 35, 43, "Conclusion",
      CellTags->"9"],
    Cell[838301, 25594, 2041, 55, 58, "Conclusion",
      CellTags->"9"],
    Cell[870671, 26789, 360, 14, 105, "Assumption",
      CellTags->"9"],
    Cell[894232, 27785, 341, 13, 43, "Conclusion",
      CellTags->"9"]},
  "minimum, greater"->{
    Cell[418047, 12277, 477, 13, 72, "Input",
      CellTags->"minimum, greater"],
    Cell[519516, 16051, 2357, 60, 372, "Input",
      CellTags->{
      "distance of product", "fprod", "function product", "minimum, greater", 
        "minimum, less"}]},
  "cont3:+"->{
    Cell[419678, 12328, 1985, 54, 148, "Conclusion",
      CellTags->"cont3:+"],
    Cell[447288, 13298, 1858, 51, 88, "Assumption",
      CellTags->"cont3:+"]},
  "cont3"->{
    Cell[421760, 12388, 1792, 48, 102, "Assumption",
      CellTags->"cont3"]},
  "min>"->{
    Cell[426183, 12508, 1195, 38, 57, "Assumption",
      CellTags->"min>"],
    Cell[532587, 16413, 1216, 38, 57, "Assumption",
      CellTags->"min>"],
    Cell[617268, 18864, 1216, 38, 57, "Assumption",
      CellTags->"min>"]},
  "10"->{
    Cell[437914, 12975, 1233, 37, 66, "Conclusion",
      CellTags->"10"],
    Cell[460534, 13836, 302, 12, 43, "Conclusion",
      CellTags->"10"],
    Cell[492987, 15034, 357, 14, 43, "Assumption",
      CellTags->"10"],
    Cell[555681, 17144, 302, 12, 43, "Assumption",
      CellTags->"10"],
    Cell[640362, 19595, 302, 12, 43, "Assumption",
      CellTags->"10"],
    Cell[715209, 21903, 2022, 54, 55, "Conclusion",
      CellTags->"10"],
    Cell[809994, 24694, 850, 28, 43, "Assumption",
      CellTags->"10"],
    Cell[840733, 25673, 2172, 56, 90, "Conclusion",
      CellTags->"10"]},
  "3-ary continuity of sum: variant"->{
    Cell[442103, 13142, 621, 14, 172, "Input",
      CellTags->"3-ary continuity of sum: variant"]},
  "positiveness"->{
    Cell[442797, 13160, 364, 9, 109, "Input",
      CellTags->"positiveness"]},
  "cont2:+"->{
    Cell[444276, 13205, 1454, 42, 85, "Conclusion",
      CellTags->"cont2:+"]},
  "cont2"->{
    Cell[445827, 13253, 1458, 43, 60, "Assumption",
      CellTags->"cont2"]},
  "/2>"->{
    Cell[449149, 13351, 658, 24, 52, "Assumption",
      CellTags->"/2>"]},
  "sec:PC-otter"->{
    Cell[461693, 13888, 113, 3, 63, "Subsubsection",
      CellTags->{"sec:PC-otter", "c:56"}]},
  "c:56"->{
    Cell[461693, 13888, 113, 3, 63, "Subsubsection",
      CellTags->{"sec:PC-otter", "c:56"}]},
  "Definition (Set equality)"->{
    Cell[462430, 13909, 614, 15, 85, "Input",
      CellTags->{
      "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
        "Union"}]},
  "Inclusion"->{
    Cell[462430, 13909, 614, 15, 85, "Input",
      CellTags->{
      "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
        "Union"}]},
  "Powerset"->{
    Cell[462430, 13909, 614, 15, 85, "Input",
      CellTags->{
      "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
        "Union"}],
    Cell[477103, 14459, 481, 11, 90, "Input",
      CellTags->"Powerset"]},
  "Set equality"->{
    Cell[462430, 13909, 614, 15, 85, "Input",
      CellTags->{
      "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
        "Union"}],
    Cell[477657, 14474, 496, 13, 85, "Input",
      CellTags->"Set equality"]},
  "Union"->{
    Cell[462430, 13909, 614, 15, 85, "Input",
      CellTags->{
      "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
        "Union"}]},
  "Union of powerset is included..."->{
    Cell[464117, 13958, 448, 11, 96, "Input",
      CellTags->"Union of powerset is included..."]},
  "P\[Union]\[SubsetEqual]"->{
    Cell[465680, 14005, 507, 16, 52, "Conclusion",
      CellTags->"P\[Union]\[SubsetEqual]"]},
  "\[SubsetEqual]:"->{
    Cell[466234, 14025, 1298, 39, 57, "Assumption",
      CellTags->"\[SubsetEqual]:"]},
  "\[Union]:"->{
    Cell[467535, 14066, 1256, 37, 57, "Assumption",
      CellTags->"\[Union]:"],
    Cell[482616, 14626, 1376, 42, 57, "Assumption",
      CellTags->"\[Union]:"],
    Cell[483995, 14670, 1392, 42, 64, "Assumption",
      CellTags->"\[Union]:"]},
  "P:"->{
    Cell[468794, 14105, 714, 23, 54, "Assumption",
      CellTags->"P:"]},
  "Fixpoint property"->{
    Cell[478200, 14491, 491, 12, 85, "Input",
      CellTags->"Fixpoint property"]},
  "Examples"->{
    Cell[478912, 14511, 1146, 26, 214, "Input",
      CellTags->"Examples"]},
  "FP"->{
    Cell[480159, 14545, 1020, 32, 55, "Conclusion",
      CellTags->"FP"]},
  "seq:"->{
    Cell[481276, 14583, 1337, 41, 57, "Assumption",
      CellTags->"seq:"]},
  "13"->{
    Cell[494226, 15092, 757, 25, 57, "Conclusion",
      CellTags->"13"],
    Cell[560782, 17310, 2190, 58, 58, "Conclusion",
      CellTags->"13"],
    Cell[645528, 19758, 2244, 57, 58, "Conclusion",
      CellTags->"13"],
    Cell[724514, 22178, 3969, 88, 99, "Conclusion",
      CellTags->"13"],
    Cell[847802, 25893, 777, 25, 43, "Conclusion",
      CellTags->"13"],
    Cell[865947, 26556, 436, 16, 105, "Conclusion",
      CellTags->"13"],
    Cell[929296, 28823, 1449, 38, 100, "Conclusion",
      CellTags->"13"]},
  "14"->{
    Cell[495067, 15123, 357, 14, 43, "Assumption",
      CellTags->"14"],
    Cell[563369, 17392, 4150, 99, 249, "Conclusion",
      CellTags->"14"],
    Cell[648169, 19839, 4150, 99, 249, "Conclusion",
      CellTags->"14"],
    Cell[729587, 22321, 3965, 89, 133, "Conclusion",
      CellTags->"14"],
    Cell[867502, 26633, 312, 12, 105, "Assumption",
      CellTags->"14"],
    Cell[933834, 28994, 1708, 46, 100, "Assumption",
      CellTags->"14"]},
  "15"->{
    Cell[495507, 15143, 342, 13, 43, "Conclusion",
      CellTags->"15"],
    Cell[567973, 17511, 3730, 91, 90, "Conclusion",
      CellTags->"15"],
    Cell[652773, 19958, 3730, 91, 90, "Conclusion",
      CellTags->"15"],
    Cell[742534, 22644, 3648, 85, 99, "Conclusion",
      CellTags->"15"],
    Cell[935626, 29047, 2224, 59, 100, "Conclusion",
      CellTags->"15"]},
  "16"->{
    Cell[496254, 15180, 762, 26, 52, "Conclusion",
      CellTags->"16"],
    Cell[580480, 17840, 3570, 87, 117, "Conclusion",
      CellTags->"16"],
    Cell[665392, 20290, 3498, 85, 159, "Conclusion",
      CellTags->"16"],
    Cell[746429, 22745, 3689, 84, 99, "Conclusion",
      CellTags->"16"],
    Cell[867912, 26651, 436, 16, 105, "Conclusion",
      CellTags->"16"],
    Cell[930983, 28877, 691, 21, 57, "Assumption",
      CellTags->"16"]},
  "17"->{
    Cell[497280, 15222, 555, 20, 43, "Conclusion",
      CellTags->"17"],
    Cell[584297, 17943, 3297, 82, 93, "Conclusion",
      CellTags->"17"],
    Cell[669137, 20391, 3435, 86, 124, "Conclusion",
      CellTags->"17"],
    Cell[750834, 22864, 3216, 74, 99, "Conclusion",
      CellTags->"17"],
    Cell[866937, 26604, 298, 12, 105, "Conclusion",
      CellTags->"17"],
    Cell[931707, 28902, 734, 22, 57, "Conclusion",
      CellTags->"17"]},
  "12"->{
    Cell[500006, 15354, 398, 14, 43, "Assumption",
      CellTags->"12"],
    Cell[558366, 17232, 2023, 54, 58, "Conclusion",
      CellTags->"12"],
    Cell[643066, 19681, 2069, 53, 58, "Conclusion",
      CellTags->"12"],
    Cell[720205, 22062, 3878, 96, 168, "Conclusion",
      CellTags->"12"],
    Cell[812188, 24783, 340, 13, 43, "Conclusion",
      CellTags->"12"],
    Cell[845625, 25824, 1908, 53, 58, "Conclusion",
      CellTags->"12"],
    Cell[865540, 26538, 309, 12, 43, "Assumption",
      CellTags->"12"]},
  "11"->{
    Cell[500487, 15374, 357, 14, 43, "Conclusion",
      CellTags->"11"],
    Cell[556066, 17162, 2073, 58, 75, "Conclusion",
      CellTags->"11"],
    Cell[640747, 19613, 2092, 56, 75, "Conclusion",
      CellTags->"11"],
    Cell[717624, 21981, 2184, 57, 55, "Conclusion",
      CellTags->"11"],
    Cell[811395, 24745, 450, 16, 43, "Conclusion",
      CellTags->"11"],
    Cell[843152, 25745, 2089, 55, 90, "Conclusion",
      CellTags->"11"],
    Cell[871129, 26809, 574, 20, 105, "Conclusion",
      CellTags->"11"]},
  "18"->{
    Cell[501240, 15412, 757, 25, 57, "Assumption",
      CellTags->"18"],
    Cell[587863, 18041, 2915, 75, 97, "Conclusion",
      CellTags->"18"],
    Cell[672841, 20493, 2947, 76, 97, "Conclusion",
      CellTags->"18"],
    Cell[754134, 22944, 302, 12, 43, "Assumption",
      CellTags->"18"],
    Cell[849323, 25953, 406, 15, 43, "Conclusion",
      CellTags->"18"],
    Cell[868902, 26699, 298, 12, 105, "Conclusion",
      CellTags->"18"],
    Cell[932782, 28946, 576, 19, 57, "Conclusion",
      CellTags->"18"]},
  "19"->{
    Cell[502381, 15461, 839, 27, 52, "Assumption",
      CellTags->"19"],
    Cell[597442, 18312, 2661, 68, 70, "Conclusion",
      CellTags->"19"],
    Cell[678337, 20650, 1561, 42, 43, "Assumption",
      CellTags->"19"],
    Cell[754519, 22962, 2520, 63, 99, "Conclusion",
      CellTags->"19"],
    Cell[850122, 25992, 302, 12, 43, "Conclusion",
      CellTags->"19"],
    Cell[869786, 26743, 309, 12, 105, "Assumption",
      CellTags->"19"],
    Cell[938088, 29122, 1071, 32, 57, "Assumption",
      CellTags->"19"]},
  "20"->{
    Cell[504222, 15540, 766, 26, 57, "Conclusion",
      CellTags->"20"],
    Cell[680766, 20724, 626, 21, 43, "Conclusion",
      CellTags->"20"],
    Cell[757487, 23045, 1879, 51, 85, "Conclusion",
      CellTags->"20"],
    Cell[873528, 26914, 359, 14, 105, "Assumption",
      CellTags->"20"],
    Cell[939192, 29158, 1100, 32, 57, "Conclusion",
      CellTags->"20"]},
  "21"->{
    Cell[505072, 15572, 357, 14, 43, "Assumption",
      CellTags->"21"],
    Cell[759635, 23112, 1332, 38, 43, "Conclusion",
      CellTags->"21"],
    Cell[873985, 26934, 436, 16, 105, "Conclusion",
      CellTags->"21"],
    Cell[940668, 29214, 488, 18, 54, "Assumption",
      CellTags->"21"]},
  "22"->{
    Cell[505512, 15592, 357, 14, 43, "Conclusion",
      CellTags->"22"],
    Cell[875588, 27013, 362, 14, 105, "Assumption",
      CellTags->"22"],
    Cell[941204, 29236, 1103, 32, 57, "Conclusion",
      CellTags->"22"]},
  "23"->{
    Cell[506784, 15656, 762, 26, 52, "Assumption",
      CellTags->"23"],
    Cell[683247, 20832, 377, 14, 43, "Conclusion",
      CellTags->"23"],
    Cell[962256, 30088, 491, 18, 54, "Assumption",
      CellTags->"23"]},
  "24"->{
    Cell[507816, 15698, 555, 20, 43, "Assumption",
      CellTags->"24"],
    Cell[876048, 27033, 436, 16, 105, "Conclusion",
      CellTags->"24"]},
  "25"->{
    Cell[509359, 15770, 766, 26, 57, "Assumption",
      CellTags->"25"],
    Cell[874975, 26982, 348, 14, 105, "Conclusion",
      CellTags->"25"],
    Cell[962795, 30110, 1099, 32, 57, "Conclusion",
      CellTags->"25"]},
  "26"->{
    Cell[510516, 15820, 357, 14, 43, "Conclusion",
      CellTags->"26"],
    Cell[876916, 27075, 309, 12, 43, "Assumption",
      CellTags->"26"],
    Cell[942692, 29290, 1855, 51, 93, "Conclusion",
      CellTags->"26"]},
  "c:57"->{
    Cell[511933, 15876, 99, 1, 67, "Subsection",
      CellTags->"c:57"]},
  "continuity of product"->{
    Cell[518826, 16031, 488, 12, 109, "Input",
      CellTags->"continuity of product"]},
  "distance of product"->{
    Cell[519516, 16051, 2357, 60, 372, "Input",
      CellTags->{
      "distance of product", "fprod", "function product", "minimum, greater", 
        "minimum, less"}]},
  "fprod"->{
    Cell[519516, 16051, 2357, 60, 372, "Input",
      CellTags->{
      "distance of product", "fprod", "function product", "minimum, greater", 
        "minimum, less"}]},
  "minimum, less"->{
    Cell[519516, 16051, 2357, 60, 372, "Input",
      CellTags->{
      "distance of product", "fprod", "function product", "minimum, greater", 
        "minimum, less"}]},
  "cont\[RawStar]"->{
    Cell[523733, 16162, 1450, 42, 85, "Conclusion",
      CellTags->"cont\[RawStar]"],
    Cell[608414, 18613, 1450, 42, 85, "Conclusion",
      CellTags->"cont\[RawStar]"]},
  "cont"->{
    Cell[525280, 16210, 2896, 76, 99, "Assumption",
      CellTags->"cont"],
    Cell[609961, 18661, 2896, 76, 99, "Assumption",
      CellTags->"cont"],
    Cell[784377, 23886, 2846, 74, 99, "Assumption",
      CellTags->"cont"],
    Cell[820343, 25033, 2896, 76, 99, "Assumption",
      CellTags->"cont"]},
  "f\[RawStar]g"->{
    Cell[528179, 16288, 1237, 40, 58, "Assumption",
      CellTags->"f\[RawStar]g"],
    Cell[612860, 18739, 1237, 40, 58, "Assumption",
      CellTags->"f\[RawStar]g"]},
  "dist\[RawStar]"->{
    Cell[529419, 16330, 3165, 81, 84, "Assumption",
      CellTags->"dist\[RawStar]"],
    Cell[614100, 18781, 3165, 81, 84, "Assumption",
      CellTags->"dist\[RawStar]"]},
  "convergence"->{
    Cell[686721, 20975, 686, 16, 136, "Input",
      CellTags->{"convergence", "convergent"}],
    Cell[687410, 20993, 60, 1, 48, "Text",
      CellTags->"convergence"]},
  "convergent"->{
    Cell[686721, 20975, 686, 16, 136, "Input",
      CellTags->{"convergence", "convergent"}],
    Cell[687473, 20996, 511, 13, 109, "Input",
      CellTags->{
      "2-ary limit of sum", "convergence of sum", "convergent", "limit"}]},
  "2-ary limit of sum"->{
    Cell[687473, 20996, 511, 13, 109, "Input",
      CellTags->{
      "2-ary limit of sum", "convergence of sum", "convergent", "limit"}],
    Cell[688085, 21016, 429, 11, 72, "Input",
      CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}],
    Cell[991736, 31232, 1625, 40, 259, "Input",
      CellTags->{
      "2-ary limit of sum", "distance of sum", "fsum", "limit", 
        "limit of sum"}]},
  "convergence of sum"->{
    Cell[687473, 20996, 511, 13, 109, "Input",
      CellTags->{
      "2-ary limit of sum", "convergence of sum", "convergent", "limit"}]},
  "limit"->{
    Cell[687473, 20996, 511, 13, 109, "Input",
      CellTags->{
      "2-ary limit of sum", "convergence of sum", "convergent", "limit"}],
    Cell[688085, 21016, 429, 11, 72, "Input",
      CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}],
    Cell[991736, 31232, 1625, 40, 259, "Input",
      CellTags->{
      "2-ary limit of sum", "distance of sum", "fsum", "limit", 
        "limit of sum"}]},
  "fsum"->{
    Cell[688085, 21016, 429, 11, 72, "Input",
      CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}],
    Cell[989467, 31167, 519, 13, 85, "Input",
      CellTags->{"fsum", "sum of sequences"}],
    Cell[991736, 31232, 1625, 40, 259, "Input",
      CellTags->{
      "2-ary limit of sum", "distance of sum", "fsum", "limit", 
        "limit of sum"}]},
  "sequences sum"->{
    Cell[688085, 21016, 429, 11, 72, "Input",
      CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}]},
  "sum greater"->{
    Cell[689364, 21052, 466, 12, 72, "Input",
      CellTags->"sum greater"]},
  "conv+"->{
    Cell[691344, 21108, 975, 31, 58, "Conclusion",
      CellTags->"conv+"]},
  "conv"->{
    Cell[692416, 21145, 2424, 64, 84, "Assumption",
      CellTags->"conv"]},
  "\[GreaterEqual]+"->{
    Cell[698587, 21325, 1272, 38, 57, "Assumption",
      CellTags->"\[GreaterEqual]+"]},
  "c:58"->{
    Cell[765212, 23302, 96, 3, 67, "Subsection",
      CellTags->"c:58"]},
  "Continuity, Sign"->{
    Cell[765838, 23322, 562, 14, 154, "Input",
      CellTags->"Continuity, Sign"],
    Cell[995052, 31324, 567, 13, 72, "Input",
      CellTags->{"Absolute Value", "Continuity, Sign"}],
    Cell[995644, 31341, 535, 12, 72, "Input",
      CellTags->{"Absolute Value", "Continuity, Sign"}]},
  "Absolute Value"->{
    Cell[766513, 23343, 415, 11, 72, "Input",
      CellTags->"Absolute Value"],
    Cell[995052, 31324, 567, 13, 72, "Input",
      CellTags->{"Absolute Value", "Continuity, Sign"}],
    Cell[995644, 31341, 535, 12, 72, "Input",
      CellTags->{"Absolute Value", "Continuity, Sign"}]},
  "cont, sign"->{
    Cell[767813, 23383, 2220, 62, 120, "Conclusion",
      CellTags->"cont, sign"],
    Cell[782110, 23820, 2220, 62, 120, "Conclusion",
      CellTags->"cont, sign"]},
  "c2:"->{
    Cell[770080, 23449, 2844, 74, 99, "Assumption",
      CellTags->"c2:"]},
  "absv"->{
    Cell[772927, 23525, 1117, 35, 55, "Assumption",
      CellTags->"absv"],
    Cell[787226, 23962, 1117, 35, 55, "Assumption",
      CellTags->"absv"]},
  "limit at"->{
    Cell[813531, 24838, 675, 14, 154, "Input",
      CellTags->"limit at"],
    Cell[814261, 24856, 455, 12, 96, "Input",
      CellTags->{"Continuity, Limit", "limit at"}]},
  "Continuity, Limit"->{
    Cell[814261, 24856, 455, 12, 96, "Input",
      CellTags->{"Continuity, Limit", "limit at"}]},
  "cont, lim"->{
    Cell[815786, 24903, 1121, 36, 57, "Conclusion",
      CellTags->"cont, lim"]},
  "limf"->{
    Cell[817004, 24945, 3336, 86, 99, "Assumption",
      CellTags->"limf"]},
  "sec:max-as"->{
    Cell[851151, 26038, 90, 1, 78, "Section",
      CellTags->{"sec:max-as", "c:59"}]},
  "c:59"->{
    Cell[851151, 26038, 90, 1, 78, "Section",
      CellTags->{"sec:max-as", "c:59"}]},
  "Maximum"->{
    Cell[852394, 26068, 745, 20, 112, "Input",
      CellTags->"Maximum"]},
  "maximum is associative"->{
    Cell[853246, 26095, 442, 11, 72, "Input",
      CellTags->{"maximum is associative", "Max is Upper Bound"}]},
  "Max is Upper Bound"->{
    Cell[853246, 26095, 442, 11, 72, "Input",
      CellTags->{"maximum is associative", "Max is Upper Bound"}]},
  "Reflexivity \[LessEqual]"->{
    Cell[853783, 26113, 1101, 28, 145, "Input",
      CellTags->{
      "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
        "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}]},
  "totality \[LessEqual]"->{
    Cell[853783, 26113, 1101, 28, 145, "Input",
      CellTags->{
      "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
        "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}]},
  "transitivity \[LessEqual]"->{
    Cell[853783, 26113, 1101, 28, 145, "Input",
      CellTags->{
      "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
        "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}]},
  "Transitivity \[LessEqual]"->{
    Cell[853783, 26113, 1101, 28, 145, "Input",
      CellTags->{
      "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
        "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}]},
  "max-A"->{
    Cell[856003, 26176, 1367, 42, 57, "Conclusion",
      CellTags->"max-A"]},
  "max"->{
    Cell[857467, 26224, 1402, 41, 64, "Assumption",
      CellTags->"max"]},
  "tot \[LessEqual]"->{
    Cell[858872, 26267, 847, 27, 57, "Assumption",
      CellTags->"tot \[LessEqual]"]},
  "trans \[LessEqual]"->{
    Cell[859722, 26296, 1149, 36, 57, "Assumption",
      CellTags->"trans \[LessEqual]"]},
  "27"->{
    Cell[877323, 27093, 298, 12, 43, "Conclusion",
      CellTags->"27"],
    Cell[946068, 29408, 857, 26, 57, "Conclusion",
      CellTags->"27"]},
  "31"->{
    Cell[878031, 27129, 359, 14, 43, "Assumption",
      CellTags->"31"],
    Cell[953599, 29724, 1147, 36, 57, "Conclusion",
      CellTags->"31"]},
  "32"->{
    Cell[878980, 27175, 309, 12, 43, "Assumption",
      CellTags->"32"],
    Cell[955946, 29820, 576, 19, 57, "Conclusion",
      CellTags->"32"]},
  "28"->{
    Cell[879865, 27221, 312, 12, 43, "Assumption",
      CellTags->"28"],
    Cell[947948, 29489, 1175, 33, 57, "Assumption",
      CellTags->"28"]},
  "30"->{
    Cell[880275, 27239, 348, 14, 43, "Conclusion",
      CellTags->"30"],
    Cell[950359, 29584, 372, 13, 43, "Assumption",
      CellTags->"30"]},
  "c:60"->{
    Cell[881173, 27278, 63, 1, 78, "Section",
      CellTags->"c:60"]},
  "c:61"->{
    Cell[883623, 27331, 140, 5, 67, "Subsection",
      CellTags->"c:61"]},
  "Addition"->{
    Cell[884359, 27355, 790, 20, 118, "Input",
      CellTags->{
      "Addition", "Addition from Left", "Addition of Zero from Left", 
        "even"}]},
  "Addition from Left"->{
    Cell[884359, 27355, 790, 20, 118, "Input",
      CellTags->{
      "Addition", "Addition from Left", "Addition of Zero from Left", 
        "even"}]},
  "Addition of Zero from Left"->{
    Cell[884359, 27355, 790, 20, 118, "Input",
      CellTags->{
      "Addition", "Addition from Left", "Addition of Zero from Left", 
        "even"}]},
  "even"->{
    Cell[884359, 27355, 790, 20, 118, "Input",
      CellTags->{
      "Addition", "Addition from Left", "Addition of Zero from Left", 
        "even"}],
    Cell[897822, 27895, 3793, 79, 223, "Input",
      CellTags->{"conc", "even", "member"}]},
  " +0"->{
    Cell[886666, 27439, 521, 19, 52, "Assumption",
      CellTags->" +0"]},
  " + succ"->{
    Cell[887190, 27460, 887, 30, 54, "Assumption",
      CellTags->" + succ"]},
  "succ + "->{
    Cell[888080, 27492, 886, 30, 54, "Assumption",
      CellTags->"succ + "]},
  "sec:indcdp"->{
    Cell[895126, 27829, 98, 1, 67, "Subsection",
      CellTags->{"sec:indcdp", "c:62"}]},
  "c:62"->{
    Cell[895126, 27829, 98, 1, 67, "Subsection",
      CellTags->{"sec:indcdp", "c:62"}]},
  "conc"->{
    Cell[897822, 27895, 3793, 79, 223, "Input",
      CellTags->{"conc", "even", "member"}]},
  "member"->{
    Cell[897822, 27895, 3793, 79, 223, "Input",
      CellTags->{"conc", "even", "member"}],
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[904741, 28065, 616, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "merge", "prepend", 
        "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}]},
  "is\[Dash]sorted"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[903520, 28031, 592, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, merge", "merge", "prepend", 
        "subtuple is\[Dash]sorted"}],
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}],
    Cell[904741, 28065, 616, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "merge", "prepend", 
        "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}]},
  "member, merge"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[903520, 28031, 592, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, merge", "merge", "prepend", 
        "subtuple is\[Dash]sorted"}]},
  "member, sorted"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}]},
  "merge"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[903520, 28031, 592, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, merge", "merge", "prepend", 
        "subtuple is\[Dash]sorted"}],
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}],
    Cell[904741, 28065, 616, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "merge", "prepend", 
        "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}]},
  "prepend"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[903520, 28031, 592, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, merge", "merge", "prepend", 
        "subtuple is\[Dash]sorted"}],
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}],
    Cell[904741, 28065, 616, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "merge", "prepend", 
        "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}]},
  "subtuple is\[Dash]sorted"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
    Cell[903520, 28031, 592, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, merge", "merge", "prepend", 
        "subtuple is\[Dash]sorted"}],
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}]},
  "totality"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", 
        "transitivity"}]},
  "transitivity"->{
    Cell[902962, 28016, 555, 13, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge",
         "prepend", "subtuple is\[Dash]sorted", "totality", 
        "transitivity"}]},
  "sorted, \[GreaterEqual]"->{
    Cell[904115, 28048, 623, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
        "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}]},
  "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "->{
    Cell[904741, 28065, 616, 15, 72, "Input",
      CellTags->{
      "is\[Dash]sorted", "member", "merge", "prepend", 
        "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}]},
  "sort\[Dash]merge"->{
    Cell[907544, 28139, 1428, 37, 85, "Conclusion",
      CellTags->"sort\[Dash]merge"]},
  "mr"->{
    Cell[909019, 28180, 607, 20, 52, "Assumption",
      CellTags->"mr"]},
  "ml"->{
    Cell[909629, 28202, 637, 22, 52, "Assumption",
      CellTags->"ml"]},
  "mi"->{
    Cell[910269, 28226, 3707, 84, 162, "Assumption",
      CellTags->"mi"]},
  "sorted\[LeftAngleBracket]\[RightAngleBracket]"->{
    Cell[913979, 28312, 316, 9, 43, "Assumption",
      CellTags->"sorted\[LeftAngleBracket]\[RightAngleBracket]"]},
  "sorted\[LeftAngleBracket].\[RightAngleBracket]"->{
    Cell[914298, 28323, 572, 17, 52, "Assumption",
      CellTags->"sorted\[LeftAngleBracket].\[RightAngleBracket]"]},
  "sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]"->{
    Cell[914873, 28342, 1589, 43, 96, "Assumption",
      CellTags->"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]"]},
  "\[Cup],\[GreaterTilde],s"->{
    Cell[916465, 28387, 1074, 32, 54, "Assumption",
      CellTags->"\[Cup],\[GreaterTilde],s"]},
  "\[GreaterTilde],s"->{
    Cell[917542, 28421, 1054, 31, 58, "Assumption",
      CellTags->"\[GreaterTilde],s"]},
  "\[GreaterTilde]-merge"->{
    Cell[918599, 28454, 1278, 39, 54, "Assumption",
      CellTags->"\[GreaterTilde]-merge"]},
  "sub\[Dash]sort"->{
    Cell[919880, 28495, 991, 29, 58, "Assumption",
      CellTags->"sub\[Dash]sort"]},
  "\[GreaterEqual]tot"->{
    Cell[920874, 28526, 857, 27, 57, "Assumption",
      CellTags->"\[GreaterEqual]tot"]},
  "29"->{
    Cell[949489, 29544, 510, 18, 52, "Assumption",
      CellTags->"29"]},
  "33"->{
    Cell[959052, 29948, 981, 31, 57, "Conclusion",
      CellTags->"33"]},
  "34"->{
    Cell[964279, 30164, 1847, 51, 93, "Conclusion",
      CellTags->"34"]},
  "35"->{
    Cell[967662, 30283, 859, 26, 57, "Conclusion",
      CellTags->"35"]},
  "36"->{
    Cell[970969, 30431, 488, 18, 54, "Assumption",
      CellTags->"36"]},
  "37"->{
    Cell[971823, 30471, 510, 18, 52, "Assumption",
      CellTags->"37"]},
  "38"->{
    Cell[972693, 30511, 372, 13, 43, "Assumption",
      CellTags->"38"]},
  "39"->{
    Cell[973431, 30546, 510, 18, 54, "Assumption",
      CellTags->"39"]},
  "40"->{
    Cell[974301, 30586, 372, 13, 43, "Assumption",
      CellTags->"40"]},
  "41"->{
    Cell[976522, 30680, 1147, 36, 57, "Conclusion",
      CellTags->"41"]},
  "42"->{
    Cell[980062, 30817, 981, 31, 57, "Conclusion",
      CellTags->"42"]},
  "43"->{
    Cell[983242, 30955, 488, 18, 54, "Assumption",
      CellTags->"43"]},
  "44"->{
    Cell[985067, 31041, 576, 19, 57, "Conclusion",
      CellTags->"44"]},
  "c:63"->{
    Cell[987718, 31116, 57, 1, 78, "Section",
      CellTags->"c:63"]},
  "c:64"->{
    Cell[988370, 31133, 112, 4, 325, "Chapter",
      CellTags->"c:64"]},
  "c:65"->{
    Cell[988819, 31148, 61, 1, 78, "Section",
      CellTags->"c:65"]},
  "sum of sequences"->{
    Cell[989467, 31167, 519, 13, 85, "Input",
      CellTags->{"fsum", "sum of sequences"}]},
  "c:66"->{
    Cell[990023, 31185, 77, 1, 78, "Section",
      CellTags->"c:66"]},
  "c:67"->{
    Cell[990778, 31206, 68, 1, 67, "Subsection",
      CellTags->"c:67"]},
  "limit of sum"->{
    Cell[991736, 31232, 1625, 40, 259, "Input",
      CellTags->{
      "2-ary limit of sum", "distance of sum", "fsum", "limit", 
        "limit of sum"}]},
  "c:68"->{
    Cell[993398, 31277, 88, 3, 67, "Subsection",
      CellTags->"c:68"]},
  "c:69"->{
    Cell[996261, 31361, 76, 1, 78, "Section",
      CellTags->"c:69"]},
  "c:70"->{
    Cell[997331, 31397, 88, 1, 78, "Section",
      CellTags->"c:70"]},
  "c:71"->{
    Cell[998085, 31418, 68, 1, 67, "Subsection",
      CellTags->"c:71"]},
  "c:72"->{
    Cell[998896, 31444, 88, 3, 67, "Subsection",
      CellTags->"c:72"]},
  "c:73"->{
    Cell[1002615, 31543, 80, 1, 78, "Section",
      CellTags->"c:73"]},
  "c:74"->{
    Cell[1003208, 31565, 68, 1, 67, "Subsection",
      CellTags->"c:74"]},
  "c:75"->{
    Cell[1004303, 31602, 88, 3, 67, "Subsection",
      CellTags->"c:75"]},
  "addition, subtraction, division"->{
    Cell[1006614, 31672, 365, 10, 72, "Input",
      CellTags->"addition, subtraction, division"],
    Cell[1008854, 31739, 447, 11, 114, "Input",
      CellTags->"addition, subtraction, division"]},
  "c:76"->{
    Cell[1007249, 31694, 95, 1, 78, "Section",
      CellTags->"c:76"]},
  "c:77"->{
    Cell[1008080, 31716, 68, 1, 67, "Subsection",
      CellTags->"c:77"]},
  "c:78"->{
    Cell[1009338, 31755, 88, 3, 67, "Subsection",
      CellTags->"c:78"]},
  "c:79"->{
    Cell[1010345, 31786, 86, 1, 78, "Section",
      CellTags->"c:79"]},
  "c:80"->{
    Cell[1010976, 31808, 68, 1, 67, "Subsection",
      CellTags->"c:80"]},
  "c:81"->{
    Cell[1011731, 31833, 88, 3, 67, "Subsection",
      CellTags->"c:81"]},
  "c:82"->{
    Cell[1012491, 31860, 81, 1, 78, "Section",
      CellTags->"c:82"]},
  "References"->{
    Cell[1013724, 31904, 103, 2, 229, "Chapter",
      CellTags->{"References", "c:83"}]},
  "c:83"->{
    Cell[1013724, 31904, 103, 2, 229, "Chapter",
      CellTags->{"References", "c:83"}]},
  "TPS"->{
    Cell[1013830, 31908, 556, 15, 102, "Text",
      CellTags->"TPS"]},
  "omrs:99"->{
    Cell[1014389, 31925, 679, 17, 156, "Text",
      CellTags->"omrs:99"]},
  "BallarinEtAl1995"->{
    Cell[1015071, 31944, 494, 11, 129, "Text",
      CellTags->"BallarinEtAl1995"]},
  "BallarinPaulson1998"->{
    Cell[1015568, 31957, 487, 11, 102, "Text",
      CellTags->"BallarinPaulson1998"]},
  "Beeson:89"->{
    Cell[1016058, 31970, 369, 10, 75, "Text",
      CellTags->"Beeson:89"]},
  "Beeson:98"->{
    Cell[1016430, 31982, 439, 12, 102, "Text",
      CellTags->"Beeson:98"]},
  "Benzmueller_al:97"->{
    Cell[1016872, 31996, 715, 19, 156, "Text",
      CellTags->"Benzmueller_al:97"]},
  "AISC98\[RawStar]94"->{
    Cell[1017590, 32017, 492, 13, 129, "Text",
      CellTags->"AISC98\[RawStar]94"]},
  "Bledsoe:90"->{
    Cell[1018085, 32032, 325, 9, 75, "Text",
      CellTags->"Bledsoe:90"]},
  "Bledsoe_Boyer_Henneman:72"->{
    Cell[1018413, 32043, 348, 10, 75, "Text",
      CellTags->"Bledsoe_Boyer_Henneman:72"]},
  "Bledsoe_Bruell:74"->{
    Cell[1018764, 32055, 323, 9, 75, "Text",
      CellTags->"Bledsoe_Bruell:74"]},
  "Boyer:88a"->{
    Cell[1019090, 32066, 339, 10, 75, "Text",
      CellTags->"Boyer:88a"]},
  "Boyer_Moore:79"->{
    Cell[1019432, 32078, 317, 9, 75, "Text",
      CellTags->"Boyer_Moore:79"]},
  "OBDD"->{
    Cell[1019752, 32089, 333, 10, 75, "Text",
      CellTags->"OBDD"]},
  "Buchb:70"->{
    Cell[1020088, 32101, 358, 10, 75, "Text",
      CellTags->"Buchb:70"]},
  "Buchb:85c"->{
    Cell[1020449, 32113, 280, 9, 48, "Text",
      CellTags->"Buchb:85c"]},
  "Buchb:96b"->{
    Cell[1020732, 32124, 339, 9, 75, "Text",
      CellTags->"Buchb:96b"]},
  "Buchb:96c"->{
    Cell[1021074, 32135, 358, 10, 75, "Text",
      CellTags->"Buchb:96c"]},
  "Buchb:96d"->{
    Cell[1021435, 32147, 472, 11, 129, "Text",
      CellTags->"Buchb:96d"]},
  "Buchb:96e"->{
    Cell[1021910, 32160, 407, 11, 102, "Text",
      CellTags->"Buchb:96e"]},
  "Buchb:97a"->{
    Cell[1022320, 32173, 386, 10, 102, "Text",
      CellTags->"Buchb:97a"]},
  "Buchb:97d"->{
    Cell[1022709, 32185, 414, 11, 102, "Text",
      CellTags->"Buchb:97d"]},
  "Buchb_al:97"->{
    Cell[1023126, 32198, 449, 11, 102, "Text",
      CellTags->"Buchb_al:97"]},
  "Buchb_all:99"->{
    Cell[1023578, 32211, 316, 8, 102, "Text",
      CellTags->"Buchb_all:99"]},
  "Buchb_Coll_Kutz:88"->{
    Cell[1023897, 32221, 358, 10, 75, "Text",
      CellTags->"Buchb_Coll_Kutz:88"]},
  "Buchb_expl:99"->{
    Cell[1024258, 32233, 465, 12, 129, "Text",
      CellTags->"Buchb_expl:99"]},
  "Buchb_Vasa:97"->{
    Cell[1024726, 32247, 418, 11, 102, "Text",
      CellTags->"Buchb_Vasa:97"]},
  "Buchb_WW:98"->{
    Cell[1025147, 32260, 424, 10, 102, "Text",
      CellTags->"Buchb_WW:98"]},
  "Bundy:90"->{
    Cell[1025574, 32272, 421, 12, 102, "Text",
      CellTags->"Bundy:90"]},
  "Bundy_AD:99"->{
    Cell[1025998, 32286, 273, 7, 75, "Text",
      CellTags->"Bundy_AD:99"]},
  "Rippling"->{
    Cell[1026274, 32295, 383, 10, 75, "Text",
      CellTags->"Rippling"]},
  "CA"->{
    Cell[1026660, 32307, 330, 9, 75, "Text",
      CellTags->"CA"]},
  "openmath:99"->{
    Cell[1026993, 32318, 684, 17, 156, "Text",
      CellTags->"openmath:99"]},
  "maple"->{
    Cell[1027680, 32337, 348, 12, 75, "Text",
      CellTags->"maple"]},
  "Chou:88"->{
    Cell[1028031, 32351, 280, 9, 48, "Text",
      CellTags->"Chou:88"]},
  "Clarke_Zhao:93"->{
    Cell[1028314, 32362, 325, 9, 75, "Text",
      CellTags->"Clarke_Zhao:93"]},
  "Collins:75"->{
    Cell[1028642, 32373, 441, 12, 102, "Text",
      CellTags->"Collins:75"]},
  "Collins_Hong:91"->{
    Cell[1029086, 32387, 366, 10, 75, "Text",
      CellTags->"Collins_Hong:91"]},
  "Constable:86"->{
    Cell[1029455, 32399, 317, 10, 75, "Text",
      CellTags->"Constable:86"]},
  "Cooper"->{
    Cell[1029775, 32411, 344, 9, 75, "Text",
      CellTags->"Cooper"]},
  "ILF"->{
    Cell[1030122, 32422, 390, 12, 102, "Text",
      CellTags->"ILF"]},
  "Davenport_all:88"->{
    Cell[1030515, 32436, 349, 10, 75, "Text",
      CellTags->"Davenport_all:88"]},
  "RedLog:97"->{
    Cell[1030867, 32448, 489, 15, 75, "Text",
      CellTags->"RedLog:97"]},
  "Dutertre:96"->{
    Cell[1031359, 32465, 306, 9, 75, "Text",
      CellTags->"Dutertre:96"]},
  "Farmer_al:93"->{
    Cell[1031668, 32476, 357, 10, 75, "Text",
      CellTags->"Farmer_al:93"]},
  "Gamboa"->{
    Cell[1032028, 32488, 306, 9, 75, "Text",
      CellTags->"Gamboa"]},
  "Garland_Guttag:91"->{
    Cell[1032337, 32499, 269, 7, 75, "Text",
      CellTags->"Garland_Guttag:91"]},
  "omrs"->{
    Cell[1032609, 32508, 354, 9, 102, "Text",
      CellTags->"omrs"]},
  "Gordon:93"->{
    Cell[1032966, 32519, 344, 10, 75, "Text",
      CellTags->"Gordon:93"]},
  "Harrison-thesis"->{
    Cell[1033313, 32531, 305, 11, 75, "Text",
      CellTags->"Harrison-thesis"]},
  "hol-cas1"->{
    Cell[1033621, 32544, 381, 10, 102, "Text",
      CellTags->"hol-cas1"]},
  "Reduce"->{
    Cell[1034005, 32556, 414, 14, 75, "Text",
      CellTags->"Reduce"]},
  "Hines"->{
    Cell[1034422, 32572, 337, 11, 75, "Text",
      CellTags->"Hines"]},
  "Homann:96"->{
    Cell[1034762, 32585, 356, 10, 75, "Text",
      CellTags->"Homann:96"]},
  "Homann_Calmet:96"->{
    Cell[1035121, 32597, 503, 11, 129, "Text",
      CellTags->"Homann_Calmet:96"]},
  "Huang:96"->{
    Cell[1035627, 32610, 348, 10, 75, "Text",
      CellTags->"Huang:96"]},
  "Huet_all:94"->{
    Cell[1035978, 32622, 470, 14, 75, "Text",
      CellTags->"Huet_all:94"]},
  "Ireland_Bundy:96"->{
    Cell[1036451, 32638, 337, 9, 75, "Text",
      CellTags->"Ireland_Bundy:96"]},
  "Calculemus"->{
    Cell[1036791, 32649, 455, 10, 102, "Text",
      CellTags->"Calculemus"]},
  "Jackson:95"->{
    Cell[1037249, 32661, 384, 10, 102, "Text",
      CellTags->"Jackson:95"]},
  "Janicic:99"->{
    Cell[1037636, 32673, 367, 10, 75, "Text",
      CellTags->"Janicic:99"]},
  "ACL2:97"->{
    Cell[1038006, 32685, 373, 10, 75, "Text",
      CellTags->"ACL2:97"]},
  "ACL2-manual"->{
    Cell[1038382, 32697, 431, 14, 75, "Text",
      CellTags->"ACL2-manual"]},
  "KeKoSo96b"->{
    Cell[1038816, 32713, 524, 12, 129, "Text",
      CellTags->"KeKoSo96b"]},
  "KeKoSo98"->{
    Cell[1039343, 32727, 346, 10, 75, "Text",
      CellTags->"KeKoSo98"]},
  "Loveland:97"->{
    Cell[1039692, 32739, 502, 13, 102, "Text",
      CellTags->"Loveland:97"]},
  "Manna_Waldinger:85"->{
    Cell[1040197, 32754, 360, 10, 75, "Text",
      CellTags->"Manna_Waldinger:85"]},
  "EQP"->{
    Cell[1040560, 32766, 384, 14, 48, "Text",
      CellTags->"EQP"]},
  "McCune_Robbins"->{
    Cell[1040947, 32782, 308, 9, 75, "Text",
      CellTags->"McCune_Robbins"]},
  "McCune_Wos:97"->{
    Cell[1041258, 32793, 329, 9, 75, "Text",
      CellTags->"McCune_Wos:97"]},
  "Melis_Leron:99"->{
    Cell[1041590, 32804, 380, 11, 75, "Text",
      CellTags->"Melis_Leron:99"]},
  "melis-limit:98"->{
    Cell[1041973, 32817, 311, 10, 75, "Text",
      CellTags->"melis-limit:98"]},
  "Melis_rep"->{
    Cell[1042287, 32829, 324, 8, 102, "Text",
      CellTags->"Melis_rep"]},
  "Setheo"->{
    Cell[1042614, 32839, 375, 10, 102, "Text",
      CellTags->"Setheo"]},
  "OMD132a"->{
    Cell[1042992, 32851, 470, 14, 75, "Text",
      CellTags->"OMD132a"]},
  "PVS:92"->{
    Cell[1043465, 32867, 283, 8, 75, "Text",
      CellTags->"PVS:92"]},
  "Paule_Schorn:95"->{
    Cell[1043751, 32877, 381, 10, 75, "Text",
      CellTags->"Paule_Schorn:95"]},
  "paulson_90isabelle"->{
    Cell[1044135, 32889, 337, 9, 75, "Text",
      CellTags->"paulson_90isabelle"]},
  "Paulson:96a"->{
    Cell[1044475, 32900, 294, 9, 75, "Text",
      CellTags->"Paulson:96a"]},
  "Dagstuhl:97"->{
    Cell[1044772, 32911, 327, 10, 75, "Text",
      CellTags->"Dagstuhl:97"]},
  "QED"->{
    Cell[1045102, 32923, 334, 11, 75, "Text",
      CellTags->"QED"]},
  "lambdaClam:98"->{
    Cell[1045439, 32936, 453, 11, 102, "Text",
      CellTags->"lambdaClam:98"]},
  "Robinson:65"->{
    Cell[1045895, 32949, 355, 10, 75, "Text",
      CellTags->"Robinson:65"]},
  "Rudnicki:92"->{
    Cell[1046253, 32961, 307, 9, 75, "Text",
      CellTags->"Rudnicki:92"]},
  "Shults_thesis"->{
    Cell[1046563, 32972, 341, 10, 75, "Text",
      CellTags->"Shults_thesis"]},
  "Strzebonski:99"->{
    Cell[1046907, 32984, 335, 9, 75, "Text",
      CellTags->"Strzebonski:99"]},
  "Suppes:81"->{
    Cell[1047245, 32995, 481, 12, 129, "Text",
      CellTags->"Suppes:81"]},
  "Suppes:84"->{
    Cell[1047729, 33009, 431, 11, 102, "Text",
      CellTags->"Suppes:84"]},
  "Suppes_Ta:89"->{
    Cell[1048163, 33022, 362, 10, 75, "Text",
      CellTags->"Suppes_Ta:89"]},
  "TPTP"->{
    Cell[1048528, 33034, 389, 12, 102, "Text",
      CellTags->"TPTP"]},
  "ColorRippl"->{
    Cell[1048920, 33048, 469, 11, 129, "Text",
      CellTags->"ColorRippl"]},
  "Thery"->{
    Cell[1049392, 33061, 407, 10, 102, "Text",
      CellTags->"Thery"]},
  "Tomuta:98"->{
    Cell[1049802, 33073, 366, 10, 75, "Text",
      CellTags->"Tomuta:98"]},
  "Trybulec_Blair:85"->{
    Cell[1050171, 33085, 332, 9, 75, "Text",
      CellTags->"Trybulec_Blair:85"]},
  "Spass"->{
    Cell[1050506, 33096, 322, 9, 75, "Text",
      CellTags->"Spass"]},
  "Winkler:96"->{
    Cell[1050831, 33107, 305, 11, 75, "Text",
      CellTags->"Winkler:96"]},
  "Wolfram:96"->{
    Cell[1051139, 33120, 286, 9, 75, "Text",
      CellTags->"Wolfram:96"]},
  "Wu:97"->{
    Cell[1051428, 33131, 367, 12, 75, "Text",
      CellTags->"Wu:97"]},
  "Zeilberger:90"->{
    Cell[1051798, 33145, 355, 10, 75, "Text",
      CellTags->"Zeilberger:90"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 1053531, 33196},
  {"c:2", 1053609, 33199},
  {"c:3", 1053686, 33202},
  {"c:4", 1053765, 33205},
  {"c:5", 1053847, 33208},
  {"c:6", 1053929, 33211},
  {"sec:relw", 1054016, 33214},
  {"c:7", 1054114, 33217},
  {"c:8", 1054212, 33220},
  {"sec:prel", 1054297, 33223},
  {"c:9", 1054392, 33226},
  {"c:10", 1054488, 33229},
  {"c:11", 1054570, 33232},
  {"sec:term", 1054656, 33235},
  {"c:12", 1054752, 33238},
  {"sec:Tps", 1054851, 33241},
  {"c:13", 1054946, 33244},
  {"fig:Tmasession", 1055051, 33247},
  {"sec:up", 1055144, 33250},
  {"c:14", 1055238, 33253},
  {"sec:pp", 1055334, 33256},
  {"c:15", 1055429, 33259},
  {"eq:bp-def", 1055529, 33262},
  {"sec:grw", 1055630, 33265},
  {"c:16", 1055727, 33268},
  {"sec:rw-idea", 1055831, 33271},
  {"c:17", 1055931, 33274},
  {"fig:rules", 1056036, 33277},
  {"c:18", 1056124, 33280},
  {"r:rw-eq", 1056210, 33283},
  {"r:rw-impl", 1056309, 33286},
  {"sec:sem-match", 1056414, 33289},
  {"c:19", 1056516, 33292},
  {"sec:rw-impl", 1056625, 33295},
  {"c:20", 1056725, 33298},
  {"sec:rw-cand", 1056832, 33301},
  {"c:21", 1056936, 33304},
  {"c:22", 1057040, 33307},
  {"c:23", 1057126, 33310},
  {"fig:eq-impl", 1057220, 33313},
  {"sec:find-sm", 1057317, 33316},
  {"c:24", 1057421, 33319},
  {"c:25", 1057525, 33322},
  {"c:26", 1057611, 33325},
  {"sec:solving", 1057701, 33328},
  {"c:27", 1057802, 33331},
  {"continuity ", 1057910, 33334},
  {"sum continuity", 1058011, 33337},
  {"continuity 2-ary", 1058117, 33340},
  {"continuity 3-ary", 1058274, 33344},
  {"continuity 4-ary", 1058431, 33348},
  {"2-ary continuity", 1058588, 33352},
  {"3-ary continuity", 1058745, 33356},
  {"4-ary continuity", 1058902, 33360},
  {"sec:gsr", 1059050, 33364},
  {"c:28", 1059146, 33367},
  {"c:29", 1059242, 33370},
  {"r:prex", 1059331, 33373},
  {"c:30", 1059424, 33376},
  {"r:push", 1059513, 33379},
  {"r:subf-as", 1059611, 33382},
  {"r:isub", 1059710, 33385},
  {"c:31", 1059804, 33388},
  {"r:match-asm", 1059898, 33391},
  {"r:match-impl", 1060006, 33394},
  {"r:univ-impl", 1060112, 33397},
  {"r:apply", 1060213, 33400},
  {"r:ssub", 1060310, 33403},
  {"c:32", 1060405, 33406},
  {"sec:id-subp", 1060495, 33409},
  {"c:33", 1060599, 33412},
  {"c:34", 1060703, 33415},
  {"c:35", 1060789, 33418},
  {"sec:case", 1060876, 33421},
  {"c:36", 1060974, 33424},
  {"sec:syn-case", 1061080, 33427},
  {"c:37", 1061182, 33430},
  {"eq:casei", 1061288, 33433},
  {"eq:casec", 1061389, 33436},
  {"sec:inf-case", 1061494, 33439},
  {"c:38", 1061595, 33442},
  {"c:39", 1061696, 33445},
  {"r:elim-cd", 1061787, 33448},
  {"r:red-cd", 1061887, 33451},
  {"c:40", 1061982, 33454},
  {"r:prove-cd", 1062074, 33457},
  {"c:41", 1062170, 33460},
  {"r:transf-g-cd", 1062265, 33463},
  {"r:transf-as-cd", 1062374, 33466},
  {"r:use-cd", 1062478, 33469},
  {"sec:cdp", 1062575, 33472},
  {"c:42", 1062671, 33475},
  {"sec:ind", 1062770, 33478},
  {"c:43", 1062867, 33481},
  {"sec:nn", 1062966, 33484},
  {"c:44", 1063061, 33487},
  {"sec:tuple", 1063161, 33490},
  {"c:45", 1063259, 33493},
  {"sec:ip", 1063359, 33496},
  {"c:46", 1063454, 33499},
  {"sec:pos", 1063552, 33502},
  {"c:47", 1063649, 33505},
  {"c:48", 1063746, 33508},
  {"exp base \[RawStar]", 1063844, 33511},
  {"exp 0", 1064131, 33518},
  {"exp .", 1064373, 33525},
  {"1", 1064614, 33532},
  {"4", 1065791, 33565},
  {"2", 1067047, 33600},
  {"3", 1068228, 33633},
  {"5", 1069488, 33668},
  {"c:49", 1070609, 33699},
  {"c:50", 1070692, 33702},
  {"c:51", 1070775, 33705},
  {"sec:provers", 1070866, 33708},
  {"c:52", 1070968, 33711},
  {"sec:pcs", 1071073, 33714},
  {"c:53", 1071171, 33717},
  {"c:54", 1071269, 33720},
  {"sec:PC-dec", 1071363, 33723},
  {"c:55", 1071470, 33726},
  {"function product", 1071589, 33729},
  {"function sum", 1071883, 33736},
  {"distance of sum", 1072008, 33739},
  {"less, minimum", 1072372, 33748},
  {"cont4:+", 1072490, 33751},
  {"cont4", 1072666, 33756},
  {"f+g", 1072757, 33759},
  {"dist+", 1072923, 33764},
  {"<min", 1073092, 33769},
  {"6", 1073333, 33776},
  {"7", 1074298, 33803},
  {"8", 1075261, 33830},
  {"9", 1076228, 33857},
  {"minimum, greater", 1077063, 33880},
  {"cont3:+", 1077334, 33887},
  {"cont3", 1077509, 33892},
  {"min>", 1077601, 33895},
  {"10", 1077843, 33902},
  {"3-ary continuity of sum: variant", 1078479, 33919},
  {"positiveness", 1078600, 33922},
  {"cont2:+", 1078695, 33925},
  {"cont2", 1078789, 33928},
  {"/2>", 1078879, 33931},
  {"sec:PC-otter", 1078975, 33934},
  {"c:56", 1079084, 33937},
  {"Definition (Set equality)", 1079214, 33940},
  {"Inclusion", 1079392, 33945},
  {"Powerset", 1079569, 33950},
  {"Set equality", 1079825, 33957},
  {"Union", 1080078, 33964},
  {"Union of powerset is included...", 1080279, 33969},
  {"P\[Union]\[SubsetEqual]", 1080410, 33972},
  {"\[SubsetEqual]:", 1080529, 33975},
  {"\[Union]:", 1080635, 33978},
  {"P:", 1080892, 33985},
  {"Fixpoint property", 1080992, 33988},
  {"Examples", 1081093, 33991},
  {"FP", 1081181, 33994},
  {"seq:", 1081269, 33997},
  {"13", 1081357, 34000},
  {"14", 1081892, 34015},
  {"15", 1082356, 34028},
  {"16", 1082742, 34039},
  {"17", 1083203, 34052},
  {"12", 1083663, 34065},
  {"11", 1084197, 34080},
  {"18", 1084731, 34095},
  {"19", 1085263, 34110},
  {"20", 1085797, 34125},
  {"21", 1086181, 34136},
  {"22", 1086490, 34145},
  {"23", 1086725, 34152},
  {"24", 1086958, 34159},
  {"25", 1087118, 34164},
  {"26", 1087353, 34171},
  {"c:57", 1087589, 34178},
  {"continuity of product", 1087693, 34181},
  {"distance of product", 1087810, 34184},
  {"fprod", 1087996, 34189},
  {"minimum, less", 1088190, 34194},
  {"cont\[RawStar]", 1088385, 34199},
  {"cont", 1088572, 34204},
  {"f\[RawStar]g", 1088901, 34213},
  {"dist\[RawStar]", 1089094, 34218},
  {"convergence", 1089288, 34223},
  {"convergent", 1089477, 34228},
  {"2-ary limit of sum", 1089739, 34234},
  {"convergence of sum", 1090184, 34244},
  {"limit", 1090338, 34248},
  {"fsum", 1090769, 34258},
  {"sequences sum", 1091162, 34267},
  {"sum greater", 1091303, 34270},
  {"conv+", 1091395, 34273},
  {"conv", 1091485, 34276},
  {"\[GreaterEqual]+", 1091587, 34279},
  {"c:58", 1091689, 34282},
  {"Continuity, Sign", 1091788, 34285},
  {"Absolute Value", 1092101, 34292},
  {"cont, sign", 1092407, 34299},
  {"c2:", 1092587, 34304},
  {"absv", 1092676, 34307},
  {"limit at", 1092847, 34312},
  {"Continuity, Limit", 1093047, 34317},
  {"cont, lim", 1093163, 34320},
  {"limf", 1093258, 34323},
  {"sec:max-as", 1093354, 34326},
  {"c:59", 1093454, 34329},
  {"Maximum", 1093557, 34332},
  {"maximum is associative", 1093663, 34335},
  {"Max is Upper Bound", 1093803, 34338},
  {"Reflexivity \[LessEqual]", 1093949, 34341},
  {"totality \[LessEqual]", 1094173, 34346},
  {"transitivity \[LessEqual]", 1094401, 34351},
  {"Transitivity \[LessEqual]", 1094629, 34356},
  {"max-A", 1094837, 34361},
  {"max", 1094927, 34364},
  {"tot \[LessEqual]", 1095028, 34367},
  {"trans \[LessEqual]", 1095143, 34370},
  {"27", 1095245, 34373},
  {"31", 1095404, 34378},
  {"32", 1095564, 34383},
  {"28", 1095723, 34388},
  {"30", 1095883, 34393},
  {"c:60", 1096044, 34398},
  {"c:61", 1096128, 34401},
  {"Addition", 1096220, 34404},
  {"Addition from Left", 1096401, 34409},
  {"Addition of Zero from Left", 1096590, 34414},
  {"even", 1096757, 34419},
  {" +0", 1097016, 34426},
  {" + succ", 1097107, 34429},
  {"succ + ", 1097202, 34432},
  {"sec:indcdp", 1097300, 34435},
  {"c:62", 1097403, 34438},
  {"conc", 1097506, 34441},
  {"member", 1097614, 34444},
  {"is\[Dash]sorted", 1098133, 34455},
  {"member, merge", 1098915, 34472},
  {"member, sorted", 1099324, 34481},
  {"merge", 1099752, 34490},
  {"prepend", 1100528, 34507},
  {"subtuple is\[Dash]sorted", 1101321, 34524},
  {"totality", 1101917, 34537},
  {"transitivity", 1102168, 34543},
  {"sorted, \[GreaterEqual]", 1102430, 34549},
  {"prepend, is\[Dash]sorted, \[GreaterSlantEqual] ", 1102679, 34554},
  {"sort\[Dash]merge", 1102885, 34559},
  {"mr", 1102985, 34562},
  {"ml", 1103070, 34565},
  {"mi", 1103155, 34568},
  {"sorted\[LeftAngleBracket]\[RightAngleBracket]", 1103285, 34571},
  {"sorted\[LeftAngleBracket].\[RightAngleBracket]", 1103456, 34574},
  {"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]", 1103639, \
34577},
  {"\[Cup],\[GreaterTilde],s", 1103801, 34580},
  {"\[GreaterTilde],s", 1103924, 34583},
  {"\[GreaterTilde]-merge", 1104044, 34586},
  {"sub\[Dash]sort", 1104161, 34589},
  {"\[GreaterEqual]tot", 1104274, 34592},
  {"29", 1104375, 34595},
  {"33", 1104460, 34598},
  {"34", 1104545, 34601},
  {"35", 1104631, 34604},
  {"36", 1104716, 34607},
  {"37", 1104801, 34610},
  {"38", 1104886, 34613},
  {"39", 1104971, 34616},
  {"40", 1105056, 34619},
  {"41", 1105141, 34622},
  {"42", 1105227, 34625},
  {"43", 1105312, 34628},
  {"44", 1105397, 34631},
  {"c:63", 1105484, 34634},
  {"c:64", 1105568, 34637},
  {"c:65", 1105654, 34640},
  {"sum of sequences", 1105750, 34643},
  {"c:66", 1105856, 34646},
  {"c:67", 1105940, 34649},
  {"limit of sum", 1106035, 34652},
  {"c:68", 1106205, 34657},
  {"c:69", 1106292, 34660},
  {"c:70", 1106376, 34663},
  {"c:71", 1106460, 34666},
  {"c:72", 1106547, 34669},
  {"c:73", 1106634, 34672},
  {"c:74", 1106719, 34675},
  {"c:75", 1106807, 34678},
  {"addition, subtraction, division", 1106922, 34681},
  {"c:76", 1107134, 34686},
  {"c:77", 1107219, 34689},
  {"c:78", 1107307, 34692},
  {"c:79", 1107395, 34695},
  {"c:80", 1107480, 34698},
  {"c:81", 1107568, 34701},
  {"c:82", 1107656, 34704},
  {"References", 1107747, 34707},
  {"c:83", 1107850, 34710},
  {"TPS", 1107952, 34713},
  {"omrs:99", 1108039, 34716},
  {"BallarinEtAl1995", 1108139, 34719},
  {"BallarinPaulson1998", 1108251, 34722},
  {"Beeson:89", 1108356, 34725},
  {"Beeson:98", 1108450, 34728},
  {"Benzmueller_al:97", 1108553, 34731},
  {"AISC98\[RawStar]94", 1108665, 34734},
  {"Bledsoe:90", 1108770, 34737},
  {"Bledsoe_Boyer_Henneman:72", 1108880, 34740},
  {"Bledsoe_Bruell:74", 1108998, 34743},
  {"Boyer:88a", 1109099, 34746},
  {"Boyer_Moore:79", 1109198, 34749},
  {"OBDD", 1109291, 34752},
  {"Buchb:70", 1109379, 34755},
  {"Buchb:85c", 1109472, 34758},
  {"Buchb:96b", 1109565, 34761},
  {"Buchb:96c", 1109658, 34764},
  {"Buchb:96d", 1109752, 34767},
  {"Buchb:96e", 1109847, 34770},
  {"Buchb:97a", 1109942, 34773},
  {"Buchb:97d", 1110037, 34776},
  {"Buchb_al:97", 1110134, 34779},
  {"Buchb_all:99", 1110234, 34782},
  {"Buchb_Coll_Kutz:88", 1110340, 34785},
  {"Buchb_expl:99", 1110447, 34788},
  {"Buchb_Vasa:97", 1110550, 34791},
  {"Buchb_WW:98", 1110651, 34794},
  {"Bundy:90", 1110747, 34797},
  {"Bundy_AD:99", 1110843, 34800},
  {"Rippling", 1110937, 34803},
  {"CA", 1111023, 34806},
  {"openmath:99", 1111111, 34809},
  {"maple", 1111204, 34812},
  {"Chou:88", 1111292, 34815},
  {"Clarke_Zhao:93", 1111388, 34818},
  {"Collins:75", 1111487, 34821},
  {"Collins_Hong:91", 1111589, 34824},
  {"Constable:86", 1111692, 34827},
  {"Cooper", 1111786, 34830},
  {"ILF", 1111870, 34833},
  {"Davenport_all:88", 1111966, 34836},
  {"RedLog:97", 1112067, 34839},
  {"Dutertre:96", 1112163, 34842},
  {"Farmer_al:93", 1112261, 34845},
  {"Gamboa", 1112355, 34848},
  {"Garland_Guttag:91", 1112453, 34851},
  {"omrs", 1112549, 34854},
  {"Gordon:93", 1112638, 34857},
  {"Harrison-thesis", 1112738, 34860},
  {"hol-cas1", 1112837, 34863},
  {"Reduce", 1112928, 34866},
  {"Hines", 1113015, 34869},
  {"Homann:96", 1113105, 34872},
  {"Homann_Calmet:96", 1113206, 34875},
  {"Huang:96", 1113307, 34878},
  {"Huet_all:94", 1113402, 34881},
  {"Ireland_Bundy:96", 1113505, 34884},
  {"Calculemus", 1113606, 34887},
  {"Jackson:95", 1113703, 34890},
  {"Janicic:99", 1113800, 34893},
  {"ACL2:97", 1113893, 34896},
  {"ACL2-manual", 1113987, 34899},
  {"KeKoSo96b", 1114083, 34902},
  {"KeKoSo98", 1114177, 34905},
  {"Loveland:97", 1114272, 34908},
  {"Manna_Waldinger:85", 1114378, 34911},
  {"EQP", 1114475, 34914},
  {"McCune_Robbins", 1114568, 34917},
  {"McCune_Wos:97", 1114670, 34920},
  {"Melis_Leron:99", 1114772, 34923},
  {"melis-limit:98", 1114876, 34926},
  {"Melis_rep", 1114975, 34929},
  {"Setheo", 1115066, 34932},
  {"OMD132a", 1115156, 34935},
  {"PVS:92", 1115245, 34938},
  {"Paule_Schorn:95", 1115341, 34941},
  {"paulson_90isabelle", 1115450, 34944},
  {"Paulson:96a", 1115554, 34947},
  {"Dagstuhl:97", 1115651, 34950},
  {"QED", 1115741, 34953},
  {"lambdaClam:98", 1115833, 34956},
  {"Robinson:65", 1115934, 34959},
  {"Rudnicki:92", 1116032, 34962},
  {"Shults_thesis", 1116131, 34965},
  {"Strzebonski:99", 1116234, 34968},
  {"Suppes:81", 1116332, 34971},
  {"Suppes:84", 1116427, 34974},
  {"Suppes_Ta:89", 1116525, 34977},
  {"TPTP", 1116617, 34980},
  {"ColorRippl", 1116708, 34983},
  {"Thery", 1116800, 34986},
  {"Tomuta:98", 1116891, 34989},
  {"Trybulec_Blair:85", 1116993, 34992},
  {"Spass", 1117090, 34995},
  {"Winkler:96", 1117180, 34998},
  {"Wolfram:96", 1117276, 35001},
  {"Wu:97", 1117366, 35004},
  {"Zeilberger:90", 1117460, 35007}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 1, 227, "Chapter",
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[1818, 56, 49, 1, 76, "Section",
  CellTags->"c:2"],
Cell[1870, 59, 221, 4, 71, "Text"],
Cell[2094, 65, 67, 0, 31, "BItem1"],
Cell[2164, 67, 209, 4, 56, "BItem1"],
Cell[2376, 73, 54, 0, 31, "BItem1"],
Cell[2433, 75, 64, 0, 31, "BItem1"],
Cell[2500, 77, 92, 3, 31, "BItem1"],
Cell[2595, 82, 27, 0, 31, "BItem1"],
Cell[2625, 84, 1538, 41, 171, "Text"],
Cell[4166, 127, 673, 15, 121, "Text"],
Cell[4842, 144, 180, 4, 71, "Text"],
Cell[5025, 150, 705, 13, 131, "BItem1"],
Cell[5733, 165, 153, 3, 56, "BItem1"],
Cell[5889, 170, 308, 5, 81, "BItem1"],
Cell[6200, 177, 330, 6, 81, "BItem1"],
Cell[6533, 185, 153, 3, 56, "BItem1"],
Cell[6689, 190, 198, 4, 56, "BItem1"],
Cell[6890, 196, 263, 5, 81, "BItem1"],
Cell[7156, 203, 1007, 14, 246, "Text"],
Cell[8166, 219, 52, 0, 46, "Text"],
Cell[8221, 221, 260, 5, 56, "BItem1"],
Cell[8484, 228, 266, 5, 81, "BItem1"],
Cell[8753, 235, 201, 4, 56, "BItem1"],
Cell[8957, 241, 90, 3, 31, "BItem1"],
Cell[9050, 246, 109, 3, 31, "BItem1"],
Cell[9162, 251, 127, 3, 31, "BItem1"],
Cell[9292, 256, 121, 3, 31, "BItem1"],
Cell[9416, 261, 341, 6, 81, "BItem1"],
Cell[9760, 269, 111, 3, 31, "BItem1"],
Cell[9874, 274, 175, 4, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10086, 283, 79, 1, 76, "Section",
  CellTags->"c:3"],
Cell[10168, 286, 697, 13, 146, "Text"],

Cell[CellGroupData[{
Cell[10890, 303, 75, 1, 64, "Subsection",
  CellTags->"c:4"],
Cell[10968, 306, 66, 0, 46, "Text"],
Cell[11037, 308, 192, 4, 56, "BItem1"],
Cell[11232, 314, 391, 7, 106, "BItem1"],
Cell[11626, 323, 487, 8, 146, "Text"],
Cell[12116, 333, 692, 22, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12845, 360, 74, 1, 64, "Subsection",
  CellTags->"c:5"],
Cell[12922, 363, 1039, 22, 171, "Text"],
Cell[13964, 387, 73, 0, 46, "Text"],
Cell[14040, 389, 64, 2, 31, "BItem1"],
Cell[14107, 393, 64, 2, 31, "BItem1"],
Cell[14174, 397, 74, 2, 31, "BItem1"],
Cell[14251, 401, 2810, 81, 171, "Text"],
Cell[17064, 484, 1606, 39, 210, "Text"],
Cell[18673, 525, 1314, 38, 129, "Text"],
Cell[19990, 565, 2253, 52, 372, "Text"],
Cell[22246, 619, 3602, 78, 642, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25885, 702, 77, 1, 67, "Subsection",
  CellTags->"c:6"],
Cell[25965, 705, 1033, 21, 237, "Text"],
Cell[27001, 728, 136, 3, 75, "Text"],
Cell[27140, 733, 327, 7, 114, "BItem1"],
Cell[27470, 742, 184, 5, 60, "BItem1"],
Cell[27657, 749, 1165, 33, 141, "BItem1"],
Cell[28825, 784, 110, 3, 48, "Text"],
Cell[28938, 789, 1097, 28, 183, "Text"],
Cell[30038, 819, 1337, 33, 105, "Text"],
Cell[31378, 854, 1130, 30, 105, "Text"],
Cell[32511, 886, 1229, 29, 105, "Text"],
Cell[33743, 917, 1455, 40, 105, "Text"],
Cell[35201, 959, 1158, 28, 105, "Text"],
Cell[36362, 989, 1272, 32, 105, "Text"],
Cell[37637, 1023, 986, 21, 105, "Text"],
Cell[38626, 1046, 1013, 21, 105, "Text"],
Cell[39642, 1069, 3256, 87, 105, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42935, 1161, 77, 1, 105, "Subsection",
  CellTags->{"sec:relw", "c:7"}],
Cell[43015, 1164, 1693, 31, 105, "Text"],
Cell[44711, 1197, 577, 12, 105, "Text"],
Cell[45291, 1211, 1611, 32, 105, "Text"],
Cell[46905, 1245, 664, 13, 105, "Text"],
Cell[47572, 1260, 770, 19, 105, "Text"],
Cell[48345, 1281, 1236, 25, 105, "Text"],
Cell[49584, 1308, 294, 5, 105, "Text"],
Cell[49881, 1315, 1092, 24, 105, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51022, 1345, 57, 1, 48, "Section",
  CellTags->"c:8"],
Cell[51082, 1348, 639, 10, 210, "Text"],
Cell[51724, 1360, 1401, 23, 372, "Text"],
Cell[53128, 1385, 946, 14, 105, "Text"],
Cell[54077, 1401, 479, 8, 105, "Text"],
Cell[54559, 1411, 195, 4, 105, "Text"],
Cell[54757, 1417, 171, 4, 105, "BItem1"],
Cell[54931, 1423, 214, 4, 105, "BItem1"],
Cell[55148, 1429, 229, 4, 105, "BItem1"],
Cell[55380, 1435, 300, 5, 105, "BItem1"],
Cell[55683, 1442, 284, 5, 105, "BItem1"],
Cell[55970, 1449, 165, 4, 105, "BItem1"],
Cell[56138, 1455, 1148, 16, 105, "Text"],
Cell[57289, 1473, 747, 11, 105, "Text"],
Cell[58039, 1486, 353, 6, 129, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58441, 1498, 69, 1, 229, "Chapter",
  CellTags->{"sec:prel", "c:9"}],

Cell[CellGroupData[{
Cell[58535, 1503, 54, 1, 78, "Section",
  CellTags->"c:10"],
Cell[58592, 1506, 346, 7, 102, "Text"],
Cell[58941, 1515, 306, 12, 60, "BItem1"],
Cell[59250, 1529, 289, 5, 114, "BItem1"],
Cell[59542, 1536, 249, 5, 67, "DisplayFormula"],
Cell[59794, 1543, 367, 13, 60, "ContinueBItem1"],
Cell[60164, 1558, 279, 5, 52, "DisplayFormula"],
Cell[60446, 1565, 435, 9, 129, "Text"],
Cell[60884, 1576, 17317, 231, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78238, 1812, 54, 1, 78, "Section",
  CellTags->"c:11"],
Cell[78295, 1815, 367, 10, 75, "Text"],
Cell[78665, 1827, 77, 0, 33, "BItem1"],
Cell[78745, 1829, 133, 5, 33, "BItem1"],
Cell[78881, 1836, 111, 3, 33, "BItem1"],
Cell[78995, 1841, 128, 5, 33, "BItem1"],
Cell[79126, 1848, 273, 8, 33, "BItem1"],
Cell[79402, 1858, 842, 27, 87, "BItem1"],
Cell[80247, 1887, 332, 6, 60, "BItem1"],
Cell[80582, 1895, 1061, 30, 210, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81680, 1930, 71, 1, 78, "Section",
  CellTags->{"sec:term", "c:12"}],
Cell[81754, 1933, 422, 7, 129, "Text"],
Cell[82179, 1942, 199, 4, 75, "Text"],
Cell[82381, 1948, 99, 3, 33, "BItem1"],
Cell[82483, 1953, 93, 3, 33, "BItem1"],
Cell[82579, 1958, 131, 3, 60, "BItem1"],
Cell[82713, 1963, 146, 3, 60, "BItem2"],
Cell[82862, 1968, 153, 3, 60, "BItem2"],
Cell[83018, 1973, 241, 5, 102, "Text"],
Cell[83262, 1980, 1117, 16, 372, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84416, 2001, 84, 1, 78, "Section",
  CellTags->{"sec:Tps", "c:13"}],
Cell[84503, 2004, 183, 4, 75, "Text"],
Cell[84689, 2010, 59, 0, 33, "BItem1"],
Cell[84751, 2012, 252, 5, 87, "BItem1"],
Cell[85006, 2019, 354, 6, 105, "BItem1"],
Cell[85363, 2027, 900, 18, 220, "Paragraph"],
Cell[86266, 2047, 645, 11, 220, "Paragraph"],
Cell[86914, 2060, 129, 4, 58, "Paragraph"],
Cell[87046, 2066, 151, 3, 60, "BItem1"],
Cell[87200, 2071, 140, 3, 60, "BItem1"],
Cell[87343, 2076, 1095, 16, 345, "Text"],

Cell[CellGroupData[{
Cell[88463, 2096, 4280, 109, 735, "Input"],
Cell[92746, 2207, 89, 2, 45, "TmaText"],
Cell[92838, 2211, 89, 1, 69, "Output"]
}, Open  ]],
Cell[92942, 2215, 95, 1, 22, "Figure",
  CellTags->"fig:Tmasession"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93074, 2221, 94, 1, 78, "Section",
  CellTags->{"sec:up", "c:14"}],
Cell[93171, 2224, 224, 4, 102, "Text"],
Cell[93398, 2230, 711, 11, 237, "Text"],
Cell[94112, 2243, 582, 15, 118, "Input"],
Cell[94697, 2260, 307, 5, 102, "Text"],
Cell[95007, 2267, 504, 8, 156, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95548, 2280, 107, 1, 78, "Section",
  CellTags->{"sec:pp", "c:15"}],
Cell[95658, 2283, 242, 5, 102, "Text"],
Cell[95903, 2290, 134, 3, 60, "BItem1"],
Cell[96040, 2295, 85, 3, 33, "BItem1"],
Cell[96128, 2300, 69, 0, 33, "BItem1"],
Cell[96200, 2302, 110, 3, 48, "Text"],
Cell[96313, 2307, 115, 3, 60, "BItem1"],
Cell[96431, 2312, 142, 3, 60, "BItem1"],
Cell[96576, 2317, 1297, 22, 345, "Text"],
Cell[97876, 2341, 379, 6, 129, "Text"],
Cell[98258, 2349, 219, 4, 102, "Text"],
Cell[98480, 2355, 326, 12, 45, "NumberedEquation",
  CellTags->"eq:bp-def"],
Cell[98809, 2369, 21, 0, 48, "Text"],
Cell[98833, 2371, 108, 3, 33, "BItem1"],
Cell[98944, 2376, 95, 3, 33, "BItem1"],
Cell[99042, 2381, 203, 4, 60, "BItem1"],
Cell[99248, 2387, 77, 3, 33, "BItem1"],
Cell[99328, 2392, 67, 0, 33, "BItem2"],
Cell[99398, 2394, 133, 3, 60, "BItem2"],
Cell[99534, 2399, 110, 3, 60, "BItem2"],
Cell[99647, 2404, 472, 8, 156, "Text"],
Cell[100122, 2414, 1059, 16, 355, "Paragraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101230, 2436, 73, 1, 229, "Chapter",
  CellTags->{"sec:grw", "c:16"}],
Cell[101306, 2439, 790, 12, 264, "Text"],
Cell[102099, 2453, 302, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[102426, 2462, 72, 1, 78, "Section",
  CellTags->{"sec:rw-idea", "c:17"}],
Cell[102501, 2465, 79, 2, 48, "Text"],
Cell[102583, 2469, 308, 6, 112, "NumberedEquation"],
Cell[102894, 2477, 21, 0, 48, "Text"],
Cell[102918, 2479, 305, 7, 33, "BItem1"],
Cell[103226, 2488, 337, 11, 33, "BItem1"],
Cell[103566, 2501, 319, 10, 60, "BItem1"],
Cell[103888, 2513, 283, 5, 102, "Text"],
Cell[104174, 2520, 782, 13, 229, "3ColumnTable"],
Cell[104959, 2535, 130, 4, 22, "Figure",
  CellTags->"fig:rules"],
Cell[105092, 2541, 241, 5, 102, "Text"],
Cell[105336, 2548, 208, 4, 75, "Text"],
Cell[105547, 2554, 119, 2, 60, "DisplayFormula"],
Cell[105669, 2558, 414, 12, 102, "Text"],
Cell[106086, 2572, 128, 2, 70, "DisplayFormula"],
Cell[106217, 2576, 202, 5, 85, "Text"],
Cell[106422, 2583, 183, 4, 75, "Example"],
Cell[106608, 2589, 418, 7, 78, "DisplayFormula"],
Cell[107029, 2598, 70, 0, 48, "Text"],
Cell[107102, 2600, 379, 7, 73, "DisplayFormula"],
Cell[107484, 2609, 136, 3, 75, "Text"],
Cell[107623, 2614, 88, 1, 45, "DisplayFormula"],
Cell[107714, 2617, 45, 0, 48, "Text"],
Cell[107762, 2619, 386, 6, 78, "DisplayFormula"],
Cell[108151, 2627, 59, 0, 48, "Text"],
Cell[108213, 2629, 81, 1, 45, "DisplayFormula"],
Cell[108297, 2632, 38, 0, 48, "Text"],
Cell[108338, 2634, 362, 6, 78, "DisplayFormula"],
Cell[108703, 2642, 174, 4, 75, "Example"],
Cell[108880, 2648, 200, 3, 60, "DisplayFormula"],
Cell[109083, 2653, 128, 3, 75, "Text"],
Cell[109214, 2658, 224, 5, 43, "DisplayFormula"],
Cell[109441, 2665, 51, 0, 48, "Text"],
Cell[109495, 2667, 228, 5, 43, "DisplayFormula"],
Cell[109726, 2674, 59, 0, 48, "Text"],
Cell[109788, 2676, 150, 2, 45, "DisplayFormula"],
Cell[109941, 2680, 37, 0, 48, "Text"],
Cell[109981, 2682, 673, 19, 51, "DisplayFormula"],
Cell[110657, 2703, 148, 3, 75, "Text"],
Cell[110808, 2708, 62, 0, 48, "Text"],
Cell[110873, 2710, 107, 2, 45, "DisplayFormula"],
Cell[110983, 2714, 67, 0, 48, "Text"],
Cell[111053, 2716, 148, 2, 45, "DisplayFormula"],
Cell[111204, 2720, 129, 3, 75, "Text"],
Cell[111336, 2725, 323, 6, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111696, 2736, 61, 1, 78, "Section",
  CellTags->"c:18"],
Cell[111760, 2739, 64, 0, 48, "Text"],
Cell[111827, 2741, 444, 8, 154, "DisplayFormula"],
Cell[112274, 2751, 108, 3, 48, "Text"],
Cell[112385, 2756, 355, 14, 75, "InferenceRule",
  CellTags->"r:rw-eq"],
Cell[112743, 2772, 162, 3, 60, "DisplayFormula"],
Cell[112908, 2777, 1611, 46, 156, "Text"],
Cell[114522, 2825, 240, 5, 102, "ProofBegin"],
Cell[114765, 2832, 302, 11, 75, "InferenceRule",
  CellTags->"r:rw-impl"],
Cell[115070, 2845, 163, 3, 60, "DisplayFormula"],
Cell[115236, 2850, 87, 3, 48, "Text"],
Cell[115326, 2855, 954, 29, 87, "BItem1"],
Cell[116283, 2886, 963, 29, 87, "BItem1"],
Cell[117249, 2917, 369, 10, 75, "ProofBegin"],
Cell[117621, 2929, 120, 3, 75, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117778, 2937, 83, 1, 78, "Section",
  CellTags->{"sec:sem-match", "c:19"}],
Cell[117864, 2940, 398, 7, 129, "Text"],
Cell[118265, 2949, 129, 2, 45, "DisplayFormula"],
Cell[118397, 2953, 57, 0, 48, "Text"],
Cell[118457, 2955, 323, 5, 60, "DisplayFormula"],
Cell[118783, 2962, 226, 4, 75, "Text"],
Cell[119012, 2968, 366, 8, 43, "DisplayFormula"],
Cell[119381, 2978, 601, 15, 102, "Text"],
Cell[119985, 2995, 245, 4, 72, "DisplayFormula"],
Cell[120233, 3001, 287, 6, 75, "Text"],
Cell[120523, 3009, 351, 5, 103, "DisplayFormula"],
Cell[120877, 3016, 459, 7, 156, "Text"],
Cell[121339, 3025, 270, 10, 75, "InferenceRule"],
Cell[121612, 3037, 392, 7, 60, "DisplayFormula"],
Cell[122007, 3046, 678, 20, 102, "Text"],
Cell[122688, 3068, 660, 16, 106, "DisplayFormula"],
Cell[123351, 3086, 157, 4, 75, "ProofBegin"],
Cell[123511, 3092, 112, 3, 48, "Remark"],
Cell[123626, 3097, 116, 3, 75, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123779, 3105, 77, 1, 78, "Section",
  CellTags->{"sec:rw-impl", "c:20"}],
Cell[123859, 3108, 425, 15, 102, "Text"],
Cell[124287, 3125, 104, 2, 43, "DisplayFormula"],
Cell[124394, 3129, 21, 0, 48, "Text"],
Cell[124418, 3131, 180, 6, 33, "BItem1"],
Cell[124601, 3139, 443, 12, 87, "BItem1"],
Cell[125047, 3153, 88, 3, 33, "BItem1"],
Cell[125138, 3158, 792, 24, 114, "BItem2"],
Cell[125933, 3184, 94, 3, 33, "BItem2"],
Cell[126030, 3189, 216, 5, 75, "Text"],
Cell[126249, 3196, 222, 4, 75, "Remark"],
Cell[126474, 3202, 538, 10, 193, "Paragraph"],

Cell[CellGroupData[{
Cell[127037, 3216, 116, 1, 67, "Subsection",
  CellTags->{"sec:rw-cand", "c:21"}],
Cell[127156, 3219, 461, 8, 156, "Text"],
Cell[127620, 3229, 69, 1, 33, "BItem1"],
Cell[127692, 3232, 69, 1, 33, "BItem1"],
Cell[127764, 3235, 142, 4, 33, "BItem1"],
Cell[127909, 3241, 233, 5, 75, "Text"],
Cell[128145, 3248, 251, 4, 72, "DisplayFormula"],
Cell[128399, 3254, 303, 7, 48, "Text"],
Cell[128705, 3263, 166, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128908, 3272, 73, 1, 67, "Subsection",
  CellTags->"c:22"],
Cell[128984, 3275, 352, 6, 75, "Text"],
Cell[129339, 3283, 95, 3, 33, "BItem1"],
Cell[129437, 3288, 101, 3, 33, "BItem1"],
Cell[129541, 3293, 105, 3, 33, "BItem1"],
Cell[129649, 3298, 425, 7, 102, "Text"],
Cell[130077, 3307, 305, 5, 75, "Text"],
Cell[130385, 3314, 373, 6, 102, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130795, 3325, 114, 4, 67, "Subsection",
  CellTags->"c:23"],
Cell[130912, 3331, 337, 6, 75, "Text"],
Cell[131252, 3339, 277, 5, 75, "Text"],
Cell[131532, 3346, 461, 7, 102, "Text"],
Cell[131996, 3355, 477, 8, 102, "Text"],
Cell[132476, 3365, 584, 10, 102, "Text"],
Cell[133063, 3377, 1758, 27, 298, "2ColumnTable"],
Cell[134824, 3406, 129, 4, 22, "Figure",
  CellTags->"fig:eq-impl"],
Cell[134956, 3412, 391, 7, 102, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135384, 3424, 111, 1, 67, "Subsection",
  CellTags->{"sec:find-sm", "c:24"}],
Cell[135498, 3427, 286, 5, 75, "Text"],
Cell[135787, 3434, 516, 19, 48, "Text"],
Cell[136306, 3455, 276, 5, 43, "DisplayFormula"],
Cell[136585, 3462, 308, 11, 48, "Text"],
Cell[136896, 3475, 337, 5, 63, "DisplayFormula"],
Cell[137236, 3482, 72, 0, 48, "Text"],
Cell[137311, 3484, 712, 16, 87, "BItem1"],
Cell[138026, 3502, 491, 7, 126, "DisplayFormula"],
Cell[138520, 3511, 480, 8, 87, "ContinueBItem1"],
Cell[139003, 3521, 249, 8, 33, "BItem1"],
Cell[139255, 3531, 339, 9, 60, "BItem1"],
Cell[139597, 3542, 232, 4, 78, "DisplayFormula"],
Cell[139832, 3548, 111, 3, 33, "ContinueBItem1"],
Cell[139946, 3553, 257, 5, 75, "Text"],
Cell[140206, 3560, 155, 2, 61, "DisplayFormula"],
Cell[140364, 3564, 57, 0, 48, "Text"],
Cell[140424, 3566, 284, 4, 78, "DisplayFormula"],
Cell[140711, 3572, 88, 3, 48, "Text"],
Cell[140802, 3577, 258, 4, 78, "DisplayFormula"],
Cell[141063, 3583, 167, 4, 48, "Text"],
Cell[141233, 3589, 398, 6, 76, "DisplayFormula"],
Cell[141634, 3597, 587, 17, 48, "Text"],
Cell[142224, 3616, 296, 5, 102, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142557, 3626, 63, 1, 67, "Subsection",
  CellTags->"c:25"],
Cell[142623, 3629, 581, 9, 210, "Text"],
Cell[143207, 3640, 346, 6, 129, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[143602, 3652, 58, 1, 78, "Section",
  CellTags->"c:26"],
Cell[143663, 3655, 100, 3, 48, "Text"],
Cell[143766, 3660, 200, 4, 87, "BItem1"],
Cell[143969, 3666, 177, 4, 60, "BItem1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[144195, 3676, 94, 1, 277, "Chapter",
  CellTags->{"sec:solving", "c:27"}],
Cell[144292, 3679, 678, 10, 237, "Text"],
Cell[144973, 3691, 227, 5, 75, "Example"],
Cell[145203, 3698, 622, 13, 154, "Input",
  CellTags->"continuity "],
Cell[145828, 3713, 44, 0, 48, "Text"],
Cell[145875, 3715, 490, 12, 109, "Input",
  CellTags->"sum continuity"],
Cell[146368, 3729, 278, 5, 102, "Text"],
Cell[146649, 3736, 535, 12, 109, "Input",
  CellTags->{"continuity 2-ary", "continuity 3-ary", "continuity 4-ary"}],
Cell[147187, 3750, 519, 13, 148, "Input"],
Cell[147709, 3765, 633, 15, 154, "Input"],
Cell[148345, 3782, 216, 4, 102, "Text"],
Cell[148564, 3788, 770, 17, 202, "Input",
  CellTags->{"2-ary continuity", "3-ary continuity", "4-ary continuity"}],
Cell[149337, 3807, 631, 15, 136, "Input"],
Cell[149971, 3824, 495, 12, 109, "Input"],
Cell[150469, 3838, 535, 9, 183, "Text"],
Cell[151007, 3849, 2494, 62, 372, "Text"],
Cell[153504, 3913, 271, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[153800, 3922, 90, 1, 78, "Section",
  CellTags->{"sec:gsr", "c:28"}],
Cell[153893, 3925, 1065, 26, 210, "Text"],
Cell[154961, 3953, 592, 9, 183, "Text"],
Cell[155556, 3964, 1449, 39, 129, "Definition"],
Cell[157008, 4005, 522, 8, 156, "Text"],
Cell[157533, 4015, 360, 6, 129, "Text"],
Cell[157896, 4023, 52, 0, 33, "BItem1"],
Cell[157951, 4025, 77, 2, 33, "BItem1"],
Cell[158031, 4029, 135, 3, 60, "BItem1"],
Cell[158169, 4034, 184, 4, 75, "Text"],
Cell[158356, 4040, 319, 6, 102, "Text"],

Cell[CellGroupData[{
Cell[158700, 4050, 105, 4, 67, "Subsection",
  CellTags->"c:29"],
Cell[158808, 4056, 304, 11, 75, "InferenceRule",
  CellTags->"r:prex"],
Cell[159115, 4069, 130, 2, 60, "DisplayFormula"],
Cell[159248, 4073, 350, 10, 75, "Text"],
Cell[159601, 4085, 99, 3, 48, "ProofBegin"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159737, 4093, 116, 4, 67, "Subsection",
  CellTags->"c:30"],
Cell[159856, 4099, 372, 12, 75, "InferenceRule",
  CellTags->"r:push"],
Cell[160231, 4113, 192, 3, 60, "DisplayFormula"],
Cell[160426, 4118, 216, 6, 75, "Text"],
Cell[160645, 4126, 257, 4, 70, "DisplayFormula"],
Cell[160905, 4132, 145, 3, 75, "ProofBegin"],
Cell[161053, 4137, 330, 5, 70, "DisplayFormula"],
Cell[161386, 4144, 232, 6, 48, "Text"],
Cell[161621, 4152, 587, 18, 102, "InferenceRule",
  CellTags->"r:subf-as"],
Cell[162211, 4172, 226, 6, 75, "ProofBegin"],
Cell[162440, 4180, 657, 19, 102, "InferenceRule",
  CellTags->"r:isub"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163134, 4204, 115, 4, 67, "Subsection",
  CellTags->"c:31"],
Cell[163252, 4210, 1380, 36, 156, "InferenceRule",
  CellTags->"r:match-asm"],
Cell[164635, 4248, 99, 3, 48, "ProofBegin"],
Cell[164737, 4253, 403, 6, 70, "DisplayFormula"],
Cell[165143, 4261, 348, 10, 75, "Text"],
Cell[165494, 4273, 286, 4, 70, "DisplayFormula"],
Cell[165783, 4279, 227, 5, 48, "Text"],
Cell[166013, 4286, 348, 12, 75, "InferenceRule",
  CellTags->"r:match-impl"],
Cell[166364, 4300, 175, 3, 60, "DisplayFormula"],
Cell[166542, 4305, 1389, 33, 183, "Text"],
Cell[167934, 4340, 136, 3, 75, "Text"],
Cell[168073, 4345, 329, 5, 70, "DisplayFormula"],
Cell[168405, 4352, 270, 6, 75, "Text"],
Cell[168678, 4360, 205, 4, 75, "Text"],
Cell[168886, 4366, 4906, 104, 103, "DisplayFormula"],
Cell[173795, 4472, 50, 0, 48, "Text"],
Cell[173848, 4474, 2459, 62, 60, "DisplayFormula"],
Cell[176310, 4538, 511, 15, 75, "Text"],
Cell[176824, 4555, 5382, 115, 103, "DisplayFormula"],
Cell[182209, 4672, 392, 12, 75, "InferenceRule",
  CellTags->"r:univ-impl"],
Cell[182604, 4686, 152, 2, 60, "DisplayFormula"],
Cell[182759, 4690, 1102, 28, 129, "Text"],
Cell[183864, 4720, 76, 0, 48, "ProofBegin"],
Cell[183943, 4722, 296, 4, 60, "DisplayFormula"],
Cell[184242, 4728, 683, 22, 102, "InferenceRule",
  CellTags->"r:apply"],
Cell[184928, 4752, 67, 0, 48, "ProofBegin"],
Cell[184998, 4754, 1106, 31, 129, "InferenceRule",
  CellTags->"r:ssub"],
Cell[186107, 4787, 107, 3, 48, "ProofBegin"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[186263, 4796, 67, 1, 78, "Section",
  CellTags->"c:32"],
Cell[186333, 4799, 672, 10, 237, "Text"],
Cell[187008, 4811, 131, 3, 60, "BItem1"],
Cell[187142, 4816, 53, 0, 33, "BItem1"],
Cell[187198, 4818, 111, 3, 33, "BItem1"],
Cell[187312, 4823, 917, 13, 291, "Text"],
Cell[188232, 4838, 768, 15, 183, "Text"],

Cell[CellGroupData[{
Cell[189025, 4857, 102, 1, 67, "Subsection",
  CellTags->{"sec:id-subp", "c:33"}],
Cell[189130, 4860, 430, 7, 129, "Text"],
Cell[189563, 4869, 62, 0, 48, "Text"],
Cell[189628, 4871, 1826, 41, 72, "DisplayFormula"],
Cell[191457, 4914, 61, 0, 48, "Text"],
Cell[191521, 4916, 419, 12, 99, "DisplayFormula"],
Cell[191943, 4930, 803, 28, 102, "Text"],
Cell[192749, 4960, 231, 7, 33, "ContinueBItem1"],
Cell[192983, 4969, 486, 12, 114, "BItem2"],
Cell[193472, 4983, 156, 4, 33, "BItem2"],
Cell[193631, 4989, 377, 13, 33, "ContinueBItem1"],
Cell[194011, 5004, 1610, 38, 45, "DisplayFormula"],
Cell[195624, 5044, 704, 19, 60, "ContinueBItem1"],
Cell[196331, 5065, 1027, 25, 195, "ContinueBItem1"],
Cell[197361, 5092, 492, 13, 45, "DisplayFormula"],
Cell[197856, 5107, 2661, 83, 114, "ContinueBItem1"],
Cell[200520, 5192, 1214, 33, 195, "ContinueBItem1"],
Cell[201737, 5227, 165, 6, 33, "ContinueBItem1"],
Cell[201905, 5235, 219, 4, 60, "DisplayFormula"],
Cell[202127, 5241, 259, 8, 33, "ContinueBItem1"],
Cell[202389, 5251, 525, 13, 60, "DisplayFormula"],
Cell[202917, 5266, 765, 22, 87, "ContinueBItem1"],

Cell[CellGroupData[{
Cell[203707, 5292, 480, 8, 168, "Input"],
Cell[204190, 5302, 38, 1, 69, "Output"]
}, Open  ]],
Cell[204243, 5306, 280, 5, 114, "ContinueBItem1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204560, 5316, 75, 1, 67, "Subsection",
  CellTags->"c:34"],
Cell[204638, 5319, 694, 13, 129, "Text"],
Cell[205335, 5334, 72, 0, 48, "Text"],
Cell[205410, 5336, 184, 5, 33, "BItem1"],
Cell[205597, 5343, 298, 5, 114, "BItem1"],
Cell[205898, 5350, 1486, 35, 249, "BItem1"],
Cell[207387, 5387, 95, 3, 48, "Text"],
Cell[207485, 5392, 345, 9, 60, "BItem1"],
Cell[207833, 5403, 455, 12, 60, "BItem1"],
Cell[208291, 5417, 348, 7, 87, "BItem1"],
Cell[208642, 5426, 500, 13, 87, "BItem2"],
Cell[209145, 5441, 507, 15, 87, "BItem2"],
Cell[209655, 5458, 508, 15, 87, "BItem2"],
Cell[210166, 5475, 270, 6, 60, "ContinueBItem1"],
Cell[210439, 5483, 155, 3, 75, "Text"],
Cell[210597, 5488, 1237, 34, 195, "BItem1"],
Cell[211837, 5524, 324, 5, 70, "DisplayFormula"],
Cell[212164, 5531, 340, 9, 60, "ContinueBItem1"],
Cell[212507, 5542, 399, 10, 87, "BItem1"],
Cell[212909, 5554, 253, 4, 45, "DisplayFormula"],
Cell[213165, 5560, 1510, 40, 168, "ContinueBItem1"],
Cell[214678, 5602, 192, 3, 45, "DisplayFormula"],
Cell[214873, 5607, 382, 9, 60, "ContinueBItem1"],
Cell[215258, 5618, 157, 2, 45, "DisplayFormula"],
Cell[215418, 5622, 196, 4, 75, "Text"],

Cell[CellGroupData[{
Cell[215639, 5630, 283, 4, 94, "Input"],
Cell[215925, 5636, 200, 3, 121, "Output"]
}, Open  ]],
Cell[216140, 5642, 604, 21, 102, "Text"],
Cell[216747, 5665, 2412, 57, 210, "DisplayFormula"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[219208, 5728, 60, 1, 78, "Section",
  CellTags->"c:35"],
Cell[219271, 5731, 397, 15, 102, "Text"],
Cell[219671, 5748, 104, 2, 43, "DisplayFormula"],
Cell[219778, 5752, 21, 0, 48, "Text"],
Cell[219802, 5754, 262, 7, 60, "BItem1"],
Cell[220067, 5763, 123, 3, 33, "BItem1"],
Cell[220193, 5768, 88, 3, 33, "BItem1"],
Cell[220284, 5773, 313, 8, 60, "BItem2"],
Cell[220600, 5783, 143, 3, 60, "BItem2"],
Cell[220746, 5788, 198, 4, 60, "BItem2"],
Cell[220947, 5794, 306, 5, 102, "Remark"],
Cell[221256, 5801, 139, 3, 48, "Text"],
Cell[221398, 5806, 70, 2, 33, "BItem1"],
Cell[221471, 5810, 64, 0, 33, "BItem1"],
Cell[221538, 5812, 90, 3, 33, "BItem1"],
Cell[221631, 5817, 195, 4, 87, "BItem1"],
Cell[221829, 5823, 98, 3, 33, "BItem1"],
Cell[221930, 5828, 76, 0, 33, "BItem1"],
Cell[222009, 5830, 107, 3, 33, "BItem1"],
Cell[222119, 5835, 121, 3, 60, "BItem1"],
Cell[222243, 5840, 414, 7, 156, "Text"],
Cell[222660, 5849, 524, 8, 183, "Text"],
Cell[223187, 5859, 166, 4, 75, "Text"],
Cell[223356, 5865, 181, 4, 60, "BItem1"],
Cell[223540, 5871, 163, 4, 60, "BItem1"],
Cell[223706, 5877, 262, 5, 87, "BItem1"],
Cell[223971, 5884, 114, 3, 48, "Text"],
Cell[224088, 5889, 48, 0, 33, "BItem1"],
Cell[224139, 5891, 230, 4, 78, "DisplayFormula"],
Cell[224372, 5897, 376, 5, 75, "DisplayFormula"],
Cell[224751, 5904, 559, 8, 139, "DisplayFormula"],
Cell[225313, 5914, 228, 8, 33, "ContinueBItem1"],
Cell[225544, 5924, 38, 0, 33, "BItem1"],
Cell[225585, 5926, 920, 23, 73, "DisplayFormula"],
Cell[226508, 5951, 311, 5, 73, "DisplayFormula"],
Cell[226822, 5958, 1343, 29, 73, "DisplayFormula"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[228214, 5993, 73, 1, 229, "Chapter",
  CellTags->{"sec:case", "c:36"}],
Cell[228290, 5996, 489, 8, 183, "Text"],
Cell[228782, 6006, 203, 4, 75, "Text"],

Cell[CellGroupData[{
Cell[229010, 6014, 104, 1, 78, "Section",
  CellTags->{"sec:syn-case", "c:37"}],
Cell[229117, 6017, 106, 3, 48, "Text"],
Cell[229226, 6022, 295, 6, 45, "NumberedEquation",
  CellTags->"eq:casei"],
Cell[229524, 6030, 22, 0, 48, "Text"],
Cell[229549, 6032, 138, 1, 33, "BulletText"],
Cell[229690, 6035, 304, 9, 60, "BulletText"],
Cell[229997, 6046, 338, 9, 60, "BulletText"],
Cell[230338, 6057, 272, 9, 33, "BulletText"],
Cell[230613, 6068, 219, 6, 60, "BulletText"],
Cell[230835, 6076, 356, 10, 33, "BulletText"],
Cell[231194, 6088, 780, 22, 156, "Text"],
Cell[231977, 6112, 265, 6, 112, "Paragraph"],
Cell[232245, 6120, 501, 12, 97, "NumberedEquation"],
Cell[232749, 6134, 349, 9, 102, "Text"],
Cell[233101, 6145, 244, 4, 45, "NumberedEquation",
  CellTags->"eq:casec"],
Cell[233348, 6151, 18, 0, 48, "Text"],
Cell[233369, 6153, 486, 12, 97, "NumberedEquation"],
Cell[233858, 6167, 238, 7, 75, "Text"],
Cell[234099, 6176, 154, 3, 75, "Example"],
Cell[234256, 6181, 1598, 35, 166, "DisplayFormula"],
Cell[235857, 6218, 75, 0, 48, "Text"],
Cell[235935, 6220, 786, 18, 70, "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236758, 6243, 79, 1, 78, "Section",
  CellTags->{"sec:inf-case", "c:38"}],
Cell[236840, 6246, 184, 4, 75, "Text"],
Cell[237027, 6252, 501, 8, 183, "Text"],
Cell[237531, 6262, 114, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[237670, 6269, 84, 1, 67, "Subsection",
  CellTags->"c:39"],
Cell[237757, 6272, 364, 11, 75, "InferenceRule",
  CellTags->"r:elim-cd"],
Cell[238124, 6285, 172, 7, 33, "BulletText"],
Cell[238299, 6294, 309, 11, 33, "BulletText"],
Cell[238611, 6307, 171, 5, 33, "BulletText"],
Cell[238785, 6314, 172, 5, 48, "Text"],
Cell[238960, 6321, 305, 11, 75, "InferenceRule",
  CellTags->"r:red-cd"],
Cell[239268, 6334, 173, 7, 33, "BulletText"],
Cell[239444, 6343, 319, 11, 33, "BulletText"],
Cell[239766, 6356, 168, 5, 33, "BulletText"],
Cell[239937, 6363, 50, 0, 48, "Text"],
Cell[239990, 6365, 269, 5, 45, "DisplayFormula"],
Cell[240262, 6372, 168, 7, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240467, 6384, 73, 1, 67, "Subsection",
  CellTags->"c:40"],
Cell[240543, 6387, 204, 7, 48, "InferenceRule",
  CellTags->"r:prove-cd"],
Cell[240750, 6396, 261, 4, 45, "DisplayFormula"],
Cell[241014, 6402, 464, 15, 75, "Text"],
Cell[241481, 6419, 223, 4, 102, "ProofBegin"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241741, 6428, 71, 1, 67, "Subsection",
  CellTags->"c:41"],
Cell[241815, 6431, 300, 8, 75, "InferenceRule",
  CellTags->"r:transf-g-cd"],
Cell[242118, 6441, 312, 5, 60, "DisplayFormula"],
Cell[242433, 6448, 459, 15, 75, "Text"],
Cell[242895, 6465, 281, 9, 33, "BulletText"],
Cell[243179, 6476, 390, 12, 33, "BulletText"],
Cell[243572, 6490, 345, 11, 33, "BulletText"],
Cell[243920, 6503, 156, 4, 48, "Remark"],
Cell[244079, 6509, 236, 7, 75, "InferenceRule",
  CellTags->"r:transf-as-cd"],
Cell[244318, 6518, 299, 5, 60, "DisplayFormula"],
Cell[244620, 6525, 533, 15, 75, "Text"],
Cell[245156, 6542, 303, 9, 33, "BulletText"],
Cell[245462, 6553, 410, 12, 33, "BulletText"],
Cell[245875, 6567, 364, 11, 33, "BulletText"],
Cell[246242, 6580, 156, 4, 48, "Remark"],
Cell[246401, 6586, 227, 7, 75, "InferenceRule",
  CellTags->"r:use-cd"],
Cell[246631, 6595, 261, 4, 45, "DisplayFormula"],
Cell[246895, 6601, 51, 0, 48, "Text"],
Cell[246949, 6603, 250, 8, 33, "BulletText"],
Cell[247202, 6613, 341, 11, 33, "BulletText"],
Cell[247546, 6626, 246, 8, 33, "BulletText"],
Cell[247795, 6636, 480, 10, 156, "Remark"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248324, 6652, 73, 1, 78, "Section",
  CellTags->{"sec:cdp", "c:42"}],
Cell[248400, 6655, 323, 12, 75, "Text"],
Cell[248726, 6669, 86, 1, 43, "DisplayFormula"],
Cell[248815, 6672, 21, 0, 48, "Text"],
Cell[248839, 6674, 150, 4, 60, "BItem1"],
Cell[248992, 6680, 384, 7, 114, "BItem1"],
Cell[249379, 6689, 120, 5, 33, "BItem1"],
Cell[249502, 6696, 104, 3, 33, "BItem2"],
Cell[249609, 6701, 327, 6, 114, "BItem2"],
Cell[249939, 6709, 261, 5, 102, "Remark"],
Cell[250203, 6716, 215, 5, 75, "Example"],
Cell[250421, 6723, 878, 16, 321, "Input"],
Cell[251302, 6741, 1153, 24, 318, "Text"],
Cell[252458, 6767, 140, 4, 48, "Text"],
Cell[252601, 6773, 69, 0, 33, "BItem1"],
Cell[252673, 6775, 95, 3, 33, "BItem1"],
Cell[252771, 6780, 111, 3, 33, "BItem1"],
Cell[252885, 6785, 415, 7, 156, "Text"],
Cell[253303, 6794, 629, 10, 220, "Paragraph"],
Cell[253935, 6806, 102, 3, 33, "BulletText"],
Cell[254040, 6811, 109, 3, 33, "BulletText"],
Cell[254152, 6816, 84, 3, 33, "BulletText"],
Cell[254239, 6821, 96, 3, 33, "BulletText"],
Cell[254338, 6826, 102, 3, 33, "BulletText"],
Cell[254443, 6831, 89, 3, 33, "BulletText"],
Cell[254535, 6836, 359, 6, 129, "Text"],
Cell[254897, 6844, 492, 8, 166, "Paragraph"],
Cell[255392, 6854, 220, 4, 87, "BItem1"],
Cell[255615, 6860, 209, 4, 87, "BItem1"],
Cell[255827, 6866, 155, 3, 75, "Example"],
Cell[255985, 6871, 308, 7, 72, "DisplayFormula"],
Cell[256296, 6880, 53, 0, 48, "Text"],
Cell[256352, 6882, 118, 2, 45, "DisplayFormula"],
Cell[256473, 6886, 199, 5, 75, "Text"],
Cell[256675, 6893, 213, 8, 33, "BulletText"],
Cell[256891, 6903, 216, 8, 33, "BulletText"],
Cell[257110, 6913, 410, 8, 129, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[257569, 6927, 65, 1, 229, "Chapter",
  CellTags->{"sec:ind", "c:43"}],
Cell[257637, 6930, 684, 14, 183, "Text"],
Cell[258324, 6946, 237, 4, 102, "Text"],

Cell[CellGroupData[{
Cell[258586, 6954, 73, 1, 78, "Section",
  CellTags->{"sec:nn", "c:44"}],
Cell[258662, 6957, 701, 20, 129, "Text"],
Cell[259366, 6979, 189, 6, 48, "InferenceRule"],
Cell[259558, 6987, 90, 1, 55, "DisplayFormula"],
Cell[259651, 6990, 141, 5, 48, "Text"],
Cell[259795, 6997, 116, 2, 45, "DisplayFormula"],
Cell[259914, 7001, 31, 0, 48, "Text"],
Cell[259948, 7003, 104, 2, 45, "DisplayFormula"],
Cell[260055, 7007, 25, 0, 48, "Text"],
Cell[260083, 7009, 324, 9, 45, "DisplayFormula"],
Cell[260410, 7020, 272, 10, 48, "Text"],
Cell[260685, 7032, 171, 3, 75, "Example"],
Cell[260859, 7037, 135, 2, 58, "DisplayFormula"],
Cell[260997, 7041, 123, 5, 48, "Text"],
Cell[261123, 7048, 64, 0, 33, "BulletText"],
Cell[261190, 7050, 141, 2, 55, "DisplayFormula"],
Cell[261334, 7054, 172, 5, 33, "BulletText"],
Cell[261509, 7061, 145, 2, 55, "DisplayFormula"],
Cell[261657, 7065, 70, 0, 33, "BulletText"],
Cell[261730, 7067, 176, 3, 55, "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261943, 7075, 83, 1, 78, "Section",
  CellTags->{"sec:tuple", "c:45"}],
Cell[262029, 7078, 553, 14, 129, "Text"],
Cell[262585, 7094, 46, 0, 48, "Text"],
Cell[262634, 7096, 667, 14, 97, "DisplayFormula"],
Cell[263304, 7112, 140, 5, 48, "Text"],
Cell[263447, 7119, 917, 17, 97, "DisplayFormula"],
Cell[264367, 7138, 21, 0, 48, "Text"],
Cell[264391, 7140, 355, 6, 49, "DisplayFormula"],
Cell[264749, 7148, 91, 3, 48, "Text"],
Cell[264843, 7153, 227, 5, 75, "Text"],
Cell[265073, 7160, 358, 7, 97, "DisplayFormula"],
Cell[265434, 7169, 172, 4, 75, "Text"],
Cell[265609, 7175, 1058, 23, 127, "DisplayFormula"],
Cell[266670, 7200, 143, 3, 75, "Text"],
Cell[266816, 7205, 183, 6, 48, "InferenceRule"],
Cell[267002, 7213, 98, 2, 57, "DisplayFormula"],
Cell[267103, 7217, 141, 5, 48, "Text"],
Cell[267247, 7224, 106, 2, 45, "DisplayFormula"],
Cell[267356, 7228, 151, 5, 48, "Text"],
Cell[267510, 7235, 28, 0, 48, "Text"],
Cell[267541, 7237, 114, 2, 45, "DisplayFormula"],
Cell[267658, 7241, 25, 0, 48, "Text"],
Cell[267686, 7243, 120, 2, 45, "DisplayFormula"],
Cell[267809, 7247, 330, 12, 48, "Text"],
Cell[268142, 7261, 219, 4, 75, "Example"],
Cell[268364, 7267, 407, 6, 61, "DisplayFormula"],
Cell[268774, 7275, 148, 5, 48, "Text"],
Cell[268925, 7282, 65, 0, 33, "BulletText"],
Cell[268993, 7284, 406, 6, 61, "DisplayFormula"],
Cell[269402, 7292, 186, 5, 33, "BulletText"],
Cell[269591, 7299, 428, 6, 61, "DisplayFormula"],
Cell[270022, 7307, 169, 5, 33, "BulletText"],
Cell[270194, 7314, 452, 7, 61, "DisplayFormula"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270683, 7326, 72, 1, 78, "Section",
  CellTags->{"sec:ip", "c:46"}],
Cell[270758, 7329, 578, 25, 102, "Text"],
Cell[271339, 7356, 194, 4, 60, "BItem1"],
Cell[271536, 7362, 439, 9, 114, "BItem1"],
Cell[271978, 7373, 306, 7, 87, "BItem1"],
Cell[272287, 7382, 226, 4, 75, "Remark"],
Cell[272516, 7388, 157, 4, 48, "Example"],
Cell[272676, 7394, 98, 2, 60, "DisplayFormula"],
Cell[272777, 7398, 270, 9, 75, "Example"],
Cell[273050, 7409, 171, 5, 33, "BItem1"],
Cell[273224, 7416, 332, 10, 33, "BItem1"],
Cell[273559, 7428, 21, 0, 48, "Text"],
Cell[273583, 7430, 537, 12, 142, "DisplayFormula"],
Cell[274123, 7444, 127, 5, 48, "Text"],
Cell[274253, 7451, 493, 8, 183, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[274795, 7465, 78, 1, 229, "Chapter",
  CellTags->{"sec:pos", "c:47"}],
Cell[274876, 7468, 960, 14, 291, "Text"],
Cell[275839, 7484, 69, 0, 33, "BItem1"],
Cell[275911, 7486, 99, 3, 33, "BItem1"],
Cell[276013, 7491, 101, 3, 33, "BItem1"],
Cell[276117, 7496, 119, 3, 60, "BItem1"],
Cell[276239, 7501, 100, 3, 33, "BItem1"],
Cell[276342, 7506, 445, 8, 139, "Paragraph"],
Cell[276790, 7516, 151, 3, 60, "BItem1"],
Cell[276944, 7521, 324, 6, 114, "BItem1"],
Cell[277271, 7529, 110, 3, 33, "BItem1"],
Cell[277384, 7534, 181, 4, 60, "BItem1"],
Cell[277568, 7540, 253, 5, 87, "BItem1"],
Cell[277824, 7547, 1053, 16, 328, "Paragraph"],
Cell[278880, 7565, 125, 3, 60, "BItem1"],
Cell[279008, 7570, 576, 9, 195, "BItem1"],
Cell[279587, 7581, 213, 4, 87, "BItem1"],
Cell[279803, 7587, 170, 4, 60, "BItem1"],
Cell[279976, 7593, 151, 3, 60, "BItem1"],
Cell[280130, 7598, 895, 14, 274, "Paragraph"],
Cell[281028, 7614, 777, 11, 247, "Paragraph"],
Cell[281808, 7627, 873, 13, 264, "Text"],

Cell[CellGroupData[{
Cell[282706, 7644, 62, 1, 78, "Section",
  CellTags->"c:48"],
Cell[282771, 7647, 397, 7, 129, "Text"],

Cell[CellGroupData[{
Cell[283193, 7658, 996, 23, 216, "Input"],
Cell[284192, 7683, 25, 0, 45, "TmaText"],
Cell[284220, 7685, 1919, 58, 55, "Conclusion",
  CellTags->"exp base \[RawStar]"],
Cell[286142, 7745, 41, 0, 45, "TmaText"],
Cell[286186, 7747, 616, 22, 52, "Assumption",
  CellTags->"exp 0"],
Cell[286805, 7771, 1397, 44, 57, "Assumption",
  CellTags->"exp ."],
Cell[288205, 7817, 132, 3, 69, "TmaText"],
Cell[288340, 7822, 47, 0, 45, "TmaText"],
Cell[288390, 7824, 267, 10, 69, "TmaText"],
Cell[288660, 7836, 47, 0, 45, "TmaText"],
Cell[288710, 7838, 368, 18, 45, "TmaText"],
Cell[289081, 7858, 35, 0, 45, "TmaText"],
Cell[289119, 7860, 1356, 43, 55, "Conclusion",
  CellTags->"1"],
Cell[290478, 7905, 132, 3, 69, "TmaText"],
Cell[290613, 7910, 47, 0, 45, "TmaText"],
Cell[290663, 7912, 223, 10, 45, "TmaText"],
Cell[290889, 7924, 909, 30, 43, "Conclusion",
  CellTags->"4"],
Cell[291801, 7956, 203, 10, 45, "TmaText"],
Cell[292007, 7968, 50, 0, 45, "TmaText"],
Cell[292060, 7970, 590, 24, 45, "TmaText"],
Cell[292653, 7996, 469, 19, 45, "TmaText"],
Cell[293125, 8017, 401, 18, 45, "TmaText"],
Cell[293529, 8037, 122, 5, 45, "TmaText"],
Cell[293654, 8044, 50, 0, 45, "TmaText"],
Cell[293707, 8046, 607, 24, 45, "TmaText"],
Cell[294317, 8072, 122, 5, 45, "TmaText"],
Cell[294442, 8079, 48, 0, 45, "TmaText"],
Cell[294493, 8081, 220, 11, 69, "TmaText"],
Cell[294716, 8094, 34, 0, 45, "TmaText"],
Cell[294753, 8096, 78, 3, 45, "TmaText"],
Cell[294834, 8101, 1780, 54, 55, "Assumption",
  CellTags->"2"],
Cell[296617, 8157, 78, 3, 45, "TmaText"],
Cell[296698, 8162, 1917, 57, 58, "Conclusion",
  CellTags->"3"],
Cell[298618, 8221, 132, 3, 69, "TmaText"],
Cell[298753, 8226, 47, 0, 45, "TmaText"],
Cell[298803, 8228, 223, 10, 45, "TmaText"],
Cell[299029, 8240, 1415, 45, 46, "Conclusion",
  CellTags->"5"],
Cell[300447, 8287, 203, 10, 45, "TmaText"],
Cell[300653, 8299, 50, 0, 45, "TmaText"],
Cell[300706, 8301, 914, 34, 46, "TmaText"],
Cell[301623, 8337, 1126, 39, 46, "TmaText"],
Cell[302752, 8378, 1100, 39, 46, "TmaText"],
Cell[303855, 8419, 1312, 44, 45, "TmaText"],
Cell[305170, 8465, 1137, 35, 45, "TmaText"],
Cell[306310, 8502, 50, 0, 45, "TmaText"],
Cell[306363, 8504, 759, 29, 46, "TmaText"],
Cell[307125, 8535, 1124, 39, 45, "TmaText"],
Cell[308252, 8576, 1090, 39, 45, "TmaText"],
Cell[309345, 8617, 1312, 44, 45, "TmaText"],
Cell[310660, 8663, 1137, 35, 45, "TmaText"],
Cell[311800, 8700, 48, 0, 45, "TmaText"],
Cell[311851, 8702, 220, 11, 69, "TmaText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[312120, 8719, 73, 1, 78, "Section",
  CellTags->"c:49"],
Cell[312196, 8722, 241, 5, 102, "Text"],

Cell[CellGroupData[{
Cell[312462, 8731, 1042, 24, 240, "Input"],
Cell[313507, 8757, 25, 0, 45, "TmaText"],
Cell[313535, 8759, 1919, 58, 55, "Conclusion",
  CellTags->"exp base \[RawStar]"],
Cell[315457, 8819, 41, 0, 45, "TmaText"],
Cell[315501, 8821, 616, 22, 52, "Assumption",
  CellTags->"exp 0"],
Cell[316120, 8845, 1397, 44, 57, "Assumption",
  CellTags->"exp ."],
Cell[317520, 8891, 132, 3, 69, "TmaText"],
Cell[317655, 8896, 47, 0, 45, "TmaText"],
Cell[317705, 8898, 267, 10, 69, "TmaText"],
Cell[317975, 8910, 47, 0, 45, "TmaText"],
Cell[318025, 8912, 368, 18, 45, "TmaText"],
Cell[318396, 8932, 35, 0, 45, "TmaText"],
Cell[318434, 8934, 1356, 43, 55, "Conclusion",
  CellTags->"1"],
Cell[319793, 8979, 223, 10, 45, "TmaText"],
Cell[320019, 8991, 909, 30, 43, "Conclusion",
  CellTags->"4"],
Cell[320931, 9023, 203, 10, 45, "TmaText"],
Cell[321137, 9035, 50, 0, 45, "TmaText"],
Cell[321190, 9037, 590, 24, 45, "TmaText"],
Cell[321783, 9063, 469, 19, 45, "TmaText"],
Cell[322255, 9084, 401, 18, 45, "TmaText"],
Cell[322659, 9104, 122, 5, 45, "TmaText"],
Cell[322784, 9111, 50, 0, 45, "TmaText"],
Cell[322837, 9113, 607, 24, 45, "TmaText"],
Cell[323447, 9139, 122, 5, 45, "TmaText"],
Cell[323572, 9146, 34, 0, 45, "TmaText"],
Cell[323609, 9148, 78, 3, 45, "TmaText"],
Cell[323690, 9153, 1780, 54, 55, "Assumption",
  CellTags->"2"],
Cell[325473, 9209, 78, 3, 45, "TmaText"],
Cell[325554, 9214, 1917, 57, 58, "Conclusion",
  CellTags->"3"],
Cell[327474, 9273, 223, 10, 45, "TmaText"],
Cell[327700, 9285, 1415, 45, 46, "Conclusion",
  CellTags->"5"],
Cell[329118, 9332, 203, 10, 45, "TmaText"],
Cell[329324, 9344, 50, 0, 45, "TmaText"],
Cell[329377, 9346, 914, 34, 46, "TmaText"],
Cell[330294, 9382, 1126, 39, 46, "TmaText"],
Cell[331423, 9423, 1100, 39, 46, "TmaText"],
Cell[332526, 9464, 1312, 44, 45, "TmaText"],
Cell[333841, 9510, 1137, 35, 45, "TmaText"],
Cell[334981, 9547, 50, 0, 45, "TmaText"],
Cell[335034, 9549, 759, 29, 46, "TmaText"],
Cell[335796, 9580, 1124, 39, 45, "TmaText"],
Cell[336923, 9621, 1090, 39, 45, "TmaText"],
Cell[338016, 9662, 1312, 44, 45, "TmaText"],
Cell[339331, 9708, 1137, 35, 45, "TmaText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[340517, 9749, 73, 1, 78, "Section",
  CellTags->"c:50"],
Cell[340593, 9752, 129, 3, 75, "Text"],

Cell[CellGroupData[{
Cell[340747, 9759, 1040, 24, 240, "Input"],
Cell[341790, 9785, 25, 0, 45, "TmaText"],
Cell[341818, 9787, 1919, 58, 55, "Conclusion",
  CellTags->"exp base \[RawStar]"],
Cell[343740, 9847, 41, 0, 45, "TmaText"],
Cell[343784, 9849, 616, 22, 52, "Assumption",
  CellTags->"exp 0"],
Cell[344403, 9873, 1397, 44, 57, "Assumption",
  CellTags->"exp ."],
Cell[345803, 9919, 368, 18, 45, "TmaText"],
Cell[346174, 9939, 35, 0, 45, "TmaText"],
Cell[346212, 9941, 1356, 43, 55, "Conclusion",
  CellTags->"1"],
Cell[347571, 9986, 223, 10, 45, "TmaText"],
Cell[347797, 9998, 909, 30, 43, "Conclusion",
  CellTags->"4"],
Cell[348709, 10030, 203, 10, 45, "TmaText"],
Cell[348915, 10042, 50, 0, 45, "TmaText"],
Cell[348968, 10044, 590, 24, 45, "TmaText"],
Cell[349561, 10070, 469, 19, 45, "TmaText"],
Cell[350033, 10091, 401, 18, 45, "TmaText"],
Cell[350437, 10111, 122, 5, 45, "TmaText"],
Cell[350562, 10118, 50, 0, 45, "TmaText"],
Cell[350615, 10120, 607, 24, 45, "TmaText"],
Cell[351225, 10146, 122, 5, 45, "TmaText"],
Cell[351350, 10153, 34, 0, 45, "TmaText"],
Cell[351387, 10155, 78, 3, 45, "TmaText"],
Cell[351468, 10160, 1780, 54, 55, "Assumption",
  CellTags->"2"],
Cell[353251, 10216, 78, 3, 45, "TmaText"],
Cell[353332, 10221, 1917, 57, 58, "Conclusion",
  CellTags->"3"],
Cell[355252, 10280, 223, 10, 45, "TmaText"],
Cell[355478, 10292, 1415, 45, 46, "Conclusion",
  CellTags->"5"],
Cell[356896, 10339, 203, 10, 45, "TmaText"],
Cell[357102, 10351, 50, 0, 45, "TmaText"],
Cell[357155, 10353, 914, 34, 46, "TmaText"],
Cell[358072, 10389, 1126, 39, 46, "TmaText"],
Cell[359201, 10430, 1100, 39, 46, "TmaText"],
Cell[360304, 10471, 1312, 44, 45, "TmaText"],
Cell[361619, 10517, 1137, 35, 45, "TmaText"],
Cell[362759, 10554, 50, 0, 45, "TmaText"],
Cell[362812, 10556, 759, 29, 46, "TmaText"],
Cell[363574, 10587, 1124, 39, 45, "TmaText"],
Cell[364701, 10628, 1090, 39, 45, "TmaText"],
Cell[365794, 10669, 1312, 44, 45, "TmaText"],
Cell[367109, 10715, 1137, 35, 45, "TmaText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[368295, 10756, 82, 1, 78, "Section",
  CellTags->"c:51"],
Cell[368380, 10759, 222, 4, 102, "Text"],

Cell[CellGroupData[{
Cell[368627, 10767, 1041, 24, 240, "Input"],
Cell[369671, 10793, 39, 0, 45, "TmaText"]
}, Open  ]],
Cell[369725, 10796, 328, 6, 129, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[370102, 10808, 67, 1, 229, "Chapter",
  CellTags->{"sec:provers", "c:52"}],
Cell[370172, 10811, 256, 5, 102, "Text"],
Cell[370431, 10818, 768, 11, 264, "Text"],
Cell[371202, 10831, 923, 15, 264, "Remark"],

Cell[CellGroupData[{
Cell[372150, 10850, 128, 4, 78, "Section",
  CellTags->{"sec:pcs", "c:53"}],
Cell[372281, 10856, 749, 18, 129, "Text"],
Cell[373033, 10876, 203, 4, 75, "Text"],
Cell[373239, 10882, 256, 4, 73, "DisplayFormula"],
Cell[373498, 10888, 865, 13, 291, "Text"],
Cell[374366, 10903, 190, 4, 60, "BItem1"],
Cell[374559, 10909, 130, 3, 60, "BItem1"],
Cell[374692, 10914, 183, 4, 60, "BItem1"],
Cell[374878, 10920, 898, 13, 291, "Text"],
Cell[375779, 10935, 941, 14, 318, "Text"],
Cell[376723, 10951, 222, 4, 102, "Text"],

Cell[CellGroupData[{
Cell[376970, 10959, 64, 1, 105, "Subsection",
  CellTags->"c:54"],
Cell[377037, 10962, 247, 5, 105, "Text"],
Cell[377287, 10969, 233, 5, 105, "BItem1"],
Cell[377523, 10976, 111, 3, 105, "BItem1"],
Cell[377637, 10981, 676, 10, 105, "Text"],
Cell[378316, 10993, 1081, 15, 345, "Text"],
Cell[379400, 11010, 501, 12, 129, "Text"],

Cell[CellGroupData[{
Cell[379926, 11026, 121, 2, 63, "Subsubsection",
  CellTags->{"sec:PC-dec", "c:55"}],
Cell[380050, 11030, 689, 11, 237, "Text"],
Cell[380742, 11043, 208, 5, 75, "Example"],
Cell[380953, 11050, 457, 12, 72, "Input",
  CellTags->{"function product", "function sum"}],
Cell[381413, 11064, 195, 4, 102, "Text"],
Cell[381611, 11070, 773, 17, 109, "Input",
  CellTags->{"distance of sum", "less, minimum"}],
Cell[382387, 11089, 411, 11, 72, "Input"],
Cell[382801, 11102, 147, 3, 75, "Text"],

Cell[CellGroupData[{
Cell[382973, 11109, 1133, 27, 166, "Input"],
Cell[384109, 11138, 75, 2, 45, "TmaText"],
Cell[384187, 11142, 2625, 68, 199, "Conclusion",
  CellTags->"cont4:+"],
Cell[386815, 11212, 91, 2, 45, "TmaText"],
Cell[386909, 11216, 2555, 65, 117, "Assumption",
  CellTags->"cont4"],
Cell[389467, 11283, 1237, 40, 58, "Assumption",
  CellTags->"f+g"],
Cell[390707, 11325, 2413, 68, 78, "Assumption",
  CellTags->"dist+"],
Cell[393123, 11395, 1195, 38, 57, "Assumption",
  CellTags->"<min"],
Cell[394321, 11435, 78, 2, 45, "TmaText"],
Cell[394402, 11439, 969, 30, 43, "Assumption",
  CellTags->"1"],
Cell[395374, 11471, 77, 2, 45, "TmaText"],
Cell[395454, 11475, 913, 29, 43, "Conclusion",
  CellTags->"2"],
Cell[396370, 11506, 384, 20, 45, "TmaText"],
Cell[396757, 11528, 1423, 41, 57, "Assumption",
  CellTags->"3"],
Cell[398183, 11571, 384, 20, 45, "TmaText"],
Cell[398570, 11593, 1423, 41, 57, "Assumption",
  CellTags->"4"],
Cell[399996, 11636, 389, 20, 45, "TmaText"],
Cell[400388, 11658, 2071, 56, 93, "Conclusion",
  CellTags->"5"],
Cell[402462, 11716, 78, 2, 45, "TmaText"],
Cell[402543, 11720, 670, 22, 43, "Assumption",
  CellTags->"6"],
Cell[403216, 11744, 77, 2, 45, "TmaText"],
Cell[403296, 11748, 1165, 36, 43, "Conclusion",
  CellTags->"7"],
Cell[404464, 11786, 378, 20, 45, "TmaText"],
Cell[404845, 11808, 841, 25, 45, "TmaText"],
Cell[405689, 11835, 237, 12, 45, "TmaText"],
Cell[405929, 11849, 1084, 32, 45, "TmaText"],
Cell[407016, 11883, 237, 12, 45, "TmaText"],
Cell[407256, 11897, 1327, 39, 45, "TmaText"],
Cell[408586, 11938, 245, 12, 45, "TmaText"],
Cell[408834, 11952, 1417, 42, 43, "Assumption",
  CellTags->"8"],
Cell[410254, 11996, 385, 20, 45, "TmaText"],
Cell[410642, 12018, 1351, 39, 45, "TmaText"],
Cell[411996, 12059, 254, 12, 45, "TmaText"],
Cell[412253, 12073, 1327, 39, 45, "TmaText"],
Cell[413583, 12114, 246, 12, 45, "TmaText"],
Cell[413832, 12128, 1084, 32, 45, "TmaText"],
Cell[414919, 12162, 246, 12, 45, "TmaText"],
Cell[415168, 12176, 841, 25, 45, "TmaText"],
Cell[416012, 12203, 252, 12, 45, "TmaText"],
Cell[416267, 12217, 670, 22, 43, "Conclusion",
  CellTags->"9"],
Cell[416940, 12241, 394, 20, 45, "TmaText"]
}, Open  ]],
Cell[417349, 12264, 695, 11, 237, "Text"],
Cell[418047, 12277, 477, 13, 72, "Input",
  CellTags->"minimum, greater"],
Cell[418527, 12292, 68, 3, 75, "Text"],

Cell[CellGroupData[{
Cell[418620, 12299, 977, 23, 142, "Input"],
Cell[419600, 12324, 75, 2, 45, "TmaText"],
Cell[419678, 12328, 1985, 54, 148, "Conclusion",
  CellTags->"cont3:+"],
Cell[421666, 12384, 91, 2, 45, "TmaText"],
Cell[421760, 12388, 1792, 48, 102, "Assumption",
  CellTags->"cont3"],
Cell[423555, 12438, 2625, 68, 199, "Assumption",
  CellTags->"cont4:+"],
Cell[426183, 12508, 1195, 38, 57, "Assumption",
  CellTags->"min>"],
Cell[427381, 12548, 78, 2, 45, "TmaText"],
Cell[427462, 12552, 807, 26, 43, "Assumption",
  CellTags->"1"],
Cell[428272, 12580, 77, 2, 45, "TmaText"],
Cell[428352, 12584, 682, 23, 43, "Conclusion",
  CellTags->"2"],
Cell[429037, 12609, 384, 20, 45, "TmaText"],
Cell[429424, 12631, 925, 29, 52, "Assumption",
  CellTags->"3"],
Cell[430352, 12662, 262, 12, 45, "TmaText"],
Cell[430617, 12676, 699, 23, 43, "Assumption",
  CellTags->"4"],
Cell[431319, 12701, 384, 20, 45, "TmaText"],
Cell[431706, 12723, 925, 29, 52, "Assumption",
  CellTags->"5"],
Cell[432634, 12754, 262, 12, 45, "TmaText"],
Cell[432899, 12768, 699, 23, 43, "Assumption",
  CellTags->"6"],
Cell[433601, 12793, 560, 28, 69, "TmaText"],
Cell[434164, 12823, 443, 16, 43, "Assumption",
  CellTags->"7"],
Cell[434610, 12841, 566, 28, 69, "TmaText"],
Cell[435179, 12871, 911, 29, 43, "Assumption",
  CellTags->"8"],
Cell[436093, 12902, 389, 20, 45, "TmaText"],
Cell[436485, 12924, 1167, 35, 52, "Conclusion",
  CellTags->"9"],
Cell[437655, 12961, 256, 12, 45, "TmaText"],
Cell[437914, 12975, 1233, 37, 66, "Conclusion",
  CellTags->"10"],
Cell[439150, 13014, 265, 12, 45, "TmaText"],
Cell[439418, 13028, 539, 22, 45, "TmaText"],
Cell[439960, 13052, 400, 20, 45, "TmaText"],
Cell[440363, 13074, 1007, 35, 45, "TmaText"],
Cell[441373, 13111, 400, 20, 45, "TmaText"]
}, Open  ]],
Cell[441788, 13134, 312, 6, 129, "Text"],
Cell[442103, 13142, 621, 14, 172, "Input",
  CellTags->"3-ary continuity of sum: variant"],
Cell[442727, 13158, 67, 0, 48, "Text"],
Cell[442797, 13160, 364, 9, 109, "Input",
  CellTags->"positiveness"],
Cell[443164, 13171, 35, 0, 48, "Text"],

Cell[CellGroupData[{
Cell[443224, 13175, 971, 24, 166, "Input"],
Cell[444198, 13201, 75, 2, 45, "TmaText"],
Cell[444276, 13205, 1454, 42, 85, "Conclusion",
  CellTags->"cont2:+"],
Cell[445733, 13249, 91, 2, 45, "TmaText"],
Cell[445827, 13253, 1458, 43, 60, "Assumption",
  CellTags->"cont2"],
Cell[447288, 13298, 1858, 51, 88, "Assumption",
  CellTags->"cont3:+"],
Cell[449149, 13351, 658, 24, 52, "Assumption",
  CellTags->"/2>"],
Cell[449810, 13377, 78, 2, 45, "TmaText"],
Cell[449891, 13381, 641, 22, 43, "Assumption",
  CellTags->"1"],
Cell[450535, 13405, 77, 2, 45, "TmaText"],
Cell[450615, 13409, 495, 18, 43, "Conclusion",
  CellTags->"2"],
Cell[451113, 13429, 384, 20, 45, "TmaText"],
Cell[451500, 13451, 844, 27, 52, "Assumption",
  CellTags->"3"],
Cell[452347, 13480, 384, 20, 45, "TmaText"],
Cell[452734, 13502, 844, 27, 52, "Assumption",
  CellTags->"4"],
Cell[453581, 13531, 389, 20, 45, "TmaText"],
Cell[453973, 13553, 960, 30, 52, "Conclusion",
  CellTags->"5"],
Cell[454936, 13585, 78, 2, 45, "TmaText"],
Cell[455017, 13589, 300, 12, 43, "Assumption",
  CellTags->"6"],
Cell[455320, 13603, 77, 2, 45, "TmaText"],
Cell[455400, 13607, 573, 20, 43, "Conclusion",
  CellTags->"7"],
Cell[455976, 13629, 372, 20, 45, "TmaText"],
Cell[456351, 13651, 475, 17, 43, "Assumption",
  CellTags->"8"],
Cell[456829, 13670, 372, 20, 45, "TmaText"],
Cell[457204, 13692, 475, 17, 43, "Assumption",
  CellTags->"9"],
Cell[457682, 13711, 393, 20, 45, "TmaText"],
Cell[458078, 13733, 809, 25, 51, "TmaText"],
Cell[458890, 13760, 246, 12, 45, "TmaText"],
Cell[459139, 13774, 622, 20, 51, "TmaText"],
Cell[459764, 13796, 246, 12, 45, "TmaText"],
Cell[460013, 13810, 265, 10, 51, "TmaText"],
Cell[460281, 13822, 250, 12, 45, "TmaText"],
Cell[460534, 13836, 302, 12, 43, "Conclusion",
  CellTags->"10"],
Cell[460839, 13850, 396, 20, 45, "TmaText"]
}, Open  ]],
Cell[461250, 13873, 139, 3, 75, "Text"],
Cell[461392, 13878, 264, 5, 112, "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461693, 13888, 113, 3, 63, "Subsubsection",
  CellTags->{"sec:PC-otter", "c:56"}],
Cell[461809, 13893, 473, 8, 156, "Text"],
Cell[462285, 13903, 142, 4, 48, "Example"],
Cell[462430, 13909, 614, 15, 85, "Input",
  CellTags->{
  "Definition (Set equality)", "Inclusion", "Powerset", "Set equality", 
    "Union"}],
Cell[463047, 13926, 502, 12, 85, "Input"],
Cell[463552, 13940, 458, 11, 72, "Input"],
Cell[464013, 13953, 101, 3, 48, "Text"],
Cell[464117, 13958, 448, 11, 96, "Input",
  CellTags->"Union of powerset is included..."],
Cell[464568, 13971, 118, 3, 75, "Text"],

Cell[CellGroupData[{
Cell[464711, 13978, 938, 23, 166, "Input"],
Cell[465652, 14003, 25, 0, 45, "TmaText"],
Cell[465680, 14005, 507, 16, 52, "Conclusion",
  CellTags->"P\[Union]\[SubsetEqual]"],
Cell[466190, 14023, 41, 0, 45, "TmaText"],
Cell[466234, 14025, 1298, 39, 57, "Assumption",
  CellTags->"\[SubsetEqual]:"],
Cell[467535, 14066, 1256, 37, 57, "Assumption",
  CellTags->"\[Union]:"],
Cell[468794, 14105, 714, 23, 54, "Assumption",
  CellTags->"P:"],
Cell[469511, 14130, 276, 10, 45, "TmaText"],
Cell[469790, 14142, 400, 14, 43, "Conclusion",
  CellTags->"1"],
Cell[470193, 14158, 359, 18, 45, "TmaText"],
Cell[470555, 14178, 817, 26, 52, "Conclusion",
  CellTags->"2"],
Cell[471375, 14206, 28, 0, 45, "TmaText"],
Cell[471406, 14208, 396, 14, 43, "Assumption",
  CellTags->"3"],
Cell[471805, 14224, 27, 0, 45, "TmaText"],
Cell[471835, 14226, 305, 12, 43, "Conclusion",
  CellTags->"4"],
Cell[472143, 14240, 338, 18, 45, "TmaText"],
Cell[472484, 14260, 770, 25, 52, "Assumption",
  CellTags->"5"],
Cell[473257, 14287, 212, 10, 45, "TmaText"],
Cell[473472, 14299, 559, 19, 43, "Assumption",
  CellTags->"6"],
Cell[474034, 14320, 328, 18, 45, "TmaText"],
Cell[474365, 14340, 243, 9, 45, "TmaText"],
Cell[474611, 14351, 215, 10, 45, "TmaText"],
Cell[474829, 14363, 714, 24, 52, "Assumption",
  CellTags->"7"],
Cell[475546, 14389, 326, 18, 45, "TmaText"],
Cell[475875, 14409, 305, 12, 43, "Assumption",
  CellTags->"8"],
Cell[476183, 14423, 344, 18, 45, "TmaText"]
}, Open  ]],
Cell[476542, 14444, 401, 7, 156, "Text"],
Cell[476946, 14453, 154, 4, 48, "Example"],
Cell[477103, 14459, 481, 11, 90, "Input",
  CellTags->"Powerset"],
Cell[477587, 14472, 67, 0, 48, "Text"],
Cell[477657, 14474, 496, 13, 85, "Input",
  CellTags->"Set equality"],
Cell[478156, 14489, 41, 0, 48, "Text"],
Cell[478200, 14491, 491, 12, 85, "Input",
  CellTags->"Fixpoint property"],
Cell[478694, 14505, 215, 4, 102, "Text"],
Cell[478912, 14511, 1146, 26, 214, "Input",
  CellTags->"Examples"],
Cell[480061, 14539, 17, 0, 48, "Text"],
Cell[480081, 14541, 75, 2, 45, "TmaText"],
Cell[480159, 14545, 1020, 32, 55, "Conclusion",
  CellTags->"FP"],
Cell[481182, 14579, 91, 2, 45, "TmaText"],
Cell[481276, 14583, 1337, 41, 57, "Assumption",
  CellTags->"seq:"],
Cell[482616, 14626, 1376, 42, 57, "Assumption",
  CellTags->"\[Union]:"],
Cell[483995, 14670, 1392, 42, 64, "Assumption",
  CellTags->"\[Union]:"],
Cell[485390, 14714, 284, 12, 45, "TmaText"],
Cell[485677, 14728, 879, 27, 52, "Conclusion",
  CellTags->"1"],
Cell[486559, 14757, 246, 12, 45, "TmaText"],
Cell[486808, 14771, 98, 2, 45, "TmaText"],
Cell[486909, 14775, 78, 2, 45, "TmaText"],
Cell[486990, 14779, 398, 14, 43, "Assumption",
  CellTags->"3"],
Cell[487391, 14795, 77, 2, 45, "TmaText"],
Cell[487471, 14799, 603, 21, 52, "Conclusion",
  CellTags->"2"],
Cell[488077, 14822, 398, 20, 45, "TmaText"],
Cell[488478, 14844, 98, 2, 45, "TmaText"],
Cell[488579, 14848, 78, 2, 45, "TmaText"],
Cell[488660, 14852, 603, 21, 52, "Assumption",
  CellTags->"5"],
Cell[489266, 14875, 77, 2, 45, "TmaText"],
Cell[489346, 14879, 398, 14, 43, "Conclusion",
  CellTags->"4"],
Cell[489747, 14895, 262, 12, 45, "TmaText"],
Cell[490012, 14909, 411, 15, 43, "Assumption",
  CellTags->"6"],
Cell[490426, 14926, 387, 20, 45, "TmaText"],
Cell[490816, 14948, 832, 26, 52, "Conclusion",
  CellTags->"7"],
Cell[491651, 14976, 282, 12, 45, "TmaText"],
Cell[491936, 14990, 617, 20, 43, "Conclusion",
  CellTags->"8"],
Cell[492556, 15012, 246, 12, 45, "TmaText"],
Cell[492805, 15026, 98, 2, 45, "TmaText"],
Cell[492906, 15030, 78, 2, 45, "TmaText"],
Cell[492987, 15034, 357, 14, 43, "Assumption",
  CellTags->"10"],
Cell[493347, 15050, 77, 2, 45, "TmaText"],
Cell[493427, 15054, 396, 14, 43, "Conclusion",
  CellTags->"9"],
Cell[493826, 15070, 397, 20, 45, "TmaText"],
Cell[494226, 15092, 757, 25, 57, "Conclusion",
  CellTags->"13"],
Cell[494986, 15119, 78, 2, 45, "TmaText"],
Cell[495067, 15123, 357, 14, 43, "Assumption",
  CellTags->"14"],
Cell[495427, 15139, 77, 2, 45, "TmaText"],
Cell[495507, 15143, 342, 13, 43, "Conclusion",
  CellTags->"15"],
Cell[495852, 15158, 399, 20, 45, "TmaText"],
Cell[496254, 15180, 762, 26, 52, "Conclusion",
  CellTags->"16"],
Cell[497019, 15208, 258, 12, 45, "TmaText"],
Cell[497280, 15222, 555, 20, 43, "Conclusion",
  CellTags->"17"],
Cell[497838, 15244, 265, 12, 45, "TmaText"],
Cell[498106, 15258, 451, 20, 45, "TmaText"],
Cell[498560, 15280, 402, 20, 45, "TmaText"],
Cell[498965, 15302, 451, 20, 45, "TmaText"],
Cell[499419, 15324, 402, 20, 45, "TmaText"],
Cell[499824, 15346, 98, 2, 45, "TmaText"],
Cell[499925, 15350, 78, 2, 45, "TmaText"],
Cell[500006, 15354, 398, 14, 43, "Assumption",
  CellTags->"12"],
Cell[500407, 15370, 77, 2, 45, "TmaText"],
Cell[500487, 15374, 357, 14, 43, "Conclusion",
  CellTags->"11"],
Cell[500847, 15390, 390, 20, 45, "TmaText"],
Cell[501240, 15412, 757, 25, 57, "Assumption",
  CellTags->"18"],
Cell[502000, 15439, 378, 20, 45, "TmaText"],
Cell[502381, 15461, 839, 27, 52, "Assumption",
  CellTags->"19"],
Cell[503223, 15490, 385, 20, 45, "TmaText"],
Cell[503611, 15512, 343, 12, 45, "TmaText"],
Cell[503957, 15526, 262, 12, 45, "TmaText"],
Cell[504222, 15540, 766, 26, 57, "Conclusion",
  CellTags->"20"],
Cell[504991, 15568, 78, 2, 45, "TmaText"],
Cell[505072, 15572, 357, 14, 43, "Assumption",
  CellTags->"21"],
Cell[505432, 15588, 77, 2, 45, "TmaText"],
Cell[505512, 15592, 357, 14, 43, "Conclusion",
  CellTags->"22"],
Cell[505872, 15608, 376, 20, 45, "TmaText"],
Cell[506251, 15630, 274, 10, 45, "TmaText"],
Cell[506528, 15642, 253, 12, 45, "TmaText"],
Cell[506784, 15656, 762, 26, 52, "Assumption",
  CellTags->"23"],
Cell[507549, 15684, 264, 12, 45, "TmaText"],
Cell[507816, 15698, 555, 20, 43, "Assumption",
  CellTags->"24"],
Cell[508374, 15720, 380, 20, 45, "TmaText"],
Cell[508757, 15742, 343, 12, 45, "TmaText"],
Cell[509103, 15756, 253, 12, 45, "TmaText"],
Cell[509359, 15770, 766, 26, 57, "Assumption",
  CellTags->"25"],
Cell[510128, 15798, 385, 20, 45, "TmaText"],
Cell[510516, 15820, 357, 14, 43, "Conclusion",
  CellTags->"26"],
Cell[510876, 15836, 402, 20, 45, "TmaText"],
Cell[511281, 15858, 122, 2, 69, "Output"],
Cell[511406, 15862, 478, 8, 183, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[511933, 15876, 99, 1, 67, "Subsection",
  CellTags->"c:57"],
Cell[512035, 15879, 306, 5, 129, "Text"],
Cell[512344, 15886, 1058, 16, 345, "Text"],
Cell[513405, 15904, 217, 4, 102, "Text"],
Cell[513625, 15910, 214, 4, 87, "BItem1"],
Cell[513842, 15916, 261, 5, 87, "BItem1"],
Cell[514106, 15923, 488, 8, 105, "Text"],
Cell[514597, 15933, 219, 4, 105, "Text"],
Cell[514819, 15939, 47, 0, 105, "Text"],
Cell[514869, 15941, 258, 5, 105, "BItem1"],
Cell[515130, 15948, 515, 8, 105, "BItem1"],
Cell[515648, 15958, 259, 5, 105, "Text"],
Cell[515910, 15965, 47, 0, 105, "Text"],
Cell[515960, 15967, 294, 5, 105, "BItem1"],
Cell[516257, 15974, 386, 6, 141, "BItem1"],
Cell[516646, 15982, 913, 13, 291, "Text"],
Cell[517562, 15997, 303, 5, 129, "Text"],
Cell[517868, 16004, 686, 17, 129, "Text"],
Cell[518557, 16023, 266, 6, 102, "Example"],
Cell[518826, 16031, 488, 12, 109, "Input",
  CellTags->"continuity of product"],
Cell[519317, 16045, 196, 4, 75, "Text"],
Cell[519516, 16051, 2357, 60, 372, "Input",
  CellTags->{
  "distance of product", "fprod", "function product", "minimum, greater", 
    "minimum, less"}],
Cell[521876, 16113, 450, 8, 129, "Text"],
Cell[522329, 16123, 1303, 31, 214, "Input"],
Cell[523635, 16156, 17, 0, 48, "Text"],
Cell[523655, 16158, 75, 2, 45, "TmaText"],
Cell[523733, 16162, 1450, 42, 85, "Conclusion",
  CellTags->"cont\[RawStar]"],
Cell[525186, 16206, 91, 2, 45, "TmaText"],
Cell[525280, 16210, 2896, 76, 99, "Assumption",
  CellTags->"cont"],
Cell[528179, 16288, 1237, 40, 58, "Assumption",
  CellTags->"f\[RawStar]g"],
Cell[529419, 16330, 3165, 81, 84, "Assumption",
  CellTags->"dist\[RawStar]"],
Cell[532587, 16413, 1216, 38, 57, "Assumption",
  CellTags->"min>"],
Cell[533806, 16453, 1221, 39, 57, "Assumption",
  CellTags->"<min"],
Cell[535030, 16494, 78, 2, 45, "TmaText"],
Cell[535111, 16498, 641, 22, 43, "Assumption",
  CellTags->"1"],
Cell[535755, 16522, 77, 2, 45, "TmaText"],
Cell[535835, 16526, 495, 18, 43, "Conclusion",
  CellTags->"2"],
Cell[536333, 16546, 382, 20, 45, "TmaText"],
Cell[536718, 16568, 2096, 60, 75, "Assumption",
  CellTags->"3"],
Cell[538817, 16630, 274, 12, 45, "TmaText"],
Cell[539094, 16644, 2291, 63, 99, "Assumption",
  CellTags->"4"],
Cell[541388, 16709, 243, 12, 45, "TmaText"],
Cell[541634, 16723, 2898, 72, 105, "Assumption",
  CellTags->"5"],
Cell[544535, 16797, 382, 20, 45, "TmaText"],
Cell[544920, 16819, 2096, 60, 75, "Assumption",
  CellTags->"6"],
Cell[547019, 16881, 274, 12, 45, "TmaText"],
Cell[547296, 16895, 2291, 63, 99, "Assumption",
  CellTags->"7"],
Cell[549590, 16960, 243, 12, 45, "TmaText"],
Cell[549836, 16974, 2898, 72, 105, "Assumption",
  CellTags->"8"],
Cell[552737, 17048, 387, 20, 45, "TmaText"],
Cell[553127, 17070, 2470, 68, 75, "Conclusion",
  CellTags->"9"],
Cell[555600, 17140, 78, 2, 45, "TmaText"],
Cell[555681, 17144, 302, 12, 43, "Assumption",
  CellTags->"10"],
Cell[555986, 17158, 77, 2, 45, "TmaText"],
Cell[556066, 17162, 2073, 58, 75, "Conclusion",
  CellTags->"11"],
Cell[558142, 17222, 221, 8, 45, "TmaText"],
Cell[558366, 17232, 2023, 54, 58, "Conclusion",
  CellTags->"12"],
Cell[560392, 17288, 387, 20, 45, "TmaText"],
Cell[560782, 17310, 2190, 58, 58, "Conclusion",
  CellTags->"13"],
Cell[562975, 17370, 391, 20, 45, "TmaText"],
Cell[563369, 17392, 4150, 99, 249, "Conclusion",
  CellTags->"14"],
Cell[567522, 17493, 448, 16, 45, "TmaText"],
Cell[567973, 17511, 3730, 91, 90, "Conclusion",
  CellTags->"15"],
Cell[571706, 17604, 387, 20, 45, "TmaText"],
Cell[572096, 17626, 3803, 88, 120, "TmaText"],
Cell[575902, 17716, 250, 12, 45, "TmaText"],
Cell[576155, 17730, 4067, 94, 117, "TmaText"],
Cell[580225, 17826, 252, 12, 45, "TmaText"],
Cell[580480, 17840, 3570, 87, 117, "Conclusion",
  CellTags->"16"],
Cell[584053, 17929, 241, 12, 45, "TmaText"],
Cell[584297, 17943, 3297, 82, 93, "Conclusion",
  CellTags->"17"],
Cell[587597, 18027, 263, 12, 45, "TmaText"],
Cell[587863, 18041, 2915, 75, 97, "Conclusion",
  CellTags->"18"],
Cell[590781, 18118, 389, 20, 45, "TmaText"],
Cell[591173, 18140, 2948, 72, 96, "TmaText"],
Cell[594124, 18214, 250, 12, 45, "TmaText"],
Cell[594377, 18228, 2809, 68, 96, "TmaText"],
Cell[597189, 18298, 250, 12, 45, "TmaText"],
Cell[597442, 18312, 2661, 68, 70, "Conclusion",
  CellTags->"19"],
Cell[600106, 18382, 73, 2, 45, "TmaText"],
Cell[600182, 18386, 1847, 47, 69, "TmaText"],
Cell[602032, 18435, 338, 10, 69, "TmaText"],
Cell[602373, 18447, 304, 9, 55, "TmaText"],
Cell[602680, 18458, 679, 19, 61, "TmaText"],
Cell[603362, 18479, 80, 2, 45, "TmaText"],
Cell[603445, 18483, 1135, 30, 61, "TmaText"],
Cell[604583, 18515, 226, 10, 45, "TmaText"],
Cell[604812, 18527, 369, 6, 139, "Paragraph"],
Cell[605184, 18535, 476, 8, 141, "BItem1"],
Cell[605663, 18545, 560, 9, 168, "BItem1"],
Cell[606226, 18556, 401, 7, 156, "Text"],
Cell[606630, 18565, 300, 6, 102, "Example"],
Cell[606933, 18573, 1380, 32, 214, "Input"],
Cell[608316, 18607, 17, 0, 48, "Text"],
Cell[608336, 18609, 75, 2, 45, "TmaText"],
Cell[608414, 18613, 1450, 42, 85, "Conclusion",
  CellTags->"cont\[RawStar]"],
Cell[609867, 18657, 91, 2, 45, "TmaText"],
Cell[609961, 18661, 2896, 76, 99, "Assumption",
  CellTags->"cont"],
Cell[612860, 18739, 1237, 40, 58, "Assumption",
  CellTags->"f\[RawStar]g"],
Cell[614100, 18781, 3165, 81, 84, "Assumption",
  CellTags->"dist\[RawStar]"],
Cell[617268, 18864, 1216, 38, 57, "Assumption",
  CellTags->"min>"],
Cell[618487, 18904, 1221, 39, 57, "Assumption",
  CellTags->"<min"],
Cell[619711, 18945, 78, 2, 45, "TmaText"],
Cell[619792, 18949, 641, 22, 43, "Assumption",
  CellTags->"1"],
Cell[620436, 18973, 77, 2, 45, "TmaText"],
Cell[620516, 18977, 495, 18, 43, "Conclusion",
  CellTags->"2"],
Cell[621014, 18997, 382, 20, 45, "TmaText"],
Cell[621399, 19019, 2096, 60, 75, "Assumption",
  CellTags->"3"],
Cell[623498, 19081, 274, 12, 45, "TmaText"],
Cell[623775, 19095, 2291, 63, 99, "Assumption",
  CellTags->"4"],
Cell[626069, 19160, 243, 12, 45, "TmaText"],
Cell[626315, 19174, 2898, 72, 105, "Assumption",
  CellTags->"5"],
Cell[629216, 19248, 382, 20, 45, "TmaText"],
Cell[629601, 19270, 2096, 60, 75, "Assumption",
  CellTags->"6"],
Cell[631700, 19332, 274, 12, 45, "TmaText"],
Cell[631977, 19346, 2291, 63, 99, "Assumption",
  CellTags->"7"],
Cell[634271, 19411, 243, 12, 45, "TmaText"],
Cell[634517, 19425, 2898, 72, 105, "Assumption",
  CellTags->"8"],
Cell[637418, 19499, 387, 20, 45, "TmaText"],
Cell[637808, 19521, 2470, 68, 75, "Conclusion",
  CellTags->"9"],
Cell[640281, 19591, 78, 2, 45, "TmaText"],
Cell[640362, 19595, 302, 12, 43, "Assumption",
  CellTags->"10"],
Cell[640667, 19609, 77, 2, 45, "TmaText"],
Cell[640747, 19613, 2092, 56, 75, "Conclusion",
  CellTags->"11"],
Cell[642842, 19671, 221, 8, 45, "TmaText"],
Cell[643066, 19681, 2069, 53, 58, "Conclusion",
  CellTags->"12"],
Cell[645138, 19736, 387, 20, 45, "TmaText"],
Cell[645528, 19758, 2244, 57, 58, "Conclusion",
  CellTags->"13"],
Cell[647775, 19817, 391, 20, 45, "TmaText"],
Cell[648169, 19839, 4150, 99, 249, "Conclusion",
  CellTags->"14"],
Cell[652322, 19940, 448, 16, 45, "TmaText"],
Cell[652773, 19958, 3730, 91, 90, "Conclusion",
  CellTags->"15"],
Cell[656506, 20051, 387, 20, 45, "TmaText"],
Cell[656896, 20073, 3915, 91, 117, "TmaText"],
Cell[660814, 20166, 250, 12, 45, "TmaText"],
Cell[661067, 20180, 4067, 94, 117, "TmaText"],
Cell[665137, 20276, 252, 12, 45, "TmaText"],
Cell[665392, 20290, 3498, 85, 159, "Conclusion",
  CellTags->"16"],
Cell[668893, 20377, 241, 12, 45, "TmaText"],
Cell[669137, 20391, 3435, 86, 124, "Conclusion",
  CellTags->"17"],
Cell[672575, 20479, 263, 12, 45, "TmaText"],
Cell[672841, 20493, 2947, 76, 97, "Conclusion",
  CellTags->"18"],
Cell[675791, 20571, 73, 2, 45, "TmaText"],
Cell[675867, 20575, 1557, 39, 42, "TmaText"],
Cell[677427, 20616, 771, 25, 69, "TmaText"],
Cell[678201, 20643, 133, 5, 45, "TmaText"],
Cell[678337, 20650, 1561, 42, 43, "Assumption",
  CellTags->"19"],
Cell[679901, 20694, 80, 2, 45, "TmaText"],
Cell[679984, 20698, 681, 20, 42, "TmaText"],
Cell[680668, 20720, 95, 2, 45, "TmaText"],
Cell[680766, 20724, 626, 21, 43, "Conclusion",
  CellTags->"20"],
Cell[681395, 20747, 389, 20, 45, "TmaText"],
Cell[681787, 20769, 529, 17, 45, "TmaText"],
Cell[682319, 20788, 250, 12, 45, "TmaText"],
Cell[682572, 20802, 419, 14, 45, "TmaText"],
Cell[682994, 20818, 250, 12, 45, "TmaText"],
Cell[683247, 20832, 377, 14, 43, "Conclusion",
  CellTags->"23"],
Cell[683627, 20848, 265, 12, 45, "TmaText"],
Cell[683895, 20862, 340, 16, 45, "TmaText"],
Cell[684238, 20880, 406, 20, 45, "TmaText"],
Cell[684647, 20902, 342, 16, 45, "TmaText"],
Cell[684992, 20920, 373, 18, 45, "TmaText"],
Cell[685368, 20940, 273, 5, 112, "Paragraph"],
Cell[685644, 20947, 204, 4, 87, "BItem1"],
Cell[685851, 20953, 475, 8, 168, "BItem1"],
Cell[686329, 20963, 198, 4, 87, "BItem1"],
Cell[686530, 20969, 188, 4, 75, "Example"],
Cell[686721, 20975, 686, 16, 136, "Input",
  CellTags->{"convergence", "convergent"}],
Cell[687410, 20993, 60, 1, 48, "Text",
  CellTags->"convergence"],
Cell[687473, 20996, 511, 13, 109, "Input",
  CellTags->{
  "2-ary limit of sum", "convergence of sum", "convergent", "limit"}],
Cell[687987, 21011, 95, 3, 48, "Text"],
Cell[688085, 21016, 429, 11, 72, "Input",
  CellTags->{"2-ary limit of sum", "fsum", "limit", "sequences sum"}],
Cell[688517, 21029, 56, 0, 48, "Text"],
Cell[688576, 21031, 728, 17, 109, "Input",
  CellTags->"distance of sum"],
Cell[689307, 21050, 54, 0, 48, "Text"],
Cell[689364, 21052, 466, 12, 72, "Input",
  CellTags->"sum greater"],
Cell[689833, 21066, 173, 4, 75, "Text"],

Cell[CellGroupData[{
Cell[690031, 21074, 1232, 28, 190, "Input"],
Cell[691266, 21104, 75, 2, 45, "TmaText"],
Cell[691344, 21108, 975, 31, 58, "Conclusion",
  CellTags->"conv+"],
Cell[692322, 21141, 91, 2, 45, "TmaText"],
Cell[692416, 21145, 2424, 64, 84, "Assumption",
  CellTags->"conv"],
Cell[694843, 21211, 1237, 40, 58, "Assumption",
  CellTags->"f+g"],
Cell[696083, 21253, 2501, 70, 93, "Assumption",
  CellTags->"dist+"],
Cell[698587, 21325, 1272, 38, 57, "Assumption",
  CellTags->"\[GreaterEqual]+"],
Cell[699862, 21365, 78, 2, 45, "TmaText"],
Cell[699943, 21369, 445, 16, 43, "Assumption",
  CellTags->"1"],
Cell[700391, 21387, 77, 2, 45, "TmaText"],
Cell[700471, 21391, 397, 15, 43, "Conclusion",
  CellTags->"2"],
Cell[700871, 21408, 382, 20, 45, "TmaText"],
Cell[701256, 21430, 1817, 53, 67, "Assumption",
  CellTags->"3"],
Cell[703076, 21485, 262, 12, 45, "TmaText"],
Cell[703341, 21499, 1600, 48, 67, "Assumption",
  CellTags->"4"],
Cell[704944, 21549, 274, 12, 45, "TmaText"],
Cell[705221, 21563, 1505, 45, 69, "Assumption",
  CellTags->"5"],
Cell[706729, 21610, 382, 20, 45, "TmaText"],
Cell[707114, 21632, 1817, 53, 67, "Assumption",
  CellTags->"6"],
Cell[708934, 21687, 262, 12, 45, "TmaText"],
Cell[709199, 21701, 1600, 48, 67, "Assumption",
  CellTags->"7"],
Cell[710802, 21751, 274, 12, 45, "TmaText"],
Cell[711079, 21765, 1505, 45, 69, "Assumption",
  CellTags->"8"],
Cell[712587, 21812, 387, 20, 45, "TmaText"],
Cell[712977, 21834, 2012, 57, 67, "Conclusion",
  CellTags->"9"],
Cell[714992, 21893, 214, 8, 45, "TmaText"],
Cell[715209, 21903, 2022, 54, 55, "Conclusion",
  CellTags->"10"],
Cell[717234, 21959, 387, 20, 45, "TmaText"],
Cell[717624, 21981, 2184, 57, 55, "Conclusion",
  CellTags->"11"],
Cell[719811, 22040, 391, 20, 45, "TmaText"],
Cell[720205, 22062, 3878, 96, 168, "Conclusion",
  CellTags->"12"],
Cell[724086, 22160, 425, 16, 45, "TmaText"],
Cell[724514, 22178, 3969, 88, 99, "Conclusion",
  CellTags->"13"],
Cell[728486, 22268, 1098, 51, 69, "TmaText"],
Cell[729587, 22321, 3965, 89, 133, "Conclusion",
  CellTags->"14"],
Cell[733555, 22412, 383, 20, 45, "TmaText"],
Cell[733941, 22434, 3993, 88, 99, "TmaText"],
Cell[737937, 22524, 246, 12, 45, "TmaText"],
Cell[738186, 22538, 4066, 90, 234, "TmaText"],
Cell[742255, 22630, 276, 12, 45, "TmaText"],
Cell[742534, 22644, 3648, 85, 99, "Conclusion",
  CellTags->"15"],
Cell[746185, 22731, 241, 12, 45, "TmaText"],
Cell[746429, 22745, 3689, 84, 99, "Conclusion",
  CellTags->"16"],
Cell[750121, 22831, 710, 31, 69, "TmaText"],
Cell[750834, 22864, 3216, 74, 99, "Conclusion",
  CellTags->"17"],
Cell[754053, 22940, 78, 2, 45, "TmaText"],
Cell[754134, 22944, 302, 12, 43, "Assumption",
  CellTags->"18"],
Cell[754439, 22958, 77, 2, 45, "TmaText"],
Cell[754519, 22962, 2520, 63, 99, "Conclusion",
  CellTags->"19"],
Cell[757042, 23027, 442, 16, 45, "TmaText"],
Cell[757487, 23045, 1879, 51, 85, "Conclusion",
  CellTags->"20"],
Cell[759369, 23098, 263, 12, 45, "TmaText"],
Cell[759635, 23112, 1332, 38, 43, "Conclusion",
  CellTags->"21"],
Cell[760970, 23152, 73, 2, 45, "TmaText"],
Cell[761046, 23156, 678, 19, 42, "TmaText"],
Cell[761727, 23177, 393, 13, 69, "TmaText"],
Cell[762123, 23192, 354, 12, 51, "TmaText"],
Cell[762480, 23206, 357, 12, 51, "TmaText"],
Cell[762840, 23220, 80, 2, 45, "TmaText"],
Cell[762923, 23224, 700, 22, 51, "TmaText"],
Cell[763626, 23248, 224, 10, 45, "TmaText"]
}, Open  ]],
Cell[763865, 23261, 268, 5, 112, "Paragraph"],
Cell[764136, 23268, 293, 5, 87, "BItem1"],
Cell[764432, 23275, 342, 6, 114, "BItem1"],
Cell[764777, 23283, 95, 3, 33, "BItem1"],
Cell[764875, 23288, 140, 3, 60, "BItem1"],
Cell[765018, 23293, 157, 4, 75, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[765212, 23302, 96, 3, 67, "Subsection",
  CellTags->"c:58"],
Cell[765311, 23307, 340, 6, 129, "Text"],
Cell[765654, 23315, 181, 5, 75, "Example"],
Cell[765838, 23322, 562, 14, 154, "Input",
  CellTags->"Continuity, Sign"],
Cell[766403, 23338, 107, 3, 48, "Text"],
Cell[766513, 23343, 415, 11, 72, "Input",
  CellTags->"Absolute Value"],
Cell[766931, 23356, 54, 0, 48, "Text"],

Cell[CellGroupData[{
Cell[767010, 23360, 772, 19, 118, "Input"],
Cell[767785, 23381, 25, 0, 45, "TmaText"],
Cell[767813, 23383, 2220, 62, 120, "Conclusion",
  CellTags->"cont, sign"],
Cell[770036, 23447, 41, 0, 45, "TmaText"],
Cell[770080, 23449, 2844, 74, 99, "Assumption",
  CellTags->"c2:"],
Cell[772927, 23525, 1117, 35, 55, "Assumption",
  CellTags->"absv"],
Cell[774047, 23562, 28, 0, 45, "TmaText"],
Cell[774078, 23564, 582, 20, 43, "Assumption",
  CellTags->"1"],
Cell[774663, 23586, 27, 0, 45, "TmaText"],
Cell[774693, 23588, 1242, 39, 75, "Conclusion",
  CellTags->"2"],
Cell[775938, 23629, 179, 7, 45, "TmaText"],
Cell[776120, 23638, 1156, 35, 58, "Conclusion",
  CellTags->"3"],
Cell[777279, 23675, 330, 18, 45, "TmaText"],
Cell[777612, 23695, 2046, 58, 75, "Assumption",
  CellTags->"4"],
Cell[779661, 23755, 271, 12, 69, "TmaText"]
}, Open  ]],
Cell[779947, 23770, 368, 6, 129, "Text"],
Cell[780318, 23778, 867, 13, 291, "Text"],

Cell[CellGroupData[{
Cell[781210, 23795, 869, 21, 142, "Input"],
Cell[782082, 23818, 25, 0, 45, "TmaText"],
Cell[782110, 23820, 2220, 62, 120, "Conclusion",
  CellTags->"cont, sign"],
Cell[784333, 23884, 41, 0, 45, "TmaText"],
Cell[784377, 23886, 2846, 74, 99, "Assumption",
  CellTags->"cont"],
Cell[787226, 23962, 1117, 35, 55, "Assumption",
  CellTags->"absv"],
Cell[788346, 23999, 28, 0, 45, "TmaText"],
Cell[788377, 24001, 582, 20, 43, "Assumption",
  CellTags->"1"],
Cell[788962, 24023, 27, 0, 45, "TmaText"],
Cell[788992, 24025, 1242, 39, 75, "Conclusion",
  CellTags->"2"],
Cell[790237, 24066, 332, 18, 45, "TmaText"],
Cell[790572, 24086, 1980, 55, 76, "TmaText"],
Cell[792555, 24143, 193, 10, 45, "TmaText"],
Cell[792751, 24155, 1923, 56, 75, "Assumption",
  CellTags->"3"],
Cell[794677, 24213, 224, 10, 45, "TmaText"],
Cell[794904, 24225, 2114, 59, 99, "Assumption",
  CellTags->"4"],
Cell[797021, 24286, 193, 10, 45, "TmaText"],
Cell[797217, 24298, 2759, 70, 105, "Assumption",
  CellTags->"5"],
Cell[799979, 24370, 335, 18, 45, "TmaText"],
Cell[800317, 24390, 2312, 66, 75, "Conclusion",
  CellTags->"6"],
Cell[802632, 24458, 287, 10, 45, "TmaText"],
Cell[802922, 24470, 2151, 57, 90, "Conclusion",
  CellTags->"7"],
Cell[805076, 24529, 189, 10, 45, "TmaText"],
Cell[805268, 24541, 2068, 56, 90, "Conclusion",
  CellTags->"8"],
Cell[807339, 24599, 211, 10, 45, "TmaText"],
Cell[807553, 24611, 1192, 35, 43, "Conclusion",
  CellTags->"9"],
Cell[808748, 24648, 23, 0, 45, "TmaText"],
Cell[808774, 24650, 584, 17, 42, "TmaText"],
Cell[809361, 24669, 230, 7, 45, "TmaText"],
Cell[809594, 24678, 356, 12, 45, "TmaText"],
Cell[809953, 24692, 38, 0, 45, "TmaText"],
Cell[809994, 24694, 850, 28, 43, "Assumption",
  CellTags->"10"],
Cell[810847, 24724, 30, 0, 45, "TmaText"],
Cell[810880, 24726, 464, 15, 45, "TmaText"],
Cell[811347, 24743, 45, 0, 45, "TmaText"],
Cell[811395, 24745, 450, 16, 43, "Conclusion",
  CellTags->"11"],
Cell[811848, 24763, 337, 18, 45, "TmaText"],
Cell[812188, 24783, 340, 13, 43, "Conclusion",
  CellTags->"12"],
Cell[812531, 24798, 367, 18, 45, "TmaText"]
}, Open  ]],
Cell[812913, 24819, 315, 6, 139, "Paragraph"],
Cell[813231, 24827, 121, 3, 48, "Text"],
Cell[813355, 24832, 173, 4, 75, "Example"],
Cell[813531, 24838, 675, 14, 154, "Input",
  CellTags->"limit at"],
Cell[814209, 24854, 49, 0, 48, "Text"],
Cell[814261, 24856, 455, 12, 96, "Input",
  CellTags->{"Continuity, Limit", "limit at"}],
Cell[814719, 24870, 195, 4, 75, "Text"],

Cell[CellGroupData[{
Cell[814939, 24878, 766, 19, 118, "Input"],
Cell[815708, 24899, 75, 2, 45, "TmaText"],
Cell[815786, 24903, 1121, 36, 57, "Conclusion",
  CellTags->"cont, lim"],
Cell[816910, 24941, 91, 2, 45, "TmaText"],
Cell[817004, 24945, 3336, 86, 99, "Assumption",
  CellTags->"limf"],
Cell[820343, 25033, 2896, 76, 99, "Assumption",
  CellTags->"cont"],
Cell[823242, 25111, 78, 2, 45, "TmaText"],
Cell[823323, 25115, 397, 15, 43, "Assumption",
  CellTags->"1"],
Cell[823723, 25132, 77, 2, 45, "TmaText"],
Cell[823803, 25136, 564, 20, 43, "Conclusion",
  CellTags->"2"],
Cell[824370, 25158, 378, 20, 45, "TmaText"],
Cell[824751, 25180, 2096, 60, 75, "Assumption",
  CellTags->"3"],
Cell[826850, 25242, 274, 12, 45, "TmaText"],
Cell[827127, 25256, 2346, 61, 99, "Assumption",
  CellTags->"4"],
Cell[829476, 25319, 243, 12, 45, "TmaText"],
Cell[829722, 25333, 2898, 72, 105, "Assumption",
  CellTags->"5"],
Cell[832623, 25407, 387, 20, 45, "TmaText"],
Cell[833013, 25429, 2490, 69, 75, "Conclusion",
  CellTags->"6"],
Cell[835506, 25500, 78, 2, 45, "TmaText"],
Cell[835587, 25504, 300, 12, 43, "Assumption",
  CellTags->"7"],
Cell[835890, 25518, 77, 2, 45, "TmaText"],
Cell[835970, 25522, 2104, 60, 75, "Conclusion",
  CellTags->"8"],
Cell[838077, 25584, 221, 8, 45, "TmaText"],
Cell[838301, 25594, 2041, 55, 58, "Conclusion",
  CellTags->"9"],
Cell[840345, 25651, 385, 20, 45, "TmaText"],
Cell[840733, 25673, 2172, 56, 90, "Conclusion",
  CellTags->"10"],
Cell[842908, 25731, 241, 12, 45, "TmaText"],
Cell[843152, 25745, 2089, 55, 90, "Conclusion",
  CellTags->"11"],
Cell[845244, 25802, 378, 20, 45, "TmaText"],
Cell[845625, 25824, 1908, 53, 58, "Conclusion",
  CellTags->"12"],
Cell[847536, 25879, 263, 12, 45, "TmaText"],
Cell[847802, 25893, 777, 25, 43, "Conclusion",
  CellTags->"13"],
Cell[848582, 25920, 738, 31, 69, "TmaText"],
Cell[849323, 25953, 406, 15, 43, "Conclusion",
  CellTags->"18"],
Cell[849732, 25970, 387, 20, 45, "TmaText"],
Cell[850122, 25992, 302, 12, 43, "Conclusion",
  CellTags->"19"],
Cell[850427, 26006, 364, 18, 45, "TmaText"]
}, Open  ]],
Cell[850806, 26027, 296, 5, 112, "Paragraph"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[851151, 26038, 90, 1, 78, "Section",
  CellTags->{"sec:max-as", "c:59"}],
Cell[851244, 26041, 793, 13, 237, "Text"],
Cell[852040, 26056, 197, 4, 75, "Text"],
Cell[852240, 26062, 151, 4, 48, "Example"],
Cell[852394, 26068, 745, 20, 112, "Input",
  CellTags->"Maximum"],
Cell[853142, 26090, 101, 3, 48, "Text"],
Cell[853246, 26095, 442, 11, 72, "Input",
  CellTags->{"maximum is associative", "Max is Upper Bound"}],
Cell[853691, 26108, 89, 3, 48, "Text"],
Cell[853783, 26113, 1101, 28, 145, "Input",
  CellTags->{
  "Reflexivity \[LessEqual]", "totality \[LessEqual]", 
    "transitivity \[LessEqual]", "Transitivity \[LessEqual]"}],
Cell[854887, 26143, 34, 0, 48, "Text"],

Cell[CellGroupData[{
Cell[854946, 26147, 976, 23, 142, "Input"],
Cell[855925, 26172, 75, 2, 45, "TmaText"],
Cell[856003, 26176, 1367, 42, 57, "Conclusion",
  CellTags->"max-A"],
Cell[857373, 26220, 91, 2, 45, "TmaText"],
Cell[857467, 26224, 1402, 41, 64, "Assumption",
  CellTags->"max"],
Cell[858872, 26267, 847, 27, 57, "Assumption",
  CellTags->"tot \[LessEqual]"],
Cell[859722, 26296, 1149, 36, 57, "Assumption",
  CellTags->"trans \[LessEqual]"],
Cell[860874, 26334, 290, 12, 45, "TmaText"],
Cell[861167, 26348, 880, 28, 43, "Conclusion",
  CellTags->"1"],
Cell[862050, 26378, 390, 20, 45, "TmaText"],
Cell[862443, 26400, 77, 2, 45, "TmaText"],
Cell[862523, 26404, 307, 12, 43, "Assumption",
  CellTags->"2"],
Cell[862833, 26418, 92, 2, 45, "TmaText"],
Cell[862928, 26422, 726, 24, 43, "Conclusion",
  CellTags->"3"],
Cell[863657, 26448, 390, 20, 45, "TmaText"],
Cell[864050, 26470, 29, 0, 45, "TmaText"],
Cell[864082, 26472, 357, 14, 43, "Assumption",
  CellTags->"7"],
Cell[864442, 26488, 92, 2, 45, "TmaText"],
Cell[864537, 26492, 572, 20, 43, "Conclusion",
  CellTags->"8"],
Cell[865112, 26514, 390, 20, 45, "TmaText"],
Cell[865505, 26536, 32, 0, 45, "TmaText"],
Cell[865540, 26538, 309, 12, 43, "Assumption",
  CellTags->"12"],
Cell[865852, 26552, 92, 2, 105, "TmaText"],
Cell[865947, 26556, 436, 16, 105, "Conclusion",
  CellTags->"13"],
Cell[866386, 26574, 548, 28, 105, "TmaText"],
Cell[866937, 26604, 298, 12, 105, "Conclusion",
  CellTags->"17"],
Cell[867238, 26618, 227, 11, 105, "TmaText"],
Cell[867468, 26631, 31, 0, 105, "TmaText"],
Cell[867502, 26633, 312, 12, 105, "Assumption",
  CellTags->"14"],
Cell[867817, 26647, 92, 2, 105, "TmaText"],
Cell[867912, 26651, 436, 16, 105, "Conclusion",
  CellTags->"16"],
Cell[868351, 26669, 548, 28, 105, "TmaText"],
Cell[868902, 26699, 298, 12, 105, "Conclusion",
  CellTags->"18"],
Cell[869203, 26713, 580, 28, 105, "TmaText"],
Cell[869786, 26743, 309, 12, 105, "Assumption",
  CellTags->"19"],
Cell[870098, 26757, 538, 28, 105, "TmaText"],
Cell[870639, 26787, 29, 0, 105, "TmaText"],
Cell[870671, 26789, 360, 14, 105, "Assumption",
  CellTags->"9"],
Cell[871034, 26805, 92, 2, 105, "TmaText"],
Cell[871129, 26809, 574, 20, 105, "Conclusion",
  CellTags->"11"],
Cell[871706, 26831, 227, 11, 105, "TmaText"],
Cell[871936, 26844, 27, 0, 105, "TmaText"],
Cell[871966, 26846, 310, 12, 105, "Assumption",
  CellTags->"4"],
Cell[872279, 26860, 92, 2, 105, "TmaText"],
Cell[872374, 26864, 726, 24, 105, "Conclusion",
  CellTags->"6"],
Cell[873103, 26890, 390, 20, 105, "TmaText"],
Cell[873496, 26912, 29, 0, 105, "TmaText"],
Cell[873528, 26914, 359, 14, 105, "Assumption",
  CellTags->"20"],
Cell[873890, 26930, 92, 2, 105, "TmaText"],
Cell[873985, 26934, 436, 16, 105, "Conclusion",
  CellTags->"21"],
Cell[874424, 26952, 548, 28, 105, "TmaText"],
Cell[874975, 26982, 348, 14, 105, "Conclusion",
  CellTags->"25"],
Cell[875326, 26998, 227, 11, 105, "TmaText"],
Cell[875556, 27011, 29, 0, 105, "TmaText"],
Cell[875588, 27013, 362, 14, 105, "Assumption",
  CellTags->"22"],
Cell[875953, 27029, 92, 2, 105, "TmaText"],
Cell[876048, 27033, 436, 16, 105, "Conclusion",
  CellTags->"24"],
Cell[876487, 27051, 392, 20, 105, "TmaText"],
Cell[876882, 27073, 31, 0, 105, "TmaText"],
Cell[876916, 27075, 309, 12, 43, "Assumption",
  CellTags->"26"],
Cell[877228, 27089, 92, 2, 45, "TmaText"],
Cell[877323, 27093, 298, 12, 43, "Conclusion",
  CellTags->"27"],
Cell[877624, 27107, 404, 20, 45, "TmaText"],
Cell[878031, 27129, 359, 14, 43, "Assumption",
  CellTags->"31"],
Cell[878393, 27145, 584, 28, 69, "TmaText"],
Cell[878980, 27175, 309, 12, 43, "Assumption",
  CellTags->"32"],
Cell[879292, 27189, 536, 28, 45, "TmaText"],
Cell[879831, 27219, 31, 0, 45, "TmaText"],
Cell[879865, 27221, 312, 12, 43, "Assumption",
  CellTags->"28"],
Cell[880180, 27235, 92, 2, 45, "TmaText"],
Cell[880275, 27239, 348, 14, 43, "Conclusion",
  CellTags->"30"],
Cell[880626, 27255, 238, 10, 45, "TmaText"]
}, Open  ]],
Cell[880879, 27268, 257, 5, 112, "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[881173, 27278, 63, 1, 78, "Section",
  CellTags->"c:60"],
Cell[881239, 27281, 875, 20, 183, "Text"],
Cell[882117, 27303, 1037, 15, 318, "Text"],
Cell[883157, 27320, 441, 7, 156, "Text"],

Cell[CellGroupData[{
Cell[883623, 27331, 140, 5, 67, "Subsection",
  CellTags->"c:61"],
Cell[883766, 27338, 472, 8, 156, "Example"],
Cell[884241, 27348, 93, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[884359, 27355, 790, 20, 118, "Input",
  CellTags->{
  "Addition", "Addition from Left", "Addition of Zero from Left", "even"}],
Cell[885152, 27377, 25, 0, 45, "TmaText"],
Cell[885180, 27379, 487, 18, 52, "Conclusion",
  CellTags->"3"],
Cell[885670, 27399, 41, 0, 45, "TmaText"],
Cell[885714, 27401, 174, 8, 43, "Assumption",
  CellTags->"1"],
Cell[885891, 27411, 772, 26, 52, "Assumption",
  CellTags->"2"],
Cell[886666, 27439, 521, 19, 52, "Assumption",
  CellTags->" +0"],
Cell[887190, 27460, 887, 30, 54, "Assumption",
  CellTags->" + succ"],
Cell[888080, 27492, 886, 30, 54, "Assumption",
  CellTags->"succ + "],
Cell[888969, 27524, 295, 16, 45, "TmaText"],
Cell[889267, 27542, 35, 0, 45, "TmaText"],
Cell[889305, 27544, 178, 8, 43, "Conclusion",
  CellTags->"4"],
Cell[889486, 27554, 335, 18, 45, "TmaText"],
Cell[889824, 27574, 174, 8, 43, "Conclusion",
  CellTags->"7"],
Cell[890001, 27584, 344, 18, 45, "TmaText"],
Cell[890348, 27604, 34, 0, 45, "TmaText"],
Cell[890385, 27606, 78, 3, 45, "TmaText"],
Cell[890466, 27611, 340, 13, 43, "Assumption",
  CellTags->"5"],
Cell[890809, 27626, 78, 3, 45, "TmaText"],
Cell[890890, 27631, 413, 15, 43, "Conclusion",
  CellTags->"6"],
Cell[891306, 27648, 343, 18, 45, "TmaText"],
Cell[891652, 27668, 401, 14, 45, "TmaText"],
Cell[892056, 27684, 196, 10, 45, "TmaText"],
Cell[892255, 27696, 400, 14, 45, "TmaText"],
Cell[892658, 27712, 208, 10, 45, "TmaText"],
Cell[892869, 27724, 449, 15, 45, "TmaText"],
Cell[893321, 27741, 196, 10, 45, "TmaText"],
Cell[893520, 27753, 514, 18, 43, "Conclusion",
  CellTags->"8"],
Cell[894037, 27773, 192, 10, 45, "TmaText"],
Cell[894232, 27785, 341, 13, 43, "Conclusion",
  CellTags->"9"],
Cell[894576, 27800, 361, 18, 45, "TmaText"]
}, Open  ]],
Cell[894952, 27821, 137, 3, 85, "Paragraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[895126, 27829, 98, 1, 67, "Subsection",
  CellTags->{"sec:indcdp", "c:62"}],
Cell[895227, 27832, 614, 9, 210, "Text"],
Cell[895844, 27843, 318, 6, 129, "Text"],
Cell[896165, 27851, 185, 5, 75, "Example"],
Cell[896353, 27858, 940, 19, 187, "Input"],
Cell[897296, 27879, 523, 14, 129, "Text"],
Cell[897822, 27895, 3793, 79, 223, "Input",
  CellTags->{"conc", "even", "member"}],
Cell[901618, 27976, 113, 3, 48, "Text"],
Cell[901734, 27981, 577, 11, 109, "Input"],
Cell[902314, 27994, 108, 3, 48, "Text"],
Cell[902425, 27999, 431, 10, 72, "Input"],
Cell[902859, 28011, 100, 3, 48, "Text"],
Cell[902962, 28016, 555, 13, 72, "Input",
  CellTags->{
  "is\[Dash]sorted", "member", "member, merge", "member, sorted", "merge", 
    "prepend", "subtuple is\[Dash]sorted", "totality", "transitivity"}],
Cell[903520, 28031, 592, 15, 72, "Input",
  CellTags->{
  "is\[Dash]sorted", "member, merge", "merge", "prepend", 
    "subtuple is\[Dash]sorted"}],
Cell[904115, 28048, 623, 15, 72, "Input",
  CellTags->{
  "is\[Dash]sorted", "member, sorted", "merge", "prepend", 
    "sorted, \[GreaterEqual]", "subtuple is\[Dash]sorted"}],
Cell[904741, 28065, 616, 15, 72, "Input",
  CellTags->{
  "is\[Dash]sorted", "member", "merge", "prepend", 
    "prepend, is\[Dash]sorted, \[GreaterSlantEqual] "}],
Cell[905360, 28082, 400, 7, 156, "Text"],

Cell[CellGroupData[{
Cell[905785, 28093, 1728, 42, 238, "Input"],
Cell[907516, 28137, 25, 0, 45, "TmaText"],
Cell[907544, 28139, 1428, 37, 85, "Conclusion",
  CellTags->"sort\[Dash]merge"],
Cell[908975, 28178, 41, 0, 45, "TmaText"],
Cell[909019, 28180, 607, 20, 52, "Assumption",
  CellTags->"mr"],
Cell[909629, 28202, 637, 22, 52, "Assumption",
  CellTags->"ml"],
Cell[910269, 28226, 3707, 84, 162, "Assumption",
  CellTags->"mi"],
Cell[913979, 28312, 316, 9, 43, "Assumption",
  CellTags->"sorted\[LeftAngleBracket]\[RightAngleBracket]"],
Cell[914298, 28323, 572, 17, 52, "Assumption",
  CellTags->"sorted\[LeftAngleBracket].\[RightAngleBracket]"],
Cell[914873, 28342, 1589, 43, 96, "Assumption",
  CellTags->"sorted\[LeftAngleBracket]\[Ellipsis]\[RightAngleBracket]"],
Cell[916465, 28387, 1074, 32, 54, "Assumption",
  CellTags->"\[Cup],\[GreaterTilde],s"],
Cell[917542, 28421, 1054, 31, 58, "Assumption",
  CellTags->"\[GreaterTilde],s"],
Cell[918599, 28454, 1278, 39, 54, "Assumption",
  CellTags->"\[GreaterTilde]-merge"],
Cell[919880, 28495, 991, 29, 58, "Assumption",
  CellTags->"sub\[Dash]sort"],
Cell[920874, 28526, 857, 27, 57, "Assumption",
  CellTags->"\[GreaterEqual]tot"],
Cell[921734, 28555, 330, 16, 45, "TmaText"],
Cell[922067, 28573, 35, 0, 45, "TmaText"],
Cell[922105, 28575, 1046, 29, 96, "Conclusion",
  CellTags->"3"],
Cell[923154, 28606, 28, 0, 45, "TmaText"],
Cell[923185, 28608, 484, 15, 43, "Assumption",
  CellTags->"6"],
Cell[923672, 28625, 27, 0, 45, "TmaText"],
Cell[923702, 28627, 501, 15, 43, "Conclusion",
  CellTags->"7"],
Cell[924206, 28644, 333, 18, 45, "TmaText"],
Cell[924542, 28664, 370, 13, 43, "Conclusion",
  CellTags->"8"],
Cell[924915, 28679, 348, 18, 45, "TmaText"],
Cell[925266, 28699, 34, 0, 45, "TmaText"],
Cell[925303, 28701, 78, 3, 45, "TmaText"],
Cell[925384, 28706, 1438, 38, 85, "Assumption",
  CellTags->"4"],
Cell[926825, 28746, 78, 3, 45, "TmaText"],
Cell[926906, 28751, 2046, 50, 111, "Conclusion",
  CellTags->"5"],
Cell[928955, 28803, 300, 16, 45, "TmaText"],
Cell[929258, 28821, 35, 0, 45, "TmaText"],
Cell[929296, 28823, 1449, 38, 100, "Conclusion",
  CellTags->"13"],
Cell[930748, 28863, 201, 10, 45, "TmaText"],
Cell[930952, 28875, 28, 0, 45, "TmaText"],
Cell[930983, 28877, 691, 21, 57, "Assumption",
  CellTags->"16"],
Cell[931677, 28900, 27, 0, 45, "TmaText"],
Cell[931707, 28902, 734, 22, 57, "Conclusion",
  CellTags->"17"],
Cell[932444, 28926, 335, 18, 45, "TmaText"],
Cell[932782, 28946, 576, 19, 57, "Conclusion",
  CellTags->"18"],
Cell[933361, 28967, 352, 18, 45, "TmaText"],
Cell[933716, 28987, 34, 0, 45, "TmaText"],
Cell[933753, 28989, 78, 3, 45, "TmaText"],
Cell[933834, 28994, 1708, 46, 100, "Assumption",
  CellTags->"14"],
Cell[935545, 29042, 78, 3, 45, "TmaText"],
Cell[935626, 29047, 2224, 59, 100, "Conclusion",
  CellTags->"15"],
Cell[937853, 29108, 201, 10, 45, "TmaText"],
Cell[938057, 29120, 28, 0, 45, "TmaText"],
Cell[938088, 29122, 1071, 32, 57, "Assumption",
  CellTags->"19"],
Cell[939162, 29156, 27, 0, 45, "TmaText"],
Cell[939192, 29158, 1100, 32, 57, "Conclusion",
  CellTags->"20"],
Cell[940295, 29192, 340, 18, 45, "TmaText"],
Cell[940638, 29212, 27, 0, 45, "TmaText"],
Cell[940668, 29214, 488, 18, 54, "Assumption",
  CellTags->"21"],
Cell[941159, 29234, 42, 0, 45, "TmaText"],
Cell[941204, 29236, 1103, 32, 57, "Conclusion",
  CellTags->"22"],
Cell[942310, 29270, 379, 18, 45, "TmaText"],
Cell[942692, 29290, 1855, 51, 93, "Conclusion",
  CellTags->"26"],
Cell[944550, 29343, 215, 10, 45, "TmaText"],
Cell[944768, 29355, 957, 31, 57, "TmaText"],
Cell[945728, 29388, 337, 18, 45, "TmaText"],
Cell[946068, 29408, 857, 26, 57, "Conclusion",
  CellTags->"27"],
Cell[946928, 29436, 215, 10, 45, "TmaText"],
Cell[947146, 29448, 466, 19, 45, "TmaText"],
Cell[947615, 29469, 330, 18, 45, "TmaText"],
Cell[947948, 29489, 1175, 33, 57, "Assumption",
  CellTags->"28"],
Cell[949126, 29524, 360, 18, 45, "TmaText"],
Cell[949489, 29544, 510, 18, 52, "Assumption",
  CellTags->"29"],
Cell[950002, 29564, 354, 18, 45, "TmaText"],
Cell[950359, 29584, 372, 13, 43, "Assumption",
  CellTags->"30"],
Cell[950734, 29599, 352, 18, 45, "TmaText"],
Cell[951089, 29619, 670, 25, 57, "TmaText"],
Cell[951762, 29646, 356, 18, 45, "TmaText"],
Cell[952121, 29666, 1095, 36, 57, "TmaText"],
Cell[953219, 29704, 377, 18, 45, "TmaText"],
Cell[953599, 29724, 1147, 36, 57, "Conclusion",
  CellTags->"31"],
Cell[954749, 29762, 215, 10, 45, "TmaText"],
Cell[954967, 29774, 604, 24, 52, "TmaText"],
Cell[955574, 29800, 369, 18, 45, "TmaText"],
Cell[955946, 29820, 576, 19, 57, "Conclusion",
  CellTags->"32"],
Cell[956525, 29841, 352, 18, 45, "TmaText"],
Cell[956880, 29861, 804, 30, 57, "TmaText"],
Cell[957687, 29893, 369, 18, 45, "TmaText"],
Cell[958059, 29913, 681, 21, 57, "TmaText"],
Cell[958743, 29936, 306, 10, 45, "TmaText"],
Cell[959052, 29948, 981, 31, 57, "Conclusion",
  CellTags->"33"],
Cell[960036, 29981, 215, 10, 45, "TmaText"],
Cell[960254, 29993, 670, 25, 57, "TmaText"],
Cell[960927, 30020, 356, 18, 45, "TmaText"],
Cell[961286, 30040, 582, 24, 54, "TmaText"],
Cell[961871, 30066, 352, 18, 45, "TmaText"],
Cell[962226, 30086, 27, 0, 45, "TmaText"],
Cell[962256, 30088, 491, 18, 54, "Assumption",
  CellTags->"23"],
Cell[962750, 30108, 42, 0, 45, "TmaText"],
Cell[962795, 30110, 1099, 32, 57, "Conclusion",
  CellTags->"25"],
Cell[963897, 30144, 379, 18, 45, "TmaText"],
Cell[964279, 30164, 1847, 51, 93, "Conclusion",
  CellTags->"34"],
Cell[966129, 30217, 215, 10, 45, "TmaText"],
Cell[966347, 30229, 970, 32, 57, "TmaText"],
Cell[967320, 30263, 339, 18, 45, "TmaText"],
Cell[967662, 30283, 859, 26, 57, "Conclusion",
  CellTags->"35"],
Cell[968524, 30311, 362, 18, 45, "TmaText"],
Cell[968889, 30331, 215, 10, 45, "TmaText"],
Cell[969107, 30343, 670, 25, 57, "TmaText"],
Cell[969780, 30370, 356, 18, 45, "TmaText"],
Cell[970139, 30390, 466, 19, 45, "TmaText"],
Cell[970608, 30411, 358, 18, 45, "TmaText"],
Cell[970969, 30431, 488, 18, 54, "Assumption",
  CellTags->"36"],
Cell[971460, 30451, 360, 18, 45, "TmaText"],
Cell[971823, 30471, 510, 18, 52, "Assumption",
  CellTags->"37"],
Cell[972336, 30491, 354, 18, 45, "TmaText"],
Cell[972693, 30511, 372, 13, 43, "Assumption",
  CellTags->"38"],
Cell[973068, 30526, 360, 18, 45, "TmaText"],
Cell[973431, 30546, 510, 18, 54, "Assumption",
  CellTags->"39"],
Cell[973944, 30566, 354, 18, 45, "TmaText"],
Cell[974301, 30586, 372, 13, 43, "Assumption",
  CellTags->"40"],
Cell[974676, 30601, 352, 18, 45, "TmaText"],
Cell[975031, 30621, 1108, 37, 57, "TmaText"],
Cell[976142, 30660, 377, 18, 45, "TmaText"],
Cell[976522, 30680, 1147, 36, 57, "Conclusion",
  CellTags->"41"],
Cell[977672, 30718, 215, 10, 45, "TmaText"],
Cell[977890, 30730, 804, 30, 57, "TmaText"],
Cell[978697, 30762, 369, 18, 45, "TmaText"],
Cell[979069, 30782, 681, 21, 57, "TmaText"],
Cell[979753, 30805, 306, 10, 45, "TmaText"],
Cell[980062, 30817, 981, 31, 57, "Conclusion",
  CellTags->"42"],
Cell[981046, 30850, 215, 10, 45, "TmaText"],
Cell[981264, 30862, 670, 25, 57, "TmaText"],
Cell[981937, 30889, 356, 18, 45, "TmaText"],
Cell[982296, 30909, 582, 24, 54, "TmaText"],
Cell[982881, 30935, 358, 18, 45, "TmaText"],
Cell[983242, 30955, 488, 18, 54, "Assumption",
  CellTags->"43"],
Cell[983733, 30975, 352, 18, 45, "TmaText"],
Cell[984088, 30995, 604, 24, 54, "TmaText"],
Cell[984695, 31021, 369, 18, 45, "TmaText"],
Cell[985067, 31041, 576, 19, 57, "Conclusion",
  CellTags->"44"],
Cell[985646, 31062, 369, 18, 45, "TmaText"]
}, Open  ]],
Cell[986030, 31083, 865, 13, 301, "Paragraph"],
Cell[986898, 31098, 771, 12, 264, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[987718, 31116, 57, 1, 78, "Section",
  CellTags->"c:63"],
Cell[987778, 31119, 543, 8, 183, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[988370, 31133, 112, 4, 325, "Chapter",
  CellTags->"c:64"],
Cell[988485, 31139, 309, 5, 129, "Text"],

Cell[CellGroupData[{
Cell[988819, 31148, 61, 1, 78, "Section",
  CellTags->"c:65"],
Cell[988883, 31151, 287, 5, 87, "BItem1"],
Cell[989173, 31158, 291, 7, 60, "BItem1"],
Cell[989467, 31167, 519, 13, 85, "Input",
  CellTags->{"fsum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[990023, 31185, 77, 1, 78, "Section",
  CellTags->"c:66"],
Cell[990103, 31188, 650, 14, 139, "Input"],

Cell[CellGroupData[{
Cell[990778, 31206, 68, 1, 67, "Subsection",
  CellTags->"c:67"],
Cell[990849, 31209, 535, 13, 133, "Input"],
Cell[991387, 31224, 346, 6, 102, "Text"],
Cell[991736, 31232, 1625, 40, 259, "Input",
  CellTags->{
  "2-ary limit of sum", "distance of sum", "fsum", "limit", "limit of sum"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[993398, 31277, 88, 3, 67, "Subsection",
  CellTags->"c:68"],
Cell[993489, 31282, 106, 3, 48, "Text"],
Cell[993598, 31287, 1293, 30, 265, "Input"],
Cell[994894, 31319, 155, 3, 75, "Text"],
Cell[995052, 31324, 567, 13, 72, "Input",
  CellTags->{"Absolute Value", "Continuity, Sign"}],
Cell[995622, 31339, 19, 0, 48, "Text"],
Cell[995644, 31341, 535, 12, 72, "Input",
  CellTags->{"Absolute Value", "Continuity, Sign"}],
Cell[996182, 31355, 30, 0, 48, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[996261, 31361, 76, 1, 78, "Section",
  CellTags->"c:69"],
Cell[996340, 31364, 398, 10, 111, "Input"],
Cell[996741, 31376, 75, 0, 48, "Text"],
Cell[996819, 31378, 343, 9, 72, "Input"],
Cell[997165, 31389, 129, 3, 75, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[997331, 31397, 88, 1, 78, "Section",
  CellTags->"c:70"],
Cell[997422, 31400, 638, 14, 139, "Input"],

Cell[CellGroupData[{
Cell[998085, 31418, 68, 1, 67, "Subsection",
  CellTags->"c:71"],
Cell[998156, 31421, 435, 11, 109, "Input"],
Cell[998594, 31434, 265, 5, 102, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[998896, 31444, 88, 3, 67, "Subsection",
  CellTags->"c:72"],
Cell[998987, 31449, 207, 4, 102, "Text"],
Cell[999197, 31455, 384, 10, 72, "Input"],
Cell[999584, 31467, 634, 10, 210, "Text"],
Cell[1000221, 31479, 100, 3, 48, "Text"],
Cell[1000324, 31484, 1918, 45, 436, "Input"],
Cell[1002245, 31531, 321, 6, 129, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1002615, 31543, 80, 1, 78, "Section",
  CellTags->"c:73"],
Cell[1002698, 31546, 106, 3, 48, "Text"],
Cell[1002807, 31551, 376, 10, 96, "Input"],

Cell[CellGroupData[{
Cell[1003208, 31565, 68, 1, 67, "Subsection",
  CellTags->"c:74"],
Cell[1003279, 31568, 416, 11, 96, "Input"],
Cell[1003698, 31581, 186, 4, 75, "Text"],
Cell[1003887, 31587, 379, 10, 96, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1004303, 31602, 88, 3, 67, "Subsection",
  CellTags->"c:75"],
Cell[1004394, 31607, 95, 3, 48, "Text"],
Cell[1004492, 31612, 374, 9, 96, "Input"],
Cell[1004869, 31623, 530, 11, 156, "Text"],
Cell[1005402, 31636, 107, 3, 48, "Text"],
Cell[1005512, 31641, 953, 24, 241, "Input"],
Cell[1006468, 31667, 143, 3, 75, "Text"],
Cell[1006614, 31672, 365, 10, 72, "Input",
  CellTags->"addition, subtraction, division"],
Cell[1006982, 31684, 218, 4, 75, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1007249, 31694, 95, 1, 78, "Section",
  CellTags->"c:76"],
Cell[1007347, 31697, 708, 15, 163, "Input"],

Cell[CellGroupData[{
Cell[1008080, 31716, 68, 1, 67, "Subsection",
  CellTags->"c:77"],
Cell[1008151, 31719, 463, 12, 172, "Input"],
Cell[1008617, 31733, 234, 4, 102, "Text"],
Cell[1008854, 31739, 447, 11, 114, "Input",
  CellTags->"addition, subtraction, division"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1009338, 31755, 88, 3, 67, "Subsection",
  CellTags->"c:78"],
Cell[1009429, 31760, 374, 10, 96, "Input"],
Cell[1009806, 31772, 490, 8, 183, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1010345, 31786, 86, 1, 78, "Section",
  CellTags->"c:79"],
Cell[1010434, 31789, 111, 3, 48, "Text"],
Cell[1010548, 31794, 403, 10, 114, "Input"],

Cell[CellGroupData[{
Cell[1010976, 31808, 68, 1, 67, "Subsection",
  CellTags->"c:80"],
Cell[1011047, 31811, 467, 11, 96, "Input"],
Cell[1011517, 31824, 177, 4, 75, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1011731, 31833, 88, 3, 67, "Subsection",
  CellTags->"c:81"],
Cell[1011822, 31838, 466, 11, 115, "Input"],
Cell[1012291, 31851, 151, 3, 75, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1012491, 31860, 81, 1, 78, "Section",
  CellTags->"c:82"],
Cell[1012575, 31863, 467, 12, 111, "Input"],
Cell[1013045, 31877, 90, 3, 48, "Text"],
Cell[1013138, 31882, 376, 10, 72, "Input"],
Cell[1013517, 31894, 158, 4, 75, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1013724, 31904, 103, 2, 229, "Chapter",
  CellTags->{"References", "c:83"}],
Cell[1013830, 31908, 556, 15, 102, "Text",
  CellTags->"TPS"],
Cell[1014389, 31925, 679, 17, 156, "Text",
  CellTags->"omrs:99"],
Cell[1015071, 31944, 494, 11, 129, "Text",
  CellTags->"BallarinEtAl1995"],
Cell[1015568, 31957, 487, 11, 102, "Text",
  CellTags->"BallarinPaulson1998"],
Cell[1016058, 31970, 369, 10, 75, "Text",
  CellTags->"Beeson:89"],
Cell[1016430, 31982, 439, 12, 102, "Text",
  CellTags->"Beeson:98"],
Cell[1016872, 31996, 715, 19, 156, "Text",
  CellTags->"Benzmueller_al:97"],
Cell[1017590, 32017, 492, 13, 129, "Text",
  CellTags->"AISC98\[RawStar]94"],
Cell[1018085, 32032, 325, 9, 75, "Text",
  CellTags->"Bledsoe:90"],
Cell[1018413, 32043, 348, 10, 75, "Text",
  CellTags->"Bledsoe_Boyer_Henneman:72"],
Cell[1018764, 32055, 323, 9, 75, "Text",
  CellTags->"Bledsoe_Bruell:74"],
Cell[1019090, 32066, 339, 10, 75, "Text",
  CellTags->"Boyer:88a"],
Cell[1019432, 32078, 317, 9, 75, "Text",
  CellTags->"Boyer_Moore:79"],
Cell[1019752, 32089, 333, 10, 75, "Text",
  CellTags->"OBDD"],
Cell[1020088, 32101, 358, 10, 75, "Text",
  CellTags->"Buchb:70"],
Cell[1020449, 32113, 280, 9, 48, "Text",
  CellTags->"Buchb:85c"],
Cell[1020732, 32124, 339, 9, 75, "Text",
  CellTags->"Buchb:96b"],
Cell[1021074, 32135, 358, 10, 75, "Text",
  CellTags->"Buchb:96c"],
Cell[1021435, 32147, 472, 11, 129, "Text",
  CellTags->"Buchb:96d"],
Cell[1021910, 32160, 407, 11, 102, "Text",
  CellTags->"Buchb:96e"],
Cell[1022320, 32173, 386, 10, 102, "Text",
  CellTags->"Buchb:97a"],
Cell[1022709, 32185, 414, 11, 102, "Text",
  CellTags->"Buchb:97d"],
Cell[1023126, 32198, 449, 11, 102, "Text",
  CellTags->"Buchb_al:97"],
Cell[1023578, 32211, 316, 8, 102, "Text",
  CellTags->"Buchb_all:99"],
Cell[1023897, 32221, 358, 10, 75, "Text",
  CellTags->"Buchb_Coll_Kutz:88"],
Cell[1024258, 32233, 465, 12, 129, "Text",
  CellTags->"Buchb_expl:99"],
Cell[1024726, 32247, 418, 11, 102, "Text",
  CellTags->"Buchb_Vasa:97"],
Cell[1025147, 32260, 424, 10, 102, "Text",
  CellTags->"Buchb_WW:98"],
Cell[1025574, 32272, 421, 12, 102, "Text",
  CellTags->"Bundy:90"],
Cell[1025998, 32286, 273, 7, 75, "Text",
  CellTags->"Bundy_AD:99"],
Cell[1026274, 32295, 383, 10, 75, "Text",
  CellTags->"Rippling"],
Cell[1026660, 32307, 330, 9, 75, "Text",
  CellTags->"CA"],
Cell[1026993, 32318, 684, 17, 156, "Text",
  CellTags->"openmath:99"],
Cell[1027680, 32337, 348, 12, 75, "Text",
  CellTags->"maple"],
Cell[1028031, 32351, 280, 9, 48, "Text",
  CellTags->"Chou:88"],
Cell[1028314, 32362, 325, 9, 75, "Text",
  CellTags->"Clarke_Zhao:93"],
Cell[1028642, 32373, 441, 12, 102, "Text",
  CellTags->"Collins:75"],
Cell[1029086, 32387, 366, 10, 75, "Text",
  CellTags->"Collins_Hong:91"],
Cell[1029455, 32399, 317, 10, 75, "Text",
  CellTags->"Constable:86"],
Cell[1029775, 32411, 344, 9, 75, "Text",
  CellTags->"Cooper"],
Cell[1030122, 32422, 390, 12, 102, "Text",
  CellTags->"ILF"],
Cell[1030515, 32436, 349, 10, 75, "Text",
  CellTags->"Davenport_all:88"],
Cell[1030867, 32448, 489, 15, 75, "Text",
  CellTags->"RedLog:97"],
Cell[1031359, 32465, 306, 9, 75, "Text",
  CellTags->"Dutertre:96"],
Cell[1031668, 32476, 357, 10, 75, "Text",
  CellTags->"Farmer_al:93"],
Cell[1032028, 32488, 306, 9, 75, "Text",
  CellTags->"Gamboa"],
Cell[1032337, 32499, 269, 7, 75, "Text",
  CellTags->"Garland_Guttag:91"],
Cell[1032609, 32508, 354, 9, 102, "Text",
  CellTags->"omrs"],
Cell[1032966, 32519, 344, 10, 75, "Text",
  CellTags->"Gordon:93"],
Cell[1033313, 32531, 305, 11, 75, "Text",
  CellTags->"Harrison-thesis"],
Cell[1033621, 32544, 381, 10, 102, "Text",
  CellTags->"hol-cas1"],
Cell[1034005, 32556, 414, 14, 75, "Text",
  CellTags->"Reduce"],
Cell[1034422, 32572, 337, 11, 75, "Text",
  CellTags->"Hines"],
Cell[1034762, 32585, 356, 10, 75, "Text",
  CellTags->"Homann:96"],
Cell[1035121, 32597, 503, 11, 129, "Text",
  CellTags->"Homann_Calmet:96"],
Cell[1035627, 32610, 348, 10, 75, "Text",
  CellTags->"Huang:96"],
Cell[1035978, 32622, 470, 14, 75, "Text",
  CellTags->"Huet_all:94"],
Cell[1036451, 32638, 337, 9, 75, "Text",
  CellTags->"Ireland_Bundy:96"],
Cell[1036791, 32649, 455, 10, 102, "Text",
  CellTags->"Calculemus"],
Cell[1037249, 32661, 384, 10, 102, "Text",
  CellTags->"Jackson:95"],
Cell[1037636, 32673, 367, 10, 75, "Text",
  CellTags->"Janicic:99"],
Cell[1038006, 32685, 373, 10, 75, "Text",
  CellTags->"ACL2:97"],
Cell[1038382, 32697, 431, 14, 75, "Text",
  CellTags->"ACL2-manual"],
Cell[1038816, 32713, 524, 12, 129, "Text",
  CellTags->"KeKoSo96b"],
Cell[1039343, 32727, 346, 10, 75, "Text",
  CellTags->"KeKoSo98"],
Cell[1039692, 32739, 502, 13, 102, "Text",
  CellTags->"Loveland:97"],
Cell[1040197, 32754, 360, 10, 75, "Text",
  CellTags->"Manna_Waldinger:85"],
Cell[1040560, 32766, 384, 14, 48, "Text",
  CellTags->"EQP"],
Cell[1040947, 32782, 308, 9, 75, "Text",
  CellTags->"McCune_Robbins"],
Cell[1041258, 32793, 329, 9, 75, "Text",
  CellTags->"McCune_Wos:97"],
Cell[1041590, 32804, 380, 11, 75, "Text",
  CellTags->"Melis_Leron:99"],
Cell[1041973, 32817, 311, 10, 75, "Text",
  CellTags->"melis-limit:98"],
Cell[1042287, 32829, 324, 8, 102, "Text",
  CellTags->"Melis_rep"],
Cell[1042614, 32839, 375, 10, 102, "Text",
  CellTags->"Setheo"],
Cell[1042992, 32851, 470, 14, 75, "Text",
  CellTags->"OMD132a"],
Cell[1043465, 32867, 283, 8, 75, "Text",
  CellTags->"PVS:92"],
Cell[1043751, 32877, 381, 10, 75, "Text",
  CellTags->"Paule_Schorn:95"],
Cell[1044135, 32889, 337, 9, 75, "Text",
  CellTags->"paulson_90isabelle"],
Cell[1044475, 32900, 294, 9, 75, "Text",
  CellTags->"Paulson:96a"],
Cell[1044772, 32911, 327, 10, 75, "Text",
  CellTags->"Dagstuhl:97"],
Cell[1045102, 32923, 334, 11, 75, "Text",
  CellTags->"QED"],
Cell[1045439, 32936, 453, 11, 102, "Text",
  CellTags->"lambdaClam:98"],
Cell[1045895, 32949, 355, 10, 75, "Text",
  CellTags->"Robinson:65"],
Cell[1046253, 32961, 307, 9, 75, "Text",
  CellTags->"Rudnicki:92"],
Cell[1046563, 32972, 341, 10, 75, "Text",
  CellTags->"Shults_thesis"],
Cell[1046907, 32984, 335, 9, 75, "Text",
  CellTags->"Strzebonski:99"],
Cell[1047245, 32995, 481, 12, 129, "Text",
  CellTags->"Suppes:81"],
Cell[1047729, 33009, 431, 11, 102, "Text",
  CellTags->"Suppes:84"],
Cell[1048163, 33022, 362, 10, 75, "Text",
  CellTags->"Suppes_Ta:89"],
Cell[1048528, 33034, 389, 12, 102, "Text",
  CellTags->"TPTP"],
Cell[1048920, 33048, 469, 11, 129, "Text",
  CellTags->"ColorRippl"],
Cell[1049392, 33061, 407, 10, 102, "Text",
  CellTags->"Thery"],
Cell[1049802, 33073, 366, 10, 75, "Text",
  CellTags->"Tomuta:98"],
Cell[1050171, 33085, 332, 9, 75, "Text",
  CellTags->"Trybulec_Blair:85"],
Cell[1050506, 33096, 322, 9, 75, "Text",
  CellTags->"Spass"],
Cell[1050831, 33107, 305, 11, 75, "Text",
  CellTags->"Winkler:96"],
Cell[1051139, 33120, 286, 9, 75, "Text",
  CellTags->"Wolfram:96"],
Cell[1051428, 33131, 367, 12, 75, "Text",
  CellTags->"Wu:97"],
Cell[1051798, 33145, 355, 10, 75, "Text",
  CellTags->"Zeilberger:90"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

